#!/bin/bash
#
##############################################################
### For feedback please email juergen.fleischer@oracle.com ###
##############################################################

export PATH=/usr/sbin:/usr/bin:$PATH
if [ "$LD_LIBRARY_PATH" = "" ]; then
    export LD_LIBRARY_PATH_DOCTOR_ORIGINAL="EMPTY"       ## Used by some tests
else
    export LD_LIBRARY_PATH_DOCTOR_ORIGINAL="$LD_LIBRARY_PATH"	## Used by some tests
fi
# This line caused a lot of havoc wrt two bugs 23336316 and 22534619
# leading to the nasty error: 'module' object does not have attribute 'getuid'
# Just commenting this line for now, to be uncommented if required in future

#export LD_LIBRARY_PATH=/usr/lib:/lib
unset LD_LIBRARY_PATH

TLS_PROTO=TLSv1_2
WGET_SEC="--secure-protocol=$TLS_PROTO"

scriptDir=$(cd $(dirname $0); pwd)

# move to the OCDoctor directory
cd $scriptDir

source ./functions

UNAME=`uname`
if [ $UNAME = "Linux" ];then
    WGET="/usr/bin/wget -q --no-cache --timeout=10 --tries 3"
    WGETPRINT="/usr/bin/wget"
else
    WGET="/usr/sfw/bin/wget -q --no-cache --timeout=10 --tries 3"
    WGETPRINT="/usr/sfw/bin/wget"
fi
NULL=/dev/null
if [ ! -f ./OCDoctor.sh ];then
    echo "Please run OCDoctor.sh from the OCDoctor folder"
    exit 1
fi
FVERSION=version
if [ ! -f ./${FVERSION} ];then
    echo "Please run OCDoctor.sh from the OCDoctor folder"
    exit 1
fi
if [[ "$(/usr/bin/id|cut -d"(" -f1|cut -d"=" -f2)" != "0" ]]; then
    echo "Please run OCDoctor.sh as root"
    exit 1
fi

OCDOCTORZIP="/var/opt/sun/xvm/images/os/others/OCDoctor.zip"
OCDOCTORZIPPATH="/var/opt/sun/xvm/images/os/others"
PATH_TO_OCDOCTOR_BLOB="/private_blobs/PRODUCT_UPDATE/OCDoctor.zip"

# -------------- Determine the version -----------
get_major_version ""		### provides MAJORVERSION and MAJORVERSIONLONG

if [ ! "$MAJORVERSION" = "" ]; then
    case $MAJORVERSION in
	12)
	    TUNING_FOLDER=tuning/12
	    TUNING_PROXY_FOLDER=tuning_proxy/12
	    AGENT_FOLDER=agent/12
	    SAT_FOLDER=ec/12
	    PROXY_FOLDER=proxy/12
	    PRODUCTMETADATAFOLDER=product_metadata_update/12
	    ;;
        11)
	    TUNING_FOLDER=tuning/11
	    TUNING_PROXY_FOLDER="undef"
	    AGENT_FOLDER=agent/11
	    SAT_FOLDER=ec/11
	    PROXY_FOLDER=proxy/11
	    PRODUCTMETADATAFOLDER="undef"
	    ;;
        2)
	    TUNING_FOLDER=tuning/25
	    TUNING_PROXY_FOLDER="undef"
	    AGENT_FOLDER=agent/25
	    SAT_FOLDER=ec/25
	    PROXY_FOLDER=proxy/25
	    PRODUCTMETADATAFOLDER="undef"
	    ;;
        *)              
	    TUNING_FOLDER=/dev/null
	    AGENT_FOLDER=/dev/null
	    SAT_FOLDER=/dev/null
	    PROXY_FOLDER=/dev/null
	    echo "ERROR: Unsupported Ops Center version: $MAJORVERSION, try updating the OCDoctor." 
	    echo "" 
	    ;;
    esac
fi


# -------------- Display support information ------------
need_help() {
    more Debug.nfo
}

# ---------------- Suggest tuning ----------------
run_tuning(){
    if [ "$UNAME" = "Linux" ]; then
	PROXY_BIN="/opt/sun/xvmoc/bin/proxyadm"
    else
	PROXY_BIN="/opt/SUNWxvmoc/bin/proxyadm"
    fi
    RAN_TUNING=0
    check_if_sat_installed ""
    returncode=$?
    if [ $returncode -eq 1 ];then
	RAN_TUNING=1
	TOTAL=`ls $TUNING_FOLDER | grep -v TEMPLATE | wc -l | awk '{print $1}'`
	CURRENT=1
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "========= Checking for possible EC tuning... ==============="
	else
	    echo "===================== Checking for possible EC tuning... ==========================="
	fi
	
	for file in `ls $TUNING_FOLDER/* | grep -v TEMPLATE`; do
	    echo
	    if [ "$UIDOCTOR" = "1" ]; then
		echo "--- Tuning script $CURRENT / $TOTAL --- ($file)"
	    else
		echo "------------------ Tuning script $CURRENT / $TOTAL ------------------ ($file)"
	    fi
	    $file
	    CURRENT=`expr $CURRENT + 1`
	done
	echo
    fi
    check_if_proxy_installed ""		### returns 1 if installed but not configured. 2 if installed and configured.
    returncode=$?
    if [ $returncode -eq 2 ] && [ -d $TUNING_PROXY_FOLDER ];then			#### TUNING_PROXY_FOLDER is only available in 12c	
	RAN_TUNING=1
	TOTAL=`ls $TUNING_PROXY_FOLDER | grep -v TEMPLATE | wc -l | awk '{print $1}'`
	CURRENT=1
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "========= Checking for possible Proxy tuning... ============="
	else
	    echo "===================== Checking for possible Proxy tuning... ========================"
	fi
	
	for file in `ls $TUNING_PROXY_FOLDER/* | grep -v TEMPLATE`; do
	    echo
	    if [ "$UIDOCTOR" = "1" ]; then
		echo "--- Tuning script $CURRENT / $TOTAL --- ($file)"
	    else
		echo "------------------ Tuning script $CURRENT / $TOTAL ------------------ ($file)"
	    fi
	    $file
	    CURRENT=`expr $CURRENT + 1`
	done
	echo
    fi
    if [ "$RAN_TUNING" = "0" ]; then
	echo "The tuning parameter should be used on the Enterprise Controller or Proxy Controller only"
	echo ""
	exit 1
    fi

}

# ---------------- Check for BLOB ID -----------
whatisblobid(){
    if [ "$MAJORVERSION" = "12" ]; then
	whatisblobid/whatisblobid.sh $*
    else
	whatisblobid/whatisblobid-11g.sh $*
    fi
}

getblobid(){
    if [ "$MAJORVERSION" = "12" ]; then
	whatisblobid/getblobid.sh $*
    else
	whatisblobid/getblobid-11g.sh $*
    fi
}

# --------------- Check connectivity script -----
check_connectivity(){
    echo "======================== Checking Network Connectivity =============================="
    prereq/check_connectivity.sh
}

# --------------- The following 2 functions are used by product metadata update (which is below)
# --------------- get the current latest ID in sequence table
sequence_last_id() {
    ####### Determine the last ID in SEQUENCE table
    rm -f /var/tmp/lastid.out.doctor >/dev/null 2>/dev/null
    rm -f /var/tmp/sql.txt.doctor* >/dev/null 2>/dev/null
    SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/lastid.out.doctor "select SEQ_COUNT from SEQUENCE where SEQ_NAME='SEQ_PROPERTY';"
    echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
    if [ ! -s /var/tmp/lastid.out.doctor ]; then
	echo "ERROR: Unable to read the 'SEQUENCE' table from the database to obtain latest ID"
	echo "ERROR: Unable to read the 'SEQUENCE' table from the database to obtain latest ID" >> ${METADATALOG}
	echo ""
	exit 1
    else
	SEQUENCE_LAST_ID=`cat /var/tmp/lastid.out.doctor | awk '{print $1}'`
	let TEST=$SEQUENCE_LAST_ID+1
	let TEST=$TEST-1
	if [ $TEST -eq 0 ]; then
	    echo "ERROR: Unable to verify SEQUENCE last ID - got 0"
	    echo "ERROR: Unable to verify SEQUENCE last ID - got 0" >> ${METADATALOG}
	    echo ""
	    exit 1
	fi
	if [ ! "$TEST" = "$SEQUENCE_LAST_ID" ]; then
	    echo "ERROR: Unable to properly obtain SEQUENCE last ID (SEQUENCE_LAST_ID:${SEQUENCE_LAST_ID} TEST:${TEST})"
	    echo "ERROR: Unable to properly obtain SEQUENCE last ID (SEQUENCE_LAST_ID:${SEQUENCE_LAST_ID} TEST:${TEST})" >> ${METADATALOG}
	    echo ""
	    exit 1
	fi
	export SEQUENCE_LAST_ID
	SEQUENCE_LAST_ID_ORIG=$SEQUENCE_LAST_ID
	export SEQUENCE_LAST_ID_ORIG
	echo "OK: SEQUENCE last ID is $SEQUENCE_LAST_ID"
	echo "OK: SEQUENCE last ID is $SEQUENCE_LAST_ID" >> ${METADATALOG}
    fi
    rm -f /var/tmp/lastid.out.doctor >/dev/null 2>/dev/null
}
asr_fma_last_id() {
    ####### Determine last ID of ASR FMA event #######
    rm -f /var/tmp/lastid.out.doctor >/dev/null 2>/dev/null
    SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/lastid.out.doctor "select pkey from SYSTEMPROPERTY where subsystem='ASR' and pvisibility='HIDDEN' and PKEY like 'fma%';"
    echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
    if [ ! -s /var/tmp/lastid.out.doctor ]; then
	echo "ERROR: Unable to read the 'systemproperty' table from the database to obtain latest FMA event ID"
	echo "ERROR: Unable to read the 'systemproperty' table from the database to obtain latest FMA event ID" >> ${METADATALOG}
	echo ""
	exit 1
    else
	FMA_LAST_ID=`cat /var/tmp/lastid.out.doctor | awk -F"." '{print $2}' | sort -n | tail -1`
	let TEST=$FMA_LAST_ID+1
	let TEST=$TEST-1
	if [ $TEST -eq 0 ]; then
	    echo "ERROR: Unable to verify FMA last ID - got 0"
	    echo "ERROR: Unable to verify FMA last ID - got 0" >> ${METADATALOG}
	    echo ""
	    exit 1
	fi
	if [ ! "$TEST" = "$FMA_LAST_ID" ]; then
	    echo "ERROR: Unable to properly obtain FMA last ID (FMA_LAST_ID:${FMA_LAST_ID} TEST:${TEST})"
	    echo "ERROR: Unable to properly obtain FMA last ID (FMA_LAST_ID:${FMA_LAST_ID} TEST:${TEST})" >> ${METADATALOG}
	    echo ""
	    exit 1
	fi
	export FMA_LAST_ID
	echo "OK: FMA last ID is $FMA_LAST_ID"
	echo "OK: FMA last ID is $FMA_LAST_ID" >> ${METADATALOG}
    fi
    rm -f /var/tmp/lastid.out.doctor >/dev/null 2>/dev/null
}
asr_ilom_last_id() {
    ####### Determine last ID of ASR ILOM event ########
    rm -f /var/tmp/lastid.out.doctor >/dev/null 2>/dev/null
    SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/lastid.out.doctor "select pkey from SYSTEMPROPERTY where subsystem='ASR' and pvisibility='HIDDEN' and PKEY like 'ilom%';"
    echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
    if [ ! -s /var/tmp/lastid.out.doctor ]; then
	echo "ERROR: Unable to read the 'systemproperty' table from the database to obtain latest ILOM event ID"
	echo "ERROR: Unable to read the 'systemproperty' table from the database to obtain latest ILOM event ID" >> ${METADATALOG}
	echo ""
	exit 1
    else
	ILOM_LAST_ID=`cat /var/tmp/lastid.out.doctor | awk -F"." '{print $2}' | sort -n | tail -1`
	let TEST=$ILOM_LAST_ID+1
	let TEST=$TEST-1
	if [ $TEST -eq 0 ]; then
	    echo "ERROR: Unable to verify ILOM last ID - got 0"
	    echo "ERROR: Unable to verify ILOM last ID - got 0" >> ${METADATALOG}
	    echo ""
	    exit 1
	fi
	if [ ! "$TEST" = "$ILOM_LAST_ID" ]; then
	    echo "ERROR: Unable to properly obtain ILOM last ID (ILOM_LAST_ID:${ILOM_LAST_ID} TEST:${TEST})"
	    echo "ERROR: Unable to properly obtain ILOM last ID (ILOM_LAST_ID:${ILOM_LAST_ID} TEST:${TEST})" >> ${METADATALOG}
	    echo ""
	    exit 1
	fi
	export ILOM_LAST_ID
	echo "OK: ILOM last ID is $ILOM_LAST_ID"
	echo "OK: ILOM last ID is $ILOM_LAST_ID" >> ${METADATALOG}
    fi
    rm -f /var/tmp/lastid.out.doctor >/dev/null 2>/dev/null
}

# --------------- listasrproducts ----------
listasrproducts() {
    check_if_sat_installed ""
    returncode=$?
    if [ $returncode -ne 1 ];then
	echo "ERROR: ASR Product list can only run on the Enterprise Controller."
	echo ""
	exit 1
    fi
    if [ ! "$MAJORVERSION" = "12" ]; then
	echo "ERROR: ASR Product list is only available in Ops Center 12c."
	echo ""
	exit 1
    fi
    ##### Generate 2 big files from the products and product_attributes tables to speed things up as running the satadm is very slow
    rm -f /var/tmp/products.list.out.doctor >/dev/null 2>/dev/null
    SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/products.list.out.doctor "select name ||'|'||product_uuid from products where product_uuid is not null;"
    echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
    if [ ! -s /var/tmp/products.list.out.doctor ]; then
	echo "ERROR: Unable to read the 'products' table from the database"
	echo ""
	exit 1
    else
	echo "OK: Extracted the 'products' table"
    fi
    
    rm -f /var/tmp/product_attributes.list.out.doctor
    SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/product_attributes.list.out.doctor "select product_uuid from product_attributes where key='ASR_QUALIFIED' and value='true';"
    echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
    if [ ! -s /var/tmp/product_attributes.list.out.doctor ]; then
	echo "ERROR: Unable to read the 'product_attributes' table from the database"
	echo ""
	exit 1
    else
	echo "OK: Extracted the 'product_attributes' table"
    fi
    ##### Loop through the csv file	and see if it's in the DB already
    rm -f /var/tmp/asr_supported_list_unsorted.txt
    rm -f /var/tmp/asr_supported_list_sorted.txt
    cat /var/tmp/product_attributes.list.out.doctor | while read UUID; do
	PRODUCTS=`grep -i "|${UUID}" /var/tmp/products.list.out.doctor | awk -F"|" '{print $1}'`
	printf "$PRODUCTS\n" >> /var/tmp/asr_supported_list_unsorted.txt
	let COUNT=$COUNT+1
    done
    ### Sort
    cat /var/tmp/asr_supported_list_unsorted.txt | sort | uniq >> /var/tmp/asr_supported_list_sorted.txt 
    echo ""
    echo "Current list of ASR supported hardware through Ops Center, extracted from the local database:"
    COUNT=1
    cat /var/tmp/asr_supported_list_sorted.txt | while read PRODUCTNAME; do
	printf "$COUNT|$PRODUCTNAME\n"
	let COUNT=$COUNT+1
    done
    
    rm -f /var/tmp/asr_supported_list_unsorted.txt
    rm -f /var/tmp/asr_supported_list_sorted.txt
    rm -f /var/tmp/products.list.out.doctor
    rm -f /var/tmp/product_attributes.list.out.doctor
    rm -f /var/tmp/sql.txt.doctor*
    echo ""
    exit 0
}

# --------------- productmetadataupdate ---
productmetadataupdate() {
    SEQUENCE_LAST_ID=0
    FMA_LAST_ID=0
    ILOM_LAST_ID=0
    check_if_sat_installed ""
    returncode=$?
    if [ $returncode -ne 1 ];then
	echo "ERROR: Product Metadata Update can only run on the Enterprise Controller."
	echo ""
	exit 1
    fi
    if [ ! "$MAJORVERSION" = "12" ]; then
	echo "ERROR: Product Metadata Update is only available in Ops Center 12c."
	echo ""
	exit 1
    fi
    are_we_connected ""
    CONNECTED_RETVAL=$?
    METADATALOG="/var/opt/sun/xvm/logs/OCDoctor-metadata.log"
    echo "Downloading Product Metadata Update..."
    figure_proxy_settings ""
    echo ""
    VERSIONFILE="product_metadata_update/product_metadata.version"
    DOWNLOADLINK="https://updates.oracle.com/OCDoctor/product_metadata.version"
    if [ -f beta ]; then
	DOWNLOADLINK="https://updates.oracle.com/OCDoctor/product_metadata.version.beta"
    fi
    
    SAVEAS="${VERSIONFILE}.online"
    
    FORCED=0
    if [ "$1" = "--force" ];then
	FORCED=1
    fi
    
    if [ -f $SAVEAS ]; then
	rm -f $SAVEAS
    fi
    
    wget_wrapper $DOWNLOADLINK $SAVEAS $WGET_SEC
    RET_WGET=$?
    if [ $RET_WGET -eq 0 ]; then
	wget_output_metadata_sanity_check $SAVEAS
	RET_SANITY=$?
    fi
    if [ $RET_WGET -ne 0 ] || [ $RET_SANITY -ne 0 ]; then		### if download failed, or sanity check failed
	echo ""
	echo "Failed download link: $DOWNLOADLINK"
	echo ""
	if [ $CONNECTED_RETVAL -eq 0 ]; then			##### only if connected, return bad exit code
	    echo "ERROR: Unable to download $DOWNLOADLINK"
	    echo ""
	    exit 1
	else
	    if [ $CONNECTED_RETVAL -eq 1 ]; then
		echo "OK: This Enterprise Controller is not configured yet (empty connection.properties), skipping automatic updates."
		echo ""
		exit 0
	    fi
	    if [ $CONNECTED_RETVAL -eq 2 ]; then
		echo "OK: This Enterprise Controller is in disconnected mode, skipping automatic updates."
		echo ""
		exit 0
	    fi
	    if [ $CONNECTED_RETVAL -eq 3 ]; then
		echo "OK: This Enterprise Controller does not have .uce.rc, skipping automatic updates."
		echo ""
		exit 0
	    fi
	    echo "Could not determine connection state (value $CONNECTED_RETVAL), skipping automatic updates."
	    exit 0
	fi
    fi
    ##### Do we have current version file? we may not if this is the first time
    if [ -f $VERSIONFILE ]; then
	CURRENTVER=`cat $VERSIONFILE`
    else
	CURRENTVER=1
    fi
    if [ $CURRENTVER -ge $ONLINEVER ]; then
	if [ "$FORCED" = "1" ]; then
	    echo "OK: No updates were found, but '--force' was selected (current: $CURRENTVER, online: $ONLINEVER)."
	    date >> ${METADATALOG}
	    echo "OK: No updates were found, but '--force' was selected (current: $CURRENTVER, online: $ONLINEVER)." >> ${METADATALOG}
	else
	    echo "OK: Connected successfully - but no updates were found (current: $CURRENTVER, online: $ONLINEVER)."
	    echo ""
	    echo "You may force downloading the online version by running:"
	    echo "# ./OCDoctor.sh --product-metadata-update --force"
	    echo ""
	    exit 0
	fi
    else
	echo "OK: Found a new Product Metadata Update, Version $ONLINEVER (current version $CURRENTVER)"
	date >> ${METADATALOG}
	echo "OK: Found a new Product Metadata Update, Version $ONLINEVER (current version $CURRENTVER)"  >> ${METADATALOG}
    fi
    
    
    
    DOWNLOADLINK="https://updates.oracle.com/OCDoctor/product_metadata-${ONLINEVER}.zip"
    if [ -f beta ]; then
	DOWNLOADLINK="https://updates.oracle.com/OCDoctor/product_metadata-${ONLINEVER}.beta.zip"
    fi
    SAVEAS="product_metadata_update/product_metadata-${ONLINEVER}.zip"
    rm -f product_metadata_update/product_metadata-*.zip  >/dev/null 2>/dev/null
    wget_wrapper $DOWNLOADLINK $SAVEAS $WGET_SEC
    RET_WGET=$?
    if [ $RET_WGET -eq 0 ]; then
	wget_output_ZIP_sanity_check $SAVEAS
	RET_SANITY=$?
    fi
    if [ $RET_WGET -ne 0 ] || [ $RET_SANITY -ne 0 ]; then		### if download failed, or sanity check failed
	echo "ERROR: Error downloading $DOWNLOADLINK."
	echo "ERROR: Error downloading $DOWNLOADLINK." >> ${METADATALOG}
	echo ""
	exit 1
    fi
    echo "OK: Downloaded $DOWNLOADLINK"
    cd product_metadata_update
    CSVFILE="asr_products.csv"
    unzip -qq -o product_metadata-${ONLINEVER}.zip >/dev/null 2>/dev/null
    if [ ! -s $CSVFILE  ]; then		### not zero size
	echo "ERROR: Could not extract $CSVFILE from product_metadata-${ONLINEVER}.zip"
	echo "ERROR: Could not extract $CSVFILE from product_metadata-${ONLINEVER}.zip" >> ${METADATALOG}
	echo ""
	exit 1
    fi
    echo "OK: Extracted $CSVFILE"
    echo "OK: Extracted $CSVFILE" >> ${METADATALOG}
    
    ##### Generate 2 big files from the products and product_attributes tables to speed things up as running the satadm is very slow
    rm -f /var/tmp/products.out.doctor /var/tmp/product_attributes.out.doctor  >/dev/null 2>/dev/null
    SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/products.out.doctor "select name ||'|'||product_uuid from products where product_uuid is not null;"
    echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
    if [ ! -s /var/tmp/products.out.doctor ]; then
	echo "ERROR: Unable to read the 'products' table from the database"
	echo "ERROR: Unable to read the 'products' table from the database" >> ${METADATALOG}
	echo ""
	exit 1
    else
	echo "OK: Extracted the 'products' table"
	echo "OK: Extracted the 'products' table" >> ${METADATALOG}
    fi
    #SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/product_attributes.out.doctor "select product_uuid ||'|'||key from product_attributes where key='ASR_QUALIFIED' and value='true';"
    SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/product_attributes.out.doctor "select product_uuid ||'|'||key ||'|'||value from product_attributes where key='ASR_QUALIFIED' and value='true';"
    echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
    if [ ! -s /var/tmp/product_attributes.out.doctor ]; then
	echo "ERROR: Unable to read the 'product_attributes' table from the database"
	echo "ERROR: Unable to read the 'product_attributes' table from the database" >> ${METADATALOG}
	echo ""
	exit 1
    else
	echo "OK: Extracted the 'product_attributes' table"
	echo "OK: Extracted the 'product_attributes' table" >> ${METADATALOG}
    fi
    
    ##### Loop through the csv file	and see if it's in the DB already
    rm -f /var/tmp/sql.txt.doctor* /var/tmp/out.txt.doctor* /var/tmp/inserts.ocdoctor.*  >/dev/null 2>/dev/null
    cat $CSVFILE | while read MODEL; do
	UUIDS=`grep -i "^${MODEL}|" /var/tmp/products.out.doctor | awk -F"|" '{print $2}'`		### this may return one or more lines
	if [ ! "$UUIDS" = "" ]; then
	    printf "$UUIDS\n" | while read UUID; do			##### loop through the lines, and read each UUID
		OUTPUT=`grep -i "^${UUID}|" /var/tmp/product_attributes.out.doctor`		## is this already in the product_attributes table?
		if [ "$OUTPUT" = "" ]; then												## if not, add it
		    echo "Found a new hardware that supports ASR: $MODEL (UUID $UUID)"
		    echo "Found a new hardware that supports ASR: $MODEL (UUID $UUID)" >> ${METADATALOG}
		    echo "INSERT INTO product_attributes (PRODUCT_UUID,KEY,VALUE) values ('$UUID','ASR_QUALIFIED','true');" >> /var/tmp/inserts.ocdoctor.$$
		fi
	    done
	fi
    done
    echo ""
    if [ -s /var/tmp/inserts.ocdoctor.$$ ]; then
	echo "Running the following SQL statements:" >> ${METADATALOG}
	cat /var/tmp/inserts.ocdoctor.$$ >> ${METADATALOG}
	echo "@/var/tmp/inserts.ocdoctor.$$" |  ${SAT_BIN} sqlplus >>${METADATALOG} 2>&1
	RETVAL=$?
	if [ $RETVAL -ne 0 ]; then
	    echo "ERROR trying to insert data to the database. Please review ${METADATALOG} for more info"
	    echo "ERROR trying to insert data to the database. Please review ${METADATALOG} for more info" >>${METADATALOG}
	    echo ""
	    exit 1
	else
	    echo "OK: Updated the database with this new information"
	    echo "OK: Updated the database with this new information" >>${METADATALOG}
	fi
    else 
	echo "OK: No new ASR hardware was found"
	echo "OK: No new ASR hardware was found" >>${METADATALOG}
    fi
    echo ""
    
    
    
    ####### Update the ASR FMA events ########
    CSVFILE="asr_fma_events.csv"
    if [ -s $CSVFILE  ]; then		### not zero size
	#### Older metadata versions do not have this file
	echo "OK: Extracted $CSVFILE"
	echo "OK: Extracted $CSVFILE" >> ${METADATALOG}
	
	##### Generate a big file from the systemproperty table - this will include both the FMA and ILOM events
	rm -f /var/tmp/systemproperty.out.doctor >/dev/null 2>/dev/null
	SQL_Template /var/tmp/sql.txt.doctor.$$ /var/tmp/systemproperty.out.doctor "select pkey ||'|'||pvalue from SYSTEMPROPERTY where subsystem='ASR' and pvisibility='HIDDEN';"
	echo "@/var/tmp/sql.txt.doctor.$$" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
	if [ ! -s /var/tmp/systemproperty.out.doctor ]; then
	    echo "ERROR: Unable to read the 'systemproperty' table from the database"
	    echo "ERROR: Unable to read the 'systemproperty' table from the database" >> ${METADATALOG}
	    echo ""
	    exit 1
	else
	    echo "OK: Extracted the 'systemproperty' table"
	    echo "OK: Extracted the 'systemproperty' table" >> ${METADATALOG}
	fi
	##### Loop through the csv file	and see if it's in the DB already
	rm -f /var/tmp/sql.txt.doctor.$$ /var/tmp/out.txt.doctor.$$ /var/tmp/inserts.ocdoctor.$$  >/dev/null 2>/dev/null
	cat $CSVFILE | while read MODEL; do
	    OUTPUT=`grep -i "|${MODEL}" /var/tmp/systemproperty.out.doctor | awk -F"|" '{print $2}'`
	    if [ "$OUTPUT" = "" ]; then			#### Not in DB yet
		echo "Found a new FMA event: $MODEL"
		echo "Found a new FMA event: $MODEL" >> ${METADATALOG}
		if [ $SEQUENCE_LAST_ID -eq 0 ]; then
		    sequence_last_id ""
		fi
		let SEQUENCE_LAST_ID=$SEQUENCE_LAST_ID+1
		
		if [ $FMA_LAST_ID -eq 0 ]; then
		    asr_fma_last_id	""		### Get the latest FMA_LAST_ID
		fi
		let FMA_LAST_ID=$FMA_LAST_ID+1
		echo "INSERT INTO SYSTEMPROPERTY (id, subsystem, pkey, pvalue, pdefault, pvisibility) values (${SEQUENCE_LAST_ID},'ASR','fma.${FMA_LAST_ID}','${MODEL}','','HIDDEN');" >> /var/tmp/inserts.ocdoctor.$$
		echo "$SEQUENCE_LAST_ID" > /var/tmp/doctor_sequence_last_id.txt			### Need to save it because it will be lost once out of this "while do" loop
		echo "$SEQUENCE_LAST_ID_ORIG" >> /var/tmp/doctor_sequence_last_id.txt
	    fi
	done
	echo ""
	if [ -s /var/tmp/inserts.ocdoctor.$$ ]; then
	    SEQUENCE_LAST_ID=`head -1 /var/tmp/doctor_sequence_last_id.txt`
	    SEQUENCE_LAST_ID_ORIG=`tail -1 /var/tmp/doctor_sequence_last_id.txt`
	    if [ $SEQUENCE_LAST_ID -gt 1000 ]; then
		#echo "SEQUENCE_LAST_ID:$SEQUENCE_LAST_ID SEQUENCE_LAST_ID_ORIG:$SEQUENCE_LAST_ID_ORIG"
		DONOTHING=1
	    else
		echo "ERROR: Unable to read SEQUENCE table last ID."
		echo ""
		exit 1
	    fi

	    echo "update SEQUENCE set SEQ_COUNT='$SEQUENCE_LAST_ID' where SEQ_NAME='SEQ_PROPERTY';" > /var/tmp/allinserts.ocdoctor.$$    #| ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
	    cat /var/tmp/inserts.ocdoctor.$$ >> /var/tmp/allinserts.ocdoctor.$$

	    echo "Running the following SQL statements:" >> ${METADATALOG}
	    cat /var/tmp/allinserts.ocdoctor.$$ >> ${METADATALOG}
	    echo "@/var/tmp/allinserts.ocdoctor.$$" |  ${SAT_BIN} sqlplus >>${METADATALOG} 2>&1
	    RETVAL=$?
	    rm -f /var/tmp/allinserts.ocdoctor.$$ >/dev/null 2>/dev/null
	    if [ $RETVAL -ne 0 ]; then
		echo "ERROR trying to insert data to the database. Please review ${METADATALOG} for more info"
		echo "ERROR trying to insert data to the database. Please review ${METADATALOG} for more info" >>${METADATALOG}
		echo ""
		exit 1
	    else
		echo "OK: Updated the database with this new information"
		echo "OK: Updated the database with this new information" >>${METADATALOG}
	    fi
	else 
	    echo "OK: No new ASR FMA events were found"
	    echo "OK: No new ASR FMA events were found" >>${METADATALOG}
	fi
	echo ""
    fi
    ####### Update the ASR ILOM events ########
    CSVFILE="asr_ilom_events.csv"
    if [ -s $CSVFILE  ]; then		### not zero size
	#### Older metadata versions do not have this file
	echo "OK: Extracted $CSVFILE"
	echo "OK: Extracted $CSVFILE" >> ${METADATALOG}
	
	### We're reusing 'systemproperty.out.doctor' from the FMA above
	##### Loop through the csv file	and see if it's in the DB already
	rm -f /var/tmp/sql.txt.doctor.$$ /var/tmp/out.txt.doctor.$$ /var/tmp/inserts.ocdoctor.$$  >/dev/null 2>/dev/null
	cat $CSVFILE | while read MODEL; do
	    OUTPUT=`grep -i "|${MODEL}" /var/tmp/systemproperty.out.doctor | awk -F"|" '{print $2}'`
	    if [ "$OUTPUT" = "" ]; then			#### Not in DB yet
		echo "Found a new ILOM event: $MODEL"
		echo "Found a new ILOM event: $MODEL" >> ${METADATALOG}
		if [ $SEQUENCE_LAST_ID -eq 0 ]; then
		    sequence_last_id ""
		fi
		let SEQUENCE_LAST_ID=$SEQUENCE_LAST_ID+1
		if [ $ILOM_LAST_ID -eq 0 ]; then
		    asr_ilom_last_id	""		### Get the latest ILOM_LAST_ID
		fi
		let ILOM_LAST_ID=$ILOM_LAST_ID+1
		echo "INSERT INTO SYSTEMPROPERTY (id, subsystem, pkey, pvalue, pdefault, pvisibility) values (${SEQUENCE_LAST_ID},'ASR','ilom.${ILOM_LAST_ID}','${MODEL}','','HIDDEN');" >> /var/tmp/inserts.ocdoctor.$$
		echo "$SEQUENCE_LAST_ID" > /var/tmp/doctor_sequence_last_id.txt		### Need to save it because it will be lost once out of this "while do" loop
		echo "$SEQUENCE_LAST_ID_ORIG" >> /var/tmp/doctor_sequence_last_id.txt
	    fi
	done
	echo ""
	if [ -s /var/tmp/inserts.ocdoctor.$$ ]; then
	    SEQUENCE_LAST_ID=`head -1 /var/tmp/doctor_sequence_last_id.txt`
	    SEQUENCE_LAST_ID_ORIG=`tail -1 /var/tmp/doctor_sequence_last_id.txt`
	    if [ $SEQUENCE_LAST_ID -gt 1000 ]; then
		#echo "SEQUENCE_LAST_ID:$SEQUENCE_LAST_ID SEQUENCE_LAST_ID_ORIG:$SEQUENCE_LAST_ID_ORIG"
		DONOTHING=1
	    else
		echo "ERROR: Unable to read SEQUENCE table last ID."
		echo ""
		exit 1
	    fi

	    echo "update SEQUENCE set SEQ_COUNT='$SEQUENCE_LAST_ID' where SEQ_NAME='SEQ_PROPERTY';" > /var/tmp/allinserts.ocdoctor.$$    #| ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
	    cat /var/tmp/inserts.ocdoctor.$$ >> /var/tmp/allinserts.ocdoctor.$$
	    
	    echo "Running the following SQL statements:" >> ${METADATALOG}
	    cat /var/tmp/allinserts.ocdoctor.$$ >> ${METADATALOG}
	    
	    echo "@/var/tmp/allinserts.ocdoctor.$$" |  ${SAT_BIN} sqlplus >>${METADATALOG} 2>&1
	    RETVAL=$?
	    rm -f /var/tmp/allinserts.ocdoctor.$$ >/dev/null 2>/dev/null
	    if [ $RETVAL -ne 0 ]; then
		echo "ERROR trying to insert data to the database. Please review ${METADATALOG} for more info"
		echo "ERROR trying to insert data to the database. Please review ${METADATALOG} for more info" >>${METADATALOG}
		echo ""
		exit 1
	    else
		echo "OK: Updated the database with this new information"
		echo "OK: Updated the database with this new information" >>${METADATALOG}
	    fi
	else 
	    echo "OK: No new ASR ILOM events were found"
	    echo "OK: No new ASR ILOM events were found" >>${METADATALOG}
	fi
	echo ""
    fi
    
    
    #### Update the metadata version file
    echo "$ONLINEVER" > product_metadata.version
    chmod 644 product_metadata.version
    
    #### Cleanup
    rm -f /var/tmp/sql.txt.doctor.$$ /var/tmp/out.txt.doctor.$$ /var/tmp/inserts.ocdoctor.$$ >/dev/null 2>/dev/null
    rm -f /var/tmp/products.out.doctor /var/tmp/product_attributes.out.doctor /var/tmp/systemproperty.out.doctor >/dev/null 2>/dev/null
    rm -f product_metadata.version.online product_metadata-*.zip asr_products.csv asr_fma_events.csv asr_ilom_events.csv >/dev/null 2>/dev/null
    exit 0
}

# ---------------- Look for issues ---------------
scan_for_issues() {
    check_if_sat_installed ""
    SATINST=$?
    if [ $SATINST -eq 1 ];then
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "============== Checking Enterprise Controller... ===================="
	else
	    echo "======================== Checking Enterprise Controller... =============================="
	fi
	for file in `ls $SAT_FOLDER/* | grep -v TEMPLATE`; do
	    $file
	done
    else
	if [ "$UIDOCTOR" = "1" ]; then
            echo "======= No Enterprise Controller is installed, skipping ============="
	else
            echo "================= No Enterprise Controller is installed, skipping ======================="
	fi
    fi

    check_if_proxy_installed ""
    returncode=$?
    if [ $returncode -eq 1 ];then
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "==== Proxy controller is installed but not configured, skipping ====="
	else
	    echo "=========== Proxy controller is installed but not configured, skipping =================="
	fi
    fi
    if [ $returncode -eq 2 ];then
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "============= Checking LOCAL Proxy Controller... ===================="
	else
	    echo "======================= Checking LOCAL Proxy Controller... =============================="
	fi
	for file in `ls $PROXY_FOLDER/* | grep -v TEMPLATE`; do
	    $file
	done
	#if [ $SATINST -eq 0 ]; then
	#	echo "TIP: don't forget to run the --tuning to optimize performance on the PC"
	#fi
    fi
    if [ $returncode -eq 0 ];then
	if [ "$UIDOCTOR" = "1" ]; then
	    echo         "========= No Proxy Controller is installed, skipping =============="
	else
	    echo         "==================== No Proxy Controller is installed, skipping ========================="
	fi
    fi

    check_if_agent_installed ""
    returncode=$?
    if [ $returncode -eq 1 ];then
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "===== Agent controller is installed but not configured, skipping ===="
	else
	    echo "=========== Agent controller is installed but not configured, skipping =================="
	fi
    fi
    if [ $returncode -eq 2 ];then
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "=============== Checking agent... ====================="
	else
	    echo "================================ Checking agent... ======================================"
	fi
	for file in `ls $AGENT_FOLDER/* | grep -v TEMPLATE`; do
            #### Is this a ksh script? if so, some RHEL 6 don't have it in the /usr/bin/ksh or even in /bin/ksh
            TOPLINE=`head -1 $file | grep ksh`
            if [ ! "$TOPLINE" = "" ]; then
            	if [ -x /usr/bin/ksh ]; then
            	    /usr/bin/ksh $file
            	else
	            if [ -x /bin/ksh ]; then
	            	/bin/ksh $file
	            else
	            	/bin/sh $file
	            fi
	        fi
            else
            	$file
            fi
	done
    fi
    if [ $returncode -eq 0 ];then
	if [ "$UIDOCTOR" = "1" ]; then
	    echo "========== Agent controller is not installed, skipping =============="
	else
	    echo "==================== Agent controller is not installed, skipping ========================"
	fi
    fi

}

# ---------------- Check functions to see if components are installed ----------
check_if_agent_installed(){
    CONPROP="/var/opt/sun/xvm/persistence/scn-agent/connection.properties"
    if [ -f $CONPROP ];then
        OUTPUT=`grep client-reg-id $CONPROP`
        if [ "$OUTPUT" = "" ]; then
            #echo "=========== Agent controller is installed but not configured, skipping =================="
	    return 1
        else
            #echo "================================ Checking agent... ======================================"
	    return 2
        fi
    else
	return 0
    fi
}

check_if_proxy_installed(){
    CONPROP="/var/opt/sun/xvm/persistence/scn-proxy/connection.properties"
    if [ -f $CONPROP ];then
	OUTPUT=`grep client-reg-id $CONPROP`
	if [ "$OUTPUT" = "" ]; then
	    #echo "=========== Proxy controller is installed but not configured, skipping =================="
	    return 1
	else
	    #echo "======================= Checking LOCAL Proxy Controller... =============================="
	    return 2
	fi
    else
	return 0
    fi
}

check_if_sat_installed(){
    if [ "$UNAME" = "Linux" ]; then
        SAT_BIN="/opt/sun/xvmoc/bin/satadm"
    else
        SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
    fi
    if [ -f $SAT_BIN ];then
	return 1
    else
	return 0
    fi
}

# ----------------- Wget wrapper for auto update, called by check_for_update -----------
wget_wrapper(){
    WRAPPER_URL=$1
    DOWNLOAD_FILE=$2
    TLS_STR=$3
    # Check if wget exists
    if [ ! -f $WGETPRINT ]; then
	echo 
	echo "ERROR - couldn't find $WGETPRINT, can't run auto update without it"
	echo "For manual downloads please visit: $WIKISURL"
	echo
	exit 1
    fi
    
    ################ Figure out if wget supports 'no-check-certificate' flag ########################
    CERTSUPPORT=`$WGET --help 2>/dev/null | grep no-check-certificate`
    if [ "$CERTSUPPORT" = "" ]; then
	CERTFLAG=""
    else
	CERTFLAG="--no-check-certificate "
    fi
    
    
    if [ "$PROXYUSER" = "" ]; then
	$WGET ${TLS_STR} ${CERTFLAG}$WRAPPER_URL -O $DOWNLOAD_FILE 2>$NULL
	RETVAL=$?
	#echo "$WGET ${TLS_STR} ${CERTFLAG}$WRAPPER_URL -O $DOWNLOAD_FILE"
    else
	eval "$WGET ${TLS_STR} ${CERTFLAG} --proxy-user=$PROXYUSER --proxy-password='$PROXYPASS' $WRAPPER_URL -O $DOWNLOAD_FILE 2>$NULL"
	RETVAL=$?
    fi
    if [ $RETVAL -ne 0 ]; then
	if [ "$PROXYUSER" = "" ]; then
	    echo "ERROR: Download failed."
	    echo "Command used: $WGETPRINT ${TLS_STR} ${CERTFLAG}$WRAPPER_URL"
	else
	    echo "ERROR: Download failed."
	    echo "Command used: $WGETPRINT ${TLS_STR} ${CERTFLAG}--proxy-user=\"$PROXYUSER\" --proxy-password=\"hidden\" $WRAPPER_URL"
	fi
	return 1
    fi
    return 0
}
# ----------------------------------------------
wget_output_metadata_sanity_check(){
    ### Verify it's a valid verion file - one number, integer
    SAVEAS=$1
    ONLINEVER=`cat $SAVEAS`
    if [ ! "$ONLINEVER" = "" ]; then
	PLUSONE=`expr $ONLINEVER + 1`
	MINUSONE=`expr $PLUSONE - 1`
	if [ ! "$MINUSONE" = "$ONLINEVER" ]; then
	    echo "ERROR: Unable to download Product Metadata version file, got a non-numeric value:"
	    cat $SAVEAS
	    return 1
	else
	    echo "OK: Version file was downloaded successfully"
	    return 0
	fi
    else
	echo "ERROR: Unable to download Product Metadata version file, got an empty file"
	return 1
    fi
}

# ----------------------------------------------
wget_output_version_sanity_check(){
    DOWNLOAD_FILE=$1
    ### Do we even have version file?
    if [ ! -f $DOWNLOAD_FILE ]; then	
	echo "ERROR: $VERSION_FILE was not found after trying to download"	
	return 1
    fi
    ### Another sanity check - saw this one time: "Status: 500 Internal Server Error"
    ### Also check we have less than 5 lines (today we have 3, leaving room for one additionl line)
    WGETERROR=`grep -i error $DOWNLOAD_FILE`
    LINES=`wc -l $DOWNLOAD_FILE | awk '{print $1}'`
    if [ "$WGETERROR" != "" ] || [ $LINES -gt 5 ]; then
	echo "ERROR: Downloaded $DOWNLOAD_FILE but there is a problem with the content"
	return 1
    fi
    
    if [ "$(head -1 $DOWNLOAD_FILE 2>/dev/null)" = "" ]; then		 #if wget did download something try to decode content
	echo "ERROR: Downloaded $DOWNLOAD_FILE, but first line is empty"
	echo "For manual downloads please visit: $WIKISURL"
	return 1
    fi
    return 0
}
# ----------------------------------------------
wget_output_ZIP_sanity_check(){
    DOWNLOADED_FILENAME=$1
    if [ ! -f $DOWNLOADED_FILENAME ]; then
	echo "ERROR: $DOWNLOADED_FILENAME was not found after trying to download"
	return 1
    fi
    OUTPUT=`file $DOWNLOADED_FILENAME | grep -i "zip "`
    if [ "$OUTPUT" = "" ]; then
	echo "ERROR: Downloaded $DOWNLOADED_FILENAME, but file is not a ZIP file"
	return 1
    fi
    return 0
}
# ----------------------------------------------
wget_output_SIG_sanity_check(){
    DOWNLOADED_SIGFILENAME=$1
    if [ ! -f $DOWNLOADED_SIGFILENAME ]; then
	echo "ERROR: $DOWNLOADED_SIGFILENAME was not found after trying to download"
	return 1
    fi
    OUTPUT=`wc -l $DOWNLOADED_SIGFILENAME | awk '{print \$1}'`
    if [ $OUTPUT -gt 2 ] || [ $OUTPUT -eq 0 ]; then				### should be one, but may have newline
	echo "ERROR: Downloaded $DOWNLOADED_SIGFILENAME, but it has $OUTPUT lines"
	return 1
    fi
    return 0
}

# ----------------- figure proxy settings ----------------
figure_proxy_settings(){
    ################################## Proxy & user/pass #######################################
    ###### if we have EC installed, read proxy settings
    check_if_sat_installed ""
    SATINST=$?
    if [ $SATINST -eq 1 ];then
	CONNPROP="/var/opt/sun/xvm/persistence/scn-satellite/connection.properties"
	if [ -f $CONNPROP ]; then
	    #### Read proxy settings now
	    PROXYHOST=`grep proxy-host $CONNPROP | awk -F"=" '{print $2}' 2>/dev/null`
	    PROXYPORT=`grep proxy-port $CONNPROP | awk -F"=" '{print $2}' 2>/dev/null`
	    PROXYUSER=`grep proxy-username $CONNPROP | cut -c16- 2>/dev/null`
	    PROXYPASS=`grep proxy-password $CONNPROP | cut -c16- 2>/dev/null`
	    if [ ! "$PROXYHOST" = "" ] && [ ! "$PROXYPORT" = "" ]; then
		export http_proxy="$PROXYHOST:$PROXYPORT"
		export https_proxy="$PROXYHOST:$PROXYPORT"
		export PROXYSETBYDOC=1
		if [ "$PROXYUSER" = "" ]; then
		    echo "Using Ops Center Proxy server:$PROXYHOST   Port:$PROXYPORT"
		else
		    echo "Using Ops Center Proxy server:$PROXYHOST   Port:$PROXYPORT   User:$PROXYUSER   Pass:[hidden]"
		fi
	    fi		#### End of "If PROXYHOST is in the connection.properties
	fi
    fi		#### If SAT is not installed
    #### If didn't find proxy in EC, use environment variables
    if [ ! "$http_proxy" = "" ] && [ ! "$PROXYSETBYDOC" = "1" ]; then				### If env var is set, but wasn't set by this script
	echo "Using environment variable http_proxy=$http_proxy"
	if [ "$https_proxys" = "" ]; then
	    export https_proxy="$http_proxy"
	fi
    fi
    if [ ! "$https_proxy" = "" ] && [ ! "$https_proxy" = "$http_proxy" ]; then		### If https_proxy is set but http_proxy is not set
	echo "Using environment variable https_proxy=$https_proxy"
	if [ "$http_proxy" = "" ]; then
	    export http_proxy="$https_proxy"
	fi
    fi
    ################################## Proxy & user/pass #######################################
}
# ----------------- Signature check ----------------
get_signature() {
    FILENAME=$1
    if [ `uname` = "SunOS" ] ; then
	MD5SUM="/bin/digest"
	MD5SUM_ARGS="-a md5"
    else
	MD5SUM="/usr/bin/md5sum"
	MD5SUM_ARGS=""
    fi
    FINAL_MD5SUM=""
    if [ ! -x $MD5SUM ]; then
	echo ""
	echo "WARNING: Unable to find executable $MD5SUM, will not check signature."
	echo ""
	return 111
    fi
    if [ -f $FILENAME ]; then
	MD5SUM=`$MD5SUM $MD5SUM_ARGS $FILENAME 2>/dev/null`
	if [ $? -eq 0 ]; then
	    FINAL_MD5SUM=`echo "${MD5SUM}" | cut -f1 -d' '  2>/dev/null`
	    return $?
	else
	    echo "ERROR: Unable to run $MD5SUM $MD5SUM_ARGS $FILENAME"
	    return 1
	fi
    else
	echo "ERROR: Unable to find $FILENAME to generate a signature from it"
	return 1
    fi
}
# ----------------- Self Update ----------------
check_for_update(){

    check_for_download_link    ### create UCE download link on EC

    DOWNLOAD=1
    DELETE_FILE=false
    if [ "$1" = "--file" ];then
	shift
	DOWNLOAD=0
	UPDATEFILE=$1
	shift
	if [ "$UPDATEFILE" = "" ]; then
	    echo "ERROR: Need to specify update file location after --file"
	    echo ""
	    exit 1
	fi
	if [ ! -f $UPDATEFILE ]; then
	    echo "ERROR: Could not find update file $UPDATEFILE"
	    echo ""
	    exit 1
	fi
	echo "Updating OCDoctor from file $UPDATEFILE"
    fi
    FORCED=0
    if [ "$1" = "--force" ];then
	FORCED=1
    fi

    # we will try to download the latest OCDoctor from the EC
    are_we_connected ""
    CONNECTED_RETVAL=$?
    if [ "$CONNECTED_RETVAL" -eq 1 -a $DOWNLOAD -eq 1 ]; then
	DOWNLOAD_URL=""
	# this system is not a configured EC
	check_if_proxy_installed
	returncode=$?
	if [ "$returncode" -eq 2 ]; then
	    # this is a configured PC
	    DOWNLOAD_URL="http://localhost:8003$PATH_TO_OCDOCTOR_BLOB"
	else
	    # Check for agent only if it isn't already a proxy
	    check_if_agent_installed
	    returncode=$?
	    if [ "$returncode" -eq 2 ]; then
	        # this is a configured Agent
		CONNPROP=/var/opt/sun/xvm/persistence/scn-agent/connection.properties
		DOWNLOAD_URL="http://$(grep ^url= $CONNPROP | sed 's@^.*//@@' | sed 's/\\.*$//'):8003$PATH_TO_OCDOCTOR_BLOB"
	    fi
	fi
	if [ -n "$DOWNLOAD_URL" ]; then
	    UPDATEFILE=/var/tmp/$$_OCDoctor.zip
	    # we will try to download the latest OCDoctor from the EC using the existing connection
	    $WGET --no-proxy -O $UPDATEFILE $DOWNLOAD_URL
	    if [ $? -eq 0 ]; then
		DOWNLOAD=0
		printf "\nSuccessfully downloaded latest OCDoctor from Enterprise Controller\n"
		DELETE_FILE=true
	    else
		# download from EC failed, we will continue as usual ...
		UPDATEFILE=""
	    fi
	fi
    fi

    if [ "$DOWNLOAD" = "1" ]; then		### If not using a file to update
	# due to recent issues with uploading data to updates.oracle.com, we will now enhance the 
	# update mechanism: We will download the OCDoctor-latest.version file from both download sites
	# and if one of it is more recent, we will use that site for updating OCDoctor

	echo "Trying to download updates..."
	MIRROR1="https://updates.oracle.com/OCDoctor"
	MIRROR2="https://java.net/projects/oc-doctor/downloads/download"
	MIRROR1_NAME="updates.oracle.com"
	MIRROR2_NAME="java.net"
	WIKISURL="https://docs.oracle.com/en/enterprise-manager/?tab=2"
	VERSION_FILE_NAME="OCDoctor-latest.version"
	VERSION_FILE="/var/tmp/$VERSION_FILE_NAME"
        VERSION_FILE_MIRROR1="${VERSION_FILE}_mirror1"
        VERSION_FILE_MIRROR2="${VERSION_FILE}_mirror2"
	if [ -f beta ]; then
	    VERSION_FILE="OCDoctor-latest.version.beta"
	    MIRROR2=$MIRROR1			#### only use updates.oracle.com for beta
	    MIRROR1_NAME="updates.oracle.com (Beta)"
	    MIRROR2_NAME=$MIRROR1_NAME
	fi
	MIRROR1_URL=${MIRROR1}/${VERSION_FILE_NAME}
	MIRROR2_URL=${MIRROR2}/${VERSION_FILE_NAME}
	rm -f $VERSION_FILE $VERSION_FILE_MIRROR1 $VERSION_FILE_MIRROR2 2>&1 >$NULL
	
	figure_proxy_settings ""
	
	echo ""
	echo "Downloading version file using mirror: $MIRROR1_NAME"
	wget_wrapper $MIRROR1_URL $VERSION_FILE_MIRROR1 $WGET_SEC
	RET_WGET=$?
	if [ $RET_WGET -eq 0 ]; then
	    wget_output_version_sanity_check $VERSION_FILE_MIRROR1
	    RET_SANITY=$?
	fi
	if [ $RET_WGET -ne 0 ] || [ $RET_SANITY -ne 0 ]; then		### if download failed, or sanity check failed
	    STATUS_MIRROR1="FAILED"
	else
	    STATUS_MIRROR1="SUCCESS"
	    if [ $UNAME = "Linux" ]; then
                /usr/bin/dos2unix --quiet $VERSION_FILE_MIRROR1 2>$NULL
	    else
	        /usr/bin/dos2unix $VERSION_FILE_MIRROR1 > ${VERSION_FILE_MIRROR1}_fixed 2>$NULL
	        mv -f ${VERSION_FILE_MIRROR1}_fixed $VERSION_FILE_MIRROR1
	    fi
	    ONLINEVER_MIRROR1=`head -1 $VERSION_FILE_MIRROR1 2>$NULL`
	    ### Remove - and . ###
	    ONLINEVERNUM_MIRROR1=`echo $ONLINEVER_MIRROR1 | sed -e 's/\.//g' | sed -e 's/-//g'`
	fi

        # cleanup
        rm -f $VERSION_FILE_MIRROR1 $VERSION_FILE_MIRROR2 

	echo
        if [ -n "$ONLINEVERNUM_MIRROR1" -a -n "$ONLINEVERNUM_MIRROR2" ]; then
	    # both download sites were accessible
	    if [ $ONLINEVERNUM_MIRROR2 -gt $ONLINEVERNUM_MIRROR1 ]; then
		ONLINEVERNUM=$ONLINEVERNUM_MIRROR2
		ONLINEVER=$ONLINEVER_MIRROR2
                USED_MIRROR=2
            else
		ONLINEVERNUM=$ONLINEVERNUM_MIRROR1
		ONLINEVER=$ONLINEVER_MIRROR1
		USED_MIRROR=1
	    fi
            echo "OK: Version files were downloaded successfully from both sites."
        elif [ -n "$ONLINEVERNUM_MIRROR1" ]; then
            ONLINEVERNUM=$ONLINEVERNUM_MIRROR1
	    ONLINEVER=$ONLINEVER_MIRROR1
	    USED_MIRROR=1
            echo "OK: Version file was downloaded successfully from mirror: $MIRROR1_NAME"
        elif [ -n "$ONLINEVERNUM_MIRROR2" ]; then
            ONLINEVERNUM=$ONLINEVERNUM_MIRROR2
	    ONLINEVER=$ONLINEVER_MIRROR2
	    USED_MIRROR=2
            echo "OK: Version file was downloaded successfully from mirror: $MIRROR2_NAME"
	else
	    # download failed from both sites
	    echo ""
	    echo "ERROR: Error downloading the version file."
	    if [ "$UIDOCTOR" = "1" ]; then
		echo "If your environment requires a proxy, please make sure you configure it in the Administration tab."
		echo ""
	    else 
		echo "If your environment requires a proxy, try the following and rerun:"
		echo "          export http_proxy=\"proxyname:port\""
		echo "          export https_proxy=\"proxyname:port\""
		echo "For manual downloads please visit: $WIKISURL"
		echo
	    fi
	    if [ $CONNECTED_RETVAL -eq 0 ]; then			##### only if connected, return bad exit code
		exit 1
	    else
		if [ $CONNECTED_RETVAL -eq 1 ]; then
		    echo "OK: This Enterprise Controller is not configured yet (empty connection.properties), skipping automatic updates."
		    echo ""
		    exit 0
		fi
		if [ $CONNECTED_RETVAL -eq 2 ]; then
		    echo "OK: This Enterprise Controller is in disconnected mode, skipping automatic updates."
		    echo ""
		    exit 0
		fi
		if [ $CONNECTED_RETVAL -eq 3 ]; then
		    echo "OK: This Enterprise Controller does not have .uce.rc, skipping automatic updates."
		    echo ""
		    exit 0
		fi
		echo "Could not determine connection state (value $CONNECTED_RETVAL), skipping automatic updates."
		exit 0
	    fi
	fi
	

	
	### Remove - and . ###
	VERSIONNUM=`echo $VERSION | sed -e 's/\.//g' | sed -e 's/-//g'`

	if [ $ONLINEVERNUM -gt $VERSIONNUM ] || [ "$FORCED" = "1" ]; then
	    if [ "$FORCED" = "1" ]; then
		echo "OK: No updates were found, but '--force' was selected (current: $VERSION, online: $ONLINEVER)."
	    fi
	    ### Stats will be taken in the post-upgrade script
	else
	    ### Stats
	    check_if_sat_installed ""
	    if [ $? -eq 1 ];then
 	    	if [ "$MAJORVERSION" = "12" ]; then
	    	    if [ "$UIDOCTOR" = "1" ]; then
	    		if [ -f ./ec/12/stat_basic.sh ]; then
	    		    ./ec/12/stat_basic.sh >/dev/null 2>/dev/null
	    		fi
	    	    fi
	    	fi
	    fi
	    ### End of Stats
	    echo "OK: Connected successfully - but no updates were found (current: $VERSION, online: $ONLINEVER)."
	    if [ ! "$UIDOCTOR" = "1" ]; then
		echo ""
		echo "You may force downloading the online version by running:"
		echo "# ./OCDoctor.sh --update --force"
		echo ""
	    fi
	    exit 0
	fi
	
	if [ ! "$FORCED" = "1" ]; then			
	    echo "OK: Found an update, version: $ONLINEVER"
	fi
	DOWNLOADED_FILENAME="OCDoctor-${ONLINEVER}.zip"
	
	if [ "$USED_MIRROR" = "1" ]; then					#### If we originally used mirror 2, used it here first
	    MIRROR1_URL=${MIRROR1}/${DOWNLOADED_FILENAME}
	    MIRROR2_URL=${MIRROR2}/${DOWNLOADED_FILENAME}
	    MIRROR1_SIGURL=${MIRROR1}/${DOWNLOADED_FILENAME}.sig
	    MIRROR2_SIGURL=${MIRROR2}/${DOWNLOADED_FILENAME}.sig
	    MIRROR_NAME_PRINT1=$MIRROR1_NAME
	    MIRROR_NAME_PRINT2=$MIRROR2_NAME
	    MIRROR1_TLS_STR=$WGET_SEC
	    MIRROR2_TLS_STR=""
	else
	    MIRROR1_URL=${MIRROR2}/${DOWNLOADED_FILENAME}
	    MIRROR2_URL=${MIRROR1}/${DOWNLOADED_FILENAME}
	    MIRROR1_SIGURL=${MIRROR2}/${DOWNLOADED_FILENAME}.sig
	    MIRROR2_SIGURL=${MIRROR1}/${DOWNLOADED_FILENAME}.sig
	    MIRROR_NAME_PRINT1=$MIRROR2_NAME
	    MIRROR_NAME_PRINT2=$MIRROR1_NAME
	    MIRROR1_TLS_STR=""
	    MIRROR2_TLS_STR=$WGET_SEC
	fi
	
	rm -rf ../ocdoctor_tmp/
	mkdir ../ocdoctor_tmp/
	cd ../ocdoctor_tmp/
	
	echo ""
	echo "Downloading $DOWNLOADED_FILENAME file using mirror: $MIRROR_NAME_PRINT1"
	wget_wrapper $MIRROR1_URL $DOWNLOADED_FILENAME "$MIRROR1_TLS_STR"
	RET_WGET=$?
	if [ $RET_WGET -eq 0 ]; then
	    wget_output_ZIP_sanity_check $DOWNLOADED_FILENAME
	    RET_SANITY=$?
	fi
	if [ $RET_WGET -ne 0 ] || [ $RET_SANITY -ne 0 ]; then		### if download failed, or sanity check failed
	    echo ""
	    echo "Downloading $DOWNLOADED_FILENAME file using mirror: $MIRROR_NAME_PRINT2"
	    wget_wrapper $MIRROR2_URL $DOWNLOADED_FILENAME "$MIRROR2_TLS_STR"
	    RET_WGET=$?
	    if [ $RET_WGET -eq 0 ]; then
		wget_output_ZIP_sanity_check $DOWNLOADED_FILENAME
		RET_SANITY=$?
	    fi
	    if [ $RET_WGET -ne 0 ] || [ $RET_SANITY -ne 0 ]; then		### if download failed, or sanity check failed
		echo "ERROR: Error downloading $DOWNLOADED_FILENAME."
		echo ""
		cd ..
		rm -rf ocdoctor_tmp
		exit 1
	    fi
	fi
	echo "OK: $DOWNLOADED_FILENAME was downloaded successfully"
	
	echo ""
	if [ ! -f /var/tmp/no-ocdoctor-sig-check ]; then		### A way to skip signature, for safety & workaround
	    echo "Downloading $DOWNLOADED_FILENAME.sig file using mirror: $MIRROR_NAME_PRINT1"
	    wget_wrapper $MIRROR1_SIGURL $DOWNLOADED_FILENAME.sig "$MIRROR1_TLS_STR"
	    RET_WGET=$?
	    if [ $RET_WGET -eq 0 ]; then
		wget_output_SIG_sanity_check $DOWNLOADED_FILENAME.sig
		RET_SANITY=$?
	    fi
	    if [ $RET_WGET -ne 0 ] || [ $RET_SANITY -ne 0 ]; then		### if download failed, or sanity check failed
		echo ""
		echo "Downloading $DOWNLOADED_FILENAME.sig file using mirror: $MIRROR_NAME_PRINT2"
		wget_wrapper $MIRROR2_SIGURL $DOWNLOADED_FILENAME.sig "$MIRROR2_TLS_STR"
		RET_WGET=$?
		if [ $RET_WGET -eq 0 ]; then
		    wget_output_SIG_sanity_check $DOWNLOADED_FILENAME.sig
		    RET_SANITY=$?
		fi
		if [ $RET_WGET -ne 0 ] || [ $RET_SANITY -ne 0 ]; then		### if download failed, or sanity check failed
		    echo "ERROR: Error downloading $DOWNLOADED_FILENAME.sig"
		    echo ""
		    echo "To skip signature check temporarily, create /var/tmp/no-ocdoctor-sig-check:"
		    echo "# touch /var/tmp/no-ocdoctor-sig-check"
		    echo ""
		    echo "This file will be removed once upgrade is successful so signature will be checked again next time."
		    echo ""
		    cd ..
		    rm -rf ocdoctor_tmp
		    exit 1
		fi
	    fi
	    echo "OK: $DOWNLOADED_FILENAME.sig was downloaded successfully"
	    
	    ## Massage signature file
	    if [ $UNAME = "Linux" ];then
		/usr/bin/dos2unix --quiet $DOWNLOADED_FILENAME.sig 2>$NULL
	    else
		/usr/bin/dos2unix $DOWNLOADED_FILENAME.sig > $DOWNLOADED_FILENAME.sig_fixed 2>$NULL
		mv -f $DOWNLOADED_FILENAME.sig_fixed $DOWNLOADED_FILENAME.sig
	    fi
	    #### Now verify signature ####
	    ONLINESIG=`head -1 $DOWNLOADED_FILENAME.sig`
	    get_signature $DOWNLOADED_FILENAME
	    if [ $? -ne 111 ]; then		### Signature binary not found, skip (already alerted the user in the function itself
		if [ $? -ne 0 ]; then
		    echo "ERROR: Unable to obtain signature from $DOWNLOADED_FILENAME"
		    echo ""
		    echo "To skip signature check temporarily, create /var/tmp/no-ocdoctor-sig-check:"
		    echo "# touch /var/tmp/no-ocdoctor-sig-check"
		    echo ""
		    echo "This file will be removed once upgrade is successful so signature will be checked again next time."
		    echo ""
		    cd ..
		    rm -rf ocdoctor_tmp
		    exit 1
		fi
		
		if [ "$ONLINESIG" = "$FINAL_MD5SUM" ]; then
		    echo "OK: Signature was verified successfully"
		else
		    echo "ERROR: Locally generated signature did not match online one, try again in a few minutes."
		    echo "Local signature: $FINAL_MD5SUM"
		    echo "Online signature: $ONLINESIG"
		    echo ""
		    echo "To skip signature check temporarily, create /var/tmp/no-ocdoctor-sig-check:"
		    echo "# touch /var/tmp/no-ocdoctor-sig-check"
		    echo ""
		    echo "This file will be removed once upgrade is successful so signature will be checked again next time."
		    echo ""
		    exit 1
		fi
	    fi
	else
	    echo "OK: Found /var/tmp/no-ocdoctor-sig-check, skipping signature check temporarily"
	fi		#### end of /var/tmp/no-ocdoctor-sig-check check
	
    else 	#### If Download = 0, meaning, we use --update --file
	echo ""
	rm -rf ../ocdoctor_tmp/
	mkdir ../ocdoctor_tmp/
	cd ../ocdoctor_tmp/
	DOWNLOADED_FILENAME="OCDoctor.zip"
	if $DELETE_FILE; then
	    # we have downloaded the OCDoctor.zip file from the EC, so it should get deleted at the end
	    mv $UPDATEFILE ./$DOWNLOADED_FILENAME
	else
	    #### don't touch the original file but move it to this temp folder
	    cp $UPDATEFILE ./$DOWNLOADED_FILENAME
	fi

	#### Check if we have newer version already
	unzip -qq -o $DOWNLOADED_FILENAME OCDoctor/version >/dev/null 2>/dev/null
	if [ -f OCDoctor/version ]; then
	    ONLINEVER=`head -1 OCDoctor/version`
	    ### Remove - and . ###
	    ONLINEVERNUM=`echo $ONLINEVER | sed -e 's/\.//g' | sed -e 's/-//g'`
	    VERSIONNUM=`echo $VERSION | sed -e 's/\.//g' | sed -e 's/-//g'`
	    if [ "$VERSIONNUM" = "" ]; then
		### in case something is wrong with the current install, assume version is 0, this will make it always upgrade from a file
		VERSIONNUM=0
	    fi
	    if [ "$ONLINEVERNUM" = "" ]; then
		### This means we couldn't get a version from the zip file
		echo "ERROR: Could not parse version text ($ONLINEVER) from OCDoctor.zip, aborting upgrade from file"
		echo ""
		cd ..
		rm -rf ocdoctor_tmp
		exit 1
	    fi
	    if [ $ONLINEVERNUM -gt $VERSIONNUM ] || [ "$FORCED" = "1" ]; then
		if [ "$FORCED" = "1" ] && [ $ONLINEVERNUM -le $VERSIONNUM ]; then
		    echo "OK: No updates were found, but '--force' was selected (current: $VERSION, file: $ONLINEVER)."
		fi
		
	    else
		echo "OK: Found the update file successfully - but no updates were found (current: $VERSION, file: $ONLINEVER)."
		if [ ! "$UIDOCTOR" = "1" ]; then
		    echo ""
		    echo "You may force upgrading the file version by running:"
		    echo "# ./OCDoctor.sh --update --file <file> --force"
		    echo ""
		fi
		cd ..
		rm -rf ocdoctor_tmp
		exit 0
	    fi
	    
	    if [ ! "$FORCED" = "1" ]; then			
		echo "OK: Found an update in file, version: $ONLINEVER"
	    fi
	else
	    ### if there's no version file, something is wrong
	    echo "ERROR: Could not extract version file from OCDoctor.zip, aborting upgrade from file"
	    echo ""
	    cd ..
	    rm -rf ocdoctor_tmp
	    exit 1
	fi	
	rm -rf OCDoctor >/dev/null 2>/dev/null	### delete what we just extracted (version file)
	
    fi	#### End of if Download = 1
    
    #### We're now in ../ocdoctor_tmp/
    
    ###### SANITY TESTS before upgrading and before removing current Doctor folder
    unzip -qq -o $DOWNLOADED_FILENAME >/dev/null 2>/dev/null
    if [[ ! $? -eq 0 ]]; then
	echo "ERROR: Unable to extract ZIP file $DOWNLOADED_FILENAME, cannot upgrade."
	echo ""
	exit 1
    fi
    if [ ! -f OCDoctor/OCDoctor.sh ]; then		#### Safety to make sure we have a proper ZIP file!
	echo "ERROR: Unable to extract ZIP file $DOWNLOADED_FILENAME ('OCDoctor.sh' is not inside of it), cannot upgrade."
	echo ""
	exit 1
    fi
    #### Check if we have preupgrade script
    if [ -f OCDoctor/pre-upgrade.sh ]; then
	OCDoctor/pre-upgrade.sh
	if [[ ! $? -eq 0 ]]; then
	    echo "ERROR: The pre-upgrade script from version $ONLINEVER failed, not performing the upgrade."
	    echo ""
	    echo "You may look at this script here:"
	    echo "$scriptDir/../ocdoctor_tmp/OCDoctor/pre-upgrade.sh"
	    echo ""
	    exit 1
	fi
    fi
    
    cd ..
    rm -rf OCDoctor/*
    #rm -f OCDoctor/${FVERSION}
    unzip -qq -o ocdoctor_tmp/$DOWNLOADED_FILENAME
    ##### IF this is 12g EC, put the ZIP in place
    check_if_sat_installed ""
    if [ $? -eq 1 ];then
	if [ "$MAJORVERSION" = "12" ]; then
	    mkdir -p $OCDOCTORZIPPATH
	    mv ocdoctor_tmp/$DOWNLOADED_FILENAME $OCDOCTORZIP
	fi
    fi
    rm -rf ocdoctor_tmp
    cd OCDoctor
    if [ -f pre-upgrade.sh ]; then
	rm -f pre-upgrade.sh
    fi
    if [ -f post-upgrade.sh ]; then
	./post-upgrade.sh
	if [[ ! $? -eq 0 ]]; then
	    echo "ERROR: Upgrade finished but the post-upgrade script from version $ONLINEVER failed."
	    echo ""
	    echo "You may look at this script here:"
	    echo "$scriptDir/post-upgrade.sh"
	    echo ""
	else
	    rm -f ./post-upgrade.sh
	fi
    fi
    
    if [ -f /var/tmp/no-ocdoctor-sig-check ]; then
	rm -f /var/tmp/no-ocdoctor-sig-check
	echo "OK: Removed /var/tmp/no-ocdoctor-sig-check"
	echo ""
    fi

    VERSION=`head -1 ${FVERSION}`
    VDATE=`tail -1 ${FVERSION}`
    echo "OK: Updated successfully to version $VERSION ($VDATE)."
    echo
    if [ ! "$UIDOCTOR" = "1" ]; then
	echo "Please view the CHANGELOG file for list of changes."
	echo
    fi
    
    exit 0
}


# ----------------- Print Usage -----------------
print_usage() {
    cat <<EOF

./OCDoctor.sh
             -------- Preinstallation functions ----------
             [ --ec-prereq] [--force]     Check if Enterprise Controller requirements are met
             [ --proxy-prereq] [--force]  Check if Proxy Controller requirements are met
             [ --agent-prereq] [--force]  Check if Agent requirements are met
             [ --performance]             Check machine speed and provide BT score (Benchmark Time). Run when the machine is idle.
             [ --check-connectivity]      Check the network connectivity to the world (can be run on an installed EC as well)
             
             -------- Legacy functions -------------------
             [ --ec-prereq-11g] [--force]     Check if 11g Enterprise Controller requirements are met
             [ --proxy-prereq-11g] [--force]  Check if 11g Proxy Controller requirements are met
             [ --agent-prereq-11g] [--force]  Check if 11g Agent requirements are met
             
             -------- Troubleshooting / Tuning functions ----------
             [ --troubleshoot ] [--fix]      Scan the installed components for issues.
             [ --collectlogs ] [-h] <params> Collects all logs from current system, use '-h' to see a list of optional params to pass to collect script
             [ --enable-debug] [--norestart] Enable debug mode on all installed components (default is to restart services, use --norestart to skip)
             [ --disable-debug] [--norestart]Disable debug mode on all installed components (default is to restart services, use --norestart to skip)
             [ --show-debug]                 Show the current debug settings
             [ --needhelp ]                  Display information on how to gather additional info and how to open a support case
             [ --tuning ] [--fix]            Scan current configuration and suggest improvements.

             -------- Other ----------
             [ --cleanup ] [-h] [--force]    Check for old backup and update folders which can get safely removed to free up disk space
             [ --whatisblobid ] <id>         Debugging: Provide details about a specific blob id
             [ --getblobid ] <patch-id>      Debugging: Provide a patch and get its blob id
             [ --enable-dm ]                 Start Webserver to allow access to Domain Model of Agent Controller
             [ --disable-dm ]                Stop Webserver used to access Domain Model of Agent Controller
             [ --update ] [--force]          On EC, check for OCDoctor updates online; on PC/AC, check for OCDoctor update available on EC
             [ --update ] [--file <path-to-ocdoctor.zip>] [--force]      Use a downloaded ocdoctor.zip file to update OCDoctor
             [ --get-latest-JIDR ]                   On EC, download the latest available JIDR (12.3.2 onwards)
             
EOF
	exit 0
}


check_for_download_link(){

    UCE_CONFIG=/var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc
    if [ -f $UCE_CONFIG ]; then
	# this is an EC, we will create an OCDoctor download link
	UCE_DOC_ROOT="$(grep public_dir_name $UCE_CONFIG | cut -d\" -f2)"
	OCDOCTOR_LINK="$UCE_DOC_ROOT$PATH_TO_OCDOCTOR_BLOB"
	OCDOCTOR_LINK_PARENT=$(dirname $OCDOCTOR_LINK)
	if [ -d "$OCDOCTOR_LINK_PARENT" ]; then
	    if [ ! -h "$OCDOCTOR_LINK" ]; then
		ln -s $OCDOCTORZIP $OCDOCTOR_LINK
		echo
		echo "Created UCE Download URL pointing to latest OCDoctor.zip file."
		echo "This allows to manually update OCDoctor on PCs and Agents by running ./OCDoctor.sh --update"
		echo
	    fi
	fi
    fi
}

VERSION=`head -1 ${FVERSION}`
VDATE=`tail -1 ${FVERSION}`
RDATE=`date +"%d-%b-%Y %H:%M%p %Z"`
print_version() {
    EXTRA=$1
    if [ "$UIDOCTOR" = "1" ]; then
	UISTRING="UI"
    else
	UISTRING=""
    fi
    UNAMER=`uname -r`
    if [ "$UNAMER" = "5.8" ]; then
	RELEASE="8$(head -1 /etc/release | cut -d_ -f2|sed 's/wos.*$//')"
    elif [ "$UNAMER" = "5.10" ]; then
	RELEASE="10$(head -1 /etc/release | cut -d_ -f2|sed 's/wos.*$//')"
    elif [ "$UNAMER" == "5.11" ]; then
	PKG=`pkg list -H entire`
	if [[ "$PKG" =~ [^[:space:]]+11-0[^[:space:]]+ ]]; then      #Regex pattern to match 11.[0-3]
                RELEASE="11.$(echo $PKG|cut -d. -f5,6,8)"
        else
                RELEASE=`uname -v | cut -d. -f 1-4`
        fi
    else
	RELEASE=""
    fi
    if [ -f beta ]; then
	BETATXT="[BETA]"
    else
	BETATXT=""
    fi
    if [ "$MAJORVERSIONLONG" = "" ]; then
	echo "Ops Center Doctor ${VERSION}${UISTRING}  [${UNAME}${RELEASE}]${EXTRA}${BETATXT}"
    else
	IDR_STRING=""
	if [ "${UNAME}${RELEASE}" = "SunOS11" ]; then
	    IDR="$(pkg list -H 'pkg://opscenter/idr*' 2>/dev/null | awk '{print $1}')"
	    [ -n "${IDR}" ] && IDR_STRING=",${IDR}"
	fi
	echo "Ops Center Doctor ${VERSION}${UISTRING}  [OC ${MAJORVERSIONLONG}${IDR_STRING},${UNAME} ${RELEASE}]${EXTRA}${BETATXT}"
    fi
}
print_short_version() {
    echo $VERSION
}


# -------- Reading params -------
totalArgs=0
for ARG in "$@"
do
    case $ARG in
	--ui | -ui )
	    shift
	    export UIDOCTOR=1
	    ;;
	--agent-prereq | --agent | -agent-prereq )		
	    shift
	    if [ "$1" = "--force" ] || [ "$UIDOCTOR" = "1" ];then
		FORCED=1
	    fi
	    print_version ""
	    check_if_agent_installed ""
	    returncode=$?
	    if [ "$FORCED" = "1" ] ;then
		returncode=0
	    fi
	    if [ $returncode -eq 0 ]; then	
		if [ -f /usr/bin/ksh ]; then
		    ./prereq/agent_prereq_all.sh
		    exit $?
		else
		    #### Needed for RH6
		    if [ -x /bin/ksh ]; then
			/bin/ksh ./prereq/agent_prereq_all.sh
			exit $?
		    else
			/bin/sh ./prereq/agent_prereq_all.sh
			exit $?
		    fi
		fi
		
	    else
		if [ $returncode -eq 1 ];then
		    check_if_sat_installed ""
		    satreturncode=$?
		    if [ $satreturncode -eq 1 ]; then
			echo ""
			echo "Agent is already installed but not configured."
			echo "Since this is the Enterprise Controller, use the web interface to configure the local agent:"
			echo "Administration -> Configure Local Agent"
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --agent-prereq --force"
			echo ""
		    else
			echo ""
			echo "Agent is already installed but not configured. Please check the documentation on how to configure it."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --agent-prereq --force"
			echo ""
		    fi
		else
		    echo ""
		    echo "Agent is already installed, use the following instead:"
		    echo "# ./OCDoctor.sh --troubleshoot"
		    echo "This will also verify the prerequisites."
		    echo ""
		    echo "In rare cases if needed, you may also use the following command:"
		    echo "# ./OCDoctor.sh --agent-prereq --force"
		    echo ""
		fi
	    fi
	    exit 0
	    ;;
	--agent-prereq-11g )		
	    shift
	    if [ "$1" = "--force" ] || [ "$UIDOCTOR" = "1" ];then
		FORCED=1
	    fi
	    print_version ""
	    check_if_agent_installed ""
	    returncode=$?
	    if [ "$FORCED" = "1" ] ;then
		returncode=0
	    fi
	    if [ $returncode -eq 0 ]; then	
		if [ -f /usr/bin/ksh ]; then
		    ./prereq/agent_prereq_all-11.sh
		    exit $?
		else
		    #### Needed for RH6
		    /bin/ksh ./prereq/agent_prereq_all-11.sh
		    exit $?
		fi
		
	    else
		if [ $returncode -eq 1 ];then
		    check_if_sat_installed ""
		    satreturncode=$?
		    if [ $satreturncode -eq 1 ]; then
			echo ""
			echo "Agent is already installed but not configured."
			echo "Since this is the Enterprise Controller, use the web interface to configure the local agent:"
			echo "Administration -> Configure Local Agent"
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --agent-prereq-11g --force"
			echo ""
		    else
			echo ""
			echo "Agent is already installed but not configured. Please check the documentation on how to configure it."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --agent-prereq-11g --force"
			echo ""
		    fi
		else
		    echo ""
		    echo "Agent is already installed, use the following instead:"
		    echo "# ./OCDoctor.sh --troubleshoot"
		    echo "This will also verify the prerequisites."
		    echo ""
		    echo "In rare cases if needed, you may also use the following command:"
		    echo "# ./OCDoctor.sh --agent-prereq-11g --force"
		    echo ""
		fi
	    fi
	    exit 0
	    ;;
	--ec-prereq | --sat-prereq | -ec-prereq | --ec | --sat )
	    shift
	    if [ "$1" = "--force" ];then
		FORCED=1
	    fi
	    print_version ""
	    check_if_sat_installed ""
	    satreturncode=$?
	    if [ "$FORCED" = "1" ] ;then
		satreturncode=0
	    fi
	    if [ $satreturncode -eq 0 ]; then
		check_if_proxy_installed ""
		proxyreturncode=$?
		if [ "$FORCED" = "1" ] ;then
		    proxyreturncode=0
		fi
		if [ $proxyreturncode -eq 0 ]; then
		    if [ $UNAME = "Linux" ];then
			./prereq/ec_prereq_linux.sh
		    else 
			./prereq/ec_prereq_solaris.sh
		    fi
		else
		    if [ $proxyreturncode -eq 1 ];then
			echo ""
			echo "Proxy is already installed but not configured. Please check the documentation on how to configure it."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq --force"
			echo ""
		    else
			echo ""
			echo "Proxy is already installed, use the following instead:"
			echo "# ./OCDoctor --troubleshoot"
			echo "This will also verify the prerequisites."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq --force"
			echo ""
		    fi
		fi
	    else
		echo ""
		echo "Enterprise Controller is already installed, use the following instead:"
		echo "# ./OCDoctor.sh --troubleshoot"
		echo "This will also verify the prerequisites."
		echo ""
		echo "In rare cases if needed, you may also use the following command:"
		echo "# ./OCDoctor.sh --ec-prereq --force"
		echo ""
	    fi
	    exit 0
	    ;;
	--proxy | --proxy-prereq | -proxy-prereq )
	    shift
	    if [ "$1" = "--force" ];then
		FORCED=1
	    fi
	    print_version ""
	    check_if_sat_installed ""
	    satreturncode=$?
	    if [ "$FORCED" = "1" ] ;then
		satreturncode=0
	    fi
	    if [ $satreturncode -eq 0 ]; then
		check_if_proxy_installed ""
		proxyreturncode=$?
		if [ "$FORCED" = "1" ] ;then
		    proxyreturncode=0
		fi
		if [ $proxyreturncode -eq 0 ]; then
		    if [ $UNAME = "Linux" ];then
			./prereq/proxy_prereq_linux.sh
		    else 
			./prereq/proxy_prereq_solaris.sh
		    fi
		else
		    if [ $proxyreturncode -eq 1 ];then
			echo ""
			echo "Proxy is already installed but not configured. Please check the documentation on how to configure it."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq --force"
			echo ""
		    else
			echo ""
			echo "Proxy is already installed, use the following instead:"
			echo "# ./OCDoctor --troubleshoot"
			echo "This will also verify the prerequisites."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq --force"
			echo ""
		    fi
		fi
	    else
		echo ""
		echo "Enterprise Controller is already installed, use the following instead:"
		echo "# ./OCDoctor.sh --troubleshoot"
		echo "This will also verify the prerequisites."
		echo ""
		echo "In rare cases if needed, you may also use the following command:"
		echo "# ./OCDoctor.sh --proxy-prereq --force"
		echo ""
	    fi
	    exit 0
	    ;;
	--ec-prereq-11g )
	    shift
	    if [ "$1" = "--force" ];then
		FORCED=1
	    fi
	    print_version ""
	    check_if_sat_installed ""
	    satreturncode=$?
	    if [ "$FORCED" = "1" ] ;then
		satreturncode=0
	    fi
	    if [ $satreturncode -eq 0 ]; then
		check_if_proxy_installed ""
		proxyreturncode=$?
		if [ "$FORCED" = "1" ] ;then
		    proxyreturncode=0
		fi
		if [ $proxyreturncode -eq 0 ]; then
		    if [ $UNAME = "Linux" ];then
			./prereq/ec_prereq_linux-11.sh
		    else 
			./prereq/ec_prereq_solaris-11.sh
		    fi
		else
		    if [ $proxyreturncode -eq 1 ];then
			echo ""
			echo "Proxy is already installed but not configured. Please check the documentation on how to configure it."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq-11g --force"
			echo ""
		    else
			echo ""
			echo "Proxy is already installed, use the following instead:"
			echo "# ./OCDoctor --troubleshoot"
			echo "This will also verify the prerequisites."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq-11g --force"
			echo ""
		    fi
		fi
	    else
		echo ""
		echo "Enterprise Controller is already installed, use the following instead:"
		echo "# ./OCDoctor.sh --troubleshoot"
		echo "This will also verify the prerequisites."
		echo ""
		echo "In rare cases if needed, you may also use the following command:"
		echo "# ./OCDoctor.sh --ec-prereq-11g --force"
		echo ""
	    fi
	    exit 0
	    ;;
	--proxy-prereq-11g )
	    shift
	    if [ "$1" = "--force" ];then
		FORCED=1
	    fi
	    print_version ""
	    check_if_sat_installed ""
	    satreturncode=$?
	    if [ "$FORCED" = "1" ] ;then
		satreturncode=0
	    fi
	    if [ $satreturncode -eq 0 ]; then
		check_if_proxy_installed ""
		proxyreturncode=$?
		if [ "$FORCED" = "1" ] ;then
		    proxyreturncode=0
		fi
		if [ $proxyreturncode -eq 0 ]; then
		    if [ $UNAME = "Linux" ];then
			./prereq/proxy_prereq_linux-11.sh
		    else 
			./prereq/proxy_prereq_solaris-11.sh
		    fi
		else
		    if [ $proxyreturncode -eq 1 ];then
			echo ""
			echo "Proxy is already installed but not configured. Please check the documentation on how to configure it."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq-11g --force"
			echo ""
		    else
			echo ""
			echo "Proxy is already installed, use the following instead:"
			echo "# ./OCDoctor --troubleshoot"
			echo "This will also verify the prerequisites."
			echo ""
			echo "In rare cases if needed, you may also use the following command:"
			echo "# ./OCDoctor.sh --ec-prereq-11g --force"
			echo ""
		    fi
		fi
	    else
		echo ""
		echo "Enterprise Controller is already installed, use the following instead:"
		echo "# ./OCDoctor.sh --troubleshoot"
		echo "This will also verify the prerequisites."
		echo ""
		echo "In rare cases if needed, you may also use the following command:"
		echo "# ./OCDoctor.sh --proxy-prereq-11g --force"
		echo ""
	    fi
	    exit 0
	    ;;
	--performance)		
	    print_version ""
	    echo "Starting the speed test, this may take a few minutes..."
	    cd prereq;./opscenter_speed_test.pl;cd ..
	    ;;
	--collectlogs | --collect-logs | --collect | collect)
	    print_version ""
	    shift
	    if [ -x /usr/bin/ksh ]; then
    		/usr/bin/ksh $scriptDir/GDD/GDD-OC.sh $* collect
    	    else
    		### RHEL 6
        	if [ -x /bin/ksh ]; then
        	    /bin/ksh $scriptDir/GDD/GDD-OC.sh $* collect
        	else
        	    /bin/sh $scriptDir/GDD/GDD-OC.sh $* collect
        	fi
            fi
	    exit 0
	    ;;
	--enable-debug | --enabledebug)
	    print_version ""
	    shift
	    if [ "$1" = "--norestart" -o "$1" = "--no-restart" ];then
		RESTARTSTR="-r"
	    elif [ -z "$1" ]; then
		RESTARTSTR=""
	    else
		echo "ERROR: unknown option $1"
                echo
		print_usage
	    fi
	    if [ -x /usr/bin/ksh ]; then
    		/usr/bin/ksh $scriptDir/GDD/GDD-OC.sh debug $RESTARTSTR
    	    else
    		### RHEL 6
        	if [ -x /bin/ksh ]; then
        	    /bin/ksh $scriptDir/GDD/GDD-OC.sh debug $RESTARTSTR
        	else
        	    /bin/sh $scriptDir/GDD/GDD-OC.sh debug $RESTARTSTR
        	fi
            fi
	    exit 0
	    ;;
	--disable-debug | --disabledebug)
	    print_version ""
	    shift
	    if [ "$1" = "--norestart" -o "$1" = "--no-restart" ];then
		RESTARTSTR="-r"
	    elif [ -z "$1" ]; then
		RESTARTSTR=""
	    else
		echo "ERROR: unknown option $1"
                echo
		print_usage
	    fi
	    if [ -x /usr/bin/ksh ]; then
    		/usr/bin/ksh $scriptDir/GDD/GDD-OC.sh restore $RESTARTSTR
    	    else
    		### RHEL 6
        	if [ -x /bin/ksh ]; then
        	    /bin/ksh $scriptDir/GDD/GDD-OC.sh restore $RESTARTSTR
        	else
        	    /bin/sh $scriptDir/GDD/GDD-OC.sh restore $RESTARTSTR
        	fi
            fi
	    exit 0
	    ;;
	--show-debug | --showdebug | --checkdebug | --check-debug)
	    print_version ""
	    toolbox/check-debug.sh
	    exit $?
	    ;;
	--product-metadata-update)
	    shift
	    print_version ""
	    productmetadataupdate $1
	    exit 0
	    ;;
	
	--asrlist | --asr | --listasr)
	    shift
	    print_version ""
	    listasrproducts
	    exit 0
	    ;;
	
	--troubleshoot | -t | --t)		
	    shift
	    if [ "$1" = "--fix" -o "$1" = "-fix" ];then
		export OCDOCTOR_FIX=1
		print_version " [Fix mode] [$RDATE]"
	    else
		export OCDOCTOR_FIX=0
		print_version " [Read only] [$RDATE]"
	    fi
	    scan_for_issues ""
	    exit 0
	    ;;
	--needhelp)		
	    print_version ""
	    need_help ""
	    ;;
	--tuning)
	    shift
	    if [ "$1" = "--fix" -o "$1" = "-fix" ];then
		export OCDOCTOR_FIX=1
		print_version " [TUNING] [Fix mode] [$RDATE]"
	    else
		export OCDOCTOR_FIX=0
		print_version " [TUNING] [Read only] [$RDATE]"
	    fi
	    run_tuning ""
	    exit 0
	    ;;
	--whatisblobid)
	    print_version ""
	    shift
	    whatisblobid $*
	    exit 0
	    ;;
        --getblobid)
            print_version ""
            shift
            getblobid $*
            exit 0
            ;;
	--check-connectivity)
	    print_version ""
	    shift
	    check_connectivity
	    exit 0
	    ;;
	--enable-dm)
	    toolbox/AC-DM-Navi.sh enable
	    exit $?
	    ;;
	--disable-dm)
	    toolbox/AC-DM-Navi.sh disable
	    exit $?
	    ;;
	--cleanup)
	    shift
	    OCDOCTOR=1 toolbox/remove-old-stuff.sh "$@"
	    exit $?
	    ;;
	--update | --upgrade)
	    print_version ""
	    shift
	    check_for_update $*
	    ;;
	--version)
	    print_short_version ""
	    exit
	    ;;
	--get-latest-JIDR)
	    print_version
	    toolbox/pull_JIDR.sh
            ;;
	*)
	    print_version ""
	    print_usage
	    ;;
    esac
    totalArgs=`expr $totalArgs + 1`
done
if [ $totalArgs = 0 ];then
    print_version ""
    print_usage
fi
# -------- End of reading params ---------

