#!/bin/bash

#### General variables ###
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	exit 0
else
	ARCH=`uname -p`
	if [ "$ARCH" = "sparc" ]; then
		ASOF="March 2012"
		LATEST="121430-73"
		MIN_PATCH="121430"
		PREV_MAX="65"
		MIN_REV="68"
	else
		ASOF="March 2012"
		LATEST="121431-74"
		MIN_PATCH="121431"
		PREV_MAX="66"
		MIN_REV="69"
	fi
fi

if [ ! -x /usr/bin/showrev ]; then
	exit
fi

### First see if the patch is installed (any revision)
OUTPUT=`showrev -p |egrep "^Patch: ${MIN_PATCH}" 2>/dev/null`
if [ $? -eq 1 ]; then
	echo "OK: Patch $MIN_PATCH is not installed, nothing to check."
else
	installedPtchRevision=`showrev -p | grep "Patch: ${MIN_PATCH}" | awk '{print $2}' | sort | tail -1 | awk -F"-" '{print $2}'`
	if [ $installedPtchRevision -lt $MIN_REV ] && [ $installedPtchRevision -gt $PREV_MAX ] ; then
		echo "ERROR: Patch ${MIN_PATCH}-${installedPtchRevision} is installed." 
		echo ""
		echo "There is a known Solaris ABE issue with it (CR 7103074) - you will not be able to run lucreate if you have zones."
		release=`grep Solaris /etc/release | head -1 | cut -f2 -d_ | cut -f1 -dw`
		echo "To resolve this, install the latest version of ${MIN_PATCH}."
		echo "As of ${ASOF}, ${LATEST} is the latest one but there may be a newer version available."
		echo ""
	else
		echo "OK: Patch ${MIN_PATCH}-${installedPtchRevision} is installed"
	fi
fi
