#!/bin/ksh

# check unique best implementor in NFS-Libraries

check_passed=true

BROKEN_IMAGES=/tmp/_broken_images.$$

for LIB in $(ls -d /var/mnt/virtlibs/[0-9]*/ 2>/dev/null)
do
	for image in $(ls -d ${LIB}/bestimpl/*-*-*-*-* 2>/dev/null)
	do
		COUNT=$(ls ${image}/*.bmpl 2>/dev/null | wc -l)
		if [ $COUNT -gt 1 ]; then
			UUID=$(basename $image)
			#
			# check if this image is  still listed in library.xml
			if  grep $UUID ${LIB}/library.xml >/dev/null; then
				check_passed=false
				echo "$LIB $UUID" >> $BROKEN_IMAGES
			fi
		fi
	done
done

if $check_passed; then
	echo "OK: Best Implementors in NAS Libraries are all unique"
else
	echo "ERROR: There is more than one config file in the following directory/directories:"
	while read LIB UUID
	do
		echo
		echo "# ls ${LIB}bestimpl/$UUID"
		ls -l ${LIB}bestimpl/$UUID
	done < $BROKEN_IMAGES
	rm $BROKEN_IMAGES
	echo
	echo "This issue could trigger various failures during Zone or LDOM Guest jobs (CR 7189364)."
	echo
	echo "Required Action: Determine the correct config file, backup all other file(s) and finally delete them."
	echo
	echo "Please, run '$(pwd)/toolbox/library-check.sh -b' to analyze the issue in detail."
	echo
fi
