#!/bin/ksh

# Description:  Utility for checking if diskinfo is reporting LDom disks
#
# NOTE: This utility is a workaround for CR 7067848
#
# Revision history:
#
#               v1.0.1 :: Leon Shaner
#                       -- initial version
#
#@(#) ldom_diskinfo_check.ksh v1.0.1, leon.shaner, Tue Jul 19 13:55:13 MDT 2011

UNAME=`uname`
if [ "$UNAME" = "Linux" ];then
	exit 0
fi


DISKINFO=/opt/sun/n1gc/bin/xvmserver/diskinfo
DISKINFO_BIN=/opt/sun/n1gc/bin/xvmserver/diskinfo-bin
XVMLUINFO=/opt/sun/n1gc/bin/xvmserver/xvmluinfo
XVMLUINFO_BIN=/opt/sun/n1gc/bin/xvmserver/xvmluinfo-bin
LDMCMD=/usr/sbin/ldm
PROPFILE=/opt/sun/n1gc/etc/diskinfo.properties
PATH=/bin:/sbin:/usr/bin:/usr/sbin:$PATH

# Check if on a Control Domain and have diskinfo
if [ ! -x "$LDMCMD" ] || [ ! -x "$DISKINFO_BIN" ] || [ ! -x "$XVMLUINFO_BIN" ] ; then
	# Nothing to do
	exit 0
fi 

# Save list of disks reported by diskinfo
$DISKINFO_BIN | sed -n 's;.*/dev/rdsk/\(.*\)s[0-9]*\".*;\1;p' | sort -u > /tmp/ldom_diskinfo_check.$$

# Save list of disks reported by xvmluinfo
$XVMLUINFO_BIN 2>/devnull | sed -n 's;.*/dev/rdsk/\(.*\)s[0-9]*\".*;\1;p' | sort -u > /tmp/ldom_xvmluinfo_check.$$

# Check if disks used by LDom guests are being reported by diskinfo
# but not by xvmluinfo
$LDMCMD list -l | sed -n 's;.*/dev/dsk/\(.*\)s[0-9]*$;\1;p' | while read lddisk
do
	grep $lddisk /tmp/ldom_xvmluinfo_check.$$ > /dev/null 2>&1
	XRC=$?
	grep $lddisk /tmp/ldom_diskinfo_check.$$ > /dev/null 2>&1
	DRC=$?
	if [ ! "$DRC" -eq 0 ] && [ ! "$XRC" -eq 0 ] ; then
		# guest disk not listed by diskinfo (BAD!)
		echo "WARNING: Disk $lddisk is not reported by diskinfo."

		# Remember the disk's controller
		CTRL="$CTRL $(echo $lddisk | sed -n 's/^\(c[0-9]*\)t.*/\1/p')"
	fi
done

# Save controllers already used by diskinfo, incase we need them.
DCTRL=$(sed -n 's/^\(c[0-9]*\)t.*/\1/p' /tmp/ldom_diskinfo_check.$$ | sort -u)

# cleanup
rm /tmp/ldom_diskinfo_check.$$ /tmp/ldom_xvmluinfo_check.$$

# Offer workaround if issue found
if [ -n "$CTRL" ] ; then
   # First cleanup the CTRL list and change spaces to commas
   CTRL=$(echo $CTRL $DCTRL | fmt -w 1 | sort -u | fmt -w 1000 | tr -s ' ' | tr ' ' ',' | sed -e 's/^,//' -e 's/,$//')
   if [ -n "$CTRL" ]  && [ ! "$CTRL" = "," ] ; then
	echo ""
	echo "WARNING: One or more LDom Guest disks were not reported by diskinfo."
	echo "         As a result, the associated LDom Guests will not be restartable."
	echo "         This is a known issue in Update 2 (CR 7067848)."
	echo ""
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to fix this automatically"
		echo ""
		if [ -f ${PROPFILE} ]; then 
			CURRENT=`grep local_disk_controllers ${PROPFILE} | awk -F"=" '{print $2}'`
			if [ "$CURRENT" = "" ]; then
				## Empty file
				echo "Adding \"local_disk_controllers=$CTRL\" to ${PROPFILE}"
				echo "local_disk_controllers=$CTRL" > ${PROPFILE}
			else
				echo "Found existing value \"$CURRENT\", merging with new value \"$CTRL\""
				echo "Adding \"local_disk_controllers=${CURRENT},${CTRL}\" to  ${PROPFILE}"
				echo "local_disk_controllers=${CURRENT},${CTRL}" > ${PROPFILE}
			fi
		else
			echo "Adding \"local_disk_controllers=$CTRL\" to ${PROPFILE}"
			echo "local_disk_controllers=$CTRL" > ${PROPFILE}
		fi
		rm -f /tmp/diskinfo.cache 1>/dev/null 2>/dev/null
		rm -f /tmp/xvmluinfo.cache 1>/dev/null 2>/dev/null
		echo "Done."
		echo
		
	else
		echo "WORKAROUND:"
		echo ""
		if [ -f ${PROPFILE} ]; then
			CURRENT=`grep local_disk_controllers ${PROPFILE} | awk -F"=" '{print $2}'`
			if [ "$CURRENT" = "" ]; then
				### Empty file
				echo "# echo \"local_disk_controllers=$CTRL\" > ${PROPFILE}"
			else
				echo "# echo \"local_disk_controllers=${CURRENT},$CTRL\" > ${PROPFILE}"
			fi
		else
			echo "# echo \"local_disk_controllers=$CTRL\" > ${PROPFILE}"
		fi
		echo "# rm /tmp/diskinfo.cache"
		echo "# rm /tmp/xvmluinfo.cache"
		echo ""
		echo "NOTE: Take care that you do not have more than one local_disk_controllers line."
		echo ""
	fi
   fi
   exit 200
else
	echo "OK: all disks used by LDOMs show up in diskinfo" 
fi
