#!/bin/bash
#
# check for supported OEL or RedHat release

#### Check version ####
MY_DIR=`dirname $0`
. $MY_DIR/../../functions
get_agent_version ""          ### Provide VERSION & VERSIONNUM

# state file for one of the next checks
SUPPORTED_OS=/tmp/ocdoctor_supported_os_statefile
touch $SUPPORTED_OS

UNAME=$(uname)
if [ "$UNAME" = "Linux" ]; then
    SUPPORTED_OS_VERSION=true
    RHELVERFILE="/etc/redhat-release"
    OELVERFILE="/etc/oracle-release"
    if [ -f $OELVERFILE ]; then
        OEL_VERSION=$( awk '/^.* Linux Server release / {print $5}' $OELVERFILE)
        MAJOR_REL=$(echo $OEL_VERSION | cut -d. -f1)
        MINOR_REL=$(echo $OEL_VERSION | cut -d. -f2)
        if [ -n "$MAJOR_REL" -a -n "$MINOR_REL" ]; then
            if [ $MAJOR_REL -ge 7 ] || [ $MAJOR_REL -eq 6 -a $MINOR_REL -gt 5 ]; then
            	if [ "$VERSIONNUM" -gt 12310000 ]; then
                	echo "OK: OEL $OEL_VERSION is a supported Linux OS for an Ops Center $VERSION Agent"
            	else
                	echo
                	echo "WARNING: OEL $OEL_VERSION is an unsupported Linux OS for an Ops Center $VERSION Agent!"
                	echo
                	echo "Please visit http://docs.oracle.com/cd/E59957_01/doc.123/e59961/toc.htm for the latest Certified Systems Matrix."
                	echo
			rm $SUPPORTED_OS
            	fi
	    else
		echo "OK: OEL $OEL_VERSION is a supported Linux OS for an Ops Center $VERSION Agent"
            fi
	fi		
    elif [ -f $RHELVERFILE ]; then
        RHEL_VERSION=$( awk '/^.* Linux Server release / {print $7}' $RHELVERFILE)
        MAJOR_REL=$(echo $RHEL_VERSION | cut -d. -f1)
        MINOR_REL=$(echo $RHEL_VERSION | cut -d. -f2)
        if [ -n "$MAJOR_REL" -a -n "$MINOR_REL" ]; then
            if [ $MAJOR_REL -ge 7 ] || [ $MAJOR_REL -eq 6 -a $MINOR_REL -gt 4 ]; then
            	if [ "$VERSIONNUM" -gt 12310000 ]; then
                	echo "OK: RHEL $RHEL_VERSION is a supported Linux OS for an Ops Center $VERSION Agent"
            	else
                	echo
                	echo "WARNING: RHEL $RHEL_VERSION is an unsupported Linux OS for an Ops Center $VERSION Agent!"
                	echo
                	echo "Please visit http://docs.oracle.com/cd/E59957_01/doc.123/e59961/toc.htm for the latest Certified Systems Matrix."
                	echo
			rm $SUPPORTED_OS
            	fi
	    else
		echo "OK: RHEL $RHEL_VERSION is a supported Linux OS for an Ops Center $VERSION Agent"
            fi
        fi
    fi

fi
