#!/bin/bash

# Script to report the heap usage of the cacao agent
#
# If the usage is above $WARNING_LEVEL, we will throw a warning to increase it
# If the usage is beloe $LOW_USAGE_LEVEL, we will inform user that a decrease is possible if required
#

WARNING_LEVEL=90     ### if above, we will recommend to increase max value
LOW_USAGE_LEVEL=5    ### if below, we will suggest to reduce max value

INCREASE_FACTOR=2    ### New recommended value will be $INCREASE_FACTOR * $MAX_USABLE_HEAP
DECREASE_FACTOR=6    ### Suggested new value will be $DECREASE_FACTOR * $USED_HEAP

CHANGE_HEAP_TOOL=/var/opt/sun/xvm/OCDoctor/toolbox/changeXmxValue.sh

if [ "$(uname)" = "Linux" ]; then
	# we do no longer install jmxdump on Linux Agents, therefore we exit for now ...
	exit
	AWK="/usr/bin/awk"
	CACAO_PROPERTIES="/etc/opt/sun/cacao2/instances/scn-agent/private/cacao.properties"
else
	AWK="/usr/bin/nawk"
	CACAO_PROPERTIES="/etc/cacao/instances/scn-agent/private/cacao.properties"
fi

JMXDUMP=/opt/sun/xvm/bin/jmxdump
TMPFILE=/tmp/agent_heap_usage.$$

CONFIGURED_HEAP=$(grep '^java\.flags=' $CACAO_PROPERTIES 2>/dev/null | \
		tr '=' ' ' | \
		tr ' ' '\n' | \
		sed -n 's/^-Xmx//p' |\
		tr 'kmg' 'KMG')

if [ -x $JMXDUMP ]; then
	$JMXDUMP a t root wellknown java.lang:type=Memory HeapMemoryUsage 2>/dev/null |\
	grep '^HeapMemoryUsage = {' | tr '{}' ',,' | tr ',' '\n' > $TMPFILE
	if [ -s "$TMPFILE" ]; then
		# obtaining values in rounded MB
		MAX_USABLE_HEAP=$($AWK ' /max = / {printf "%.0f\n",$3/1048576}' $TMPFILE)   
		USED_HEAP=$($AWK ' /used = / {printf "%.0f\n",$3/1048576}' $TMPFILE)
		USED_PCT=$(( 100 * $USED_HEAP / $MAX_USABLE_HEAP ))
		if [ "$USED_PCT" -gt $WARNING_LEVEL ]; then
			echo "WARNING: Agent heap stats: configured: ${CONFIGURED_HEAP}B  max. usable: ${MAX_USABLE_HEAP}MB  currently used: ${USED_HEAP}MB  percentage used: ${USED_PCT}%" 
			echo "WARNING: "
			echo "WARNING: The heap usage is above ${WARNING_LEVEL}% of the maximum usable size!"
			echo "WARNING: "
			echo "WARNING: To increase the maximum allowed heap size, you could use e.g. the following command:"
			echo "WARNING: "
			echo "WARNING: $CHANGE_HEAP_TOOL $(( $INCREASE_FACTOR * $MAX_USABLE_HEAP )) m agent"
			echo "WARNING: "
		elif [ "$USED_PCT" -lt $LOW_USAGE_LEVEL ]; then
			echo "INFO: Agent heap stats: configured: ${CONFIGURED_HEAP}B  max. usable: ${MAX_USABLE_HEAP}MB  currently used: ${USED_HEAP}MB  percentage used: ${USED_PCT}%"
			echo "INFO: "
			echo "INFO: The heap usage is below ${LOW_USAGE_LEVEL}%. It is ok to have a much higher maximum value"
			echo "INFO: configured even if the agent does not require it. If the usage of this host will change in the future"
			echo "INFO: the required heap space can grow, so it is good to have a higher value configured."
			echo "INFO: "
			echo "INFO: If desired, you can reduce the maximum allowed heap size by running e.g. the following command:"
			echo "INFO: "
			echo "INFO: $CHANGE_HEAP_TOOL $(( $DECREASE_FACTOR * $USED_HEAP )) m agent"
			echo "INFO: "
		else
			echo "OK: Agent heap stats: configured: ${CONFIGURED_HEAP}B  max. usable: ${MAX_USABLE_HEAP}MB  currently used: ${USED_HEAP}MB  percentage used: ${USED_PCT}%"
		fi
	else
		echo "WARNING: unable to connect to java instance of the cacao agent!"
	fi
else
	echo "ERROR: $0: $JMXDUMP not found!"
fi

rm -f $TMPFILE

exit
