#!/bin/bash
#
# Check for a correct SMF config of cacao services
#
# See Bug 19435700 - Since Cacao 2.4.3.0, SMF service creation on S11.1 may fail 
#
# This check needs some updates ...
#
# MOS Doc for this issue: 2114661.1
#
# 1) Bug 19435700 is for Solaris 11 only, we should not mention it on a S10 server
#
# 2) For S11 we should provide the solution from MOS Doc  2114661.1
#
# 3) For S10 we should provide the right steps as well
#

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	exit
fi

SVCS=/usr/bin/svcs
CACAOADM=/usr/sbin/cacaoadm

if [ ! -x $SVCS ]; then
	# not Solaris 10 or higher
	exit
fi

SOLARIS11_OR_HIGHER=true
[ "$(uname -r)" = "5.10" ] && SOLARIS11_OR_HIGHER=false

if [ -f "/opt/SUNWxvmoc/bin/satadm" ]; then
	## Don't run this twice on Sat
	exit
fi
if [ -f "/opt/SUNWxvmoc/bin/proxyadm" ]; then
	## Don't run this twice on proxy
	exit
fi

CACAO_INSTANCES=/tmp/cacao.instances.$$
CACAO_SMF_SERVICES=/tmp/cacao.smf.services.$$

$CACAOADM list-instances 2>/dev/null > $CACAO_INSTANCES
$SVCS -H '*common-agent-container*' 2>/dev/null > $CACAO_SMF_SERVICES

NO_OF_CACAO_INSTANCES=$(cat $CACAO_INSTANCES | wc -l)
NO_OF_CACAO_SMF_SERVICES=$(cat $CACAO_SMF_SERVICES | wc -l)

if [ "$NO_OF_CACAO_INSTANCES" -ne "$NO_OF_CACAO_SMF_SERVICES" ]; then
        echo
	echo "ERROR: The cacao SMF service config is not in sync with the cacao config!"
	echo
	echo "Existing cacao instances:"
	cat $CACAO_INSTANCES
	echo
	echo "Existing cacao SMF services:"
	cat $CACAO_SMF_SERVICES
	echo
	echo "This issue must be resolved to ensure a healthy SMF configuration of all cacao instances!"
	echo "Do not upgrade any OpsCenter software on this system while it is in this state!"
	echo
	echo "Further info can be found in MOS Doc 2114661.1"
	echo
	if $SOLARIS11_OR_HIGHER; then
		echo "Steps to fix this on hosts running Solaris 11 or higher:"
		echo
		echo "# svccfg delhash /lib/svc/manifest/site/common-agent-container-1.xml"
		echo "# for manifest in /etc/svc/profile/site/common-agent-container-1\:* ; do svccfg delhash \$manifest ; done"
		echo "# svcadm restart manifest-import"
		echo
	else
		echo "Steps to fix this on hosts running Solaris 10:"
		echo
		echo "NOTE: Services will get stopped during the SMF cleanup procedure!"
		echo
		echo "# svcadm disable svc:/application/management/common-agent-container-1:<instance name>"
		echo "# svccfg delete svc:/application/management/common-agent-container-1:<instance name>"
		echo "# svccfg import /etc/cacao/instances/<instance name>/private/svc_cacao.xml"
		echo "# svcadm enable  svc:/application/management/common-agent-container-1:<instance name>"
		echo
		echo "where <instance name> is oem-ec, scn-proxy or scn-agent."
		echo
	fi
	echo "Please, open a Service Request with Oracle Support if the above steps did not resolve the issue."
	echo

else
	echo "OK: cacao SMF config is in sync with listed cacao instances"
fi

rm -f $CACAO_INSTANCES $CACAO_SMF_SERVICES


