#!/bin/bash
#
# Check for bug 20764152 - broken script /etc/rcS.d/S85init_oc_zpool
#
# Bug is only applicable for S11 systems
#
# Impact:  OpsCenter created zones using local storage are at risk to break during OS reboot
#

UNAME=`uname`
OS_REL=`uname -r`

if [ "$UNAME" = "SunOS" -a  "$OS_REL" = "5.11" ]; then
	
	INIT_SCRIPT=/etc/rcS.d/S85init_oc_zpool
	ORIG_SRCIPT=/etc/rcS.d/orig_S85init_oc_zpool_orig

	if [ -f "$INIT_SCRIPT" ]; then
	
		LINES_W_LINENO=$(grep LINENO $INIT_SCRIPT | grep -cv '#')

		if [ "$LINES_W_LINENO" -eq 0 ]; then
			# init script is ok
			echo "OK: Found a fixed version of script S85init_oc_zpool"
		else
			# init script is broken
			echo "ERROR: OpsCenter created zones using local storage are at risk to break during OS reboot (Bug 20764152)"
			echo 
			if [ "$OCDOCTOR_FIX" = "1" ]; then
				echo "Trying to automatically fix this..."
				mv $INIT_SCRIPT $ORIG_SRCIPT
				sed 's/LINENO/LINENUMBER/g' $ORIG_SRCIPT > $INIT_SCRIPT
				chmod 755 $INIT_SCRIPT
				chown root:sys $INIT_SCRIPT
				echo
				echo "Script $INIT_SCRIPT has been fixed, original script is here: $ORIG_SRCIPT"
				echo
			else
				echo "To fix this, replace all occurences of 'LINENO' in script $INIT_SCRIPT with e.g. 'LINENUMBER'"
				echo
				echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
				echo
			fi
		fi
	fi
fi
