#!/bin/ksh

#
# checking for integrity of the Agent installation
#

# source useful functions
MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        . $MY_DIR/../../functions
fi

UNAME=`uname`
if [ $UNAME = "Linux" ];then
        CHECK=0

        # Note: Since RHEL/OEL 7.0, we do no longer install the sun-scn-update-agent* rpms
        #       The UCE Agent will no longer be used on RHEL/OEL 7.0 and higher !
        cat <<!EOF! | while read file; do
sun-cacaocrews
sun-cacaort
sun-n1hss-agentdm
sun-n1hss-agentdm-config
sun-scn-agentfacade-r
sun-scn-agentfacade-u
sun-scn-agentupgrade-r
sun-scn-agentupgrade-u
sun-scn-agent-utils
sun-scnconnmgt
sun-scnconnmgt-ra
sun-scnjobmgr-agent
sun-scnjobmgr-agent-config
sun-scn-update-util
!EOF!
        OUTPUT=`rpm -q $file`
        if [[ $? -eq 0 ]]; then
                DONOTHING=1
	else
                if [[ $CHECK -eq 0 ]]; then               ### Only print ERROR once
                        echo "ERROR while checking for agent RPM integrity:"
                fi
                echo "RPM $file is not installed properly"
                CHECK=1
        fi
        done
        if [[ $CHECK -eq 0 ]]; then
                echo "OK: All agent RPMs are installed properly"
        else
                echo "ERROR: The RPMs above are not installed properly (missing from 'rpm -q'), consider reinstallation."
                echo "       It can also be that those RPMs are not needed. Please report this to Sun Support to determine this."
                echo ""
        fi

        exit $CHECK



else                    ####### Solaris

CheckInstalledPatchesRevision(){
        patchNumber="$1"
        patchRevision="$2"
	installedPtchRevision=$(installed_rev_of_patch $patchNumber)
        if [ -z "$installedPtchRevision" ]; then
        	echo "ERROR: Patch $patchNumber-$patchRevision is not installed"
                failure=1
        else
                if [ $installedPtchRevision -lt $patchRevision ]; then
                        #### Older revision is installed
                        echo "ERROR: Patch $patchNumber-$patchRevision is not installed. Instead we have $patchNumber-$installedPtchRevision"
                        failure=1
                fi
        fi
        return $failure
}

	CHECK=0
	OS_REL=`uname -r`
	if  [ "$OS_REL" = "5.10" ]; then 
		cat <<!EOF! | while read file; do
			SUNWcacaocrews
			SUNWcacaort
			SUNWn1hss-agentdm
			SUNWscn-agentfacade-r
			SUNWscn-agentfacade-u
			SUNWscn-update-agent
			SUNWscn-update-agent-r
			SUNWscn-update-util
			SUNWscn-agent-utils
			SUNWscnjobmgr-agent
			SUNWscnconnmgt
			SUNWscnconnmgt-ra
!EOF!
		pkginfo $file >/dev/null 2>&1
		if [[ $? -eq 0 ]] ; then
			DONOTHING=1
		else
			if [[ $CHECK -eq 0 ]]; then		### Only print ERROR once
				echo "ERROR while checking for agent packages integrity:"
			fi
			echo "Package $file is not installed properly"
			CHECK=1
		fi
		done
	else		### if Solaris 11
		cat <<!EOF! | while read file; do
			SUNWcacaocrews
			SUNWcacaort
			SUNWn1hss-agentdm
			SUNWscn-agentfacade-r
			SUNWscn-agentfacade-u
			SUNWscn-update-util
			SUNWscn-agent-utils
			SUNWscnjobmgr-agent
			SUNWscnconnmgt
			SUNWscnconnmgt-ra
!EOF!
		pkginfo $file >/dev/null 2>&1
		if [[ $? -eq 0 ]] ; then
			DONOTHING=1
		else
			if [[ $CHECK -eq 0 ]]; then		### Only print ERROR once
				echo "ERROR while checking for agent packages integrity:"
			fi
			echo "Package $file is not installed properly"
			CHECK=1
		fi
		done
	fi			### end of Solaris 11

	REL=`uname -r`
	if [[ "$REL" = "5.10" ]]; then
		#### Check for Solaris 10 packages ###
		cat <<!EOF! | while read file; do
			SUNWj6rt
!EOF!
		pkginfo $file >/dev/null 2>&1
		if [[ $? -eq 0 ]] ; then
			DONOTHING=1
		else
			if [[ $CHECK -eq 0 ]]; then               ### Only print ERROR once
				echo "ERROR while checking for agent packages integrity:"
			fi
			echo "Package $file is not installed properly"
			CHECK=1
		fi
		done
	fi 		### End of Solaris 10 pkgs ###


	if [[ $CHECK -eq 0 ]]; then
		echo "OK: All agent packages are installed properly"
	else
		echo "ERROR: The agent packages above are not installed properly (missing from pkginfo), consider reinstallation."	
		echo "       It can also be that those packages are not needed. Please report this to Sun Support to determine this."
		echo ""
	fi


	####### CHECK PATCHES #######

	if [[ "$REL" = "5.10" ]]; then
		ARCH=`uname -p`
		if [[ "$ARCH" = "sparc" ]]; then
			failure=0
			CheckInstalledPatchesRevision "120900" "04"
			CheckInstalledPatchesRevision "119254" "67"
			CheckInstalledPatchesRevision "121133" "02"
			CheckInstalledPatchesRevision "119042" "09"
			CheckInstalledPatchesRevision "121901" "02"
			CheckInstalledPatchesRevision "125731" "05"
			CheckInstalledPatchesRevision "137321" "01"
			if [ $failure -eq 0 ]; then
				echo "OK: All agent patches are installed properly"
			else
				echo "ERROR: The patches above were not installed properly during the agent install."
				echo "       Check the agent installation logs."
				echo ""
				CHECK=1
			fi
		else			## X86
			failure=0
                        CheckInstalledPatchesRevision "120901" "03"
                        CheckInstalledPatchesRevision "121334" "04"
                        CheckInstalledPatchesRevision "119255" "67"
                        CheckInstalledPatchesRevision "119043" "09"
                        CheckInstalledPatchesRevision "121902" "02"
                        CheckInstalledPatchesRevision "137322" "01"
                        CheckInstalledPatchesRevision "125732" "05"
                        if [ $failure -eq 0 ]; then
                                echo "OK: All agent patches are installed properly"
                        else
                                echo "ERROR: The patches above were not installed properly during the agent install."
                                echo "       Check the agent installation logs."
                                echo ""
                                CHECK=1
                        fi

		fi
	fi
	if [[ "$REL" = "5.8" ]]; then
        	failure=0
                CheckInstalledPatchesRevision "110380" "06"
                CheckInstalledPatchesRevision "110165" "05"
                CheckInstalledPatchesRevision "112097" "08"
                CheckInstalledPatchesRevision "110934" "26"
                if [ $failure -eq 0 ]; then
                        echo "OK: All agent patches are installed properly"
                else
                        echo "ERROR: The patches above were not installed properly during the agent install."
                        echo "       Check the agent installation logs."
                        echo ""
                        CHECK=1
                fi
	fi



	exit $CHECK
fi		### End of Solaris



