#!/bin/bash
#
#
#

OS=$(uname)

if [ "${OS}" == "SunOS" ]
then
    MEM_LIMIT=1500000  # we increased max heap to 1GB with 12cR2 U2 for the Solaris VC, so we warn when it in total more than 1.5 GB
    CACAOADM=/usr/sbin/cacaoadm
    ARGS_OPTION="-o args="
    # switched from collecting VSZ to RSS output, which is more reliable on Linux
    SIZE_TIME_OPTION="-o rss="
else
    MEM_LIMIT=500000  # Linux Agent is not doing any virtualization stuff and should use much less
    CACAOADM=/opt/sun/cacao2/bin/cacaoadm
    ARGS_OPTION="-o command="
    # switched from collecting VSZ to RSS output, which is more reliable on Linux
    SIZE_TIME_OPTION="-o rss="
fi

if [ -x $CACAOADM ]
then
    if $CACAOADM list-instances | grep -w scn-agent > /dev/null
    then
        PIDs=$( $CACAOADM status -i scn-agent | grep '^[1-9]' )
        if [ -z "${PIDs}" ]
        then
            echo "ERROR: Ops Center Agent is not running." 1>&2
            exit 1
        fi
    else
        echo "ERROR: No Ops Center Agent configured." 1>&2
        exit 1
    fi
else
    echo "ERROR: Ops Center Agent is not installed." 1>&2
    exit 1
fi   

for i in ${PIDs}
do
  PID=$(ps -p $i $ARGS_OPTION | egrep 'java|cvm')
  [ -n "${PID}" ] && AGENT_PID=$i  
done

if [ -z "${AGENT_PID}" ]; then
    echo "ERROR: Unable to determine cacao agent process id." 1>&2
    exit 1
fi

if [ "${OS}" == "SunOS" ]
then
    VERSION=$(/usr/bin/pkgparam SUNWscn-agentfacade-u VERSION | awk -F"," '{print $1}')
else
    VERSION=$(rpm -q sun-scn-agentfacade-u | awk -F"u-" '{print $2}' | tr - . )
fi

MEM_USED=$(ps -p $AGENT_PID $SIZE_TIME_OPTION)

if [ "$MEM_USED" -gt $MEM_LIMIT ];then
	echo "WARNING: Agent is using $MEM_USED KB of main memory !"
	echo "         The high memory footprint could be caused by a memory leak. Restart the agent to fix this !"
        echo
        echo "         It is recommended to restart agents on a regular schedule, e.g. weekly or monthly."
        echo "         OCDoctor/toolbox contains the script 'restart_agent.sh' which could be called by an"
        echo "         Operational Plan."
        echo
else
	echo "OK: Memory usage of agent is fine."
fi
