#!/bin/ksh
#
# Check to see if we got hit by this bug:
#
# Bug 20228838 migratable guest cannot be migrated using ldom 3.2
#
# CDOMs running Logical Domains Manager 3.2 will need an additional
# line in file /opt/sun/n1gc/etc/ldoms.properties to allow guest migration
# 

LDOMS_PROPERTIES="/opt/sun/n1gc/etc/ldoms.properties"

AGENT_PROP="/opt/sun/n1gc/lib/XVM_AGENT.properties"
VIRT_TYPE=$(grep '^virtualization.type=' $AGENT_PROP 2>/dev/null | cut -d= -f2)

# check for Control Domain
[ "${VIRT_TYPE}" == "ldom" ] || exit 0 # System is not a Control Domain, check not applicable


#### source functions and determine version ####
MY_DIR=`dirname $0`
. $MY_DIR/../../functions
get_agent_version ""          ### Provide VERSIONNUM and LATESTVERNUM

[ "${VERSIONNUM}" -gt "12300000" ] && exit 0 #  Agent is of version 12cR3 or higher, check not applicable

LDM=/usr/sbin/ldm
LDOM_VERSION=$(ldm -V 2>/dev/null | nawk ' /Logical Domains Manager/ {print substr($5,1,3)}')

if [ -z "${LDOM_VERSION}" ]; then
	# ldm must have come back with an error
	# we will check the status of the SMF service
	LDMD_STATUS=$(svcs -H ldmd | nawk '{print $1}')
	if [ "${LDMD_STATUS}" != "online" ]; then
		echo "WARNING: SMF service 'svc:/ldoms/ldmd:default' is not in state ONLINE!"
		exit 1
	else
		echo "WARNING: Unable to determine version of Logical Domains Manager!"
		exit 1
	fi
fi

if [ "${LDOM_VERSION}" = "3.2" ]; then
	# check if property file has already been fixed
	if grep '^archlist.LDMMGR.3.2=' $LDOMS_PROPERTIES >/dev/null; then
		echo "OK: LDOM Version 3.2 has been added already to ldoms.properties file"
	else
		echo
		echo "WARNING: LDOM Version 3.2 must be added to file $LDOMS_PROPERTIES (Bug 20228838)!"
		echo 
		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo "Trying to automatically fix this..."
			cp $LDOMS_PROPERTIES ${LDOMS_PROPERTIES}.orig_ocdoctor
			echo 'archlist.LDMMGR.3.2=native,generic,migration-class1,sparc64-class1' >> $LDOMS_PROPERTIES
			echo
			echo "LDOM Version 3.2 has been added to file $LDOMS_PROPERTIES!"
			echo
			echo "The original file has been saved as ${LDOMS_PROPERTIES}.orig_ocdoctor"
			echo
			echo "OpsCenter Agent must be restarted to make the change effective!"
			echo
		else
			echo "This bug will prevent LDom Guest migrations to this Control Domain!"
			echo
			echo "To fix this, add the following line to file $LDOMS_PROPERTIES:"
			echo
			echo "archlist.LDMMGR.3.2=native,generic,migration-class1,sparc64-class1"
			echo
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this."
			echo
			echo "A restart of the OpsCenter Agent is required to make the fix effective."
			echo
		fi
	fi
else
	echo "OK: Control Domain is not affected by bug 20228838"
fi
