#!/bin/ksh

# check for a leftover jar file /usr/lib/cacao/lib/endorsed/jsr173_api.jar

JAR_DIR=/usr/lib/cacao/lib/endorsed
JAR_FILE=$JAR_DIR/jsr173_api.jar
JAR_FILE_RENAMED=$JAR_DIR/orig.jsr173_api.jar.orig

# to get function "is_Control_Domain" 
MY_DIR=`dirname $0`
. $MY_DIR/../../functions

if $is_Control_Domain; then
	if [ -f $JAR_FILE ]; then
		echo 
		echo "ERROR: Leftover jar file found: $JAR_FILE"
		echo
		echo "This issue is causing Agent failures, the file needs to get removed or renamed!"
		echo
		echo "Required steps:"
		echo
		echo "1) Stop agent  -> /opt/SUNWxvmoc/bin/agentadm stop"
		echo "2) Rename file -> mv $JAR_FILE $JAR_FILE_RENAMED"
		echo "3) Start agent -> /opt/SUNWxvmoc/bin/agentadm start"
		echo
		if [ "$OCDOCTOR_FIX" = "1" ]; then
			if [ "$UIDOCTOR" = "1" ]; then
				echo
				echo "WARNING: Cannot auto fix this when running from the Ops Center UI, as the agent will shutdown midway."
				echo
				echo "Please run '/var/opt/sun/xvm/OCDoctor/OCDoctor.sh --troubleshoot --fix' on the target machine directly."
				echo
				exit
			else
				echo "Trying to fix this issue automatically..."
				echo "OK: Shutting down the agent..."
				/opt/SUNWxvmoc/bin/agentadm stop
				mv $JAR_FILE $JAR_FILE_RENAMED
				echo "OK: Renamed leftover jar file to $JAR_FILE_RENAMED"
				echo "OK Starting agent..."
				/opt/SUNWxvmoc/bin/agentadm start
				echo
				echo "OK: all done with getting $JAR_FILE out of the way!"
				echo
			fi
		else
			echo
			echo "To fix this issue automatically, run '/var/opt/sun/xvm/OCDoctor/OCDoctor.sh --troubleshoot --fix'"
			echo
			echo "Note #1: The agent will be shutdown during the process, so make sure no jobs are running on it"
			echo "Note #2: Do not run this from the Web UI as the agent will shutdown. Please run this on the machine itself."
			echo
		fi
	else
		echo "OK: No leftover jar file found"
	fi
else
	echo "OK: This is not a Control Domain, will not check for a leftover jar file"
fi

exit 0
