#!/bin/bash
#
# OC Agent is made out of two components, the cacao agent and the UCE agent
# 
# The UCE Agent does not run on Solaris 11 
#
# Since Ops Center 12.3.1 the UCE Agent will no longer run on OEL/RHEL 6.6, 6.7 & 7.x
# 
# Up to 12.3.0, OEL/RHEL 6.6, 6.7 & 7.x were unsupported OS versions
#

UCE_AGENT_SHOULD_RUN=true
FAILURE1=0
FAILURE2=0
FAILURE3=0
OK=1

UNAME=`uname`
if [ $UNAME = "Linux" ]; then
	RHELVERFILE="/etc/redhat-release"
	if [ -f "$RHELVERFILE" ]; then
		MAJOR_REL=$(awk '/^.* Linux Server release / {print $7}' $RHELVERFILE | cut -d. -f1)
		MINOR_REL=$(awk '/^.* Linux Server release / {print $7}' $RHELVERFILE | cut -d. -f2)
		if [ $MAJOR_REL -ge 7 ] || [ $MAJOR_REL -eq 6 -a $MINOR_REL -ge 6 ]; then
			UCE_AGENT_SHOULD_RUN=false
		fi
	fi
		
        CACAOADM="/opt/sun/cacao2/bin/cacaoadm"
        AGENTADM="/opt/sun/xvmoc/bin/agentadm"
else
	OS_REL=`uname -r | cut -d. -f2`
	if [ "$OS_REL" -ge 11 ]; then
		UCE_AGENT_SHOULD_RUN=false
	fi 

        CACAOADM="/usr/sbin/cacaoadm"
        AGENTADM="/opt/SUNWxvmoc/bin/agentadm"
fi

if [ -x $CACAOADM ]; then
	CACAOSTATUS=`$CACAOADM -i scn-agent 2>&1 | grep "scn-agent instance is not running" `
else
	exit # no Agent installed, nothing to check
fi

if $UCE_AGENT_SHOULD_RUN; then
	AGENTSHELL=`ps -ef | grep uce_agent.sh | grep -v grep`
	AGENTBIN=`ps -ef | grep uce_agent.bin | grep -v grep`
	OK="1"
	if [ "$AGENTSHELL" = "" ]; then
	        echo "WARNING: Agent uce_agent.sh is not running"
	        FAILURE1="1"
	        OK="0"
	fi
	if [ "$AGENTBIN" = "" ]; then
	        echo "WARNING: Agent uce_agent.bin is not running"
	        FAILURE2="1"
	        OK="0"
	fi
fi


if [ -n "$CACAOSTATUS" ]; then
        echo "WARNING: Agent cacao is not running"
        FAILURE3="1"
        OK="0"
fi

if $UCE_AGENT_SHOULD_RUN; then
	if [ "$FAILURE1" -eq 1 -a "$FAILURE2" -eq 1 -a  "$FAILURE3" -eq 1 ]; then
        	##### Only print this if all 3 services are down, otherwise there could be an issue
        	echo "         To start the agent (if configured already), try: $AGENTADM start"
	fi
else
	if [ "$FAILURE3" -eq 1 ]; then
        	echo "         To start the agent (if configured already), try: $AGENTADM start"
	fi
fi

if [ "$OK" = "1" ]; then
        echo "OK: Agent services are running"
fi
