#!/bin/bash
#
# check for broken servercfg.xml files due to bug 16900331
#
# we will create copies of fixed files in U2 and U3 format
#
# we will point to a dedicated howto document in case of issues 
#
# see the document howto/howto_fix_
#

CRITICAL_VERSION=12132305

DEBUG=false

AGENT_PROP=/opt/sun/n1gc/lib/XVM_AGENT.properties
VIRT_TYPE=$(grep '^virtualization.type=' $AGENT_PROP 2>/dev/null | cut -d= -f2)

NFSLIB=/var/mnt/virtlibs
LOCALLIB=/guests
SERVERCFG=servercfg.xml
FIXED=FIXED_BY_OCDOCTOR
FIXED_CDOM=FIXED_ON_HOSTING_CDOM_BY_OCDOCTOR
ZONECTRL_ID=$(cat /etc/opt/sun/oc/zonectrlr.id 2>/dev/null)

LDOM_GUESTS_ALL=/tmp/ldom_guests.$$.all
LDOM_GUESTS_OLDFORMAT=/tmp/ldom_guests.$$.old
LDOM_GUESTS_NEWFORMAT=/tmp/ldom_guests.$$.new
LDOM_GUESTS_BOTHFORMATS=/tmp/ldom_guests.$$.both
LDOM_GUESTS_BROKEN=/tmp/ldom_guests.$$.broken
LDOM_GUESTS_RUNNING=/tmp/ldom_guests.$$.running
LDOM_GUESTS_OURS=/tmp/ldom_guests.$$.ours
touch $LDOM_GUESTS_ALL $LDOM_GUESTS_OLDFORMAT $LDOM_GUESTS_NEWFORMAT $LDOM_GUESTS_BOTHFORMATS $LDOM_GUESTS_BROKEN $LDOM_GUESTS_RUNNING $LDOM_GUESTS_OURS

scan_ldom_guests(){
	OUR_LDOM_UUIDS=/tmp/our_uuids.$$
	RUNNING_LDOM_UUIDS=/tmp/running_uuids.$$

	# get UUIDs of all running guests (no issue that primary domain will be included)
        ldm ls -l -p | nawk -F = ' $1 ~ /^UUID/ {print $2}' > $RUNNING_LDOM_UUIDS

	# get UUIDS of all owned ldom guests
	ls ${LOCALLIB}/bestimpl/*/${ZONECTRL_ID}.bmpl 2>/dev/null | cut -d/ -f4 > $OUR_LDOM_UUIDS
	ls ${NFSLIB}/*/bestimpl/*/${ZONECTRL_ID}.bmpl 2>/dev/null | cut -d/ -f7 >> $OUR_LDOM_UUIDS

	# get list of all ldom servercfg.xml files
	grep -l '<virt-type>LDOM</virt-type>' ${LOCALLIB}/*/$SERVERCFG ${NFSLIB}/*/*/$SERVERCFG 2>/dev/null > $LDOM_GUESTS_ALL
	while read PATH_TO_SERVERCFG
	do
		OLD_FORMAT="$( grep '<prom-vars' $PATH_TO_SERVERCFG )"
		NEW_FORMAT="$( grep '<promVars' $PATH_TO_SERVERCFG )"
		if [ -n "$OLD_FORMAT" -a -n "$NEW_FORMAT" ]; then
			echo $PATH_TO_SERVERCFG >> $LDOM_GUESTS_BOTHFORMATS
		elif [ -n "$OLD_FORMAT" ]; then
			echo $PATH_TO_SERVERCFG >> $LDOM_GUESTS_OLDFORMAT
		elif [ -n "$NEW_FORMAT" ]; then
			echo $PATH_TO_SERVERCFG >> $LDOM_GUESTS_NEWFORMAT
		else
			echo $PATH_TO_SERVERCFG >> $LDOM_GUESTS_BROKEN
		fi

		UUID=$(echo $PATH_TO_SERVERCFG | nawk -F / '{print $(NF-1)}')
		grep $UUID $RUNNING_LDOM_UUIDS >/dev/null && echo $PATH_TO_SERVERCFG >> $LDOM_GUESTS_RUNNING
		grep $UUID $OUR_LDOM_UUIDS >/dev/null && echo $PATH_TO_SERVERCFG >> $LDOM_GUESTS_OURS
	done < $LDOM_GUESTS_ALL
	
	if [ -s "$LDOM_GUESTS_BROKEN" -o -s "$LDOM_GUESTS_OLDFORMAT" ]; then
		FIX_NEEDED=true
	else
		FIX_NEEDED=false
	fi

	rm $OUR_LDOM_UUIDS $RUNNING_LDOM_UUIDS
}

guest_name(){
	grep '<guestName>' $1 | sed 's/^.*<guestName>//' | sed 's@</guestName>.*$@@'
}

add_new_format(){
	ORIGINAL=$1
	CONVERTED=$2
	PROM_SECTION=/tmp/prom_section.$$
	BEGIN_PROM=$(nawk '/<prom-vars>/ {print NR}' $ORIGINAL) 
	END_PROM=$(nawk '/<\/prom-vars>/ {print NR}' $ORIGINAL) 
	head -$(( $BEGIN_PROM -1 )) $ORIGINAL > $CONVERTED
	tail +$BEGIN_PROM $ORIGINAL | head -$(( $END_PROM - $BEGIN_PROM +1 )) > $PROM_SECTION
	perl -p -i -e 's/prom-vars/promVars/' $PROM_SECTION
	perl -p -i -e 's/entries>/entry>/' $PROM_SECTION
	perl -p -i -e 's@<key>@<key xsi:type="xs:string" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">@' $PROM_SECTION
	perl -p -i -e 's@<value>@<value xsi:type="xs:string" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">@' $PROM_SECTION
	cat $PROM_SECTION >> $CONVERTED
	tail +$BEGIN_PROM $ORIGINAL >> $CONVERTED
	rm $PROM_SECTION
}

add_both_formats(){
	ORIGINAL=$1
	CONVERTED=$2
	KEY_VALUE_MAP=/tmp/key_value_map.$$
	BEGIN_PROM=$(nawk '/<maus>/ {print NR}' $ORIGINAL) 
	head -$BEGIN_PROM $ORIGINAL > $CONVERTED
	if grep $ORIGINAL $LDOM_GUESTS_RUNNING > /dev/null; then
		GUEST=$(guest_name $ORIGINAL)
		ldm ls-var $GUEST 2>/dev/null >$KEY_VALUE_MAP
	fi
	if [ ! -s $KEY_VALUE_MAP ]; then
		cat > $KEY_VALUE_MAP <<EOF
boot-command=boot
auto-boot?=true
keyboard-layout=US-English
guestUUID=$(echo $ORIGINAL | nawk -F / '{print $(NF-1)}')
boot-device=disk:a
EOF
	fi

	# add new format
	KEY_STRING='            <key xsi:type="xs:string" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">'
	VALUE_STRING='            <value xsi:type="xs:string" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">'
	echo "    <promVars>" >> $CONVERTED
	while read LINE
	do
		KEY="$(echo $LINE | cut -d= -f1)"
		echo "        <entry>" >> $CONVERTED
		echo "${KEY_STRING}${KEY}</key>" >> $CONVERTED
		echo "${VALUE_STRING}$(echo $LINE | sed "s/^${KEY}=//")</value>" >> $CONVERTED
		echo "        </entry>" >> $CONVERTED
	done < $KEY_VALUE_MAP
	echo "    </promVars>" >> $CONVERTED

	# add old format
	KEY_STRING='            <key>'
	VALUE_STRING='            <value>'
	echo "    <prom-vars>" >> $CONVERTED
	while read LINE
	do
		KEY="$(echo $LINE | cut -d= -f1)"
		echo "        <entries>" >> $CONVERTED
		echo "${KEY_STRING}${KEY}</key>" >> $CONVERTED
		echo "${VALUE_STRING}$(echo $LINE | sed "s/^${KEY}=//")</value>" >> $CONVERTED
		echo "        </entries>" >> $CONVERTED
	done < $KEY_VALUE_MAP
	echo "    </prom-vars>" >> $CONVERTED

	tail +$(( $BEGIN_PROM + 1 )) $ORIGINAL >> $CONVERTED
	rm $KEY_VALUE_MAP
}

exit_ok(){
	echo "OK: $1"
	rm -f $LDOM_GUESTS_ALL $LDOM_GUESTS_OLDFORMAT $LDOM_GUESTS_NEWFORMAT $LDOM_GUESTS_BOTHFORMATS $LDOM_GUESTS_BROKEN $LDOM_GUESTS_RUNNING $LDOM_GUESTS_OURS
	exit 0
}

# check for Control Domain
[ "${VIRT_TYPE}" == "ldom" ] || exit_ok "System is not a Control Domain, check not applicable"

scan_ldom_guests

if $DEBUG; then
	echo both formats
	cat $LDOM_GUESTS_BOTHFORMATS
	echo old format
	cat $LDOM_GUESTS_OLDFORMAT
	echo new format
	cat $LDOM_GUESTS_NEWFORMAT
	echo broken
	cat $LDOM_GUESTS_BROKEN
	echo running
	cat $LDOM_GUESTS_RUNNING
	echo ours
	cat $LDOM_GUESTS_OURS
fi

# 
# We will create a fixed version of the servercfg.xml file by adding both U2 and U3 style <prom-Vars> sections

if $FIX_NEEDED; then

	printf "\nERROR:\tFound old style or already broken configuration files of LDom Guests! This will result in\n"
	printf "ERROR:\tissues when restarting LDom Guests after upgrading the Agent to U3 or newer (Bug 16900331)!\n\n"
	printf "\tOCDoctor will create fixed versions of servercfg.xml to reduce impact of the issue:\n\n"

	for PATH_TO_SERVERCFG in $(cat $LDOM_GUESTS_OLDFORMAT)
	do
		IS_RUNNING_ON_THIS_CDOM=$(grep $PATH_TO_SERVERCFG $LDOM_GUESTS_RUNNING)
		if [ -f ${PATH_TO_SERVERCFG}.${FIXED} -a -z "$IS_RUNNING_ON_THIS_CDOM" ] ; then
			: # we will not update the existing file since the guest is not running on this CDOM
		else
			add_new_format ${PATH_TO_SERVERCFG} ${PATH_TO_SERVERCFG}.${FIXED}
		fi
		printf "\t$(guest_name $PATH_TO_SERVERCFG)\t${PATH_TO_SERVERCFG}.${FIXED}\n"
	done
	
	for PATH_TO_SERVERCFG in $(cat $LDOM_GUESTS_BROKEN)
	do
		IS_RUNNING_ON_THIS_CDOM=$(grep $PATH_TO_SERVERCFG $LDOM_GUESTS_RUNNING)
		if [ -f ${PATH_TO_SERVERCFG}.${FIXED} -a -z "$IS_RUNNING_ON_THIS_CDOM" ]; then
			: # we will not update the existing file since the guest is not running on this CDOM
		else
			add_both_formats ${PATH_TO_SERVERCFG} ${PATH_TO_SERVERCFG}.${FIXED}
		fi
		printf "\t$(guest_name $PATH_TO_SERVERCFG)\t${PATH_TO_SERVERCFG}.${FIXED}\n"
	done

	printf "\n\tManually replace each 'servercfg.xml' file with the fixed version\n"
	printf "\tor use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this\n\n"

	if [ "$OCDOCTOR_FIX" = "1" ];then
		printf "\nFixing these issues automatically...\n\n"
	        for PATH_TO_SERVERCFG in $(cat $LDOM_GUESTS_OLDFORMAT $LDOM_GUESTS_BROKEN)
		do
			cp ${PATH_TO_SERVERCFG}.${FIXED} ${PATH_TO_SERVERCFG}
			printf "\t$(guest_name $PATH_TO_SERVERCFG)\tfixed\n"
		done
		printf "\n\tAll servercfg.xml config files have been replaced with fixed ones!\n\n"
	fi	
else
	echo "OK: servercfg.xml files contain required <prom-vars> and/or <promVars> elements"
fi

rm -f $LDOM_GUESTS_ALL $LDOM_GUESTS_OLDFORMAT $LDOM_GUESTS_NEWFORMAT $LDOM_GUESTS_BOTHFORMATS $LDOM_GUESTS_BROKEN $LDOM_GUESTS_RUNNING $LDOM_GUESTS_OURS
