#!/bin/bash

# source useful functions
MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        . $MY_DIR/../../functions
fi

CheckInstalledPatchesRevision(){
        patchNumber="$1"
        patchRevision="$2"
	printm=$3
	installedPtchRevision=$(installed_rev_of_patch $patchNumber)
	if [ -z "$installedPtchRevision" ]; then
                $printm && echo "WARNING: Patch $patchNumber-$patchRevision is not installed."
                failure=1
        elif [ $installedPtchRevision -lt $patchRevision ]; then
                #### Older revision is installed
                $printm && echo "WARNING: Patch $patchNumber-$patchRevision (minimum revision) is not installed. Instead we have $patchNumber-$installedPtchRevision. Consider upgrading to whatever is the latest revision."
                failure=1
	else
		failure=0
		### Newer or equal revision
        fi
	if [ "$failure" = "1" ]; then
		$printm && echo "         Without this patch you may have issues creating zones on this machine."
		$printm && echo "         Look at 'NOTE 12' here:"
		$printm && echo "         https://updates.oracle.com/readme/119255-73"

	fi
        return $failure
}

REQ_PKG="SUNWlucfg"

UNAME=`uname`
if [ $UNAME = "Linux" ];then
	exit
else
	UNAMER=`uname -r`
	if [ "$UNAMER" = "5.10" ]; then
		ARCH=`uname -p`
		if [ "$ARCH" = "sparc" ]; then
			PROBLEMS=0
			CheckInstalledPatchesRevision "119254" "68" false 
			if [ $? -eq 0 ]; then
				CheckInstalledPatchesRevision "121428" "13" true
				[ $? -ne 0 ] && PROBLEMS=1
				CheckInstalledPatchesRevision "120235" "01" true
				[ $? -ne 0 ] && PROBLEMS=1
				CheckInstalledPatchesRevision "121430" "42" true
				[ $? -ne 0 ] && PROBLEMS=1
				/usr/bin/pkginfo -q $REQ_PKG
				if [ $? -ne 0 ]; then
					echo "WARNING: Package $REQ_PKG is not installed."
					echo "         Without this package you may have issues creating zones on this machine."
					echo "         Look at 'NOTE 12' here:"
					echo "         https://updates.oracle.com/readme/119254-73"
					PROBLEMS=1
				fi
				if [ "$PROBLEMS" = "0" ]; then
                                	echo "OK: All patches and packages are installed for creating zones"
				fi
			else
                                echo "OK: No issues creating zones with the current version of the patchadd patch"
			fi		
		else  ## x86
			PROBLEMS=0
			CheckInstalledPatchesRevision "119255" "68" false
                        if [ $? -eq 0 ]; then
				CheckInstalledPatchesRevision "121429" "13" true
				[ $? -ne 0 ] && PROBLEMS=1
				CheckInstalledPatchesRevision "120236" "01" true
				[ $? -ne 0 ] && PROBLEMS=1
				CheckInstalledPatchesRevision "121431" "43" true
				[ $? -ne 0 ] && PROBLEMS=1
				/usr/bin/pkginfo -q $REQ_PKG
                                if [ $? -ne 0 ]; then        
                                        echo "WARNING: Package $REQ_PKG is not installed."
                                        echo "         Without this package you may have issues creating zones on this machine."
                                        echo "         Look at 'NOTE 12' here:"
					echo "         https://updates.oracle.com/readme/119255-73"
                                        PROBLEMS=1        
                                fi
				if [ "$PROBLEMS" = "0" ]; then
                                	echo "OK: All patches and packages are installed for creating zones"
				fi
                        else
                                echo "OK: No issues creating zones with the current version of the patchadd patch"
                        fi
		fi
	else
		exit
	fi
fi




