#!/bin/bash
REL=`uname -r`
if [[ ! "$REL" = "5.10" ]]; then
	exit
fi
if [ -f "/opt/SUNWxvmoc/bin/ecadm" ]; then
        ## Don't run this on EC, because if EC is already installed, then a workaround must have already been applied
        ## Also EC has a T3 test
        exit
fi

if [ -f ./prereq/timeout.sh ]; then
	`./prereq/timeout.sh /usr/sbin/prtdiag >/dev/null 2>/dev/null`
	RETVAL=$?
else
	`../../prereq/timeout.sh /usr/sbin/prtdiag >/dev/null 2>/dev/null`
	RETVAL=$?
fi
if [ $RETVAL -eq 137 ]; then
	echo "ERROR: prtdiag seems to be freezing. This is a known Solaris issue (Bug 15394234). To fix this, try the following Solaris workaround:"
	echo ""
	echo "# svcadm restart picl"
	echo
	exit
else
	echo "OK: prtdiag doesn't hang"		#'
fi

#### Check for a T3 problem
#
# for reference:
#
# Bug 15781984 - SUNBT7157288 ADD THE ABILITY TO ENCRYPT AGENT DB PASSWORD FOR SPARC T3/S10U9
# Bug 15775907 - SUNBT7149666 AC INSTALL MAY "HANG" SPARC T3 IF CERTAIN PATCHES AND/OR WORKAROUND
#

OUTPUT=`/usr/sbin/prtdiag 2>/dev/null | grep " T3-"`
if [ ! "$OUTPUT" = "" ]; then			### we have a T3.
	if patchadd -p | grep '^Patch: 144500-19 ' >/dev/null; then
		# all is good, issue got fixed with Kernel Patch 144500-19
		echo "OK: Kernel Patch 144500-19 is installed, T3 system not impacted by bugs 15781984 & 15775907"
		exit 0
	fi
	RELEASE=`grep Solaris /etc/release | head -1 | cut -f2 -d_ | cut -f1 -dw`	## u1, u2 etc
	RELEASE=`echo ${RELEASE} | awk -F"u" '{print $2}'`		## 1, 2 etc
	if [[ $RELEASE -lt 10 ]]; then			### Only update 9 and below
		if [ -f /platform/sun4v/kernel/drv/n2cp.conf ]; then
			OUTPUT=`grep "n2cp-use-ulcwq=0" /platform/sun4v/kernel/drv/n2cp.conf`
		else
			OUTPUT=""
		fi
		if [ "$OUTPUT" = "" ]; then
			echo "WARNING: This is a T3 machine. You may be running into Bugs 15781984 & 15775907:"
			echo "         Ops Center may hang when trying to encrypt the local agent database password."
			echo ""
			echo "         If you don't care about the local agent password not being encrypted in the config"	#'
			echo "         file, just ignore this message. There are no issues working with the agent in that configuration."
			echo ""
			echo "         If you would like to encrypt the password, you will first have to apply the following T3 workaround:"
			echo "         The workaround is to edit '/platform/sun4v/kernel/drv/n2cp.conf'"
			echo "         and insert "n2cp-use-ulcwq=0" to the existing line."
			echo ""
			echo "         For example, if your current line says this:"
			echo "            ddi-forceattach=1 ddi-no-autodetach=1;"
			echo "         The new line should look like this:"
			echo "            ddi-forceattach=1 ddi-no-autodetach=1 n2cp-use-ulcwq=0;"
			echo ""
			echo "         Note that it is recommended to reboot the machine ('init 6') for this workaround to take effect."
			echo ""
			echo "         Once the '/platform/sun4v/kernel/drv/n2cp.conf' file is modified (and the machine is rebooted), you may"
			echo "         rerun the Doctor to apply the encryption to the local agent DB password".
			echo ""
		else
			echo "OK: This is a T3 machine and the workaround is applied to '/platform/sun4v/kernel/drv/n2cp.conf'"
			if [ ! -f /var/opt/sun/xvm/vc-db.properties ]; then
				echo "ERROR: Could not find /var/opt/sun/xvm/vc-db.properties"
				echo ""
				exit
			fi
			#### Check if password is encrypted
			OUTPUT=`grep "vc_agent.connection.password.encrypted=false" /var/opt/sun/xvm/vc-db.properties 2>/dev/null`
			if [ "$OUTPUT" = "" ]; then
				echo "OK: Agent database password is encrypted in /var/opt/sun/xvm/vc-db.properties"
			else
				echo "WARNING: Agent database password is not encrypted in /var/opt/sun/xvm/vc-db.properties"
				if [ "$OCDOCTOR_FIX" = "1" ];then
					if [ "$UIDOCTOR" = "1" ]; then
						echo ""
						echo "WARNING: Cannot auto fix this when running from the Ops Center UI, as the agent will shutdown midway."
						echo ""
						echo "Please run '/var/opt/sun/xvm/OCDoctor/OCDoctor.sh --troubleshoot --fix' on the target machine directly."
						echo ""
						exit
					fi
					echo "Trying to fix this issue automatically..."
					echo "OK: Shutting down the agent..."
					/opt/SUNWxvmoc/bin/agentadm stop
					echo ""
					echo "OK: Obtaining unencrypted password..."
					PWORD=`grep vc_agent.connection.password= /var/opt/sun/xvm/vc-db.properties | sed 's/vc_agent.connection.password=//g'`
					
					echo "OK: Encrypting the password..."
					echo "If this freezes, you may not have applied the T3 workaround properly or did not reboot the machine yet"
					echo "To resolve, 'init 6' the machine and rerun the Doctor."
					JAVABIN="/usr/jdk/instances/jdk1.7.0/bin/java"
					if [ -x /usr/jdk/instances/jdk1.6.0/bin/java ]; then
						JAVABIN="/usr/jdk/instances/jdk1.6.0/bin/java"
					fi
					if [ ! -x $JAVABIN ]; then
						echo "ERROR: Could not find $JAVABIN"
						echo ""
						exit
					fi
					ENCRYPTED_PWORD=`echo $PWORD | $JAVABIN -classpath /opt/sun/n1gc/lib/domain.jar:/opt/sun/n1gc/lib/svccommon.jar com.sun.xvm.services.common.impl.CipherCLI Encrypt-Password`
					if [ "$ENCRYPTED_PWORD" = "" ]; then
						echo "ERROR: Unable to obtain encrypted password"
						echo ""
						exit
					fi
					echo "OK: Encryption is done"
					grep -v  vc_agent.connection.password /var/opt/sun/xvm/vc-db.properties > /tmp/vc-db.properties		### Create tmp file without the vc_agent.connection.password* properties 
					echo "vc_agent.connection.password=$ENCRYPTED_PWORD" >> /tmp/vc-db.properties
					echo "vc_agent.connection.password.encrypted=true" >> /tmp/vc-db.properties
					echo "OK: Saving /var/opt/sun/xvm/vc-db.properties  as  /var/opt/sun/xvm/vc-db.properties.OCDoctor.save.$$"
					cp -p /var/opt/sun/xvm/vc-db.properties /var/opt/sun/xvm/vc-db.properties.OCDoctor.save.$$
					cat /tmp/vc-db.properties > /var/opt/sun/xvm/vc-db.properties		### preserve original permissions
					rm -f /tmp/vc-db.properties
					echo "OK: Modified config file. Starting agent..."
					/opt/SUNWxvmoc/bin/agentadm start
					echo ""
					echo "OK: all done with Agent DB password encryption."
					echo ""
				else
					echo "         To encrypt it, run the the Doctor with the '--fix'":
					echo "# ./OCDoctor.sh --troubleshoot --fix"
					echo ""
					echo "Note #1: The agent will be shutdown during the process, so make sure no jobs are running on it"
					echo "Note #2: Do not run this from the Web UI as the agent will shutdown. Please run this on the machine itself."
					echo ""
				fi
			fi
		fi
	else
		echo "OK: This is a T3 machine but you're using Solaris 10 U${RELEASE}, not affected by Bug 15676804"
	fi
else
	echo "OK: This is not a T3 machine (if it was then a workaround may be needed)"
fi
