#!/bin/bash
#
# On S11 Agents, the publisher should point to the proxy
# otherwise, it can cause upgrade issues
#

if [ -f /opt/SUNWxvmoc/bin/ecadm -o -f /opt/SUNWxvmoc/bin/proxyadm ]; then
        # in case this is an EC or PC, we do not run this check
        exit
fi

if [ "$(uname)" = "SunOS" -a "$(uname -r | cut -d. -f2)" -ge 11 ]; then

	FIX_NEEDED=false

	PROXY_IP_TEMP=$(grep '^url=' /var/opt/sun/xvm/persistence/scn-agent/connection.properties 2>/dev/null | tr '\\:/' '   '| nawk '{print $2}')
	if [ -n "$PROXY_IP_TEMP" ]; then
		PROXY_IP=$(getent hosts $PROXY_IP_TEMP | nawk '{print $1}' | sort -u | head -1)
	else
		echo
		echo "ERROR: Unable to determine name/IP of Proxy Controller"
		echo
		exit
	fi

	for publisher in solaris opscenter cacao mp-re
	do
		PUBLISHER_IP_TEMP=$(pkg publisher $publisher 2>/dev/null | nawk '/Origin URI:/'| tr '/:' '  '| nawk '{print $4}')
		if [ -n "$PUBLISHER_IP_TEMP" ]; then
			PUBLISHER_IP=$(getent hosts $PUBLISHER_IP_TEMP | nawk '{print $1}' | sort -u | head -1)
			if [ "$PROXY_IP" = "$PUBLISHER_IP" ]; then
				echo "OK: IPS publisher $publisher is pointing to Proxy Controller"
			else
				echo
				echo "WARNING: IPS publisher '$publisher' is not pointing to Proxy Controller"
				echo "         Publisher-IP=$PUBLISHER_IP Proxy-IP=$PROXY_IP"
				FIX_NEEDED=true
			fi
		else
			echo
			echo "ERROR: Unable to determine name/IP of publisher '$publisher'"
			echo
		fi
	done

	if $FIX_NEEDED; then
		if [ "$OCDOCTOR_FIX" = "1" ]; then
			echo "Trying to automatically fix this..."
			/var/opt/sun/xvm/utils/install_ips_ac.sh -P $PROXY_IP
			echo "done"
			echo
		else
			echo
			echo "Do not try to upgrade the Agent while the system is in this state!"
			echo
			echo "Run the command '/var/opt/sun/xvm/utils/install_ips_ac.sh -P $PROXY_IP' to fix the issue"
			echo
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			echo
		fi
	fi
fi
