#!/bin/bash
#
# OC Agent is made out of two components, the cacao agent and the UCE agent
#
# The UCE Agent does not run on Solaris 11
#
# Since Ops Center 12.3.1 the UCE Agent will no longer run on OEL/RHEL 6.6, 6.7 & 7.x
#
# Up to 12.3.0, OEL/RHEL 6.6, 6.7 & 7.x were unsupported OS versions
#

UNAME=`uname`
if [ $UNAME = "Linux" ];then
        RHELVERFILE="/etc/redhat-release"
        if [ -f "$RHELVERFILE" ]; then
                MAJOR_REL=$( awk '/^.* Linux Server release / {print $7}' $RHELVERFILE | cut -d. -f1)
		MINOR_REL=$(awk '/^.* Linux Server release / {print $7}' $RHELVERFILE | cut -d. -f2)
                if [ $MAJOR_REL -ge 7 ] || [ $MAJOR_REL -eq 6 -a $MINOR_REL -ge 6 ]; then
			# UCE Agent will not run
			exit
                fi
        fi

	UCERCLINK="/opt/sun/scn/update-agent/bin/.uce.rc"
	UCERC="/var/opt/sun/scn/update-agent/bin/.uce.rc"
else
        OS_REL=`uname -r | cut -d. -f2`
        if [ "$OS_REL" -ge 11 ]; then
		# UCE Agent will not run
		exit
        fi

	UCERCLINK="/usr/lib/scn/update-agent/bin/.uce.rc"
	UCERC="/var/scn/update-agent/bin/.uce.rc"
fi

#### Actual test ####
if [ -f $UCERC ]; then
	echo "OK: .uce.rc exists"
else
	echo "ERROR: Did not find $UCERC, consider finding a backup file in this folder"
	echo "       or reinstall the agent."
	echo ""
	exit
fi
if [ -L $UCERCLINK ]; then
	echo "OK: .uce.rc symbolic link exists"
else
	echo "ERROR: Did not find the symbolic link $UCERCLINK."
	echo "       It needs to point to $UCERC."
	echo ""
fi
