#!/bin/bash

MEM_LIMIT=750000  # maximum memory limit n KB allowed for the agent 

OS=$(uname)

if [ "${OS}" == "SunOS" ]
then
    CACAOADM=/usr/sbin/cacaoadm
    ARGS_OPTION="-o args="
    SIZE_TIME_OPTION="-o vsz="
else
    CACAOADM=/opt/sun/cacao2/bin/cacaoadm
    ARGS_OPTION="-o command="
    SIZE_TIME_OPTION="-o vsz="
fi

if [ -x $CACAOADM ]
then
    if $CACAOADM list-instances | grep -w scn-agent > /dev/null
    then
        PIDs=$( $CACAOADM status -i scn-agent | grep '^[1-9]' )
        if [ -z "${PIDs}" ]
        then
            echo "ERROR: Ops Center Agent is not running." 1>&2
            exit 1
        fi
    else
        echo "ERROR: No Ops Center Agent configured." 1>&2
        exit 1
    fi
else
    echo "ERROR: Ops Center Agent is not installed." 1>&2
    exit 1
fi   

for i in ${PIDs}
do
  PID=$(ps -p $i $ARGS_OPTION | egrep 'java|cvm')
  [ -n "${PID}" ] && AGENT_PID=$i  
done

if [ -z "${AGENT_PID}" ]; then
    echo "ERROR: Unable to determine cacao agent process id." 1>&2
    exit 1
fi

if [ "${OS}" == "SunOS" ]
then
    VERSION=$(/usr/bin/pkgparam SUNWscn-agentfacade-u VERSION | awk -F"," '{print $1}')
else
    VERSION=$(rpm -q sun-scn-agentfacade-u | awk -F"u-" '{print $2}' | tr - . )
fi

MEM_USED=$(ps -p $AGENT_PID $SIZE_TIME_OPTION)

if [ "$MEM_USED" -gt $MEM_LIMIT ];then
	echo "WARNING: Agent is using $MEM_USED KB of main memory !"
	echo "         The high memory footprint is caused by a memory leak. Restart the agent to fix this !"
        echo
        echo "         It is recommended to restart agents on a regular schedule, e.g. weekly or monthly."
        echo "         OCDoctor/toolbox contains the script 'restart_agent.sh' which can be used as Action"
        echo "         Script to perform the restart as part of an OS Update Job."
        echo
else
	echo "OK: Memory usage of agent is fine."
fi
