#!/bin/bash

ZSTATADM=/opt/sun/xvm/lib/zstat/zstatadm

CONF=/etc/opt/sun/oc/zstat.conf

UNAME=`uname`
if [ ! -f $ZSTATADM ];then
        # zstatadm exists only in Solaris 10 Global Zones
	exit
fi

#### Check version ####
MY_DIR=`dirname $0`
source $MY_DIR/../../functions
get_agent_version ""          ### Provide VERSIONNUM
if [ $VERSIONNUM -gt "2501191" ];then               #### Is this newer than 1171?
        echo "OK: zstatadm is already the latest"
        exit            #### Only applies to 1191 and below
fi

PID_ZSTATD=`pgrep zstatd`
if [ -z "$PID_ZSTATD" ]; then
       echo "WARNING: zstat daemon is not running"
       exit
fi

if ptree $PID_ZSTATD | grep '<defunct>' >/dev/null
then
       echo "ERROR: The command 'zstatadm' is hanging, which is causing an unlimited growth" 
       echo "ERROR: of file /var/adm/exacct/zstat-process ! Current size: " `du -h /var/adm/exacct/zstat-process | awk '{print $1}'`
       if [ "$OCDOCTOR_FIX" = "1" ];then
               echo ""
               echo "  Fixing this automatically..."
               echo "  Replacing $ZSTATADM with an improved version."
               cp `dirname $0`/../toolbox/zstatadm $ZSTATADM
               echo "  Restarting SMF service 'zstat'."
               svcadm restart zstat
               echo "  Done."
               echo ""
       else
               echo ""
               echo "  To repair this perform the following:"
               echo ""
               echo "  Replace the script '$ZSTATADM' with an improved version which can be"
               echo "  found in OC Doctor's toolbox. Finally run 'svcadm restart zstat' to restart the zstat service."
               echo ""
       fi
else
       echo "OK: zstatadm is working properly"
fi
