#!/bin/bash
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	WGET="/usr/bin/wget --timeout=10 --tries 3"
else
	WGET="/usr/sfw/bin/wget --timeout=10 --tries 3"
fi

################ Figure out if wget supports 'no-check-certificate' flag ########################
CERTSUPPORT=`$WGET --help 2>/dev/null | grep no-check-certificate`
if [ "$CERTSUPPORT" = "" ]; then
	CERTFLAG=""
else
	CERTFLAG="--no-check-certificate"
fi


LINK="https://localhost:8002/cgi-bin/auth.cgi?action_type=get_credential_only"
OUTFILE="/var/tmp/test-auth-cgi.out"

OUTPUT=`$WGET --no-proxy ${CERTFLAG} $LINK -O $OUTFILE 2>&1`
RETVAL=$?
DISPLAYOUTPUT=`printf "%s\n" "$OUTPUT" | egrep -v "Certificate verification error for|Self-signed certificate encountered|cannot verify|Unable to locally verify the issuer|certificate common name"`
if [ $RETVAL -ne 0 ]; then
	echo "ERROR: Could not run 'wget $LINK', output:"
	printf " ${DISPLAYOUTPUT}\n"
	echo ""
	exit
fi
OUTPUT=`file $OUTFILE | grep -i xml`
if [ "$OUTPUT" = "" ]; then
	echo "ERROR: Running 'wget $LINK' should return an XML file but it did not."
	echo "       Instead it returned the file $OUTFILE"
	echo ""
	exit
else
	echo "OK: auth.cgi returns XML"
fi
rm -f $OUTFILE
