#!/bin/bash
TESTUSER=scncon
su - $TESTUSER -c "/bin/true" >/dev/null 2>/dev/null
if [ $? -ne 0 ]; then
        ### if this is Linux and shell is /sbin/nologin, then we're OK
        UNAME=`uname`
        if [ "$UNAME" = "Linux" ]; then
                SCNSHELL=`grep "^${TESTUSER}" /etc/passwd | awk -F":" '{print $7}'`
                if [ "$SCNSHELL" = "/sbin/nologin" ]; then
                        echo "OK: $TESTUSER shell is /sbin/nologin"
                else
                        echo "ERROR: Can't su into user $TESTUSER"
                fi
        else
                echo "ERROR: Can't su into user $TESTUSER"
        fi
else
        printf "OK: User $TESTUSER is not locked\n"
fi
if [ -f /etc/shadow ]; then
	PASSFILE=/etc/shadow
else
	PASSFILE=/etc/passwd		### Some Linux
fi
SHADOWPASS=`cat $PASSFILE | grep "^${TESTUSER}" | awk -F":" '{print $2}'`
if [ "$SHADOWPASS" = "" ]; then
        echo "ERROR: Couldn't find user $TESTUSER in $PASSFILE. Do you have this user configured at all?"
        echo ""
        exit
fi
SALT=`cat $PASSFILE | grep "^${TESTUSER}" | awk -F":" '{print $2}' | cut -c 1-2`
if [ "$SALT" = "" ]; then
        echo "ERROR: Couldn't get SALT for user $TESTUSER from $PASSFILE."
        echo ""
        exit
fi
if [ -e /var/opt/sun/xvm/persistence/scn-satellite/satellite.properties ]; then
	SCNPASS=`cat /var/opt/sun/xvm/persistence/scn-satellite/satellite.properties  | grep scncon | awk -F"=" '{print $2}'`
	if [ "$SALT" = "\$2" ]; then
		echo "Notice: $PASSFILE is using Blowfish encryption. If you can't login, run 'passwd $TESTUSER' and type in the password '$SCNPASS'"
		exit
	fi
	if [ "$SALT" = "\$5" ]; then
		echo "Notice: $PASSFILE is using SHA-256 encryption. If you can't login, run 'passwd $TESTUSER' and type in the password '$SCNPASS'"
		exit
	fi
	if [ "$SALT" = "\$6" ]; then
		echo "Notice: $PASSFILE is using SHA-512 encryption. If you can't login, run 'passwd $TESTUSER' and type in the password '$SCNPASS'"	#'
		exit
	fi
	UNAME=`uname`
	if [ "$UNAME" = "Linux" ]; then
		if [ "$SALT" = "\$1" ]; then
			### MD5 password
			MD5SALT=`cat $PASSFILE | grep "^${TESTUSER}" | awk -F":" '{print $2}' | awk -F"\$" '{print $3}'`
			if [ "$MD5SALT" = "" ]; then
				echo "ERROR: Unable to obtain MD5 salt from $PASSFILE for user $TESTUSER"
				echo
				exit 1
			fi
			OPENSSLPASS=`/usr/bin/openssl passwd -1 -salt $MD5SALT $SCNPASS`
		else
			### Original password
			OPENSSLPASS=`/usr/bin/openssl passwd -crypt -salt $SALT $SCNPASS`
		fi
	else
		OPENSSLPASS=`/usr/sfw/bin/openssl passwd -crypt -salt $SALT $SCNPASS`
	fi
	if [ "$OPENSSLPASS" = "$SHADOWPASS" ];then
		echo "OK: $TESTUSER Password is configured properly"
	else
		echo "ERROR: $TESTUSER password in /var/opt/sun/xvm/persistence/scn-satellite/satellite.properties doesnt match $PASSFILE"
	fi
else
        echo ERROR: File not found: /var/opt/sun/xvm/persistence/scn-satellite/satellite.properties
fi
