#!/usr/bin/ksh

#
# checking for integrity of the Agent installation
#

UNAME=`uname`
if [ $UNAME = "Linux" ];then
        CHECK=0
        cat <<!EOF! | while read file; do
		sun-scn-agentfacade-r
		sun-scn-agentfacade-u
		sun-scnjobmgr-agent
		sun-scnjobmgr-agent-config
		sun-scn-update-agent
		sun-scn-update-agent-r
		sun-scnconnmgt
		sun-scnconnmgt-ra
		sun-cacaome
		sun-servicetag
		sun-jdmk-runtime
		sun-jdmk-runtime-jmx
		sun-n1hss-agentdm
		sun-n1hss-agentdm-config
		sun-scn-update-util
		sun-cacaort
		sun-scn-agent-utils
		sun-cacaocrews
!EOF!
        OUTPUT=`rpm -q $file`
        if [[ $? -eq 0 ]]; then
                DONOTHING=1
	else
                if [[ $CHECK -eq 0 ]]; then               ### Only print ERROR once
                        echo "ERROR while checking for agent RPM integrity:"
                fi
                echo "RPM $file is not installed properly"
                CHECK=1
        fi
        done
        if [[ $CHECK -eq 0 ]]; then
                echo "OK: All agent RPMs are installed properly"
        else
                echo "ERROR: The RPMs above are not installed properly (missing from 'rpm -q'), consider reinstallation."
                echo "       It can also be that those RPMs are not needed. Please report this to Sun Support to determine this."
                echo ""
        fi

        exit $CHECK



else                    ####### Solaris

CheckInstalledPatchesRevision(){
        patchNumber="$1"
        patchRevision="$2"
        chkPatch=`showrev -p | grep "Patch: $patchNumber"`
        if [ "$chkPatch" = "" ]; then
                chkPatch=`showrev -p | grep $patchNumber`
                if [ "$chkPatch" = "" ]; then
                        echo "ERROR: Patch $patchNumber-$patchRevision is not installed properly"
                        failure=1
                fi
        else
                installedPtchRevision=`showrev -p | grep "Patch: $patchNumber" | awk '{print $2}' | sort | tail -1 | awk -F"-" '{print $2}'`
                if [ $installedPtchRevision -lt $patchRevision ]; then
                        #### Older revision is installed
                        echo "ERROR: Patch $patchNumber-$patchRevision is not installed properly. Instead we have $patchNumber-$installedPtchRevision"
                        failure=1
                fi
        fi
        return $failure
}

	CHECK=0
	cat <<!EOF! | while read file; do
		SUNWcacaocrews
		SUNWcacaome
		SUNWcacaort
		SUNWn1hss-agentdm
		SUNWscn-agentfacade-r
		SUNWscn-agentfacade-u
		SUNWscn-update-agent
		SUNWscn-update-agent-r
		SUNWscn-update-util
		SUNWscn-agent-utils
		SUNWscnjobmgr-agent
		SUNWscnconnmgt
		SUNWscnconnmgt-ra
!EOF!
	pkginfo $file >/dev/null 2>&1
	if [[ $? -eq 0 ]] ; then
		DONOTHING=1
	else
		if [[ $CHECK -eq 0 ]]; then		### Only print ERROR once
			echo "ERROR while checking for agent packages integrity:"
		fi
		echo "Package $file is not installed properly"
		CHECK=1
	fi
	done

	REL=`uname -r`
	if [[ "$REL" = "5.10" ]]; then
		#### Check for Solaris 10 packages ###
		cat <<!EOF! | while read file; do
			SUNWj6rt
!EOF!
		pkginfo $file >/dev/null 2>&1
		if [[ $? -eq 0 ]] ; then
			DONOTHING=1
		else
			if [[ $CHECK -eq 0 ]]; then               ### Only print ERROR once
				echo "ERROR while checking for agent packages integrity:"
			fi
			echo "Package $file is not installed properly"
			CHECK=1
		fi
		done
	fi 		### End of Solaris 10 pkgs ###


	if [[ $CHECK -eq 0 ]]; then
		echo "OK: All agent packages are installed properly"
	else
		echo "ERROR: The agent packages above are not installed properly (missing from pkginfo), consider reinstallation."	
		echo "       It can also be that those packages are not needed. Please report this to Sun Support to determine this."
		echo ""
	fi


	####### CHECK PATCHES #######

	if [[ "$REL" = "5.10" ]]; then
		ARCH=`uname -p`
		if [[ "$ARCH" = "sparc" ]]; then
			failure=0
			CheckInstalledPatchesRevision "120900" "04"
			CheckInstalledPatchesRevision "119254" "67"
			CheckInstalledPatchesRevision "121133" "02"
			CheckInstalledPatchesRevision "119042" "09"
			CheckInstalledPatchesRevision "121901" "02"
			CheckInstalledPatchesRevision "125731" "05"
			CheckInstalledPatchesRevision "137321" "01"
			if [ $failure -eq 0 ]; then
				echo "OK: All agent patches are installed properly"
			else
				echo "ERROR: The patches above were not installed properly during the agent install."
				echo "       Check the agent installation logs."
				echo ""
				CHECK=1
			fi
		else			## X86
			failure=0
                        CheckInstalledPatchesRevision "120901" "03"
                        CheckInstalledPatchesRevision "121334" "04"
                        CheckInstalledPatchesRevision "119255" "67"
                        CheckInstalledPatchesRevision "119043" "09"
                        CheckInstalledPatchesRevision "121902" "02"
                        CheckInstalledPatchesRevision "137322" "01"
                        CheckInstalledPatchesRevision "125732" "05"
                        if [ $failure -eq 0 ]; then
                                echo "OK: All agent patches are installed properly"
                        else
                                echo "ERROR: The patches above were not installed properly during the agent install."
                                echo "       Check the agent installation logs."
                                echo ""
                                CHECK=1
                        fi

		fi
	fi
	if [[ "$REL" = "5.8" ]]; then
        	failure=0
                CheckInstalledPatchesRevision "110380" "06"
                CheckInstalledPatchesRevision "110165" "05"
                CheckInstalledPatchesRevision "112097" "08"
                CheckInstalledPatchesRevision "110934" "26"
                if [ $failure -eq 0 ]; then
                        echo "OK: All agent patches are installed properly"
                else
                        echo "ERROR: The patches above were not installed properly during the agent install."
                        echo "       Check the agent installation logs."
                        echo ""
                        CHECK=1
                fi
	fi



	exit $CHECK
fi		### End of Solaris



