#!/bin/bash

### This script collects some basic statistics ###

export PATH=/usr/sbin:/usr/bin:$PATH
export LD_LIBRARY_PATH=/usr/lib:/lib

DEBUG=false

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	DB_BIN="/opt/sun/scs/sbin/db_tool.pl"
	WGET="/usr/bin/wget"
	SC_CONSOLE="/usr/bin/sc-console"
	OPENSSL=/usr/bin/openssl
else
	DB_BIN="/opt/SUNWscs/sbin/db_tool.pl"
	WGET="/usr/sfw/bin/wget"
	SC_CONSOLE="/usr/bin/sc-console"
	OPENSSL=/usr/sfw/bin/openssl
fi

if [ ! -x $WGET ]; then
	$DEBUG && echo "No $WGET"
	exit
fi

if [ ! -x $OPENSSL ]; then
	$DEBUG && echo "No $OPENSSL"
	exit
fi

if [ -f /var/opt/sun/xvm/no-oracle-stats ] || [ -f /no-oracle-stats ] || [ -f /root/no-oracle-stats ]; then
	echo "OK: Basic statistic was not collected or uploaded"
	exit 0
fi

CONNPROP="/var/opt/sun/xvm/persistence/scn-satellite/connection.properties"
if [ -f $CONNPROP ]; then
	#### Check if we're in Connected mode
	OUTPUT=`grep "^disconnected" ${CONNPROP} 2>/dev/null`
	if [ "$OUTPUT" = "" ]; then			### likely an empty file, means not configured yet
		$DEBUG && echo "Empty $CONNPROP"
		exit 0
	fi
	PROXYHOST=`grep proxy-host $CONNPROP 2>/dev/null| awk -F"=" '{print $2}' 2>/dev/null`
	PROXYPORT=`grep proxy-port $CONNPROP 2>/dev/null| awk -F"=" '{print $2}' 2>/dev/null`
	PROXYUSER=`grep proxy-username $CONNPROP 2>/dev/null| awk -F"=" '{print $2}' 2>/dev/null`
	PROXYPASS=`grep proxy-password $CONNPROP 2>/dev/null | cut -c16- 2>/dev/null`
	if [ ! "$PROXYHOST" = "" ] && [ ! "$PROXYPORT" = "" ]; then
		export http_proxy="$PROXYHOST:$PROXYPORT"
		export https_proxy="$PROXYHOST:$PROXYPORT"
	fi
else
	$DEBUG && echo "No $CONNPROP"
	exit 0
fi

##### Check if we're in disconnected mode
if [ "$UNAME" = "Linux" ];then
	if [ -f /var/opt/sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc ]; then
		UCE_RC="/var/opt/sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc"
	else
		UCE_RC="/usr/local/uce/server/cgi-bin/.uce.rc"
	fi
else
	if [ -f /var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc ]; then
		UCE_RC="/var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc"
	else
		UCE_RC="/opt/SUNWuce/server/cgi-bin/.uce.rc"
	fi
fi
OUTPUT=`grep "general\.server_name" $UCE_RC 2>/dev/null| awk -F"\"" '{print $2}' 2>/dev/null | grep -v "\.oracle\.com" 2>/dev/null | grep -v "\.sun\.com" 2>/dev/null`
### if set to anything but oracle.com or sun.com, it's disconnected
if [ "$OUTPUT" != "" ]; then
	$DEBUG && echo "Disconnected"
	exit 0
fi

################ Figure out if wget supports 'no-check-certificate' flag ########################
CERTSUPPORT=`$WGET --help 2>/dev/null | grep no-check-certificate`
if [ "$CERTSUPPORT" = "" ]; then
	CERTFLAG=""
else
	CERTFLAG="--no-check-certificate"
fi

get_token() {
	TMPFILE="/var/tmp/doctor-out-tmp.$$"
	rm -f $TMPFILE > /dev/null 2>/dev/null
	rm -f /var/tmp/doctor-out-tmp.* > /dev/null 2>/dev/null
	##### Get token ###
	if [ "$PROXYUSER" = "" ]; then
		$WGET $CERTFLAG -qq --timeout=10 --tries 2 --save-cookies /var/tmp/java-cookie.bin --keep-session-cookies  https://java.net/projects/oc-doctor/forums/updates/topics/new -O $TMPFILE 2>/dev/null
	else
		eval "$WGET $CERTFLAG -qq --timeout=10 --tries 2 --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --save-cookies /var/tmp/java-cookie.bin --keep-session-cookies  https://java.net/projects/oc-doctor/forums/updates/topics/new -O $TMPFILE 2>/dev/null"
	fi
	TOKEN=`cat $TMPFILE 2>/dev/null | grep "^var page" 2>/dev/null| awk -F"\"" '{print $4}' 2>/dev/null`
	##### End of 'get Token' #####
	rm -f $TMPFILE > /dev/null 2>/dev/null
}


if [ -f $DB_BIN ]; then

	### Check if DB is running ###
        OUTPUT=`$DB_BIN status 2>/dev/null | grep running 2>/dev/null| awk '{printf("%s %s %s\n",$2,$3,$4)}' 2>/dev/null`
        if [ ! "$OUTPUT" = "postmaster is running" ]; then
                exit
        fi

	### Total agents ###
	echo "select count(agent_ip) from agent_table" | $DB_BIN psql > /var/tmp/db.out.$$ 2>/dev/null
	VERIFY=`grep "(1 row)" /var/tmp/db.out.$$ 2>/dev/null`
	TOTAL_AGENTS=""
	if [ "$VERIFY" = "(1 row)" ]; then
		TOTAL_AGENTS=`head -3 /var/tmp/db.out.$$ 2>/dev/null | tail -1 | awk '{print $1}' 2>/dev/null`
	fi
	rm -f /var/tmp/db.out.$$

	### username ###
	echo "select authentication_id,authentication_user from download_authentication_table where authentication_id='XVM_OPS_AUTH_ID'" | $DB_BIN psql > /var/tmp/db.out.$$ 2>/dev/null
	VERIFY=`grep "(1 row)" /var/tmp/db.out.$$ 2>/dev/null`
	USERNAME=""
	if [ "$VERIFY" = "(1 row)" ]; then
		USERNAME=`grep XVM_OPS_AUTH_ID /var/tmp/db.out.$$ 2>/dev/null | awk -F"|" '{print $2}' 2>/dev/null | awk '{print $1}' 2>/dev/null`
	fi
	if [ "$USERNAME" = "" ]; then
		$DEBUG && echo Empty USERNAME
		exit 0
	fi
	rm -f /var/tmp/db.out.$$

	### OS ###
	echo "select class_name,mbean_interface from hd_resource" | $DB_BIN psql 2>/dev/null | grep "com.sun.hss.domain.SkeletalManagedResourceMXBean" 2>/dev/null> /var/tmp/doctor-out.$$
	TOTAL_OS=`grep "com.sun.hss.domain.OperatingSystemMXBean" /var/tmp/doctor-out.$$ 2>/dev/null| wc -l | awk '{print $1}' 2>/dev/null`
	TOTAL_SERVERS=`grep "com.sun.hss.domain.ServerMXBean" /var/tmp/doctor-out.$$ 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
	TOTAL_LDOMS=`grep "com.sun.hss.domain.xvmserver.XVMServerMXBean" /var/tmp/doctor-out.$$ 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`

	### Unique string ###
	UNIQS=""
	if [ -f $SC_CONSOLE ]; then
		UNIQS=`$SC_CONSOLE list-connections |grep "^localhost" 2>/dev/null| awk -F":" '{printf("%s:%s",$6,$7)}' 2>/dev/null`
	fi
	MAC=""
	if [ "$UNAME" = "Linux" ]; then
		MAC=`ifconfig -a 2>/dev/null| grep HWaddr 2>/dev/null | head -1 2>/dev/null| awk -F"HWaddr" '{print $2}' 2>/dev/null | awk '{print $1}' 2>/dev/null | sed 's/:/_/g' 2>/dev/null`
	else
		MAC=`ifconfig -a 2>/dev/null| grep ether 2>/dev/null |head -1 2>/dev/null| awk '{print $2}' 2>/dev/null| sed 's/:/_/g' 2>/dev/null`
	fi
	

	### Version ###
	VERSIONFILE="/n1gc-setup/.version.properties"
	ECVERSION=""
	if [ -f $VERSIONFILE ]; then
		ECVERSION=`cat $VERSIONFILE | grep "product\.version=" 2>/dev/null | awk -F"=" '{print $2}' 2>/dev/null`
	fi
		
	### Time ###
	GDATE=`date "+%Y-%m-%d" 2>/dev/null`
	GTIME=`date "+%H:%M:%S" 2>/dev/null`

	### EC_OS and HARDWARE ###
	EC_HARDWARE=`uname -p`
	EC_OS=`uname -s`
	
	### Job breakdown ###
	JOBS_TOTAL=`echo "select count(job_id) from scn_job;" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS1=`echo "select count(job_id) from scn_job where name='UpdateProvisioningJob';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS2=`echo "select count(job_id) from scn_job where name='LocalContentJob';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS3=`echo "select count(job_id) from scn_job where name='ActivateBootEnvironmentJob';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS4=`echo "select count(job_id) from scn_job where name='NewBARReportJob';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS5=`echo "select count(job_id) from scn_job where name='ReportGenerationJob';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS6=`echo "select count(job_id) from scn_job where name='Cold Migration Job';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS7=`echo "select count(job_id) from scn_job where name='WarmMigrationJob';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS8=`echo "select count(job_id) from scn_job where name='Create-DeploymentPlan';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS9=`echo "select count(job_id) from scn_job where name='Execute-DeploymentPlan';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	JOBS10=`echo "select count(job_id) from scn_job where name='Create guest';" | $DB_BIN psql 2>/dev/null | head -3 | tail -1 | awk '{print $1}' 2>/dev/null`
	

	#########################################

	MESSAGE="|d2|${UNIQS}|${MAC}|${GDATE}|${GTIME}|${ECVERSION}|${EC_OS}|${EC_HARDWARE}|${TOTAL_AGENTS}|${USERNAME}";
	MESSAGE="${MESSAGE}|${TOTAL_OS}|${TOTAL_SERVERS}|${TOTAL_LDOMS}|${JOBS_TOTAL}|${JOBS1}|${JOBS2}|${JOBS3}|${JOBS4}"
	MESSAGE="${MESSAGE}|${JOBS5}|${JOBS6}|${JOBS7}|${JOBS8}|${JOBS9}|${JOBS10}"
	#echo "$MESSAGE"
	echo "$MESSAGE" | $OPENSSL enc -aes128 -a -A -salt -pass pass:AAdYQpQy5ltX -out /var/tmp/doctor-message.$$ >/dev/null 2>/dev/null
	if [ -s /var/tmp/doctor-message.$$ ]; then
		MESSAGE=`cat /var/tmp/doctor-message.$$`
		MESSAGE=`echo "$MESSAGE" | sed 's/+/%2B/g' 2>/dev/null`
	else
		MESSAGE="Empty_harvester_message_file"
	fi
	rm -f /var/tmp/doctor-message.$$ >/dev/null 2>/dev/null
	rm -f /var/tmp/java-cookie.bin > /dev/null 2>/dev/null
	
	get_token ""
	if [ "$TOKEN" = "" ]; then
		get_token ""
	fi
	if [ "$TOKEN" = "" ]; then
		get_token ""
	fi
	if [ ! "$TOKEN" = "" ]; then
		if [ "$PROXYUSER" = "" ]; then
			$WGET $CERTFLAG -qq --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data="authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D2&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}" "https://java.net/projects/oc-doctor/forums/updates/topics" -O /dev/null >/dev/null 2>/dev/null
			RETVAL=$?
		else
			eval "$WGET $CERTFLAG -qq --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data='authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D2&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}' 'https://java.net/projects/oc-doctor/forums/updates/topics' -O /dev/null >/dev/null 2>/dev/null"
			RETVAL=$?
		fi
		if [ $RETVAL -ne 0 ]; then
			get_token ""
			if [ "$PROXYUSER" = "" ]; then
				$WGET $CERTFLAG -qq --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data="authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D2&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}" "https://java.net/projects/oc-doctor/forums/updates/topics" -O /dev/null >/dev/null 2>/dev/null
				RETVAL=$?
			else
				eval "$WGET $CERTFLAG -qq --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data='authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D2&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}' 'https://java.net/projects/oc-doctor/forums/updates/topics' -O /dev/null >/dev/null 2>/dev/null"
				RETVAL=$?
			fi
		fi
		if [ $RETVAL -ne 0 ]; then
			get_token ""
			if [ "$PROXYUSER" = "" ]; then
				$WGET $CERTFLAG -qq --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data="authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D2&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}" "https://java.net/projects/oc-doctor/forums/updates/topics" -O /dev/null >/dev/null 2>/dev/null
				RETVAL=$?
			else
				eval "$WGET $CERTFLAG -qq --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data='authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D2&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}' 'https://java.net/projects/oc-doctor/forums/updates/topics' -O /dev/null >/dev/null 2>/dev/null"
				RETVAL=$?
			fi
		fi
	fi
	rm -f /var/tmp/java-cookie.bin > /dev/null 2>/dev/null

fi
exit 0
