#!/bin/bash

VAR_OPT_SUN_XVM=0
VAR_OPT_SUN_XVM_NEW=0
VAR_OPT_SUN_XVM_REMOTE=0

# Base

# /var/opt/sun/xvm - should be 5G
#echo "/var/opt/sun/xvm 5242880 as base"
MESSAGE=`printf "5242880K - Base requirement in /var/opt/sun/xvm"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + 5242880`
VAR_OPT_SUN_XVM_NEW=`expr $VAR_OPT_SUN_XVM_NEW + 5242880`
VAR_OPT_SUN_XVM_REMOTE=`expr $VAR_OPT_SUN_XVM_REMOTE + 5242880`

#Disk requirement for satadm backup for update_channel
DIR="/var/opt/sun/xvm/uce/"
if [ -d $DIR ]; then 
    uce_size=`du -sk $DIR | awk '{print $1}'` ;
else
    uce_size="";
fi
#echo "UCE needs $uce_size K in /var/opt/sun/xvm/  (for backup)"
MESSAGE=`printf "$MESSAGE\n${uce_size}K - UCE files backup requirement in /var/opt/sun/xvm (based on $DIR size)"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + $uce_size`
VAR_OPT_SUN_XVM_NEW=`expr $VAR_OPT_SUN_XVM_NEW + $uce_size`
VAR_OPT_SUN_XVM_REMOTE=`expr $VAR_OPT_SUN_XVM_REMOTE + $uce_size`

#### Database
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	SCS_HOME=/opt/sun/scs
	UCE_CONFIG_DIR=/var/opt/sun/xvm/uce/usr.local/server/public
	DOT_UCE_RC="/var/opt//sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc"
	AVAILABLE=`df -Pk /var/opt/sun/xvm | tail -1 | awk '{print \$4}'`
else
	SCS_HOME=/opt/SUNWscs
	UCE_CONFIG_DIR=/opt/SUNWuce/server/public
	DOT_UCE_RC="/opt/SUNWuce/server/cgi-bin/.uce.rc"
	AVAILABLE=`df -k /var/opt/sun/xvm | tail -1 | awk '{print \$4}'`
fi
DBNAME=mgmt
PGPORT=5434
PGUSER=scndb
PGPASSWORD="`$SCS_HOME/sbin/db_tool.pl getpw`"
PGDATA=/var/opt/sun/scs/data/db/data

# The size of the unziped oracle software bundles, plus the size of $ORACLE_HOME
#   Unzipped software=2.5G
#   Installed Oracle 4.2G
ORACLE_SOFTWARE_SIZE=7194070221
ORACLE_SOFTWARE_SIZE=7025459		## in K
#echo "/var/opt/sun/xvm/oracle/ needs $ORACLE_SOFTWARE_SIZE K for unzip software (for local DB)"
MESSAGE=`printf "$MESSAGE\n${ORACLE_SOFTWARE_SIZE}K - To unzip local DB files in /var/opt/sun/xvm (for local db only)"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + $ORACLE_SOFTWARE_SIZE`
VAR_OPT_SUN_XVM_NEW=`expr $VAR_OPT_SUN_XVM_NEW + $ORACLE_SOFTWARE_SIZE`

# The size of the database before customer data is added
# Includes SYSTEM TS,sysaux, temp, redo, initial allocation for USERS datafiles
ORACLE_BASE_DB_SIZE=2362232013
ORACLE_BASE_DB_SIZE=2306868		## in K
#echo "/var/opt/sun/xvm/oracle/ also needs $ORACLE_BASE_DB_SIZE K for DB (for local DB)"
MESSAGE=`printf "$MESSAGE\n${ORACLE_BASE_DB_SIZE}K - For default DB size in /var/opt/sun/xvm (for local db only)"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + $ORACLE_BASE_DB_SIZE`
VAR_OPT_SUN_XVM_NEW=`expr $VAR_OPT_SUN_XVM_NEW + $ORACLE_BASE_DB_SIZE`

PSQL="/usr/bin/env PGPASSWORD=${PGPASSWORD} LD_LIBRARY_PATH=/lib:/usr/lib:/usr/sfw/lib:$SCS_HOME/lib $SCS_HOME/bin/psql"
###########################################################################
#
# Main
#
###########################################################################
# Calculate the additional space required for the db component update.
# If the database is local,this will include :
#   Size of Oracle software (ORACLE_SOFTWARE_SIZE)
#   Size of core db (ORACLE_BASE_DB_SIZE)
#   Data converted from Echelon (240MB per managed asset) (delta_db_size)
#   Echelon database backup (db_backup_size_compress)
#   UCE files inside db (4G for 10 channels)+ (12G if discon) + 400M each addl channel (uce_db_space)
#

# Get the size (in 512 byte units) of db files for the mgmt and report databases

mgmt_db_size_raw=`du -s /var/opt/sun/xvm/db/mgmt`
mgmt_db_size=`echo $mgmt_db_size_raw  | awk  -F" " '{print $1}'`
report_db_size_raw=`du -s /var/opt/sun/xvm/db/report`
report_db_size=`echo $report_db_size_raw  | awk  -F" " '{print $1}'`
if [ $? -ne 0 ]; then
    echo "ERROR: Unable to call the DB while trying to determine required disk space for the upgrade"
    exit 1
fi


# Add mgmt and report db file sizes and multiply by compression ratio to get
# disk space requirements for the Echelon datababase Backup
db_backup_size=`expr $mgmt_db_size \* 512 + $report_db_size \* 512` > /dev/null
# db_backup_size_compress=`expr $db_backup_size \* 20 / 100 ` > /dev/null
db_backup_size_compress=`expr $db_backup_size \* 20 / 100 / 1024 ` > /dev/null	## in K
if [ $? -ne 0 ]; then
    echo "ERROR: Unable to calculate DB while trying to determine required disk space for the upgrade"
    exit 1
fi
#echo "Size of the DB compressed (backup) is expected to be $db_backup_size_compress K in /var/opt/sun/xvm/"
MESSAGE=`printf "$MESSAGE\n${db_backup_size_compress}K - For compress DB backup size in /var/opt/sun/xvm (based on DB size)"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + $db_backup_size_compress`
VAR_OPT_SUN_XVM_NEW=`expr $VAR_OPT_SUN_XVM_NEW + $db_backup_size_compress`
VAR_OPT_SUN_XVM_REMOTE=`expr $VAR_OPT_SUN_XVM_REMOTE + $db_backup_size_compress`

# Calculate the size of the new Delta database
#
asset_count_sql_statement="select count(*) * 240*(power(1024,1)) from hd_normalize_mbean where class_name = 'com.sun.hss.domain.services.normalization.internal.NormalizedMBeanImpl' and object_name not like '%type=AssetGroup%';"
asset_size=`$PSQL -U mgmt -p $PGPORT $DBNAME -t -c "$asset_count_sql_statement"`	## in KB

asset_count_sql_statement_new="select count(*) * 240*(power(1024,1)) from hd_normalize_mbean where class_name = 'com.sun.hss.domain.services.normalization.internal.NormalizedMBeanImpl' and object_name not like '%type=AssetGroup%' and (object_name like '%type=OperatingSystem%' or object_name like '%type=Server%');"
asset_size_new=`$PSQL -U mgmt -p $PGPORT $DBNAME -t -c "$asset_count_sql_statement_new"`	## in KB


uce_channels_activated=`grep -s "<CHANNEL_ID>" $UCE_CONFIG_DIR/activated_channels.xml | wc -l`
#uce_channel_space=`expr $uce_channels_activated \* 400 \* 1024 \* 1024`
uce_channel_space=`expr $uce_channels_activated \* 400 \* 1024 `		## in KB
# If we have channels configured, check the .uce.rc file.  If there is NOT a property named server_name, then it is NOT disconnected.
# If we do have a property named server_name and we have channels, then we are running in disconnected mode (and we need more space).

uce_disconnected_space=`expr 0`
if [ $uce_channels_activated -gt 0 ]; then
	uce_disconnected_space=`grep -s general.server_name $DOT_UCE_RC | wc -l`
	if [ $uce_disconnected_space -ne 0 ]; then
		#uce_disconnected_space=`expr 12 \* 1024 \* 1024 \* 1024`
		uce_disconnected_space=`expr 12 \* 1024 \* 1024 `	## in K
	fi
	MESSAGE=`printf "$MESSAGE\n${uce_disconnected_space}K - Estimated disconnected files size in /var/opt/sun/xvm"`
fi
delta_db_size=`expr $uce_channel_space + $asset_size`
delta_db_size_new=`expr $uce_channel_space + $asset_size_new`

#echo "Size of the new DB in Delta is expected to be $delta_db_size K (for local DB) in KB in /var/opt/sun/xvm"
MESSAGE=`printf "$MESSAGE\n${delta_db_size_new}K - Estimated 12c DB size in /var/opt/sun/xvm (for local db only)"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + $delta_db_size + $uce_disconnected_space`
VAR_OPT_SUN_XVM_NEW=`expr $VAR_OPT_SUN_XVM_NEW + $delta_db_size_new + $uce_disconnected_space`
VAR_OPT_SUN_XVM_REMOTE=`expr $VAR_OPT_SUN_XVM_REMOTE + $uce_disconnected_space`

#echo "Total required for /var/opt/sun/xvm: $VAR_OPT_SUN_XVM Kb"
MESSAGE=`printf "$MESSAGE\n\n${VAR_OPT_SUN_XVM_NEW}K - Total required in /var/opt/sun/xvm"`

if [ $VAR_OPT_SUN_XVM_NEW -lt $AVAILABLE ]; then
	echo "OK: UPGRADE: Enough disk space found in /var/opt/sun/xvm for the 12c upgrade (to a local or remote DB)."
	#### Check if the old way is a problem - this is how the 12c U1 checks for space
	if [ $VAR_OPT_SUN_XVM -gt $AVAILABLE ]; then
		echo "WARNING: While you have enough disk space, there is a known issue with the disk space calculation"
		echo "         of the update to 12c. It will calculate that you need ${VAR_OPT_SUN_XVM}K available in"
		echo "         /var/opt/sun/xvm, but in fact you only need ${VAR_OPT_SUN_XVM_NEW}K."
		echo ""
		echo "         To work around this issue, you will need to modify the upgrade script. After unzipping"
		echo "         the upgrade bundle, and before running the upgrade, modify the file"
		echo "    xvmoc_full_bundle/xvmoc_update_bundle/scripts/database/precheck"
		echo "         and add 'exit 0' in the second line of the script - this will skip the bad disk space check."
		echo ""
	fi
else
	if [ $VAR_OPT_SUN_XVM_REMOTE -gt $AVAILABLE ]; then
		echo "ERROR: UPGRADE: Not enough disk space found in /var/opt/sun/xvm to upgrade to 12c (either local or remote DB)."
		echo "                Local DB Needs: ${VAR_OPT_SUN_XVM_NEW}K Available: ${AVAILABLE}K"
		echo "                Remote DB Needs: ${VAR_OPT_SUN_XVM_REMOTE}K Available: ${AVAILABLE}K"
		echo ""
		echo "Summary of the local DB calculation:"
		printf "$MESSAGE\n\n"
	else
		echo "WARNING: UPGRADE: Not enough disk space found in /var/opt/sun/xvm to upgrade to 12c with local DB."
		echo "                  There is only enough space to upgrade to a remote DB:"
		echo "                  Local DB Needs: ${VAR_OPT_SUN_XVM_NEW}K Available: ${AVAILABLE}K"
		echo "                  Remote DB Needs: ${VAR_OPT_SUN_XVM_REMOTE}K Available: ${AVAILABLE}K"
		echo ""
		echo "Summary of the local DB calculation:"
		printf "$MESSAGE\n\n"
	fi
fi

