#!/bin/bash

# Script to report the heap usage of the cacao agent
#
# If the usage is above $WARNING_LEVEL, we will throw a warning to increase it
#

WARNING_LEVEL=80     ### if above, we will recommend to increase max value

INCREASE_AMOUNT=1000    ### New recommended value will be $INCREASE_AMOUNT + $MAX_USABLE_HEAP

CHANGE_HEAP_TOOL=/var/opt/sun/xvm/OCDoctor/toolbox/changeXmxValue.sh

if [ "$(uname)" = "Linux" ]; then
	AWK="/usr/bin/awk"
	CACAO_PROPERTIES="/etc/opt/sun/cacao2/instances/oem-ec/private/cacao.properties"
else
	AWK="/usr/bin/nawk"
	CACAO_PROPERTIES="/etc/cacao/instances/oem-ec/private/cacao.properties"
fi

JMXDUMP=/opt/sun/xvm/bin/jmxdump
TMPFILE=/tmp/agent_heap_usage.$$

CONFIGURED_HEAP=$(grep '^java\.flags=' $CACAO_PROPERTIES 2>/dev/null | \
		tr '=' ' ' | \
		tr ' ' '\n' | \
		sed -n 's/^-Xmx//p' |\
		tr 'kmg' 'KMG')

if [ -x $JMXDUMP ]; then
	$JMXDUMP s t root wellknown java.lang:type=Memory HeapMemoryUsage 2>/dev/null |\
	grep '^HeapMemoryUsage = {' | tr '{}' ',,' | tr ',' '\n' > $TMPFILE
	if [ -s "$TMPFILE" ]; then
		# obtaining values in rounded MB
		MAX_USABLE_HEAP=$($AWK ' /max = / {printf "%.0f\n",$3/1048576}' $TMPFILE)   
		USED_HEAP=$($AWK ' /used = / {printf "%.0f\n",$3/1048576}' $TMPFILE)
		USED_PCT=$(( 100 * $USED_HEAP / $MAX_USABLE_HEAP ))
		if [ "$USED_PCT" -gt $WARNING_LEVEL ]; then
			echo "WARNING: EC heap stats: configured: ${CONFIGURED_HEAP}B  max. usable: ${MAX_USABLE_HEAP}MB  currently used: ${USED_HEAP}MB  percentage used: ${USED_PCT}%" 
			echo "WARNING: "
			echo "WARNING: The heap usage is above ${WARNING_LEVEL}% of the maximum usable size!"
			echo "WARNING: "
			echo "WARNING: To increase the maximum allowed heap size, you could use e.g. the following command:"
			echo "WARNING: "
			echo "WARNING: $CHANGE_HEAP_TOOL $(( $INCREASE_AMOUNT + $MAX_USABLE_HEAP )) m ec"
			echo "WARNING: "
		else
			echo "OK: EC heap stats: configured: ${CONFIGURED_HEAP}B  max. usable: ${MAX_USABLE_HEAP}MB  currently used: ${USED_HEAP}MB  percentage used: ${USED_PCT}%"
		fi
	else
		echo "WARNING: unable to connect to java instance of the cacao agent!"
	fi
else
	echo "ERROR: $0: $JMXDUMP not found!"
fi

rm -f $TMPFILE

exit
