#!/bin/bash

### This will check if there are any unimported IPS images (Bug 15807626)

UNAMER=`uname -r`
if [ ! "$UNAMER" = "5.11" ]; then
	exit
fi

### Look for 10MB and above - the current agent is 180MB, while the clean one is 19K
FOLDER="/var/opt/sun/xvm/images/agent/"
OUTPUT=`find $FOLDER -name "OpsCenterAgent.SolarisIPS*" -size +10000000c`
if [ "$OUTPUT" = "" ]; then
	echo "OK: All Solaris 11 agent bundles in $FOLDER are imported properly to the repository"
else
	echo "ERROR: Found Solaris 11 agents which were not imported yet to the local IPS repository (Bug 15807626)."
	echo "       This may cause OS provisioning to fail."
	echo ""
	echo "The files are:"
	printf "$OUTPUT\n\n"
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to automatically fix this..."
		scriptDir=$(cd $(dirname $0); pwd)
		SCRIPTPATH=$scriptDir/../../toolbox/publish_S11_agent_to_local_repo.sh
		if [ ! -x $SCRIPTPATH ]; then
			echo "ERROR: Could not fix it automatically as $SCRIPTPATH was not found"
			echo ""
			exit 1
		fi
		rm -f /var/opt/sun/xvm/images/publish_S11_agent_to_local_repo.sh
		cp -p $SCRIPTPATH /var/opt/sun/xvm/images/publish_S11_agent_to_local_repo.sh
		printf "$OUTPUT\n" | while read AGENTBUNDLE; do
			AGENTSHORT=`basename $AGENTBUNDLE`
			if [ ! "$AGENTSHORT" = "" ]; then		## Safety
				if [ -f /var/opt/sun/xvm/images/agent/$AGENTSHORT ]; then	## Safety
					echo ""
					echo "------------------- Importing ${AGENTSHORT} -------------------"
					mv -f /var/opt/sun/xvm/images/agent/$AGENTSHORT /var/opt/sun/xvm/images/
					cd /var/opt/sun/xvm/images/
					./publish_S11_agent_to_local_repo.sh $AGENTSHORT
					if [ -f /var/opt/sun/xvm/images/agent/$AGENTSHORT ]; then
						rm -f /var/opt/sun/xvm/images/$AGENTSHORT			### remove the big file
					else
						echo ""
						mv -f /var/opt/sun/xvm/images/$AGENTSHORT /var/opt/sun/xvm/images/agent/$AGENTSHORT		### move the big file back to its place
						echo "ERROR: Seems like the import of $AGENTSHORT failed"
						echo ""
					fi
				else
					echo "ERROR: Could not find file /var/opt/sun/xvm/images/agent/$AGENTSHORT"
					echo ""
					exit 1
				fi
			else
				echo "ERROR: unexpected empty file name parsed from $AGENTBUNDLE"
				echo ""
				exit 1
			fi
		done
		rm -f /var/opt/sun/xvm/images/publish_S11_agent_to_local_repo.sh
		echo ""
		echo "OK: Fix was applied"
		echo ""
	else
		echo "If this is a new version of the Solaris 11 agent, the easiest way to fix this is to perform one of the following:"
		echo "1) Deploy this new agent to a new machine (choose to manage an OS) through the HTML User Interface"
		echo "2) Upgrade an older Solaris 11 agent to this new version through the HTML User Interface"
		echo ""
		echo "Alternatively, while less recommended, you could use the script in 'OCDoctor/toolbox/publish_S11_agent_to_local_repo.sh' to "
		echo "import those agents manually:"
		echo "To see how to use it, view the first few lines of that script."
		echo ""
		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this. This will automatically run the script above for you."
		echo ""
	fi
fi

