#!/bin/bash
#
# OCDoctor check to rebuild the missing Proxy Bundle on 12c R2 U2 ECs (Bug 20235907)
#
# Issue: Due to a Perl error, the Proxy Bundle for the EC platform does not get created during upgrade
#
# The error is not a generic one, so it is not seen on all ECs 
#
# We will check, if we have the Proxy Bundle and if not, we will create it out of the original EC bundle
#

if [ "$1" = "--fix" ]; then
	OCDOCTOR_FIX=1
fi


OS=$(uname -s)
if [ "$OS" = "Linux" ]; then
	ARCH="i686"
	OS_NAME=$OS
else
	ARCH=$(uname -p)
	OS_NAME="Solaris"
fi

VERSION_PROPERTIES=/n1gc-setup/.version.properties
if [ ! -f $VERSION_PROPERTIES ]; then
	echo "ERROR: ${0}: File $VERSION_PROPERTIES not found !"
	exit 1
fi

VERSION=$(awk -F= '/^product.version/ {print $2}' $VERSION_PROPERTIES)
DIST=$(awk -F= '/^product.installLocation/ {print $2}' $VERSION_PROPERTIES)
PRODUCT_UPDATE=/var/opt/sun/xvm/images/productUpdate
PROXY_DIR=/var/opt/sun/xvm/images/proxy
INSTALLER=${DIST}/${OS}_${ARCH}/Product/installer
BUILD_SCRIPT=${INSTALLER}/scripts/buildProxyBundle.pl
PROXY_BUNDLE=${PRODUCT_UPDATE}/proxy-controller.${OS_NAME}.${ARCH}.${VERSION}.tar.zip
PROXY_BUNDLE_OLD=${PROXY_DIR}/proxy-controller.${OS_NAME}.${ARCH}.${VERSION}.tar.zip

# Example path:
#/var/opt/sun/xvm/images/productUpdate/proxy-controller.Solaris.i386.12.2.2.1103.tar.zip

LOGFILE=/var/tmp/build-proxy-bundle.$$.log

if [ -f $PROXY_BUNDLE -o -f $PROXY_BUNDLE_OLD ]; then
	echo "OK: Proxy Bundle proxy-controller.${OS_NAME}.${ARCH}.${VERSION}.tar.zip exists"
else
	echo
	echo "ERROR: Proxy Bundle proxy-controller.${OS_NAME}.${ARCH}.${VERSION}.tar.zip does not exist (Bug 20235907)!"
	echo
	echo "This bundle is required to upgrade remote Proxies running on the same platform like the EC."
	echo
	if [ "$OCDOCTOR_FIX" = "1" ]; then
		printf "Trying to automatically fix this, this process can take several minutes, please be patient..."
		if [ -f $BUILD_SCRIPT ]; then
			/usr/bin/perl -I $INSTALLER $BUILD_SCRIPT --isInstall --mediabasedir $DIST --arch $ARCH --os $OS --targetdir $PRODUCT_UPDATE > $LOGFILE 2>&1
			if [ -f $PROXY_BUNDLE ]; then
				echo "done."
				echo
				echo "Proxy Bundle proxy-controller.${OS_NAME}.${ARCH}.${VERSION}.tar.zip has been successfully created" 
				rm $LOGFILE
				
			else
				echo "failed."
				echo
				echo "An error occured during Proxy Bundle creation, please review logfile"
				echo
				echo "$LOGFILE"
				echo
				echo "for details of the error."
				echo
			fi
		else
			echo
			echo
			echo "ERROR: Distribution directory $DIST is not complete!"
			echo
			echo "To recreate this directory, you have to locate the EC Upgrade Bundle."
			echo "The directory 'xvmoc_full_bundle' must be renamed/moved to ${DIST} ."
			echo
		fi
	else
		echo "To fix this, use '# ./OCDoctor.sh --troubleshoot --fix'" 
		echo
	fi
fi

