#!/bin/bash

HAS_EXP_CERT=0
UNAME=`uname`
TMP_ALIAS_FL=/tmp/aliases.ocd.$$
DEL_ALIAS_FL=/tmp/aliases.del.ocd.$$
KSPW=changeit

# Source utility functions
MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
    source $MY_DIR/../../functions
    solaris11_stuff
else
    echo "ERROR: Unable to find $MY_DIR/../../functions"
    exit 1
fi

if [ "$UNAME" = "Linux" ]; then
    KEYTOOL=`/opt/sun/cacao2/bin/cacaoadm get-param -i oem-ec -v java-home`/bin/keytool
    KEYSTORE=/var/opt/sun/cacao2/instances/oem-ec/configs/gf/config/cacerts.jks
else
    KEYTOOL=`/usr/sbin/cacaoadm get-param -i oem-ec -v java-home`/bin/keytool
    KEYSTORE=/var/cacao/instances/oem-ec/configs/gf/config/cacerts.jks
fi

# current date in seconds since epoc
if [ "$UNAME" = "Linux" ]; then
    CURRENT=`date +%s`
else
    # s10 does not support 'date +%s'
    CURRENT=`nawk "BEGIN{print srand}"`
fi

echo $KSPW | $KEYTOOL -list -v -keystore "$KEYSTORE" > /dev/null 2>&1
if [ $? -gt 0 ]; then
    echo "ERROR: Error opening keystore, $KEYSTORE."
    exit 1
fi

echo "INFO: Checking EC Glassfish keystore for expired certs, this may take a couple of minutes"

# Extract and save the cert alias from the cert file
echo $KSPW | $KEYTOOL -list -v -keystore "$KEYSTORE" 2> /dev/null | grep Alias | awk '{print $3}' > $TMP_ALIAS_FL

# Iterate through all the certificate alias
while read ALIAS; do

    # Extract the cert expiration date from a line looking like this:
    # Valid from: Thu Aug 13 00:29:00 GMT 1998 until: Mon Aug 13 23:59:00 GMT 2018
    # In this case we grab: Mon Aug 13 23:59:00 GMT 2018
    UNTIL=`echo $KSPW | $KEYTOOL -list -v -keystore "$KEYSTORE" -alias $ALIAS 2> /dev/null | grep "Valid from:" | sed 's/^.*until: ....//'`

    # transform the exp date to 'seconds since epoc'
    if [ "$UNAME" = "Linux" ]; then
        # Linux makes it easy to translate the exp date to the seconds since epoc value we require
        EXP_EPOC=`date -d "$UNTIL" +%s`
    else
        # Unfortunately Solaris doesn't support the -d option with the date command
        EXP_EPOC=`get_date_in_epoc "$UNTIL"`
    fi

    if [ "$EXP_EPOC" -le "$CURRENT" ]; then
        HAS_EXP_CERT=1
        echo "WARNING: Alias, $ALIAS, Glassfish certificate has expired! Expired $UNTIL"
        echo $ALIAS >> $DEL_ALIAS_FL
    fi

done < $TMP_ALIAS_FL
rm $TMP_ALIAS_FL

if [ $HAS_EXP_CERT = "0" ]; then
    echo "OK: No expired certificates in $KEYSTORE"
    exit 0
fi

echo "WARNING: Any expired certificates found will generate errors in the cacao logs"
echo

if [ "$OCDOCTOR_FIX" = "1" ]; then

    echo "       Trying to fix automatically..."
    echo "INFO: Copy of $KEYSTORE saved to $KEYSTORE.sav"
    cp $KEYSTORE $KEYSTORE.sav
    while read ALIAS; do
        echo $KSPW | $KEYTOOL -delete -alias $ALIAS -keystore $KEYSTORE 2> /dev/null
        if [ $? -eq 0 ]; then 
            echo "INFO: Expired certificate, $ALIAS, deleted from $KEYSTORE"
        else 
            echo "WARNING: Unable to delete certificate $ALIAS"
        fi
    done < $DEL_ALIAS_FL
        
else
    echo "       To remove the expired certs execute the following steps:"
    echo
    echo "           cp $KEYSTORE \\"
    echo "              $KEYSTORE.sav"
    echo
    echo "       and then execute the following command for each expired cert alias listed above"
    echo "       substituting {ALIAS} for the alias name to be deleted"
    echo
    echo "           echo \"changeit\" | $KEYTOOL -delete -alias {ALIAS} \\"  
    echo "               -keystore $KEYSTORE"
    echo
    echo "       or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
    echo
    echo "       Once the expired certs are removed they will no longer generate errors in the"
    echo "       cacao logs when the EC or PC is restarted. Please note that a restart is not"
    echo "       required since the expired certificate errors, although confusing, are harmless."
    echo
fi
rm $DEL_ALIAS_FL
exit 1
