#!/bin/ksh
#
# run toolbox/AssetCount.sh to get and check the managed asset numbers
#

# warning/critical limits (warning = 90 % of critical limit)
EC_WARNING=2700
EC_CRITICAL=3000
PC_WARNING=405
PC_CRITICAL=450
# for testing purposes
#EC_WARNING=28
#EC_CRITICAL=70
#PC_WARNING=4
#PC_CRITICAL=10

MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        . $MY_DIR/../../functions
	ASSETCOUNTER=$MY_DIR/../../toolbox/AssetCount.sh
else
        if [ -f /var/opt/sun/xvm/OCDoctor/functions ]; then
                . /var/opt/sun/xvm/OCDoctor/functions
		ASSETCOUNTER=/var/opt/sun/xvm/OCDoctor/toolbox/AssetCount.sh
        else
                exit
        fi
fi

# check if AssetCount.sh is there
if [ ! -x $ASSETCOUNTER ]; then
	echo "ERROR: $0: Script $ASSETCOUNTER does not exist or is not executable!"
	exit 1
fi

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        SAT_BIN="/opt/sun/xvmoc/bin/satadm"
	AWK=/usr/bin/awk
else
        SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
	AWK=/usr/bin/nawk
fi

if [ ! -x $SAT_BIN ]; then
	echo "ERROR: $0: $SAT_BIN not found"
	exit 1
fi

# check if EC is online
STATUS=`$SAT_BIN status`
if [ "$STATUS" = "online" ];then
	OUTPUT=/tmp/asset-counts.$$.out
	$ASSETCOUNTER -q standard >$OUTPUT 2>&1
	EXIT_CODE=$?
	if [ $EXIT_CODE -eq 0 ]; then
		# checking EC number
		EC_COUNT=$($AWK '/^EC / {print $2}' $OUTPUT)
		if [ $EC_COUNT -gt $EC_CRITICAL ]; then
			echo
			echo "WARNING: The number of Assets managed by this EC is $EC_COUNT which is above the recommended limit of ${EC_CRITICAL}!"
			echo "         This could result in degraded performance of the Enterprise Controller!"
			echo
		elif [ $EC_COUNT -gt $EC_WARNING ]; then
			echo
			echo "WARNING: The number of Assets managed by this EC is $EC_COUNT which is close to the recommended limit of ${EC_CRITICAL}!"
			echo "         Managing more than the recommended limit could result in degraded performance of the Enterprise Controller!"
			echo
		else
			echo "OK: Number of Assets managed by this EC is in recommended range"
		fi

		# checking numbers for PCs
		ALL_GOOD=true
		grep -v '^ERROR' $OUTPUT | $AWK '{if (NR >5) print $1 " " $2}' | while read PROXY_NAME ASSET_COUNT
		do
			if [ $ASSET_COUNT -gt $PC_CRITICAL ]; then
				echo
				echo "WARNING: The number of Assets managed by PC $PROXY_NAME is $ASSET_COUNT which is above the recommended limit of ${PC_CRITICAL}!"
				echo "         This could result in degraded performance of this Proxy Controller and the EC!"
				echo
				ALL_GOOD=false
			elif [ $ASSET_COUNT -gt $PC_WARNING ]; then
				echo
				echo "WARNING: The number of Assets managed by PC $PROXY_NAME is $ASSET_COUNT which is close to the recommended limit of ${PC_CRITICAL}!"
				echo "         Managing more than the recommended limit could result in degraded performance of this Proxy Controller and the EC!"
				echo
				ALL_GOOD=false
			fi
		done
		if $ALL_GOOD; then
			 echo "OK: Number of managed assets for each PC is in recommended range"
		fi 
	else
		echo
		echo "WARNING: $0: Script $ASSETCOUNTER finished with an error. Output of command:"
		echo
		cat $OUTPUT
		echo	
	fi	
	rm -f $OUTPUT
else
	echo "WARNING: EC is offline, unable to determine number of managed assets"
fi

