#!/bin/bash
#
# Check connection pool 
#

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
    CACAO="/var/opt/sun/cacao2/instances/oem-ec/logs/cacao.*"
else
    CACAO="/var/cacao/instances/oem-ec/logs/cacao.*"
fi

# Source utility functions
MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
    source $MY_DIR/../../functions
    solaris11_stuff
else
    exit
fi


# Check if 12.3.3 JIDR1 is installed 
get_version ""
IS_JIDR=false
if [ $VERSIONNUM -eq 12331801 ] && $IS_S11; then
    if pkg info -q idr3731; then
	IS_JIDR=true
    fi 
fi

# Check if you see a leak in one of the connection pools 

grep CumulativeFailedConnectionWaitCount $CACAO | grep -v ":0" >/dev/null 2>&1
if [ $? -eq 0 ]; then
    echo "WARNING: The Enterprise Controller might not have available connections in the pool resulting in the BUI being inaccessible."
    echo "         NOTE: If the BUI is accessible, please ignore the warning."
    echo 
    echo "         Workaround:"
    echo "         If the BUI is inaccessible, restart the Enterprise Controller services for immediate but temporary relief."
    echo
    if [ $VERSIONNUM -ge 12401201 ] || $IS_JIDR; then
        echo "         NOTE: The Enterprise controller is already on the fixed version. Please contact Oracle Support."
        echo
    else
        echo "         Fix:"
        echo "         For a permanent fix, upgrade to the versions:"
        echo "               -  12.3.3 JIDR1 (or)" 
        echo "               -  12.4.0" 
    fi
else
    echo "OK: No leak in the connection pool" 
fi
