#!/bin/bash
#
# upgrading from 12.3.0 to 12.3.1 or higher with a local DB will require a S11 min OS of 0.175.1.14.0.5.0
# 
 

MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        . $MY_DIR/../../functions
	get_version
	solaris11_stuff
else
	echo "ERROR: ${0}: functions file $MY_DIR/../../functions not found!"
	exit 1
fi

if ! $IS_S11; then
	# check is only valid for S11
        exit 0
fi

# check if a local or remote DB is used
DB_PROPERTIES=/var/opt/sun/xvm/db.properties
if [ -f $DB_PROPERTIES ]; then
        #### Determine if this local or remote
        LOCALREMOTE=`grep "^mgmtdb.server.type" $DB_PROPERTIES | awk -F"=" '{print $2}' 2>/dev/null`
else
        echo "ERROR: $0: DB Properties file $DB_PROPERTIES not found!"
        exit 1
fi

#LOCALREMOTE=local
if [ "$LOCALREMOTE" = "remote" ]; then
	# remote DB is used, no check required
	exit 0
fi

#VERSIONNUM=12301234
if [ $VERSIONNUM -gt "12310000" ]; then
	# we are already running DB 12.1.0.2 or higher
	exit 0
fi

if [ $VERSIONNUM -lt "12300000" ]; then
	# no upgrade to 12.1.0.2 will be performed, no check needed
	exit 0
fi

if [ $(( 10000 * $S11_RELEASE + 100 * $S11_SRU + $S11_SRU_MINOR )) -lt 11405 ]; then
	echo
	echo "WARNING: Do not try to upgrade to 12.3.1 or higher !"
	echo
	echo "         Installed OS version Solaris 11.${S11_RELEASE}.${S11_SRU}.${S11_SRU_MINOR} does not meet the minimum requirement"
	echo "         of Solaris 11.1.14.5 as required by the colocated installation of 12c DB!"
	echo
else
	echo "OK: Installed version of S11 is supported with DB 12c, no issue with upgrading to 12.3.1 or higher."
fi

