#!/bin/bash
#
# IDR 12.2.1-JIDR2 has created an index PERSISTENTALERT_RESOURCENAME2 for table PERSISTENTALERT
#
# Furthermore, before the IDR went out, the index has been created with varying names to improve performance
#
# This will cause a failure when upgrading to U2, the same for the rollback
#
# We need to drop the index before we try to upgrade the EC
#

MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        source $MY_DIR/../../functions
else
		exit
fi

get_version
if [ $VERSIONNUM -gt "12200000" -a $VERSIONNUM -lt "12220000" ]; then
        IS_DIAMOND_GA_or_U1=true
else
        IS_DIAMOND_GA_or_U1=false
fi


UNAME=`uname`

if [ "$UNAME" = "Linux" ]; then
        SAT_BIN="/opt/sun/xvmoc/bin/ecadm"
else
        SAT_BIN="/opt/SUNWxvmoc/bin/ecadm"
fi

if $IS_DIAMOND_GA_or_U1; then
	OCDOCTOR_SQL=/tmp/ocdoctor.sql.$$
	OCDOCTOR_OUT=/tmp/ocdoctor.out.$$
	cat > $OCDOCTOR_SQL << EOF
	column index_name  format a35
        column column_name format a35
	spool $OCDOCTOR_OUT
	select index_name,column_name from user_ind_columns where table_name='PERSISTENTALERT';
EOF
	echo "@$OCDOCTOR_SQL" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null
	INDEX_RESOURCENAME=$(egrep ' RESOURCENAME ' $OCDOCTOR_OUT | awk '{print $1}')
	INDEX_RAISEDTIME=$(egrep ' RAISEDTIME ' $OCDOCTOR_OUT | awk '{print $1}')
	
	# echo "INDEX_RESOURCENAME= >>>${INDEX_RESOURCENAME}<<<"
	# echo "INDEX_RAISEDTIME= >>>${INDEX_RAISEDTIME}<<<"
	if [ -n "$INDEX_RESOURCENAME" -a -n "$INDEX_RAISEDTIME" -a "$INDEX_RESOURCENAME" = "$INDEX_RAISEDTIME" ]; then
		echo
		echo "ERROR: Existing DB index $INDEX_RESOURCENAME will conflict with a new index used by 12c R2 U2!"
		echo
		echo "This index will cause a failure during upgrade to 12c R2 U2 (MOS Doc 1953094.1)!"
		echo
		echo "Run the following command as user root, just before you attempt to upgrade to U2:"
		echo
		echo "# echo 'DROP INDEX $INDEX_RESOURCENAME;' | $SAT_BIN sqlplus"
		echo 
	else
		echo "OK: No existing DB index for PERSISTENTALERT(RESOURCENAME,RAISEDTIME) found"
	fi
else
	echo "OK: EC is not running 12c R2 GA or U1, no need to check for a certain index"
fi

rm -f $OCDOCTOR_SQL $OCDOCTOR_OUT
