#!/bin/bash
#
# clear_old_notifications.sh
#
# check count of notifcations in DB and recommend to purge if required
#

##### Parameters #####
TOO_MANY=10000
#TOO_MANY=100
TO_KEEP=100
#TO_KEEP=90


export PATH=/usr/sbin:/usr/bin:$PATH
export LD_LIBRARY_PATH=/usr/lib:/lib

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
    ECADM="/opt/sun/xvmoc/bin/ecadm"
    AWK=/usr/bin/awk
else
    ECADM="/opt/SUNWxvmoc/bin/ecadm"
    AWK=/usr/bin/nawk
fi

BASEDIR=$(cd $(dirname $0)/../..; pwd)
PROG=$(basename $0)
NOTIFADM="${BASEDIR}/toolbox/clear_old_notifications.sh"

if [ ! -x $NOTIFADM ]; then
    echo "ERROR: $PROG: Toolbox script $NOTIFADM not found!"
    exit 1
fi

if [ -f $ECADM ]; then
    ERROR=0

    CURRENT_COUNT=$($NOTIFADM -g 2>/dev/null) 
    if [ -n "$CURRENT_COUNT" ]; then
	if [ $CURRENT_COUNT -ge $TOO_MANY ]; then
            echo
            echo "WARNING: Too many generated notifications: $CURRENT_COUNT (recommended < $TOO_MANY)"
            ERROR=1
        else
            echo "OK: Number of generated notifications ($CURRENT_COUNT) is not beyond recommended number ($TOO_MANY)" 
        fi

	if [ "$ERROR" = "1" ]; then
	    echo "         A high number of notifications will cause slow performance of the EC."
	    echo
	    if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Fixing this automatically by running command: $NOTIFADM -d -y -q -n $TO_KEEP"
		echo
		echo "NOTICE: the delete commands may take a few minutes to even a few hours in a big environment."
		$NOTIFADM -d -y -q -n $TO_KEEP
		EXIT_CODE=$?
		echo
		if [ "$EXIT_CODE" -eq 0 ]; then 
		    echo "Done."
		    echo
		else
		    echo "ERROR: $NOTIFADM exited with exit code $EXIT_CODE"
		    echo
		    exit $EXIT_CODE
		fi
	    else
		echo "To fix this, you will need to purge old notifications from the database."
		echo "Use this command to delete all but the $TO_KEEP most recent notifications:"
		echo 
		echo "$NOTIFADM -d -n $TO_KEEP"
		echo 
		echo "or run './OCDoctor.sh --troubleshoot --fix' to automatically fix it."
		echo 
		echo "NOTICE: the delete command may take a few minutes to even a few hours in a big environment."
	    fi
	    if crontab -l 2>/dev/null | grep $(basename ${NOTIFADM}) >/dev/null; then
	        echo 
	    else
		echo
	    	echo "You may add the following to the crontab for automatic cleanups:"
	    	echo "(This example will delete all notifications every Sunday at midnight)"
	    	echo
	    	echo "0 0 * * 0 $NOTIFADM -d -a -q"
	    	echo
		echo "Run the command without arguments to see all available options."
		echo
	    fi	
	fi

    else
	# clear_old_notifications.sh came back with an error / empty output
	echo "ERROR: $PROG: Unable to access the DB, is the EC up and running ?"
    fi
else
    echo "ERROR: $PROG: Couldn't find $ECADM"
fi



