#!/bin/ksh

#
# checking for integrity of the Satellite installation - will not check for agent packages (will run those in a different script)
#

UNAME=`uname`
if [ $UNAME = "Linux" ];then
	cat <<!EOF! | while read file; do
sun-n1hss-core
sun-n1hss-core
sun-n1hss-core-config
sun-n1hss-servicescr
sun-n1hss-drvrs
sun-scnconnmgt-rs
sun-scn-osp-drivers
sun-scnsatadm
sun-scn-osp-config
sun-scn-cs
sun-scn-osp
sun-scnreportsvc
sun-scnjobmgr-common-impl
sun-scnnotifsvc
sun-scn-auth
sun-scn-osp-s
sun-scnconnmgt
sun-scnjobmgr-proxy-config
sun-scnjobmgr-satellite-config
sun-scnjobmgr-satellite
sun-scnjobmgr-common-api
sun-scnproxyadm
sun-scnconnmgt-rp
sun-scnjobmgr-proxy
sun-scn-satmgmt
sun-scn-con
sun-xvmoc-winpm-config
sun-xvm-buitools
sun-xvm-smflite
sun-xvm-client
sun-xvm-proxyrun-base
sun-xvm-ajaxterm
sun-xvmoc-satrun-oc
sun-xvm-satrun-base
sun-xvm-xvmocbui
sun-xvmoc-client
sun-xvmoc-wme
sun-xvmoc-proxyrun-oc
sun-xvmoc-winpm
!EOF!
	OUTPUT=`rpm -q $file`
	if [[ $? -eq 0 ]]; then
                DONOTHING=1
        else
                if [[ $CHECK -eq 0 ]]; then               ### Only print ERROR once
                        echo "ERROR while checking for Enterprise Controller RPM integrity:"
                fi
                echo "RPM $file is not installed properly"
                CHECK=1
        fi
        done
        if [[ $CHECK -eq 0 ]]; then
                echo "OK: All Enterprise Controller RPMs are installed properly"
        else
                echo "ERROR: The RPMs above are not installed properly (missing from 'rpm -q'), consider reinstallation."
                echo "       It can also be that those RPMS are not needed. Please report this to Sun Support to determine this."
                echo ""
        fi

        exit $CHECK



else			####### Solaris
	CHECK=0
	OS_REL=`uname -r`
	if [ "$OS_REL" = "5.10" ]; then
		cat <<!EOF! | while read file; do
			CSKlibs
			CSKncurses
			CSKpython
			CSKruntime
			SUNWn1hss-core
			SUNWn1hss-drvrs
			SUNWn1hss-servicescr
			SUNWscn-cs
			SUNWscn-osp
			SUNWscn-osp-config
			SUNWscn-osp-drivers
			SUNWscn-osp-s
			SUNWscnauth
			SUNWscncon
			SUNWscnconnmgt
			SUNWscncrs
			SUNWscnjobmgr-proxy
			SUNWscnjobmgr-proxy-config
			SUNWscnjobmgr-satellite
			SUNWscnjobmgr-satellite-config
			SUNWscnnotifsvc
			SUNWscnproxyadm
			SUNWscnreportsvc
			SUNWscnsatadm
			SUNWscnsatmgmt
			SUNWscnsatmgmt
			SUNWsms-facade
			SUNWucelarge
			SUNWuces
			SUNWxvm-ajaxterm
			SUNWxvm-bui-tools
			SUNWxvm-client
			SUNWxvm-proxyrun-base
			SUNWxvm-satrun-base
			SUNWxvmoc-client
			SUNWxvmoc-proxyrun-oc
			SUNWxvmoc-satrun-oc
			SUNWxvmocbui
			SUNWOCdhcp
!EOF!
			pkginfo $file >/dev/null 2>&1
			if [[ $? -eq 0 ]] ; then
				DONOTHING=1
			else
				if [[ $CHECK -eq 0 ]]; then		### Only print ERROR once
					echo "ERROR while checking for Enterprise Controller packages integrity:"
				fi
				echo "Package $file is not installed properly"
				CHECK=1
			fi
		done
	else			##### If not Solaris 10, then it's Solaris 11
		cat <<!EOF! | while read file; do
			SUNWn1hss-core
			SUNWn1hss-drvrs
			SUNWn1hss-servicescr
			SUNWscn-cs
			SUNWscn-osp
			SUNWscn-osp-config
			SUNWscn-osp-drivers
			SUNWscn-osp-s
			SUNWscnauth
			SUNWscncon
			SUNWscnconnmgt
			SUNWscncrs
			SUNWscnjobmgr-proxy
			SUNWscnjobmgr-proxy-config
			SUNWscnjobmgr-satellite
			SUNWscnjobmgr-satellite-config
			SUNWscnnotifsvc
			SUNWscnproxyadm
			SUNWscnreportsvc
			SUNWscnsatadm
			SUNWscnsatmgmt
			SUNWscnsatmgmt
			SUNWsms-facade
			SUNWucelarge
			SUNWuces
			SUNWxvm-ajaxterm
			SUNWxvm-bui-tools
			SUNWxvm-client
			SUNWxvm-proxyrun-base
			SUNWxvm-satrun-base
			SUNWxvmoc-client
			SUNWxvmoc-proxyrun-oc
			SUNWxvmoc-satrun-oc
			SUNWxvmocbui
!EOF!
			pkginfo $file >/dev/null 2>&1
			if [[ $? -eq 0 ]] ; then
				DONOTHING=1
			else
				if [[ $CHECK -eq 0 ]]; then		### Only print ERROR once
					echo "ERROR while checking for Enterprise Controller packages integrity:"
				fi
				echo "Package $file is not installed properly"
				CHECK=1
			fi
		done
	fi		### End of Solaris 11
	#### Check for SUNWn1hss-core-arch
	#### Check version ####
	MY_DIR=`dirname $0`
	if [ -f $MY_DIR/../../functions ]; then
		VERSIONNUM=`bash -c "source $MY_DIR/../../functions ; get_version ; echo \\$VERSIONNUM"`	### Provide VERSIONNUM via bash (this script is in ksh)
	else
		echo "ERROR: Unable to find the functions file in the check_sat_integrity.sh script"
		echo ""
		exit
	fi
	file="SUNWn1hss-core-arch"
	if [ $VERSIONNUM -gt "12202663" ];then               #### Is this newer than Diamond RR? If so, it changed names
		file="SUNWn1hss-core-arch64"
	fi
	pkginfo $file >/dev/null 2>&1
	if [[ $? -ne 0 ]] ; then
		if [[ $CHECK -eq 0 ]]; then		### Only print ERROR once
			echo "ERROR while checking for Enterprise Controller packages integrity:"
		fi
		echo "Package $file is not installed properly"
		CHECK=1
	fi	
	
	if [[ $CHECK -eq 0 ]]; then
		echo "OK: All Enterprise Controller packages are installed properly"
	else
		echo "ERROR: The packages above are not installed properly (missing from pkginfo), consider reinstallation."	
		echo "       It can also be that those packages are not needed. Please report this to Support to determine this."
		echo ""
	fi

	exit $CHECK
fi		### End of Solaris


