#!/bin/bash
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        SAT_BIN="/opt/sun/xvmoc/bin/satadm"
else
        SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
fi

### Get rid of comments ###
cat $SAT_BIN | sed -e 's/^[ \t]*//' | grep -v "^#" > /var/tmp/satadm.$$
SAT_BIN_NOCOMMENT=/var/tmp/satadm.$$

#### First check timeout ####
SHUTDOWNTIMEOUT=`grep "DEF_STARTSTOP_SHUTDOWN_TIMEOUT=" $SAT_BIN_NOCOMMENT | awk -F"=" '{print $2}'`
STARTUPTIMEOUT=`grep "DEF_STARTSTOP_STARTUP_TIMEOUT=" $SAT_BIN_NOCOMMENT | awk -F"=" '{print $2}'`

ERROR=0
if [ $SHUTDOWNTIMEOUT -lt 301 ]; then
	ERROR=1
fi
if [ $STARTUPTIMEOUT -lt 301 ]; then
	ERROR=1
fi
if [ "$ERROR" = "1" ]; then
	echo "WARNING: The startup/shutdown timeouts in satadm may be too low and may cause the backup to fail (Bug 15607543)"
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "         Trying to fix automatically..."
		REPLACE="DEF_STARTSTOP_SHUTDOWN_TIMEOUT=$SHUTDOWNTIMEOUT"
		`sed "s/$REPLACE/DEF_STARTSTOP_SHUTDOWN_TIMEOUT=3600/g" $SAT_BIN > /var/tmp/satadm_tmp`
		REPLACE="DEF_STARTSTOP_STARTUP_TIMEOUT=$STARTUPTIMEOUT"
		`sed "s/$REPLACE/DEF_STARTSTOP_STARTUP_TIMEOUT=3600/g" /var/tmp/satadm_tmp > /var/tmp/satadm_tmp2`
		cp -p $SAT_BIN ${SAT_BIN}-ocdoctor-timeout-org.$$
		cp /var/tmp/satadm_tmp2 $SAT_BIN
		rm -f /var/tmp/satadm_tmp
		rm -f /var/tmp/satadm_tmp2
		echo "         Done - backup file created - ${SAT_BIN}-ocdoctor-timeout-org.$$"
		echo ""
	else
		echo "         To increase those, edit $SAT_BIN and change the following to 1 hour timeout:"
		echo "         DEF_STARTSTOP_SHUTDOWN_TIMEOUT=300  to   DEF_STARTSTOP_SHUTDOWN_TIMEOUT=3600"
		echo "         DEF_STARTSTOP_STARTUP_TIMEOUT=300   to   DEF_STARTSTOP_STARTUP_TIMEOUT=3600"
		echo ""
		echo "         or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		echo ""
	fi
else
	echo "OK: satadm timeouts were increased"
fi

if [ "$UNAME" = "Linux" ]; then
	rm -f $SAT_BIN_NOCOMMENT
	exit
	### No need to change this in Linux!
fi

#### Check for 'tar' command ###
TAR=`grep "tar cf " $SAT_BIN_NOCOMMENT`
if [ "$TAR" = "" ]; then
	echo "OK: tar command was properly adjusted in satadm"
else
	echo "WARNING: The 'tar' command used inside 'satadm' backup may fail if the backup size is bigger than 8G (Bug 15618095)"
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "         Trying to fix automatically..."
                `sed "s/tar cf /tar cEf /g" $SAT_BIN > /var/tmp/satadm_tmp`
                cp -p $SAT_BIN ${SAT_BIN}-ocdoctor-tar-org.$$
                cp /var/tmp/satadm_tmp $SAT_BIN
                rm -f /var/tmp/satadm_tmp
                echo "         Done - backup file created - ${SAT_BIN}-ocdoctor-tar-org.$$"
                echo ""
	else
		echo "         To fix, edit $SAT_BIN and search for 'tar cf ' - you will find 2 instances. Change them both:"
		echo "         ... tar cf ..."
		echo "               to"
		echo "         ... tar cEf ..."
		echo ""
		echo "         or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		echo ""
	fi
fi
rm -f $SAT_BIN_NOCOMMENT



