#!/bin/bash

### Check database_analysis.sh path
scriptDir=$(cd $(dirname $0); pwd)
OCDOCDIR=$(dirname $(dirname $scriptDir))
if [ -f ${OCDOCDIR}/toolbox/database_analysis.sh ]; then
	DB_ANALYSIS=${OCDOCDIR}/toolbox/database_analysis.sh
else
	DB_ANALYSIS="OCDoctor/toolbox/database_analysis.sh"
fi

#### Check database file use
if [ -f /var/opt/sun/xvm/db.properties ]; then
	#### Determine if this local or remote
	LOCALREMOTE=`grep "^mgmtdb.server.type" /var/opt/sun/xvm/db.properties 2>/dev/null | awk -F"=" '{print $2}' 2>/dev/null`
else
	exit
fi

#### Check version - if this is U3 or newer, skip this test as it is fixed in Ops Center already
MY_DIR=`dirname $0`
VERSIONNUM=0		### In case we can't read it
if [ -f $MY_DIR/../../functions ]; then
        source $MY_DIR/../../functions
        get_version ""          ### Provide VERSIONNUM, used below
fi

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        ECADM="/opt/sun/xvmoc/bin/ecadm"
else
        ECADM="/opt/SUNWxvmoc/bin/ecadm"
fi
echo "set lines 600" > /var/tmp/ocdoctor.sql.$$
echo "column file_name format a80" >> /var/tmp/ocdoctor.sql.$$
echo "column bytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
echo "column maxbytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
echo "column user_bytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
echo "column pct_alloc format 999" >> /var/tmp/ocdoctor.sql.$$
echo "spool /var/tmp/ocdoctor.sql.out.$$" >> /var/tmp/ocdoctor.sql.$$
echo "select file_name,tablespace_name, round(maxbytes/1024/1024/1024), round(user_bytes/1024/1024/1024), round(bytes/1024/1024/1024) , 100- round((maxbytes-bytes)/decode(maxbytes,0,1,maxbytes) *100) pct_alloc from dba_data_files order by pct_alloc desc;" >> /var/tmp/ocdoctor.sql.$$
echo "spool off" >> /var/tmp/ocdoctor.sql.$$
rm -f /var/tmp/ocdoctor.sql.out.$$

if [ "$LOCALREMOTE" = "local" ]; then
        su - oracleoc -c "echo \"@/var/tmp/ocdoctor.sql.$$\" | sqlplus / as sysdba >/dev/null 2>/dev/null " >/dev/null 2>/dev/null
        if [ -f /var/tmp/ocdoctor.sql.out.$$ ]; then
        	OUTPUT=`cat /var/tmp/ocdoctor.sql.out.$$ 2>/dev/null | grep OC_DEFAULT_TS`
        fi
else
        echo "@/var/tmp/ocdoctor.sql.$$" | $ECADM sqlplus >/dev/null 2>/dev/null
        if [ -f /var/tmp/ocdoctor.sql.out.$$ ]; then
        	OUTPUT=`cat /var/tmp/ocdoctor.sql.out.$$ 2>/dev/null | grep USERS`
        fi
fi

PERCENTUSED=`printf "$OUTPUT\n" |tail -1 | awk '{print $6}'`;
FILESINUSE=`printf "$OUTPUT\n" | grep "/" |wc -l | awk '{print $1}'`;
LASTLOCATION=`printf "$OUTPUT\n" |tail -1 | awk '{print $1}'`;
MAXBYTES=`printf "$OUTPUT\n" |tail -1 | awk '{print $3}'`;
USEDBYTES=`printf "$OUTPUT\n" |tail -1 | awk '{print $5}'`;
LASTLOCATIONFOLDER=`dirname "$LASTLOCATION"`
LASTLOCATIONFILE=`basename "$LASTLOCATION"`
rm -f /var/tmp/ocdoctor.sql.$$ /var/tmp/ocdoctor.sql.out.$$
if [ $FILESINUSE -eq 0 ]; then
	if [ "$LOCALREMOTE" = "remote" ]; then
		echo "OK: remote DB is used, skipping check to verify disk space usage"
		#echo "WARNING: Unable to obtain proper permissions on the remote DB to verify disk space usage"
		#echo "         This may not be a problem, it's just a warning that the Doctor could not check it for you."
		#echo ""
		#echo "         To try this command manually, run the following on this machine:"
		#echo "         # $ECADM sqlplus"
		#echo "         SQL> select file_name,tablespace_name,round(maxbytes/1024/1024/1024),round(user_bytes/1024/1024/1024),round(bytes/1024/1024/1024) , 100- round((maxbytes-bytes)/maxbytes *100) pct_alloc from dba_data_files order by pct_alloc desc;"
		#echo ""
		#echo "You may need to run this as sysdba on the remote database to verify disk space usage."
		#echo ""
	else
		echo "WARNING: Unable to connect to local database with the right permissions to determine disk space usage"
	fi
	exit 0
fi
if [ $PERCENTUSED -lt 75 ]; then
	if [ "$LOCALREMOTE" = "remote" ]; then
		echo "OK: Remote Database used space is ${PERCENTUSED}%, ${USEDBYTES}G out of ${MAXBYTES}G ($LOCALREMOTE DB, using $FILESINUSE files)"
	else
		echo "OK: Local Database used space is ${PERCENTUSED}%, ${USEDBYTES}G out of ${MAXBYTES}G ($LOCALREMOTE DB, using $FILESINUSE files)"
	fi
	if [ $FILESINUSE -gt 1 ]; then
		if [ $VERSIONNUM -ge "12132305" ];then               #### Is this newer or equal to Update 3? if so, no need for exra info (unless more than 75% above)
			exit 0          
		fi
        #### If U2 and below, offer the following info:
		echo "    To stop the DB growth, you may be able to reduce the data collected by Ops Center."
		echo "    Run the following utility to determine the top monitoring attributes that consume the DB"
		echo "    # ${DB_ANALYSIS}"
		echo "Note: Even if you disable some attributes and delete some data in the DB, you may continue to see"
		echo "      this message as the size of the files on the disk will not go down. Instead the database"
		echo "      will reuse the empty space in those files."
		if [ "$LOCALREMOTE" = "remote" ]; then
			echo "Note 2: Disk space used on a remote DB may be a result of other applications using that DB and"
			echo "        may not be as a result of using Ops Center. You may use the above script to search"
			echo "        for unusually high Ops Center attribute count if you suspect Ops Center is the reason"
			echo "        for the significant DB growth."
		fi
		echo ""
	fi
else 
	echo "ERROR: Database used space is too high: ${PERCENTUSED}%, ${USEDBYTES}G is used out of ${MAXBYTES}G"
	echo "       You must add additional files to the database to avoid severe product issues."
	echo ""
	echo "Current database files in use on the $LOCALREMOTE DB server:"
	printf "$OUTPUT\n" | awk '{printf "%s       %sG used        %sG max\n",$1,$5,$3}'
	echo ""
	if [ "$LOCALREMOTE" = "remote" ]; then
		echo "On the remote DB server, run the following:"
		echo ""
		echo "# su - oracle		            (Or whatever user the database is installed as)"
		echo "$ sqlplus / as sysdba"
		echo "You will need to provide a new filename path in the next line:"
		echo "SQL> alter tablespace USERS add datafile '<put path to new file here>' size 2G autoextend on maxsize 32767M;"
		echo ""
		echo "For Example:"
		echo "SQL> alter tablespace USERS add datafile '$LASTLOCATIONFOLDER/newfile99.dbf' size 2G autoextend on maxsize 32767M;"
		echo ""
		echo "IMPORTANT: Make sure you have enough disk space to accommodate another 32G on the filesystem of the new file!"
		echo ""
	else
		echo "On this local DB server, run the following:"
		echo ""
		echo "# su - oracleoc"
		echo "$ sqlplus / as sysdba"
		echo "You will need to provide a new filename path in the next line:"
		echo "SQL> alter tablespace oc_default_ts add datafile '<put path to new file here>' size 2G autoextend on maxsize 32767M;"
		echo ""
		echo "For Example:"
		echo "SQL> alter tablespace oc_default_ts add datafile '$LASTLOCATIONFOLDER/newfile99.dbf' size 2G autoextend on maxsize 32767M;"
		echo ""
		echo "IMPORTANT: Make sure you have enough disk space to accommodate another 32G on the filesystem of the new file!"
		echo ""
	fi
	echo "*** To stop the DB growth, you may be able to reduce the data collected by Ops Center        ***"
	echo "*** Run the following utility to determine the top monitoring attributes that consume the DB ***"
	echo "*** # ${DB_ANALYSIS} ***"
	echo ""
fi

