#!/bin/bash
#
# check to see if we still exclude *_CBC* cyphers on EC and PC
#
# Bug 21470341 - SSL handshake error encountered on upgrade 
# Bug 21464720 - OPScenter 12.3 jdk- 6 update to 101 rev break agent communication
# MOS Doc ID 2036973.1 - Java 6u101, 7u85 and 8u51 and Later Releases Break Enterprise Manager 
#                        Ops Center Agent Controller to Proxy Communication
#
# Issue has been introduced with JDK6u101, JDK7u85 & JDK8_51 
#

INSTANCE="oem-ec"

CORRECT_EXCLUDE_LIST="_DES_,_40_,_anon_,_NULL_,_DES40_"

UNAME=`uname`
if [ "$UNAME" = "Linux" ];then
    	CACAOADM=/opt/sun/cacao2/bin/cacaoadm
	ECADM="/opt/sun/xvmoc/bin/ecadm"
	PROXYADM="/opt/sun/xvmoc/bin/proxyadm"
	CACAO_PROPERTIES="/etc/opt/sun/cacao2/instances/$INSTANCE/private/cacao.properties"
	CACAO_PROPERTIES_BACKUP="${CACAO_PROPERTIES}.saved_by_OCDoctor.$$"
else
	CACAOADM="/usr/sbin/cacaoadm"
	ECADM="/opt/SUNWxvmoc/bin/ecadm"
	PROXYADM="/opt/SUNWxvmoc/bin/proxyadm"
	CACAO_PROPERTIES="/etc/cacao/instances/$INSTANCE/private/cacao.properties"
	CACAO_PROPERTIES_BACKUP="${CACAO_PROPERTIES}.saved_by_OCDoctor.$$"
fi

if [ "$INSTANCE" = "oem-ec" ]; then
	TIER="EC"
	SHUTDOWN="$ECADM stop -vw"
	STARTUP="$ECADM start -vw"
else
	TIER="PC"
	SHUTDOWN="$PROXYADM stop -vw"
	STARTUP="$PROXYADM start -vw"
fi

CURRENT_EXCLUDE_LIST=$($CACAOADM get-param -i $INSTANCE -v excluded-cipher-suites 2>/dev/null)
if [ $? -ne 0 ]; then
	echo
	echo "ERROR: ${0}: got error when running command:"
	echo "ERROR:"
	echo "ERROR: $CACAOADM get-param -i $INSTANCE -v excluded-cipher-suites"
	$CACAOADM get-param -i $INSTANCE -v excluded-cipher-suites
	echo
	exit 1
fi

if echo $CURRENT_EXCLUDE_LIST | grep "_CBC" >/dev/null; then
	# we still exclude *_CBC* cypher suites
	echo
	echo "ERROR: The $TIER will cause ssl handshake errors in case latest JDK updates are used at EC/PC/AC tiers (MOS DocID 2036973.1)!" 
	echo
	# --fix is only performed when running OCDoctor manually
	if [ "$OCDOCTOR_FIX" = "1" -a "$UIDOCTOR" != "1" ]; then
		echo "Trying to fix this automatically, it will require to shutdown/restart this $TIER !"	
		echo "Shutting down $TIER"
		$SHUTDOWN
		echo "Correcting cacao parameter"
		cp $CACAO_PROPERTIES $CACAO_PROPERTIES_BACKUP
		$CACAOADM set-param -i $INSTANCE "excluded-cipher-suites=$CORRECT_EXCLUDE_LIST"
		echo "Created backup copy $CACAO_PROPERTIES_BACKUP"
		echo "Starting up $TIER"
		$STARTUP
	else
		echo "The following steps are required to fix this issue:"
		echo
		echo "1. Stop $TIER: $SHUTDOWN"
		echo "2. Correct cacao parameter: $CACAOADM set-param -i $INSTANCE \"excluded-cipher-suites=$CORRECT_EXCLUDE_LIST\"" 
		echo "3. Start up $TIER: $STARTUP"
		echo
                if [ "$UIDOCTOR" != "1" ]; then
                	echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this."
			echo
			echo "WARNING: A shutdown / restart of the $TIER will be part of the fix!"
			echo
		fi
	fi
else
	echo "OK: cacao parameter excluded-cipher-suites is correct"
fi


