#!/bin/bash
#
# check if SSLv3 is disabled - CVE-2014-3566 (SSLv3 vulnerability Poodle)
#

MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        source $MY_DIR/../../functions
	GF_TARFILE=$MY_DIR/../../toolbox/gf_jars.tar
	ABS_GF_TARFILE="<OCDoctor>/toolbox/gf_jars.tar"
        solaris11_stuff
else
        if [ -f /var/opt/sun/xvm/OCDoctor/functions ]; then
                source /var/opt/sun/xvm/OCDoctor/functions
		GF_TARFILE=/var/opt/sun/xvm/OCDoctor/toolbox/gf_jars.tar
		ABS_GF_TARFILE=$GF_TARFILE
        else
                exit
        fi
fi

# wget dumps core when run on Solaris 11.4 with secure-protocol set to sslv3 
# Since the version of the EC supported on Solaris 11.4 is not vulnerable to
# poodle, ignoring this check for Solaris 11.4
if $IS_S11 && [ "$S11_RELEASE" -gt 3 ]; then
   exit 0
fi

get_version
if [ $VERSIONNUM -lt "12100000" ]; then
	# so far we cannot fix tomcat webserver used by cacao
	CACAO_FIX_AVAILABLE=false
else
	CACAO_FIX_AVAILABLE=true
fi

if [ ! -f $GF_TARFILE ]; then
	echo "${0}: ERROR: File $GF_TARFILE not found!"
	exit
fi
 
if [ "`uname`" = "Linux" ]; then
	CONF_FILE=/var/opt/sun/xvm/uce/etc/uce_server/httpd-ssl.conf
	USER_GROUP="uce-sds.uce-sds"
	MODE="644"
	GF_JAR=/opt/sun/cacao2/share/ext/gfish/lib/cacao_gfish_private.jar
	WGET="/usr/bin/wget"
	GF_JAR_FIXED=cacao_gfish_private.jar_linux_i386
else
	CONF_FILE=/var/opt/sun/xvm/uce/etc.opt/server/uce_server/httpd-ssl.conf
	USER_GROUP="uce-sds:uce-sds"
	MODE="644"
	GF_JAR=/usr/lib/cacao/ext/gfish/lib/cacao_gfish_private.jar
	WGET="/usr/sfw/bin/wget"
	if [ "`uname -p`" = "sparc" ]; then
		GF_JAR_FIXED=cacao_gfish_private.jar_solaris_sparc
	else
		GF_JAR_FIXED=cacao_gfish_private.jar_solaris_i386
	fi
fi

if [ -x $WGET ]; then
	WGET_FOUND=true
	WGET_ARGS="-q -O /dev/null --no-check-certificate --secure-protocol SSLv3" 
	WGET_GF_URL="https://localhost:9443/emoc/"
	WGET_APACHE_URL="https://localhost:8002/channels.xml"
else
	WGET_FOUND=false
fi

CONF_FILE_ORIG=${CONF_FILE}.ocdoctor.sslv3-fix.orig
GF_JAR_ORIG=${GF_JAR}.ocdoctor.sslv3-fix.orig

# test if we still allow SSLv3 connections
if $WGET_FOUND; then
	$WGET $WGET_ARGS $WGET_GF_URL
	if [ $? -eq 0 ]; then
		GF_FIXED=false
	else
		GF_FIXED=true
	fi
	$WGET $WGET_ARGS $WGET_APACHE_URL
	if [ $? -eq 0 ]; then
		APACHE_FIXED=false
	else
		APACHE_FIXED=true
	fi
else
	if [ -f $GF_JAR_ORIG ]; then
		# due to a bug in OCDoctor 4.39, the applied fix could be incomplete
		if diff $GF_JAR $GF_JAR_ORIG >/dev/null 2>&1; then
			# $GF_JAR is still the original jar file
			GF_FIXED=false
		else
			GF_FIXED=true
		fi
	else
		GF_FIXED=false
	fi
	if egrep 'SSLProtocol.* -SSLv3' $CONF_FILE > /dev/null 2>&1; then
		 APACHE_FIXED=true
	elif [ -f $CONF_FILE_ORIG ]; then
		APACHE_FIXED=true
	else
		APACHE_FIXED=false
	fi
fi
	

print_file_exists_warning(){
	echo "WARNING: The file"
	echo
	echo $1
	echo
	echo "exists, so the fix has already been applied!"
	echo
	echo "Two possible reasons why the Webserver is still vulnerable:"
	echo " 1) The EC has probably not yet been restarted after applying the fix."
	echo " 2) The fixed file got overwritten e.g. by an upgrade. Remove or rename the above file in this case."
}

# apache server
if $APACHE_FIXED; then
	echo "OK: UCE Webserver does not allow SSLv3 connections"
else
	# apache is still allowing SSLv3 connections
	echo
	echo "ERROR: UCE Webserver does allow SSLv3 connections (CVE-2014-3566)"
	echo
	if [ "$OCDOCTOR_FIX" = "1" ]; then
		echo "Trying to automatically fix this..."
		echo
		if [ -f $CONF_FILE_ORIG ]; then
			print_file_exists_warning $CONF_FILE_ORIG
		else
			cp $CONF_FILE $CONF_FILE_ORIG
			sed 's/SSLProtocol .*$/SSLProtocol All -SSLv2 -SSLv3/' $CONF_FILE_ORIG > $CONF_FILE
			chown $USER_GROUP $CONF_FILE $CONF_FILE_ORIG
			chmod $MODE $CONF_FILE $CONF_FILE_ORIG
			echo "UCE Webserver config has been corrected, the EC must get restarted now!"
		fi
	else
		if [ -f $CONF_FILE_ORIG ]; then
			print_file_exists_warning $CONF_FILE_ORIG
		else
			echo "To disallow SSLv3 connections, you have to modify the UCE Webserver config file"
			echo
			echo "$CONF_FILE"
			echo
			echo "so that the line starting with 'SSLProtocol' looks like this:"
			echo
			echo "SSLProtocol All -SSLv2 -SSLv3"
			echo
			echo "followed by a restart of the EC."
			echo
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		fi
	fi
	echo
fi

$CACAO_FIX_AVAILABLE || exit

if $GF_FIXED; then
	echo "OK: Glassfish Webserver does not allow SSLv3 connections"
else
	# glassfish is still allowing SSLv3 connections
	echo
	echo "ERROR: Glassfish Webserver does allow SSLv3 connections (CVE-2014-3566)"
	echo
	
	if [ "$OCDOCTOR_FIX" = "1" ]; then
		echo "Trying to automatically fix this..."
		echo
		if [ -f $GF_JAR_ORIG ]; then
			# due to a bug in OCDoctor 4.39, the fix could be incomplete, we have to verify it
			if diff $GF_JAR $GF_JAR_ORIG >/dev/null 2>&1; then
				# previous applied fix was incomplete
				echo "Prevously applied fix has been incomplete, rerunning it..."
				echo
				rm $GF_JAR_ORIG
			fi
		fi
		if [ -f $GF_JAR_ORIG ]; then
			print_file_exists_warning $GF_JAR_ORIG
		else
			cat $GF_TARFILE | ( cd /tmp; tar xf - $GF_JAR_FIXED )
			cd /tmp 
			cp $GF_JAR $GF_JAR_ORIG
			cp $GF_JAR_FIXED $GF_JAR
			rm $GF_JAR_FIXED
			echo "Glassfish Webserver config has been corrected, the EC must get restarted now!"
		fi
	else
		if [ -f $GF_JAR_ORIG ]; then
			# due to a bug in OCDoctor 4.39, the fix could be incomplete, we have to verify it
			if diff $GF_JAR $GF_JAR_ORIG >/dev/null 2>&1; then
				# previous applied fix was incomplete
				echo "Prevously applied fix has been incomplete, rerun '# ./OCDoctor.sh --troubleshoot --fix' to fix it"
			else
				print_file_exists_warning $GF_JAR_ORIG
			fi
		else
			echo "To disallow SSLv3 connections, the file $GF_JAR must be replaced with file"
			echo "$GF_JAR_FIXED from tarball $ABS_GF_TARFILE"
			echo
			echo "followed by a restart of the EC."
			echo
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		fi
	fi		
	echo
fi
