#!/bin/bash

#### General variables ###
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	ECADM="/opt/sun/xvmoc/bin/ecadm"
else
	ECADM="/opt/SUNWxvmoc/bin/ecadm"
fi

MY_DIR=`dirname $0`
source $MY_DIR/../../functions
get_version ""

if [ ! "$VERSIONNUM" = "12132305" ]; then
	#### Only test this on Update 3 systems
	exit
fi

##### Check SYSTEMPROPERTY value ######
SQL_Template /var/tmp/ocdoctor.sql.$$ /var/tmp/ocdoctor.sql.out.$$ "select pvalue from SYSTEMPROPERTY where subsystem='OSP' and pkey='ldom.update_version.3.0';"
rm -f /var/tmp/ocdoctor.sql.out.$$		### Cleanup output file beforehand
echo "@/var/tmp/ocdoctor.sql.$$" | $ECADM sqlplus >/dev/null 2>/dev/null
rm -f /var/tmp/ocdoctor.sql.$$			### Cleanup of SQL file (created by SQL_Template)
if [ -f /var/tmp/ocdoctor.sql.out.$$ ]; then
	VALUE=`cat /var/tmp/ocdoctor.sql.out.$$`
	rm -f /var/tmp/ocdoctor.sql.out.$$		### Cleanup output file
	if [ "$VALUE" = "11" ]; then
		echo "ERROR: Database value for 'ldom.update_version.3.0' is 11, but it should be 10. This is a known issue in Update 3 (Bug 16681480)."
		echo "       This controls what Solaris 10 update is required to deploy LDOM 3.0. This should be Update 10 instead of Update 11".
		echo "" 
		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo "Trying to automatically fix this..."
			echo "update SYSTEMPROPERTY set pvalue='10' where subsystem='OSP' and pkey='ldom.update_version.3.0';" | $ECADM sqlplus >/dev/null
			echo "Done."
			echo ""
			echo "Make sure you restart the EC now:"
			echo "# $ECADM stop -w"
			echo "# $ECADM start -w"
			echo ""
		else
			echo "To fix, run the following:"
			echo "# echo \"update SYSTEMPROPERTY set pvalue='10' where subsystem='OSP' and pkey='ldom.update_version.3.0';\" | $ECADM sqlplus"
			echo ""
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			echo ""
			echo "After updating (manually or with --fix), you will need to restart the EC:"
			echo "# $ECADM stop -w"
			echo "# $ECADM start -w"
			echo ""
		fi
	elif [ "$VALUE" = "10" ]; then
		echo "OK: 'ldom.update_version.3.0' value is 10 in the database"
	else
		echo "ERROR: Unexpected value for 'ldom.update_version.3.0' in the database. Expected 11 or 10 but got:"
		echo $VALUE
		echo ""
	fi
else
	echo "ERROR: Unable to access DB to read the value for 'ldom.update_version.3.0'"
	echo ""
fi



