#!/bin/bash

#### Check version ####
MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
	source $MY_DIR/../../functions
	get_version ""          ### Provide VERSIONNUM
	if [ $VERSIONNUM -gt "12112076" ];then               #### Is this newer than Update 1? In testing latest one is 12112075
		echo "OK: No need to check for Solaris 11 agent bundle issue as this EC is newer than 12cR1 Update 1"
		exit 0           #### Only applies to U1 and below
	fi
fi

#### Actual test ####
if [ -d /var/opt/sun/xvm/images/agent ]; then
        COUNT=`ls /var/opt/sun/xvm/images/agent/OpsCenterAgent.SolarisIPS*.zip 2>/dev/null| wc -l  2>/dev/null| awk '{print $1}' 2>/dev/null`	## may not have S11 agents at all 
        if [ $COUNT -gt 1 ]; then
        	echo "ERROR: Found multiple Solaris 11 agent bundles in /var/opt/sun/xvm/images/agent/"
        	echo "       This will cause issues deploying agent bundles to Solaris 11 hosts (Bug 15801502):"
        	CPWD=`pwd`
        	cd /var/opt/sun/xvm/images/agent && ls -l OpsCenterAgent.SolarisIPS*.zip*
        	cd $CPWD
        	echo ""
        	if [ "$OCDOCTOR_FIX" = "1" ];then
        		echo "Trying to automatically fix this..."
        		echo ""
        		## First, determine which one we should keep
        		FILETOKEEP=`cd /var/opt/sun/xvm/images/agent && ls OpsCenterAgent.SolarisIPS*.zip | tail -1`
        		if [ "$FILETOKEEP" = "" ]; then
        			echo "ERROR: Could not identify which agent bundle to keep, skipping auto fix"
        			echo ""
        			cd $CPWD
        			exit 1
        		fi
        		echo "Keeping agent bundle $FILETOKEEP"
        		cd /var/opt/sun/xvm/images/agent && ls OpsCenterAgent.SolarisIPS*.zip* | grep -v "$FILETOKEEP" | while read FILETOREMOVE; do
        			echo "Moving $FILETOREMOVE to /var/tmp/$FILETOREMOVE"
        			mv -f $FILETOREMOVE /var/tmp/$FILETOREMOVE
        		done
        		echo ""
        		echo "OK: Fix was applied"
			echo ""
			echo "NOTE: you must restart the Enterprise Controller so it 'forgets' the old version!"
        		echo ""
        		cd $CPWD
        		
        	else
        		echo "To fix, remove all the old versions (and their .sig files) and keep only the latest version."
        		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
        		echo ""
			echo "Please note that in both cases, you need to restart the Enterprise Controller so it 'forgets' the old version!"
			echo ""
        	fi
        else
        	echo "OK: Found only one Solaris 11 agent bundle"
        fi
fi
