#!/bin/bash

### This will check for Bug 15807627 on Solaris 11
### http*_proxy environment variables in root profile can cause MSR operations to fail

UNAMER=`uname -r`
if [ ! "$UNAMER" = "5.11" ]; then
	exit
fi

#### Check if http_proxy is set in one of the profiles
OUTPUT=`su - root -c "if [ ! \"\\$http_proxy\" = \"\" ]; then  echo HTTP_PROXY_SET_IN_PROFILES \\$http_proxy; fi"  | grep HTTP_PROXY_SET_IN_PROFILES`
if [ ! "$OUTPUT" = "" ]; then
	PROXYSET=`echo "$OUTPUT" | awk '{print $2}'`
	#### we have proxy set in there, need to check if we exclude the local IPS repo"
	OUTPUT=`su - root -c "if [ ! \"\\$no_proxy\" = \"\" ]; then  echo HTTP_PROXY_SET_IN_PROFILES \\$no_proxy; fi"  | grep HTTP_PROXY_SET_IN_PROFILES`
	OUTPUT2=`echo $OUTPUT | grep oracle-oem-oc-mgmt-`
	if [ "$OUTPUT" = "" ] || [ "$OUTPUT2" = "" ] ; then		### if there's no 'no_proxy', or if there is no 'oracle-oem-oc-mgmt' in 'no_proxy'
		echo "WARNING: http_proxy is set in one of the user profile files (in ~/.profile, ~/.bashrc, in /etc, or somewhere else)"
		echo "         It is set to use the proxy $PROXYSET"
		echo "         This may cause issues with the local IPS repository (Bug 15807627)"
		echo "         To fix, add the following line to the same profile file which sets the http_proxy:"
		HOSTNAMEOUTPUT=`/usr/bin/hostname | /usr/bin/awk -F. '{print $1}'`
		echo "export no_proxy=\"oracle-oem-oc-mgmt-$HOSTNAMEOUTPUT,localhost,127.0.0.1\""
		echo ""
	else
		NOPROXY=`echo "$OUTPUT" | awk '{print $2}'`
		echo "OK: http_proxy is set and no_proxy is set to $NOPROXY"
	fi
else
	echo "OK: No http_proxy is set in the user profile files"
fi
