#!/bin/bash

OS=`uname`
PUBLIC_FOLDER="nothinghere"
PRIVATE_FOLDER="nothinghere"
if [ $OS == "Linux" ]; then
	LOGS_FOLDER=/var/opt/sun/xvm/uce/usr.local/server/logs
	UCE_RC="/var/opt/sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc"
	if [ -d /var/opt/sun/xvm/uce/usr.local/server/public/ ]; then	# 12c with no update library goes here
		PUBLIC_FOLDER=/var/opt/sun/xvm/uce/usr.local/server/public/
	fi
else
	LOGS_FOLDER=/var/opt/sun/xvm/uce/var.opt/server/logs
	UCE_RC="/var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc"
	if [ -d /var/opt/sun/xvm/uce/opt/server/public ]; then		#12c with no update library goes here
    		PUBLIC_FOLDER=/var/opt/sun/xvm/uce/opt/server/public
    	fi
fi

if [ ! -f ${UCE_RC} ]; then
	echo "ERROR: Could not find ${UCE_RC} in public/private folder permissions test"
	echo ""
	exit 1
fi

### Determine library path
PUBLIC_FOLDER_TMP=`grep "public_dir_name" $UCE_RC 2>/dev/null | awk -F"\"" '{print $2}' 2>/dev/null`
if [ ! "$PUBLIC_FOLDER_TMP" = "" ]; then
	if [ -d $PUBLIC_FOLDER_TMP ]; then			### 12c has libraries
		PUBLIC_FOLDER=$PUBLIC_FOLDER_TMP
	fi
fi
if [ ! -d $PUBLIC_FOLDER ]; then
	echo "ERROR: Could not find public folder $PUBLIC_FOLDER"
	echo ""
	exit 1 
fi
DATAFOLDER=`dirname $PUBLIC_FOLDER`

#### Check if both folders (public & private) and their subfolders have the right ownership "uce-sds:uce-sds"
TEST_OUTPUT=/tmp/public+private_folders.$$.out
ls -ld $DATAFOLDER/public $DATAFOLDER/private $DATAFOLDER/public/*  $DATAFOLDER/private/* | grep -v "uce-sds *uce-sds" > $TEST_OUTPUT
if [ -s "$TEST_OUTPUT" ]; then
	echo
	echo "ERROR: UCE Library contains files and folders not owned by uce-sds:uce-sds !"
	echo
	cat $TEST_OUTPUT
	echo
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to automatically fix this..."
		chown -R uce-sds:uce-sds $DATAFOLDER/public $DATAFOLDER/private
		echo "OK: ownership was fixed on $DATAFOLDER"
	else
		echo "To fix, run the following:"
		echo "# chown -R uce-sds:uce-sds $DATAFOLDER/public"
		echo "# chown -R uce-sds:uce-sds $DATAFOLDER/private"
		echo ""
		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
	fi
	echo ""
else
	echo "OK: UCE 'public' and 'private' folders have correct ownership"
fi
rm -f $TEST_OUTPUT

# check if there are log files which are belonging to nouser
find $LOGS_FOLDER -nouser -ls > $TEST_OUTPUT
if [ -s "$TEST_OUTPUT" ]; then
	echo
	echo "ERROR: UCE logs directory contains files and folders not owned by uce-sds:uce-sds !"
	echo
	cat $TEST_OUTPUT
	echo
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to automatically fix this..."
		find $LOGS_FOLDER -nouser -exec chown uce-sds:uce-sds {} \;
		echo "OK: ownership of logfiles fixed"
	else
		echo "To fix, run the following:"
		echo "# find $LOGS_FOLDER -nouser -exec chown uce-sds:uce-sds {} \;"
		echo ""
		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
	fi
	echo ""
else
	echo "OK: UCE log files have correct ownership"
fi
rm -f $TEST_OUTPUT

##### Check that /var/tmp/ is writable by non-root
#### Check write on the folder
rm -f /var/tmp/.doctor-test.tmp
su uce-sds -c "touch /var/tmp/.doctor-test.tmp 2>/dev/null"
if [ -f /var/tmp/.doctor-test.tmp ]; then
	su uce-sds -c "rm -f /var/tmp/.doctor-test.tmp"
	rm -f /var/tmp/.doctor-test.tmp
	echo "OK: '/var/tmp' folder is writable for uce-sds"
else
	echo "ERROR: /var/tmp is not writable by non-root user (tried using user 'uce-sds')."
	echo ""
fi
