#!/bin/bash

#### Check if opscenter publisher shows up first before solaris

UNAMER=`uname -r`
if [ ! "$UNAMER" = "5.11" ]; then
        exit
fi

TOPPUB=`pkg publisher -H | egrep "^solaris|^opscenter" | head -1 | awk '{print $1}'`

if [ "$TOPPUB" = "solaris" ]; then
	echo "OK: Solaris publisher comes before the Ops Center publisher"
elif [ "$TOPPUB" = "opscenter" ]; then
	echo "ERROR: 'opscenter' publisher comes up before the 'solaris' publisher."
	echo "       This may cause various issues. Here is the output of 'pkg publisher':"
	pkg publisher
	echo ""
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to automatically fix this..."
		pkg set-publisher -P solaris
		echo "Done."
		echo ""
	else
		echo "To fix this, run the following command to set the Solaris publisher to come first:"
		echo ""
		echo "# pkg set-publisher -P solaris"
		echo ""
		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		echo ""
	fi
else
	echo "ERROR: Unable to read 'pkg publisher' output properly in the Solaris vs. OpsCenter publisher test ('publisher.sh')"
	echo ""
fi
