#!/bin/bash
#
# In case EC is using remote DB and the remote DB user don't have permission on tablespace
# OC_RM_RESOURCE_TS, the EC upgrade will fail and roll back. More info can be found here: 
#
# CR 17737994 - new oc_rm_resource_ts tablespace for reports should be available in customer db
#

# source functions file
MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        . $MY_DIR/../../functions
else
        exit
fi
get_version

if [ $VERSIONNUM -lt 12130000 ]; then
	# this check is only applicable for Opscenter 12.1.3 and above
        exit 0
fi

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        ECADM="/opt/sun/xvmoc/bin/ecadm"
	AWK="/usr/bin/awk"
else
        ECADM="/opt/SUNWxvmoc/bin/ecadm"
	AWK="/usr/bin/nawk"
fi

# check if a remote DB is used
DB_PROPERTIES=/var/opt/sun/xvm/db.properties
if [ -f $DB_PROPERTIES ]; then
	#### Determine if this local or remote
	LOCALREMOTE=$($AWK -F= '/^mgmtdb.server.type=/ {print $2}' $DB_PROPERTIES)
	REMOTE_DB_USER=$($AWK -F= '/^mgmtdb.appuser=/ {print $2}' $DB_PROPERTIES)
else
	echo "ERROR: $0: DB Properties file $DB_PROPERTIES not found!"
        exit 1
fi


if [ "$LOCALREMOTE" = "remote" ]; then
	if echo "SELECT TABLESPACE_NAME FROM USER_TS_QUOTAS WHERE TABLESPACE_NAME='OC_RM_RESOURCE_TS';" | $ECADM sqlplus 2>/dev/null | grep '^OC_RM_RESOURCE_TS$' > /dev/null; then
		echo "OK: Tablespace OC_RM_RESOURCE_TS is accessible in remote DB"
	else
		cat << EOF	

ERROR: Tablespace OC_RM_RESOURCE_TS needs to be added to the remote DB (Bug 17737994)!
		

Tablespace creation example (to be run by DBA of remote DB):

CREATE TABLESPACE OC_RM_RESOURCE_TS
              DATAFILE '<path to datafile>/ocresource01.dbf'
              SIZE 100M REUSE
              AUTOEXTEND ON
                  NEXT 100M
                  MAXSIZE 32767M
          EXTENT MANAGEMENT LOCAL
          SEGMENT SPACE MANAGEMENT AUTO
          ;

ALTER USER $REMOTE_DB_USER QUOTA UNLIMITED ON OC_RM_RESOURCE_TS;

EOF
		exit 1
	fi
else
	echo "OK: EC is using a local DB, no check for Tablespace OC_RM_RESOURCE_TS required"
fi
