#!/bin/bash
# we will skip the whole script for now
exit 0

### This script collects some basic statistics ###

export PATH=/usr/sbin:/usr/bin:$PATH
export LD_LIBRARY_PATH=/usr/lib:/lib

#DEBUG=true ; rm -f /tmp/OCDoctor_stat_last_run.txt
DEBUG=false				### In production it should be "false"
SKIPWGET=false				### In production it should be "false"

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	SAT_BIN="/opt/sun/xvmoc/bin/satadm"
	WGET="/usr/bin/wget"
	SC_CONSOLE="/usr/bin/sc-console"
	OPENSSL=/usr/bin/openssl
else
	SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
	WGET="/usr/sfw/bin/wget"
	SC_CONSOLE="/usr/bin/sc-console"
	OPENSSL=/usr/sfw/bin/openssl
fi

LASTRUNFILE="/tmp/OCDoctor_stat_last_run.txt"
LASTRUNSHORT="OCDoctor_stat_last_run.txt"

if [ ! -x $WGET ]; then
	$DEBUG && echo "No $WGET"
	exit
fi

if [ ! -x $OPENSSL ]; then
	$DEBUG && echo "No $OPENSSL"
	exit
fi

if [ -f /var/opt/sun/xvm/no-oracle-stats ] || [ -f /no-oracle-stats ] || [ -f /root/no-oracle-stats ]; then
	echo "OK: Basic statistic was not collected or uploaded"
	exit 0
fi

if [ -f $LASTRUNFILE ]; then
	RANDNUMBER=$[ ( $RANDOM % 6 )  + 5 ] ; 	### Number between 5 and 10
	#RANDNUMBER=$[ ( $RANDOM % 3 )  + 3 ] ; 	### Number between 3 and 5
	#RANDNUMBER=$[ ( $RANDOM % 3 )  + 1 ] ; 	### Number between 1 and 3
	OUTPUT=`find /tmp/$LASTRUNSHORT -mtime -${RANDNUMBER} 2>/dev/null`
	if [ "$OUTPUT" = "" ]; then
		$DEBUG && echo "$LASTRUNFILE was not created in the past $RANDNUMBER days"
	else
		$DEBUG && echo "$LASTRUNFILE was created in the past $RANDNUMBER days, skipping"
		exit 0
	fi
else
	$DEBUG && echo "OK: $LASTRUNFILE not found, will continue as planned"
fi


CONNPROP="/var/opt/sun/xvm/persistence/scn-satellite/connection.properties"
USINGPROXY=1
if [ -f $CONNPROP ]; then
	#### Check if we're in Connected mode
	OUTPUT=`grep "^disconnected" ${CONNPROP} 2>/dev/null`
	if [ "$OUTPUT" = "" ]; then			### likely an empty file, means not configured yet
		$DEBUG && echo "Empty $CONNPROP"
		exit 0
	fi
	PROXYHOST=`grep proxy-host $CONNPROP 2>/dev/null| awk -F"=" '{print $2}' 2>/dev/null`
	PROXYPORT=`grep proxy-port $CONNPROP 2>/dev/null| awk -F"=" '{print $2}' 2>/dev/null`
	PROXYUSER=`grep proxy-username $CONNPROP 2>/dev/null| awk -F"=" '{print $2}' 2>/dev/null`
	PROXYPASS=`grep proxy-password $CONNPROP 2>/dev/null | cut -c16- 2>/dev/null`
	if [ ! "$PROXYHOST" = "" ] && [ ! "$PROXYPORT" = "" ]; then
		USINGPROXY=2
		export http_proxy="$PROXYHOST:$PROXYPORT"
		export https_proxy="$PROXYHOST:$PROXYPORT"
	fi
else
	$DEBUG && echo "No $CONNPROP"
	exit 0
fi

##### Check if we're in disconnected mode
if [ "$UNAME" = "Linux" ];then
	if [ -f /var/opt/sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc ]; then
		UCE_RC="/var/opt/sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc"
	else
		UCE_RC="/usr/local/uce/server/cgi-bin/.uce.rc"
	fi
else
	if [ -f /var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc ]; then
		UCE_RC="/var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc"
	else
		UCE_RC="/opt/SUNWuce/server/cgi-bin/.uce.rc"
	fi
fi
OUTPUT=`grep "general\.server_name" $UCE_RC 2>/dev/null| awk -F"\"" '{print $2}' 2>/dev/null | grep -v "\.oracle\.com" 2>/dev/null | grep -v "\.sun\.com" 2>/dev/null`
### if set to anything but oracle.com or sun.com, it's disconnected
if [ "$OUTPUT" != "" ]; then
	$DEBUG && echo "Disconnected"
	exit 0
fi

SQL_Template(){
        FILENAME=$1
        OUTPUTFILE=$2
        SQL=$3
        echo "set echo off" > $FILENAME
        echo "set feedback off" >> $FILENAME
        echo "set colsep," >> $FILENAME
        echo "set pagesize 0" >> $FILENAME
        echo "set trimspool on" >> $FILENAME
        echo "set headsep off" >> $FILENAME
        echo "set sqlprompt ''" >> $FILENAME
		echo "set term off" >> $FILENAME
        echo "spool $2" >> $FILENAME
        echo "$SQL" >> $FILENAME
        echo "spool off" >> $FILENAME
}
SQL_Template_cont(){
		FILENAME=$1
		OUTPUTFILE=$2
		SQL=$3
		echo "spool $2" >> $FILENAME
        echo "$SQL" >> $FILENAME
        echo "spool off" >> $FILENAME
}

################ Figure out if wget supports 'no-check-certificate' flag ########################
CERTSUPPORT=`$WGET --help 2>/dev/null | grep no-check-certificate`
if [ "$CERTSUPPORT" = "" ]; then
	CERTFLAG=""
else
	CERTFLAG="--no-check-certificate"
fi

get_token() {
	TMPFILE="/var/tmp/doctor-out-tmp.$$"
	rm -f $TMPFILE > /dev/null 2>/dev/null
	rm -f /var/tmp/doctor-out-tmp.* > /dev/null 2>/dev/null
	##### Get token ###
	if [ "$PROXYUSER" = "" ]; then
		$WGET ${CERTFLAG} -qq --timeout=10 --tries 2 --save-cookies /var/tmp/java-cookie.bin --keep-session-cookies  https://java.net/projects/oc-doctor/forums/updates/topics/new -O $TMPFILE 2>/dev/null
	else
		eval "$WGET ${CERTFLAG} -qq --timeout=10 --tries 2 --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --save-cookies /var/tmp/java-cookie.bin --keep-session-cookies  https://java.net/projects/oc-doctor/forums/updates/topics/new -O $TMPFILE 2>/dev/null"
	fi
	TOKEN=`cat $TMPFILE 2>/dev/null | grep "^var page" 2>/dev/null| awk -F"\"" '{print $4}' 2>/dev/null`
	##### End of 'get Token' #####
	rm -f $TMPFILE > /dev/null 2>/dev/null
}

OUTFILE="/var/tmp/out.txt.doctor.$$"
SQLFILE="/var/tmp/sql.txt.doctor.$$"

rm -f /var/tmp/out.txt.doctor* >/dev/null 2>/dev/null
rm -f /var/tmp/sql.txt.doctor* >/dev/null 2>/dev/null

if [ -f $SAT_BIN ]; then
	### Check if DB is running ###
    OUTPUT=`$SAT_BIN status 2>/dev/null`
    if [ ! "$OUTPUT" = "online" ]; then
            exit
    fi

	#### Merge all the DB calls into one here
	SQL_Template $SQLFILE ${OUTFILE}.1 "select count(agent_ip) from agent_table;"		### Total agents
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.2 "select authentication_user from download_authentication_table where authentication_id='XVM_OPS_AUTH_ID';"	### username
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.3 "select GEARTYPE from V_VMB_GEAR;"		### OS, SP etc
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.4a "select count(job_id) from scn_job;"		### JOBS_TOTAL
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.4 "select count(job_id) from scn_job where name='UpdateProvisioningJob';"		### Jobs1
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.5 "select count(job_id) from scn_job where name='LocalContentJob';"		### Jobs2
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.6 "select count(job_id) from scn_job where name='ActivateBootEnvironmentJob';"		### Jobs3
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.7 "select count(job_id) from scn_job where name='NewBARReportJob';"		### Jobs4
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.8 "select count(job_id) from scn_job where name='ReportGenerationJob';"		### Jobs5
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.9 "select count(job_id) from scn_job where name='Cold Migration Job';"		### Jobs6
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.10 "select count(job_id) from scn_job where name='WarmMigrationJob';"		### Jobs7
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.11 "select count(job_id) from scn_job where name='Create-DeploymentPlan';"		### Jobs8
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.12 "select count(job_id) from scn_job where name='Execute-DeploymentPlan';"		### Jobs9
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.13 "select count(job_id) from scn_job where name='Create guest';"		### Jobs10
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.14 "select count(*) from sc_client_registration where connection_type=2 and revoked_dtt is null;"		### Proxies
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.15 "select count(job_id) from scn_job where name like 'OCDoctor%';"
	SQL_Template_cont ${SQLFILE} ${OUTFILE}.16 "select count(*) from MOS_USERS;"

	echo "@${SQLFILE}" |  ${SAT_BIN} sqlplus >/dev/null 2>/dev/null

	### Total agents ###
	if [ -f ${OUTFILE}.1 ]; then
		TOTAL_AGENTS=`tail -1 ${OUTFILE}.1 | awk '{print $1}' 2>/dev/null`
	else
		TOTAL_AGENTS=""
	fi
	$DEBUG && echo TOTAL_AGENTS:$TOTAL_AGENTS

	### username ###
	if [ -f ${OUTFILE}.2 ]; then
		USERNAME=`tail -1 ${OUTFILE}.2 | awk '{print $1}' 2>/dev/null`
	else
		USERNAME=""
	fi
	if [ "$USERNAME" = "" ]; then
		$DEBUG && echo Empty USERNAME
		rm -f /var/tmp/out.txt.doctor* >/dev/null 2>/dev/null
		rm -f /var/tmp/sql.txt.doctor* >/dev/null 2>/dev/null
		exit 0
	fi
	if [ "$USERNAME" = "disconnected-mode" ]; then
		$DEBUG && echo "Disconnected mode user"
		rm -f /var/tmp/out.txt.doctor* >/dev/null 2>/dev/null
		rm -f /var/tmp/sql.txt.doctor* >/dev/null 2>/dev/null
		exit 0
	fi
	$DEBUG && echo USERNAME:$USERNAME
	
	### OS ###
	if [ -f ${OUTFILE}.3 ]; then
		OPERATINGSYSTEMS=`grep "^OperatingSystem" ${OUTFILE}.3 2>/dev/null |wc -l | awk '{print $1}' 2>/dev/null`
		GLOBALZONES=`grep "^GlobalZone" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
		TOTAL_OS=`expr $OPERATINGSYSTEMS + $GLOBALZONES 2>/dev/null`
		TOTAL_SERVERS=`grep "^Server" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
		TOTAL_LDOMS=`grep "^LDomGuest" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
		TOTAL_ZONES=`grep "^NonGlobalZone" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
		TOTAL_OVMGUEST=`grep "^OvmGuest" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
		TOTAL_VIRTPOOL=`grep "^VirtualPool" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
		TOTAL_CLOUDS=`grep "^Cloud" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
		TOTAL_TENANTS=`grep "^Tenancy" ${OUTFILE}.3 2>/dev/null | wc -l | awk '{print $1}' 2>/dev/null`
	else
		TOTAL_OS=""
		TOTAL_SERVERS=""
		TOTAL_LDOMS=""
		TOTAL_ZONES=""
		TOTAL_OVMGUEST=""
		TOTAL_VIRTPOOL=""
		TOTAL_CLOUDS=""
		TOTAL_TENANTS=""
	fi
	
	$DEBUG && echo "TOTAL_OS:$TOTAL_OS  TOTAL_SERVERS:$TOTAL_SERVERS  TOTAL_LDOMS:$TOTAL_LDOMS"

	#echo "select class_name,mbean_interface from hd_resource" | $DB_BIN psql 2>/dev/null | grep "com.sun.hss.domain.SkeletalManagedResourceMXBean" 2>/dev/null> /var/tmp/doctor-out.$$
	
	### Unique string ###
	UNIQS="undef"
	if [ -f $SC_CONSOLE ]; then
		UNIQS=`$SC_CONSOLE list-connections |grep "^localhost" 2>/dev/null| awk -F":" '{printf("%s:%s",$6,$7)}' 2>/dev/null`
	fi
	MAC="undef"
	if [ "$UNAME" = "Linux" ]; then
		MAC=`ifconfig -a 2>/dev/null| grep HWaddr 2>/dev/null | head -1 2>/dev/null| awk -F"HWaddr" '{print $2}' 2>/dev/null | awk '{print $1}' 2>/dev/null | sed 's/:/_/g' 2>/dev/null`
	else
		MAC=`ifconfig -a 2>/dev/null| grep ether 2>/dev/null |head -1 2>/dev/null| awk '{print $2}' 2>/dev/null| sed 's/:/_/g' 2>/dev/null`
	fi
	$DEBUG && echo "UNIQS:$UNIQS MAC:$MAC"
	

	### Version ###
	VERSIONFILE="/n1gc-setup/.version.properties"
	ECVERSION="undef"
	if [ -f $VERSIONFILE ]; then
		ECVERSION=`cat $VERSIONFILE | grep "product\.version=" 2>/dev/null | awk -F"=" '{print $2}' 2>/dev/null`
	fi
	
	$DEBUG && echo "ECVERSION:$ECVERSION"
		
	### Time ###
	GDATE=`date "+%Y-%m-%d" 2>/dev/null`
	GTIME=`date "+%H:%M:%S" 2>/dev/null`

	### EC_OS and HARDWARE ###
	EC_HARDWARE=`uname -p`
	EC_OS=`uname -s`
	
	##### Ec OS version #####
	EC_OSVER="undef"
	if [ "$UNAME" = "Linux" ]; then
		if [ -f /etc/redhat-release ]; then
			EC_OSVER=`cat /etc/redhat-release 2>/dev/null |awk '{print $7}' 2>/dev/null`
		elif [ -f /etc/SuSE-release ]; then
			EC_OSVER=`grep "^VERSION" /etc/SuSE-release 2>/dev/null | awk '{print $3}' 2>/dev/null`
		fi
		#### Check if this OEL or RHEL
		rpm -q oracle-logos >/dev/null 2>/dev/null
		if [ $? -eq 0 ]; then
			EC_OSVER="OEL_${EC_OSVER}"
		else
			EC_OSVER="RHEL_${EC_OSVER}"
		fi
	else
		EC_OSVER=`uname -r | awk -F"." '{print $2}'`
		EC_OSVER="SOL_${EC_OSVER}"
	fi
	
	### Job breakdown ###
	if [ -f ${OUTFILE}.4a ]; then JOBS_TOTAL=`tail -1 ${OUTFILE}.4a | awk '{print $1}' 2>/dev/null`
	else JOBS_TOTAL="";	fi
	if [ -f ${OUTFILE}.4 ]; then JOBS1=`tail -1 ${OUTFILE}.4 | awk '{print $1}' 2>/dev/null`
	else JOBS1="";	fi
	if [ -f ${OUTFILE}.5 ]; then JOBS2=`tail -1 ${OUTFILE}.5 | awk '{print $1}' 2>/dev/null`
	else JOBS2="";	fi
	if [ -f ${OUTFILE}.6 ]; then JOBS3=`tail -1 ${OUTFILE}.6 | awk '{print $1}' 2>/dev/null`
	else JOBS3="";	fi
	if [ -f ${OUTFILE}.7 ]; then JOBS4=`tail -1 ${OUTFILE}.7 | awk '{print $1}' 2>/dev/null`
	else JOBS4="";	fi
	if [ -f ${OUTFILE}.8 ]; then JOBS5=`tail -1 ${OUTFILE}.8 | awk '{print $1}' 2>/dev/null`
	else JOBS5="";	fi
	if [ -f ${OUTFILE}.9 ]; then JOBS6=`tail -1 ${OUTFILE}.9 | awk '{print $1}' 2>/dev/null`
	else JOBS6="";	fi
	if [ -f ${OUTFILE}.10 ]; then JOBS7=`tail -1 ${OUTFILE}.10 | awk '{print $1}' 2>/dev/null`
	else JOBS7="";	fi
	if [ -f ${OUTFILE}.11 ]; then JOBS8=`tail -1 ${OUTFILE}.11 | awk '{print $1}' 2>/dev/null`
	else JOBS8="";	fi
	if [ -f ${OUTFILE}.12 ]; then JOBS9=`tail -1 ${OUTFILE}.12 | awk '{print $1}' 2>/dev/null`
	else JOBS9="";	fi
	if [ -f ${OUTFILE}.13 ]; then JOBS10=`tail -1 ${OUTFILE}.13 | awk '{print $1}' 2>/dev/null`
	else JOBS10="";	fi
	if [ -f ${OUTFILE}.14 ]; then PROXIES=`tail -1 ${OUTFILE}.14 | awk '{print $1}' 2>/dev/null`
	else PROXIES="";	fi
	if [ -f ${OUTFILE}.15 ]; then 
		DOCJOBS=`tail -1 ${OUTFILE}.15 | awk '{print $1}' 2>/dev/null`
		if [ "$DOCJOBS" = "SP2-0640:" ]; then		### Not connected, prevent error
			DOCJOBS=0
		fi
		if [ $DOCJOBS -ge 1 ]; then
			DOCJOBS=`expr $DOCJOBS - 1 2>/dev/null`
		fi
	else 
		DOCJOBS=""
	fi
	if [ -f ${OUTFILE}.16 ]; then 
		MOSUSERS=`tail -1 ${OUTFILE}.16 | awk '{print $1}' 2>/dev/null`
	else 
		MOSUSERS=""
	fi
	
	#### Local or remote DB
	LOCALREMOTE="undef"
	if [ -f /var/opt/sun/xvm/db.properties ]; then
		LOCALREMOTE=`grep "^mgmtdb.server.type" /var/opt/sun/xvm/db.properties 2>/dev/null | awk -F"=" '{print $2}' 2>/dev/null`
	fi
	
	#### OCDoctor version
	DOCVER="undef"
	if [ -f /var/opt/sun/xvm/OCDoctor/version ]; then
		DOCVER=`head -1 /var/opt/sun/xvm/OCDoctor/version 2>/dev/null`
	fi
	if [ -f ./OCDoctor.sh ]; then
		DOCVER=`head -1 ./version 2>/dev/null`
	elif [ -f ../OCDoctor.sh ]; then
		DOCVER=`head -1 ../version 2>/dev/null`
	elif [ -f ../../OCDoctor.sh ]; then
		DOCVER=`head -1 ../../version 2>/dev/null`
	fi
	
	#### OCM configured?
	if [ -f /var/opt/sun/xvm/ocm/ccr/bin/configCCR ]; then
		#### OCM MAIN connected?
		EMCCR="/var/opt/sun/xvm/ocm/ccr/bin/emCCR"
		if [ -f $EMCCR ]; then
			OUTPUT=`cd /var/opt/sun/xvm/ocm/ccr/bin/ 2>/dev/null ; $EMCCR status 2>&1`
			RETVAL=$?
			if [ $RETVAL -ne 0 ]; then
				OCMM=3		### emCCR returns unexpected error, will get overwritten by the below
			fi
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Collector Mode" 2>/dev/null| awk '{print $3}' 2>/dev/null`
			if [ "$OUTPUT2" = "Connected" ]; then
				##### It's connected, figure out last connected time
				OCMM_LAST_COLLECT=""
				OCMM_LAST_COLLECT=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Last Collection Time" 2>/dev/null| awk '{printf("%s_%s\n",$4,$5)}' 2>/dev/null`
				OCMM=7
			else
				if [ "$OUTPUT2" = "Disconnected" ]; then
					OCMM=4			### Disconnected
				else
					OUTPUT3=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Oracle Configuration Manager is not running" 2>/dev/null`
					if [ "$OUTPUT3" != "" ]; then
						OCMM=5			#### Not running
					else
						OCMM=6			#### Unknown output
					fi
				fi
			fi
			#### check emCCR test -verbose
			OCMMTEST=20			#### didnt find any of those following strings
			OUTPUT=`cd /var/opt/sun/xvm/ocm/ccr/bin/ 2>/dev/null ; $EMCCR -verbose test 2>&1`
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "is not supported in disconnected mode" 2>/dev/null`
			if [ "$OUTPUT2" != "" ]; then OCMMTEST=3; fi
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "error" 2>/dev/null`
			if [ "$OUTPUT2" != "" ]; then OCMMTEST=4; fi
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Command successfully completed" 2>/dev/null`
			if [ "$OUTPUT2" != "" ]; then OCMMTEST=5; fi
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Access Denied" 2>/dev/null`
			if [ "$OUTPUT2" != "" ]; then OCMMTEST=6; fi
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Cannot connect to the server" 2>/dev/null`
			if [ "$OUTPUT2" != "" ]; then OCMMTEST=7; fi
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Proxy server information is incorrect" 2>/dev/null`
			if [ "$OUTPUT2" != "" ]; then OCMMTEST=8; fi
			OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep -i "Proxy server is not available" 2>/dev/null`
			if [ "$OUTPUT2" != "" ]; then OCMMTEST=9; fi
		else
			OCMM=2			#### emCCR does not exist
			OCMMTEST=2
		fi
		#### ocmharvester configured?
		OCHARV="/var/opt/sun/xvm/ocm/ccr/sysman/admin/util/opscenterharvester"
		OUTPUT=`crontab -l 2>/dev/null| grep $OCHARV 2>/dev/null| grep -v "^#" 2>/dev/null`
		if [ "$OUTPUT" = "" ]; then
			OCM=12
		else
			#### Check if the harvester is connected
			OUTPUT=`cd /var/opt/sun/xvm/ocm/ccr/sysman/admin/util/ ; $OCHARV -e 2>/dev/null`
			RETVAL=$?
			if [ $RETVAL -ne 0 ]; then
				OCM=13
			else
				OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep "Connected:" 2>/dev/null| awk '{print $2}' 2>/dev/null`
				if [ "$OUTPUT2" = "yes" ]; then
					#OCM=5				### Not in use anymore
					#### Check if the OCM is connected
					EMCCR="/var/opt/sun/xvm/ocm/ccr/bin/emCCR"
					if [ -f $EMCCR ]; then
						OUTPUT=`cd /var/opt/sun/xvm/ocm/ccr/bin/ 2>/dev/null ; $EMCCR status 2>/dev/null`
						RETVAL=$?
						if [ $RETVAL -ne 0 ]; then
							OCM=17		### emCCR returns unexpected error
						else
							OUTPUT2=`printf "$OUTPUT\n" 2>/dev/null| grep "Collector Mode" 2>/dev/null| awk '{print $3}' 2>/dev/null`
							if [ "$OUTPUT2" = "Connected" ]; then
								OUTPUT=`ps -ef 2>/dev/null | grep "/var/opt/sun/xvm/ocm/ccr/bin/nmz" 2>/dev/null  | grep -v grep 2>/dev/null `
								if [ "$OUTPUT" = "" ] ;then
									OCM=19		##### nmz process is not running
								else
									OCM=20		##### All good
								fi
							else
								OCM=18		##### OCM is not connected
							fi
						fi
					else
						OCM=16			#### emCCR does not exist
					fi
				else
					### harvester is not connected
					OCM=14		### harvester is not connected, system must be in disconnected mode
				fi
			fi
		fi
	else
		OCMM=1			##### OCM not configured
		OCMMTEST=1
		if [ -d /var/opt/sun/xvm/ocm/ccr ]; then
			OCM=11				#### OCM is unzipped but not configured
		else
			OCM=10				#### OCM is not unzipped
		fi
	fi
	
	HOSTNAME=`hostname 2>/dev/null`
	CCRHOSTS="/var/opt/sun/xvm/ocm/ccr/hosts"
	if [ -d $CCRHOSTS ]; then
		OUTPUT=`find $CCRHOSTS -name "*ops_center_config.xml" 2>/dev/null | head -1 2>/dev/null`
		if [ "$OUTPUT" = "" ]; then
			TARGETGUID="nofile"
		else
			TARGETGUID=`basename "$OUTPUT" 2>/dev/null | awk -F"-" '{print $1}' 2>/dev/null`
		fi
		#OCMXMLS=`find $CCRHOSTS -name "*.xml" 2>/dev/null | wc -l 2>/dev/null | awk '{print $1}' 2>/dev/null`
		OCMXMLS=`cd $CCRHOSTS && ls */state/upload/external/*/*xml 2>/dev/null | wc -l 2>/dev/null | awk '{print $1}' 2>/dev/null`
		if [ "$OCMXMLS" = "" ]; then
			OCMXMLS=0
		fi
	else
		TARGETGUID="nofolder"
		OCMXMLS=0
	fi

	$DEBUG && echo "JOBS_TOTAL:$JOBS_TOTAL  JOBS1:$JOBS1 JOBS2:$JOBS2 JOBS3:$JOBS3 JOBS4:$JOBS4"
	$DEBUG && echo "JOBS5:$JOBS5 JOBS6:$JOBS6 JOBS7:$JOBS7 JOBS8:$JOBS8 JOBS9:$JOBS9  JOBS10:$JOBS10  PROXIES:$PROXIES"
	$DEBUG && echo "EC_OSVER:$EC_OSVER LOCALREMOTE:$LOCALREMOTE TOTAL_ZONES:$TOTAL_ZONES TOTAL_OVMGUEST:$TOTAL_OVMGUEST"
	$DEBUG && echo "TOTAL_VIRTPOOL:$TOTAL_VIRTPOOL TOTAL_CLOUDS:$TOTAL_CLOUDS TOTAL_TENANTS:$TOTAL_TENANTS DOCJOBS:$DOCJOBS DOCVER:$DOCVER"
	$DEBUG && echo "OCM:$OCM HOSTNAME:$HOSTNAME TARGETGUID:$TARGETGUID MOSUSERS:$MOSUSERS  USINGPROXY:$USINGPROXY"
	$DEBUG && echo "OCMM:$OCMM OCMXMLS:$OCMXMLS OCMMTEST:$OCMMTEST OCMM_LAST_COLLECT:$OCMM_LAST_COLLECT"


	rm -f /var/tmp/out.txt.doctor* >/dev/null 2>/dev/null
	rm -f /var/tmp/sql.txt.doctor* >/dev/null 2>/dev/null

	$SKIPWGET && exit 0
	
	#########################################

	MESSAGE="|d5|${UNIQS}|${MAC}|${GDATE}|${GTIME}|${ECVERSION}|${EC_OS}|${EC_HARDWARE}|${TOTAL_AGENTS}|${USERNAME}";
	MESSAGE="${MESSAGE}|${TOTAL_OS}|${TOTAL_SERVERS}|${TOTAL_LDOMS}|${JOBS_TOTAL}|${JOBS1}|${JOBS2}|${JOBS3}|${JOBS4}"
	MESSAGE="${MESSAGE}|${JOBS5}|${JOBS6}|${JOBS7}|${JOBS8}|${JOBS9}|${JOBS10}|${PROXIES}|${EC_OSVER}"
	MESSAGE="${MESSAGE}|${LOCALREMOTE}|${TOTAL_ZONES}|${TOTAL_OVMGUEST}|${TOTAL_VIRTPOOL}|${TOTAL_CLOUDS}|${TOTAL_TENANTS}"
	MESSAGE="${MESSAGE}|${DOCJOBS}|${DOCVER}|${OCM}|${HOSTNAME}|${TARGETGUID}|${MOSUSERS}|${USINGPROXY}"
	MESSAGE="${MESSAGE}|${OCMM}|${OCMXMLS}|${OCMMTEST}|${OCMM_LAST_COLLECT}"
	#echo $MESSAGE
	#exit
	
	echo "$MESSAGE" | $OPENSSL enc -aes128 -a -A -salt -pass pass:AAdYQpQy5ltX -out /var/tmp/doctor-message.$$ >/dev/null 2>/dev/null
	if [ -s /var/tmp/doctor-message.$$ ]; then
		MESSAGE=`cat /var/tmp/doctor-message.$$`
		MESSAGE=`echo "$MESSAGE" | sed 's/+/%2B/g' 2>/dev/null`
	else
		MESSAGE="Empty_harvester_message_file"
	fi
	rm -f /var/tmp/doctor-message.$$ >/dev/null 2>/dev/null
	rm -f /var/tmp/java-cookie.bin > /dev/null 2>/dev/null
	
	get_token ""
	if [ "$TOKEN" = "" ]; then
		get_token ""
	fi
	if [ "$TOKEN" = "" ]; then
		get_token ""
	fi
	if [ ! "$TOKEN" = "" ]; then
		if [ "$PROXYUSER" = "" ]; then
			$WGET ${CERTFLAG} -qq --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data="authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D5&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}" "https://java.net/projects/oc-doctor/forums/updates/topics" -O /dev/null >/dev/null 2>/dev/null
			RETVAL=$?
		else
			eval "$WGET ${CERTFLAG} -qq --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data='authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D5&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}' 'https://java.net/projects/oc-doctor/forums/updates/topics' -O /dev/null >/dev/null 2>/dev/null"
			RETVAL=$?
		fi
		
		if [ $RETVAL -ne 0 ]; then
			get_token ""
			if [ "$PROXYUSER" = "" ]; then
				$WGET ${CERTFLAG} -qq --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data="authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D5&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}" "https://java.net/projects/oc-doctor/forums/updates/topics" -O /dev/null >/dev/null 2>/dev/null
				RETVAL=$?
			else
				eval "$WGET ${CERTFLAG} -qq --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data='authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D5&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}' 'https://java.net/projects/oc-doctor/forums/updates/topics' -O /dev/null >/dev/null 2>/dev/null"
				RETVAL=$?
			fi
		fi
		if [ $RETVAL -ne 0 ]; then
			get_token ""
			if [ "$PROXYUSER" = "" ]; then
				$WGET ${CERTFLAG} -qq --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data="authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D5&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}" "https://java.net/projects/oc-doctor/forums/updates/topics" -O /dev/null >/dev/null 2>/dev/null
				RETVAL=$?
			else
				eval "$WGET ${CERTFLAG} -qq --proxy-user=$PROXYUSER --proxy-password=$PROXYPASS --timeout=10 --tries 2 --load-cookies /var/tmp/java-cookie.bin --post-data='authenticity_token=${TOKEN}&forum_topic%5Bsubject%5D=D5&forum_topic%5Bmessage_format%5D=bbcode&forum_topic%5Bmessage%5D=${MESSAGE}' 'https://java.net/projects/oc-doctor/forums/updates/topics' -O /dev/null >/dev/null 2>/dev/null"
				RETVAL=$?
			fi
		fi
		if [ $RETVAL -eq 0 ]; then
			$DEBUG && echo "Success posting, creating $LASTRUNFILE"
			rm -f $LASTRUNFILE >/dev/null 2>/dev/null
			touch $LASTRUNFILE >/dev/null 2>/dev/null
		else 
			$DEBUG && echo "Failed posting"
		fi
			
	fi
	rm -f /var/tmp/java-cookie.bin > /dev/null 2>/dev/null

fi
exit 0
