#!/bin/bash

### Bug 8316255 - NUMCPU ALGORITHM NEEDS TO IGNORE THREADS WHEN CALCULATING CPU COUNT 

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	exit
fi

#### Check database file use
if [ -f /var/opt/sun/xvm/db.properties ]; then
	#### Determine if this local or remote
	LOCALREMOTE=`grep "^mgmtdb.server.type" /var/opt/sun/xvm/db.properties 2>/dev/null | awk -F"=" '{print $2}' 2>/dev/null`
else
	exit
fi

if [ "$LOCALREMOTE" = "remote" ]; then
	exit
fi

# reverting it back to check only till 12.2.2
MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        . $MY_DIR/../../functions
        get_version           ### Provide VERSIONNUM
	[ $VERSIONNUM -gt 12220000 ] && exit
fi


# cleanup old leftover files
rm -f /var/tmp/ocdoctor.sql.*

echo "set lines 600" > /var/tmp/ocdoctor.sql.$$
echo "column file_name format a80" >> /var/tmp/ocdoctor.sql.$$
echo "column bytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
echo "column maxbytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
echo "column user_bytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
echo "column pct_alloc format 999" >> /var/tmp/ocdoctor.sql.$$
echo "spool /var/tmp/ocdoctor.sql.out.$$" >> /var/tmp/ocdoctor.sql.$$
echo "sho parameter cpu_count;" >> /var/tmp/ocdoctor.sql.$$
echo "spool off" >> /var/tmp/ocdoctor.sql.$$
rm -f /var/tmp/ocdoctor.sql.out.$$

# changing from specific server names T3, T4, to arch...
TSERIES=`/usr/sbin/prtdiag |head -1|egrep "sun4v"`

if [ "$TSERIES" = "" ]; then
	#echo "OK: This is not a T series machine"
	rm -f /var/tmp/ocdoctor.sql.out.$$ /var/tmp/ocdoctor.sql.$$
	exit
else
	#echo "This is a T series machine:"
	su - oracleoc -c "echo \"@/var/tmp/ocdoctor.sql.$$\" | sqlplus / as sysdba >/dev/null 2>/dev/null " >/dev/null 2>/dev/null
	CPU_COUNT=""
	if [ -f /var/tmp/ocdoctor.sql.out.$$ ]; then
		CPU_COUNT=`cat /var/tmp/ocdoctor.sql.out.$$ 2>/dev/null | grep cpu_count | awk '{print $3}'`
	fi
	if [ "$CPU_COUNT" = "" ]; then
		rm -f /var/tmp/ocdoctor.sql.out.$$ /var/tmp/ocdoctor.sql.$$
		exit
	fi
	#echo "CPU_COUNT:$CPU_COUNT"

	echo "set lines 600" > /var/tmp/ocdoctor.sql.$$
	echo "column file_name format a80" >> /var/tmp/ocdoctor.sql.$$
	echo "column bytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
	echo "column maxbytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
	echo "column user_bytes format 999,999,999,999,999" >> /var/tmp/ocdoctor.sql.$$
	echo "column pct_alloc format 999" >> /var/tmp/ocdoctor.sql.$$
	echo "spool /var/tmp/ocdoctor.sql.out.$$" >> /var/tmp/ocdoctor.sql.$$
	echo "select KVITVAL,KVITTAG from x\$kvit where KVITTAG like 'ksbcpucore';" >> /var/tmp/ocdoctor.sql.$$
	echo "spool off" >> /var/tmp/ocdoctor.sql.$$
	rm -f /var/tmp/ocdoctor.sql.out.$$
	su - oracleoc -c "echo \"@/var/tmp/ocdoctor.sql.$$\" | sqlplus / as sysdba >/dev/null 2>/dev/null " >/dev/null 2>/dev/null
	CORES=""
	if [ -f /var/tmp/ocdoctor.sql.out.$$ ]; then
		CORES=`cat /var/tmp/ocdoctor.sql.out.$$ 2>/dev/null | grep ksbcpucore | awk '{print $1}'`
	fi
	if [ "$CORES" = "" ]; then
		rm -f /var/tmp/ocdoctor.sql.out.$$ /var/tmp/ocdoctor.sql.$$
		exit
	fi
	#echo "CORES:$CORES"
	if [ $CPU_COUNT -gt $CORES ]; then
		echo "BAD: CPU count:$CPU_COUNT is greater than cores:$CORES"
		echo "WARNING: T-Series machine and the Database CPU count ($CPU_COUNT) is greater than the number of cores ($CORES)"
		echo "         This may cause performance issues (bug 17943212)"
		echo ""
		echo "As an example fix, run the following command:"
		echo "# su - oracleoc -c \"echo \\\"Alter system set CPU_COUNT=$CORES scope=spfile;\\\" | sqlplus / as sysdba\"" 
		echo ""
		echo "However, setting beyond 55, may get to the point of diminishing returns."
		echo ""
		echo "Then restart the EC:"
		echo "# /opt/SUNWxvmoc/bin/ecadm stop -w"
		echo "# /opt/SUNWxvmoc/bin/ecadm start -w"
		echo ""

	else
		echo "OK: T-Series machine and DB CPU count($CPU_COUNT) is less or equal to the number of cores($CORES)"
	fi
		
fi

rm -f /var/tmp/ocdoctor.sql.out.$$ /var/tmp/ocdoctor.sql.$$
