#!/bin/bash
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	exit
else
	ZONENAME=`zonename`
	if [ ! "$ZONENAME" = "global" ]; then			#### prtdiag works only on global zone
		exit
	fi
	UNAMER=`uname -r`
	if [[ "$UNAMER" == "5.11" ]]; then			#### only relevant for Solaris 10
		exit
	fi

	####### First check if prtdiag freezes ######
	if [ -f ./prereq/timeout.sh ]; then
		`./prereq/timeout.sh /usr/sbin/prtdiag >/dev/null 2>/dev/null`
		RETVAL=$?
	else
		`../../prereq/timeout.sh /usr/sbin/prtdiag >/dev/null 2>/dev/null`
		RETVAL=$?
	fi
	if [ $RETVAL -eq 137 ]; then
		echo "ERROR: prtdiag seems to be freezing. This is a known Solaris issue (Bug 15394234). To fix this, try the following Solaris workaround:"
		echo ""
		echo "# svcadm restart picl"
		echo
		exit
	else
		echo "OK: prtdiag does not hang"
	fi
	#########

	OUTPUT=`/usr/sbin/prtdiag | grep " T3-"`
	if [ ! "$OUTPUT" = "" ]; then			### we have a T3.
		RELEASE=`grep Solaris /etc/release | head -1 | cut -f2 -d_ | cut -f1 -dw`	## u1, u2 etc
		RELEASE=`echo ${RELEASE} | awk -F"u" '{print $2}'`		## 1, 2 etc
		if [[ $RELEASE -lt 10 ]]; then
			#### Check if we have 144500-19 (explained in MOS DOC 1365194.1)
			MIN_PATCH="144500"
			MIN_REV="19"
			
			if [ -x /usr/bin/showrev ]; then
				### First see if the patch is installed (any revision)
				OUTPUT=`showrev -p |egrep "^Patch: ${MIN_PATCH}" 2>/dev/null`
				if [ $? -eq 0 ]; then
					### it is installed, lets figure out what revision
					installedPtchRevision=`showrev -p | grep "Patch: ${MIN_PATCH}" | cut -c1-80 | awk '{print $2}' | sort | tail -1 | awk -F"-" '{print $2}'`
					if [ $installedPtchRevision -ge $MIN_REV ]; then		#### installed is greater or equal to minimum
						echo "OK: This is a T3 machine with Solaris 10 Update $RELEASE, with patch ${MIN_PATCH}-${installedPtchRevision} installed"
						exit 0
					fi	
				fi
			fi
			if [ -f /platform/sun4v/kernel/drv/n2cp.conf ]; then
				OUTPUT=`grep "n2cp-use-ulcwq=0" /platform/sun4v/kernel/drv/n2cp.conf`
			else
				OUTPUT=""
			fi
			if [ "$OUTPUT" = "" ]; then
				echo "WARNING: This is a T3 machine. You may be running into Bug 15722725."
				echo "         Ops Center may hang when saving a custom discovery criteria."
				echo ""
				echo "         The workaround is to edit '/platform/sun4v/kernel/drv/n2cp.conf'"
				echo "         and insert "n2cp-use-ulcwq=0" to the existing line."
				echo ""
				echo "         For example, if your current line says this:"
				echo "            ddi-forceattach=1 ddi-no-autodetach=1;"
				echo "         The new line should look like this:"
				echo "            ddi-forceattach=1 ddi-no-autodetach=1 n2cp-use-ulcwq=0;"
				echo ""
				echo "         Note that in some cases you may need to run 'init 6' for this to take effect, but not always."
				echo ""
			else
				echo "OK: This is a T3 machine and the workaround is applied to '/platform/sun4v/kernel/drv/n2cp.conf'"
			fi
		else
			echo "OK: This is a T3 machine but you're using Solaris 10 U${RELEASE}, not affected by Bug 15676804"
		fi
	else
		echo "OK: This is not a T3 machine"
	fi
fi
