#!/bin/bash

GROUP1=`/usr/bin/groups uce-sds | grep uce-sds`
GROUP2=`/usr/bin/groups uce-sds | grep sys`
GROUP3=`/usr/bin/groups uce-sds | grep oinstoc`
ERROR=""

UNAME=`uname`
LIN_OPT=""
if [ "$UNAME" = "Linux" ]; then
    LIN_OPT="-a"
fi

if [ "$GROUP1" = "" ]; then
    echo "ERROR: User uce-sds is not part of the 'uce-sds' group (run 'groups uce-sds')"
    grep "^uce-sds:" /etc/group > /dev/null 2>&1
    if [ $? -ne 0 ]; then
        echo "ERROR: Group uce-sds does not exist."
    fi
    grep "^uce-sds:" /etc/passwd > /dev/null 2>&1
    if [ $? -ne 0 ]; then
        echo "ERROR: User uce-sds does not exist."
    fi
    echo "WARNING: UCE services may be impacted. Please contact Oracle Support to fix this."
    echo ""
    exit 1
fi
if [ "$GROUP2" = "" ]; then
    echo "ERROR: User uce-sds is not part of the 'sys' group (run 'groups uce-sds')"
    echo ""
    ERROR=1
fi
if [ "$GROUP3" = "" ]; then
    echo "ERROR: User uce-sds is not part of the 'oinstoc' group (run 'groups uce-sds')"
    echo ""
    ERROR=1
fi

if [ "$ERROR" = "" ]; then
    echo "OK: User uce-sds is part of all the proper groups"
    exit 0
fi

if [ "$OCDOCTOR_FIX" = "1" ];then
    echo "       Trying to fix automatically..."
    /sbin/usermod $LIN_OPT -G uce-sds,sys,oinstoc uce-sds
    if [ $? -eq 0 ]; then
        echo "INFO: Added uce-sds to sys and oinstoc groups"
        echo "WARNING: Must restart the Enterprise Controller for the changes to take effect!"
    else
        echo "ERROR: Could not add uce-sds user to sys and oinstoc groups"
    fi
    echo
else
    echo "       Try executing the following: /sbin/usermod $LIN_OPT -G uce-sds,sys,oinstoc uce-sds"
    echo
    echo "       or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
    echo
    echo "       Please Note: Restart the Enterprise Controller for the changes to take effect!"
    echo
fi
exit 1
