#!/bin/bash

#### Check database file use
if [ -f /var/opt/sun/xvm/db.properties ]; then
        #### Determine if this local or remote
        LOCALREMOTE=`grep "^mgmtdb.server.type" /var/opt/sun/xvm/db.properties 2>/dev/null | awk -F"=" '{print $2}' 2>/dev/null`
else
        exit
fi
if [ ! "$LOCALREMOTE" = "local" ]; then
	### Only run this on local DB
	exit
fi

UNAME=`uname`
################# SOFT LIMIT ############
rm -f /var/tmp/doctor-ulimit-out.txt 2>/dev/null
su - oracleoc -c "ulimit -Sn" >/var/tmp/doctor-ulimit-out.txt 2>/dev/null
RETVAL=$?
ULIMIT=`tail -1 /var/tmp/doctor-ulimit-out.txt 2>/dev/null`
rm -f /var/tmp/doctor-ulimit-out.txt 2>/dev/null

if [ $RETVAL -ne 0 ]; then		### If could not run ulimit in oracleoc, or if oracleoc user does not exist
	exit
fi

if [ $ULIMIT -lt 1024 ]; then
	echo "WARNING: ulimit -Sn (Open files soft limit) of 'oracleoc' user is $ULIMIT, but it needs to be at least 1024."
	echo "         This user is used by the local Oracle database for Ops Center."
	echo "         Please review the Oracle database documentation here:"
	if [ "$UNAME" = "Linux" ]; then
		echo "         http://docs.oracle.com/cd/E11882_01/install.112/e24326/toc.htm#BHCCADGD"
		echo ""
		echo "         Consider configuring this in /etc/security/limits.conf or 'sysctl -p'"
	else
		echo "         http://docs.oracle.com/cd/E11882_01/install.112/e24349/toc.htm#CDEDIBFE"
		echo ""
		echo "         One way to resolve this is to run the following as root to change it permanently:"
		echo "# projmod -s -K \"process.max-file-descriptor=(basic,1024,deny)\" user.root"
		echo "and then reboot."
	fi
	echo ""
else
	echo "OK: oracleoc user ulimit -Sn is $ULIMIT"
fi


################# HARD LIMIT ############
rm -f /var/tmp/doctor-ulimit-out.txt 2>/dev/null
su - oracleoc -c "ulimit -Hn" >/var/tmp/doctor-ulimit-out.txt 2>/dev/null
RETVAL=$?
ULIMIT=`tail -1 /var/tmp/doctor-ulimit-out.txt 2>/dev/null`
rm -f /var/tmp/doctor-ulimit-out.txt 2>/dev/null

if [ $RETVAL -ne 0 ]; then		### If could not run ulimit in oracleoc, or if oracleoc user does not exist
	exit
fi

if [ $ULIMIT -lt 65536 ]; then
	echo "WARNING: ulimit -Hn (Open files hard limit) of 'oracleoc' user is $ULIMIT, but it needs to be at least 65536."
	echo "         This user is used by the local Oracle database for Ops Center."
	echo "         Please review the Oracle database documentation here:"
	if [ "$UNAME" = "Linux" ]; then
		echo "         http://docs.oracle.com/cd/E11882_01/install.112/e24326/toc.htm#BHCCADGD"
		echo ""
		echo "         Consider configuring this in /etc/security/limits.conf or 'sysctl -p'"
	else
		echo "         http://docs.oracle.com/cd/E11882_01/install.112/e24349/toc.htm#CDEDIBFE"
		echo ""
	fi
	echo ""
else
	echo "OK: oracleoc user ulimit -Hn is $ULIMIT"
fi
