#!/bin/bash

MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        source $MY_DIR/../../functions
        get_version ""          ### Provide VERSIONNUM
        if [ $VERSIONNUM -ge "12112076" ];then               #### Is this newer than Update 1? In testing latest one is 12112075
                exit 0           #### Check for disk space only if not upgraded to U1 yet
        fi
fi

VAR_OPT_SUN_XVM=0

# Base

# /var/opt/sun/xvm - should be 5G
#echo "/var/opt/sun/xvm 5242880 as base"
MESSAGE=`printf "5242880K - Base requirement in /var/opt/sun/xvm"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + 5242880`

#Disk requirement for satadm backup for update_channel
DIR="/var/opt/sun/xvm/uce/"
if [ -d $DIR ]; then 
    uce_size=`du -sk $DIR | awk '{print $1}'` ;
else
    uce_size="";
fi
#echo "UCE needs $uce_size K in /var/opt/sun/xvm/  (for backup)"
MESSAGE=`printf "$MESSAGE\n${uce_size}K - UCE files backup requirement in /var/opt/sun/xvm (based on $DIR size)"`
VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + $uce_size`

#### Database
DBPROPS_FILE=/var/opt/sun/xvm/db.properties
db_type=`grep mgmtdb.server.type $DBPROPS_FILE | cut -d= -f2`

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	ECADM="/opt/sun/xvmoc/bin/ecadm"
	SCS_HOME=/opt/sun/scs
	AVAILABLE=`df -Pk /var/opt/sun/xvm | tail -1 | awk '{print \$4}'`
else
	ECADM="/opt/SUNWxvmoc/bin/ecadm"
	SCS_HOME=/opt/SUNWscs
	AVAILABLE=`df -k /var/opt/sun/xvm | tail -1 | awk '{print \$4}'`
fi


# Estimate the size of the local db backup.
if  [ "$db_type" = "local" ]; then
	db_req_size_compress=1000000		#1G
	MESSAGE=`printf "$MESSAGE\n${db_req_size_compress}K - Required local DB backup in /var/opt/sun/xvm"`
	VAR_OPT_SUN_XVM=`expr $VAR_OPT_SUN_XVM + $db_req_size_compress`
fi

#echo "Total required for /var/opt/sun/xvm: $VAR_OPT_SUN_XVM Kb"
MESSAGE=`printf "$MESSAGE\n\n${VAR_OPT_SUN_XVM}K - Total required in /var/opt/sun/xvm"`

if [ $VAR_OPT_SUN_XVM -lt $AVAILABLE ]; then
	echo "OK: UPDATE: Enough disk space found in /var/opt/sun/xvm to update to 12c Update 1."
else
	echo "ERROR: UPDATE: ERROR: Not enough disk space found in /var/opt/sun/xvm to update to 12c Update 1."
	echo "               Need: ${VAR_OPT_SUN_XVM}K Available: ${AVAILABLE}K"
	echo ""
	echo "Summary of the calculation:"
	printf "$MESSAGE\n\n"
fi

