#!/bin/bash
# You may use this script to perform any operations after upgrading the Doctor
# This script is used once and is deleted after the upgrade
# Exit code other than 0 will show an error but the upgrade is already complete


### Restore product metadata last version file if exists
if [ -f /var/tmp/product_metadata.version.OCDoctor ]; then
        if [ -d product_metadata_update ]; then         ### Safety check
                mv -f /var/tmp/product_metadata.version.OCDoctor product_metadata_update/product_metadata.version
        fi
fi

getJvmRelease(){
        JVMDIR=$1
        JAVAVER=""
        if [ "${JVMDIR:0:3}" = "jdk" ]; then JAVAVER=${JVMDIR:3}; fi
        if [ "${JVMDIR:0:3}" = "jre" ]; then JAVAVER=${JVMDIR:3}; fi
        if [ "${JVMDIR:0:4}" = "j2re" ]; then JAVAVER=${JVMDIR:4}; fi
        if [ "${JVMDIR:0:5}" = "j2sdk" ]; then JAVAVER=${JVMDIR:5}; fi
        if [ "$JAVAVER" = "" ]; then JAVAVER=$JVMDIR; fi
}
expandPrefix(){
        JAVAVERINT=`echo $1 | sed -e "s/_/\./g" | awk 'BEGIN {FS="."}{printf "%.2d%.2d%.2d%.2d", \$1, \$2, \$3, \$4}'`
}
findMaxJvmPath(){
        UNAME=`uname`
        MAXJVMPATH=""
        MAXJVMVERSION=0
        if [ "$UNAME" = "Linux" ];then
                JAVA_BASE="/usr/java"
        else
                JAVA_BASE="/usr/jdk/instances"
        fi
        if [ ! -d $JAVA_BASE ]; then
                return 1
        fi
        for PREFIX in "jdk" "jre" "j2sdk" "j2re"; do
                for FILENAME in `cd ${JAVA_BASE} ; ls -d ${PREFIX}* 2>/dev/null`; do
                        if [ -d ${JAVA_BASE}/$FILENAME ]; then
                                getJvmRelease $FILENAME
                                expandPrefix $JAVAVER
                                #echo FILENAME:$FILENAME JAVAVER:$JAVAVER JAVAVERINT:$JAVAVERINT
                                if [ $JAVAVERINT -gt $MAXJVMVERSION ]; then
                                        MAXJVMVERSION=$JAVAVERINT
                                        MAXJVMPATH=${JAVA_BASE}/${FILENAME}
                                fi
                        fi
                done
        done
}
findMaxJvmPath_from_cacao(){
	UNAME=`uname`
	if [ "$UNAME" = "Linux" ];then
		MAXJVMPATH=`/opt/sun/cacao2/bin/cacaoadm get-param -i oem-ec java-home 2>/dev/null | sed 's/java-home=//' 2>/dev/null`
	else
		MAXJVMPATH=`/usr/sbin/cacaoadm get-param -i oem-ec java-home 2>/dev/null| sed 's/java-home=//' 2>/dev/null`
	fi
	if [ "$MAXJVMPATH" = "" ]; then		## if couldnt get it from cacao
		findMaxJvmPath ""
	fi
}
AddOCMCron(){
	OCHARV="/var/opt/sun/xvm/ocm/ccr/sysman/admin/util/opscenterharvester"
	if [ -f $OCHARV ]; then
		#### Add cron with "-f", need to replace existing cron
		CRONENTRY="30 3 * * * [ -x ${OCHARV} ] && ${OCHARV} -f >/dev/null 2>&1"
		ORIGCRON=/var/tmp/ocm_crontab.$$
		NEWCRON=/var/tmp/ocm_crontab_new.$$
		crontab -l > ${ORIGCRON} 2>/dev/null
		if [ $? -eq 0 ]; then
			grep -v "${OCHARV}" ${ORIGCRON} > ${NEWCRON} 2>/dev/null
			EXITC=$?
			echo "${CRONENTRY}" >> ${NEWCRON}
			if [ $? -eq 0 -a $EXITC -eq 0 ]; then
				crontab ${NEWCRON} >/dev/null 2>&1
			fi
		fi
		rm -f ${NEWCRON} ${ORIGCRON} 2>/dev/null
	fi
}

UNAME=`uname`

if [ "$UNAME" = "Linux" ]; then
        SAT_BIN="/opt/sun/xvmoc/bin/satadm"
else
        SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
fi
if [ -f $SAT_BIN ]; then
	if [ -f ./functions ]; then
		source ./functions
		get_major_version ""
		if [ "$MAJORVERSION" = "12" ]; then
			##### Add OCM cronjob if it is configured
			are_we_connected ""
			RETVAL=$?
			if [ $RETVAL -eq 0 ]; then		####  configured and in connected mode
				### Need to figure out JAVA_HOME
				findMaxJvmPath_from_cacao ""			### Will give us $MAXJVMPATH
				if [ ! -f /var/opt/sun/xvm/ocm/ccr/bin/configCCR ]; then			#### If OCM is not configured
					if [ -f /var/opt/sun/xvm/ocm/ccr/bin/setupCCR ]; then			#### If we have setupCCR available, install in Disconnected mode
						OUTPUT=`cd /var/opt/sun/xvm/ocm/ccr/bin/ 2>/dev/null ; JAVA_HOME=$MAXJVMPATH ; export JAVA_HOME ; JAVA_HOME_CCR=$MAXJVMPATH ; export JAVA_HOME_CCR ; ./setupCCR -d >/dev/null 2>/dev/null`
						EXITC=$?
						if [ $EXITC -eq 0 ]; then		### if installed properly
							AddOCMCron ""
						fi
					else
						#### Not configured and setupCCR is not there
						#### We may need to extract the OCM zipfile, will take care of it in the next version
						DONOTHING=1
					fi
				else			### if OCM is already configured, set cron in "-f" mode
					AddOCMCron ""
				fi
				##### Run /var/opt/sun/xvm/ocm/ccr/bin/emSnapshotEnv, 
				##### This will fix any broken JAVA_HOME in /var/opt/sun/xvm/ocm/ccr/hosts/<HOST>/config/emCCRenv
				if [ -x /var/opt/sun/xvm/ocm/ccr/bin/emSnapshotEnv ]; then
					export JAVA_HOME=$MAXJVMPATH
					/var/opt/sun/xvm/ocm/ccr/bin/emSnapshotEnv >/dev/null 2>/dev/null
				fi
			fi
			##### Run basic statistics
			rm -f /tmp/OCDoctor_stat_last_run.txt >/dev/null 2>/dev/null
			if [ -f ./ec/12/stat_basic.sh ]; then
				./ec/12/stat_basic.sh >/dev/null 2>/dev/null
			fi
			rm -f /tmp/OCDoctor_stat_last_run.txt >/dev/null 2>/dev/null		### Force it to run again tomorrow
		fi
		if [ "$MAJORVERSION" = "11" ]; then
			##### Run basic statistics
			if [ -f ./ec/11/stat_basic.sh ]; then
				./ec/11/stat_basic.sh >/dev/null 2>/dev/null
			fi
		fi
		
		####### Workaround for 17211690
		get_version ""
		if [ $VERSIONNUM -le "12142319" ];then			### If it's Update 4 or older
			if [ ! -f /var/tmp/no_os_selfhealing ]; then
				touch /var/tmp/no_os_selfhealing >/dev/null 2>/dev/null
			fi
		fi
	fi
fi
exit 0
