#!/bin/bash
# You may use this script to perform any operations prior to upgrading the Doctor
# This script is used once and is deleted after the upgrade
# Exit code other than 0 will stop the upgrade!

CFOLDER=`pwd`
if [ ! -d ../OCDoctor ]; then           #### Safety to make sure we always upgrade
        exit 0
fi
cd ../OCDoctor/


### Try to preserve the latest product metadata version file - only available on the EC
if [ -d product_metadata_update ]; then
	if [ -f product_metadata_update/product_metadata.version ]; then
	        if [ -f /var/tmp/product_metadata.version.OCDoctor ]; then
	                rm -f /var/tmp/product_metadata.version.OCDoctor  >/dev/null 2>/dev/null
	        fi
	        cp -p product_metadata_update/product_metadata.version /var/tmp/product_metadata.version.OCDoctor
	fi
fi

UNAME=`uname`
if [ "$UNAME" = "Linux" ];then
	TAR=/bin/tar
else
	TAR=/usr/sbin/tar
fi

if [ ! -f $TAR ]; then
	#### If no TAR is available, just don't backup files that are not part of OCDoctor and placed there by the user
	exit 0
fi

######## Figure out if we have new files that the user added? ########
MANIFEST="Manifest.txt"
NEWMANIFEST="/var/tmp/OCDoctor-manifest-new.txt"
NEWFILESLIST="/var/tmp/OCDoctor-new-files.txt"

if [ ! -f "$MANIFEST" ]; then
	### No manifest file - it's an older version, do nothing
	cd $CFOLDER
	exit 0
fi

#### Create a new manifest file to compare to
find . -type f | grep -v product_metadata_update | grep -v beta > $NEWMANIFEST 2>/dev/null

if [ ! -f "$NEWMANIFEST" ]; then
	#### Safety to make sure we always upgrade
	cd $CFOLDER
	exit 0
fi

if [ -f $NEWFILESLIST ]; then
	rm -f $NEWFILESLIST
fi

cat $NEWMANIFEST | while read file; do
	OUTPUT=`grep "^$file" $MANIFEST`
	if [ "$OUTPUT" = "" ]; then
		echo "$file" >> $NEWFILESLIST
		if [ -f ../OCDoctor-backup.tar ]; then
			$TAR uf ../OCDoctor-backup.tar "$file"
		else
			$TAR cf ../OCDoctor-backup.tar "$file"		#### Needed for Solaris tar
		fi
	fi
done

if [ -f $NEWFILESLIST ]; then
	CURRENTFOLDER=`pwd`
	cd ..
	PRINTFOLDER=`pwd`
	cd $CURRENTFOLDER
	echo "PRE-UPGRADE: Found the following new files in the current OCDoctor folder, created a backup in ${PRINTFOLDER}/OCDoctor-backup.tar:"
	cat $NEWFILESLIST
	echo ""
	rm -f $NEWFILESLIST
fi

if [ -f $NEWMANIFEST ]; then
	rm -f $NEWMANIFEST
fi


### Go back to the original folder we started in
cd $CFOLDER

exit 0
