#!/bin/bash
#
# check_connectivity
#
# Version 1.1 (2016/01/21)
#
#    Copyright (c) 2007, 2016 Oracle and/or its affiliates.  All rights reserved.
#    Use is subject to license terms.
#

TLS_PROTO=TLSv1_2
WGET_SEC="--secure-protocol=$TLS_PROTO"

UNAME=`uname`
if [ $UNAME = "Linux" ];then
	WGET="/usr/bin/wget --timeout=10 --tries 3"
	SED=/bin/sed
else
	SED=/usr/bin/sed
	WGET="/usr/sfw/bin/wget --timeout=10 --tries 3"
fi

USER_AGENT="Wget/1.10.2"
#USER_AGENT="Aduva agent"

check_if_sat_installed(){
	if [ "$UNAME" = "Linux" ]; then
                SAT_BIN="/opt/sun/xvmoc/bin/satadm"
        else
                SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
        fi
        if [ -f $SAT_BIN ];then
		return 1
	else
		return 0
	fi
}

################ Figure out if wget supports 'no-check-certificate' flag ########################
CERTSUPPORT=`$WGET --help 2>/dev/null | grep no-check-certificate`
if [ "$CERTSUPPORT" = "" ]; then
	CERTFLAG=""
else
	CERTFLAG="--no-check-certificate"
fi

PROXY_STRING=""
check_if_sat_installed ""
SATINST=$?
####################### Determine Proxy settings ###########################
if [ "$http_proxy" = "" ] && [ "$https_proxy" = "" ]; then		#### If no http_proxy AND https_proxy, use EC settings instead
	###### if we have EC installed, read proxy settings
	if [ $SATINST -eq 1 ];then
		CONNPROP="/var/opt/sun/xvm/persistence/scn-satellite/connection.properties"
		PROXYHOST=`grep proxy-host $CONNPROP | awk -F"=" '{print $2}' 2>/dev/null`
		PROXYPORT=`grep proxy-port $CONNPROP | awk -F"=" '{print $2}' 2>/dev/null`
		PROXYUSER=`grep proxy-username $CONNPROP | awk -F"=" '{print $2}' 2>/dev/null`
		PROXYPASS=`grep proxy-password $CONNPROP | cut -c16- 2>/dev/null`
		if [ ! "$PROXYHOST" = "" ] && [ ! "$PROXYPORT" = "" ]; then
			export http_proxy="$PROXYHOST:$PROXYPORT"
			export https_proxy="$PROXYHOST:$PROXYPORT"
			export PROXYSETBYDOC=1
			PROXY_STRING=" --proxy -e https_proxy=${http_proxy} -e http_proxy=${http_proxy} "
			if [ "$PROXYUSER" = "" ]; then
				echo "Using Ops Center Proxy server:$PROXYHOST   Port:$PROXYPORT (you may overwrite it by setting https_proxy)"
			else
				echo "Using Ops Center Proxy server:$PROXYHOST   Port:$PROXYPORT   User:$PROXYUSER   Pass:[hidden]"
				PROXY_STRING=${PROXY_STRING}" --proxy-user=${PROXYUSER} --proxy-passwd=${PROXYPASS}"
			fi
		fi		#### End of "If PROXYHOST is in the connection.properties
	fi		#### If SAT is not installed
fi
#### If didn't find proxy in EC, or if https/http_proxy was already defined - use environment variables
if [ ! "$http_proxy" = "" ] && [ ! "$PROXYSETBYDOC" = "1" ]; then				### If env var is set, but wasn't set by this script
	echo "Using environment variable http_proxy=$http_proxy"
	if [ "$https_proxys" = "" ]; then
		export https_proxy="$http_proxy"
		if [ "$PROXY_STRING" = "" ]; then
			PROXY_STRING=" --proxy -e https_proxy=${http_proxy} -e http_proxy=${http_proxy} "
		fi
	fi
fi
if [ ! "$https_proxy" = "" ] && [ ! "$https_proxy" = "$http_proxy" ]; then		### If https_proxy is set but http_proxy is not set
	echo "Using environment variable https_proxy=$https_proxy"
	if [ "$http_proxy" = "" ]; then
		export http_proxy="$https_proxy"
		if [ "$PROXY_STRING" = "" ]; then
			PROXY_STRING=" --proxy -e https_proxy=${https_proxy} -e http_proxy=${https_proxy} "
		fi
	fi
fi

	
TMPFILE="/var/tmp/download_test.out.$$"
TEST_PATCHID="108437-06"
URL1=updates.oracle.com/channels3/channels.xml
URL2=updates.oracle.com/all_unsigned/${TEST_PATCHID}.zip

printf "Please enter the My Oracle Support (MOS) Username: "
read HTTP_USER
if [ "$HTTP_USER" = "" ]; then
	echo "Error: no username"
	exit
fi
printf "Password: "
stty -echo
read HTTP_PASSWD
stty echo
echo
if [ "$HTTP_PASSWD" = "" ]; then
	echo "Error: no password"
	exit
fi
OUTPUT=`echo "$HTTP_PASSWD" | grep ":"`
if [ ! "$OUTPUT" = "" ]; then
	echo
	echo
	echo "ERROR: Your password contains ':', this will prevent OC from downloading content!"
	echo "       This is a known issue (Bug 15723921). Please change your password and remove the ':' from it."
	echo 
	echo "       * This will also fail the tests below and will tell you that your password is incorrect *"
	echo 
	echo
fi

if [ "$https_proxy" = "" ]; then
	PROXYPORT=""
	PROXYUSER=""
	PROXYPASS=""
	printf "Is there a proxy? Type the proxy server here, for example 'www-proxy.us.oracle.com' (hit Enter if there is no proxy): "
	read PROXY
	if [ ! "$PROXY" = "" ]; then
		printf "Proxy port: "
		read PROXYPORT
		export http_proxy=${PROXY}:${PROXYPORT}
		export https_proxy=${PROXY}:${PROXYPORT}
		PROXY_STRING=" --proxy -e https_proxy=${http_proxy} -e http_proxy=${http_proxy} "
		printf "Proxy username (Enter for no username): "
		read PROXYUSER
		if [ ! "$PROXYUSER" = "" ]; then
			printf "Proxy password: "
			stty -echo
			read PROXYPASS
			stty echo
			echo
			PROXY_STRING=${PROXY_STRING}" --proxy-user=${PROXYUSER} --proxy-passwd=${PROXYPASS}"
		fi
	fi
fi

# if S11 we will check connectivity to Oracle's S11 Support repository
IS_S11=false
UNAME_R="$(uname -r)"
if [ "$UNAME" = "SunOS" -a "$UNAME_R" = "5.11" ]; then
	printf "\nOS is Solaris 11, do you want to test connectivity to Oracle's S11 Support repository (Y/n): "
	read ANSWER
	if [ -z "$ANSWER" -o "$ANSWER" = "y" -o "$ANSWER" = "Y" ]; then
		IS_S11=true
		DEFAULT_FILES_IN_PLACE=false
		OPENSSL=/usr/bin/openssl
		DEFAULT_CERT_DIR="/var/pkg/ssl"
		echo
		echo "To access the Solaris 11 Support Repository, files with certificate and key are required and you need to"
		echo "provide the pathes to them further down."
		echo
		if [ "$SATINST" -eq 1 ]; then
			echo "NOTE: Ops Center is already installed, it is recommended to use the same certificate/key for testing which"
			echo "are used by the EC! You can access the currently used content of the files from the UI:"
			echo
			echo "Administration -> Credentials -> SystemDefinedSupportCredential -> Edit Credentials"
			echo
			echo "Copy the textboxes and create two files out of them somewhere on the EC, e.g. /tmp/cert.pem and /tmp/key.pem"
			echo
		fi
		echo
		echo "Please, use the following site to generate and download new certificate and key files:"
		echo 
		echo "https://pkg-register.oracle.com/register/certificate"
		echo
		echo "After successfull download, copy the files to the Enterprise Controller."
		echo

		LIST_OF_FILES="$(grep -l 'BEGIN CERTIFICATE' ${DEFAULT_CERT_DIR}/* 2>/dev/null )"
		if [ -n "$LIST_OF_FILES" ]; then
			DEFAULT_S11CERT=$(ls -t $LIST_OF_FILES | head -1)
		else
			DEFAULT_S11CERT="no file found"
		fi
		LIST_OF_FILES="$(grep -l 'BEGIN RSA PRIVATE KEY' ${DEFAULT_CERT_DIR}/* 2>/dev/null )"
		if [ -n "$LIST_OF_FILES" ]; then
			DEFAULT_S11KEY=$(ls -t $LIST_OF_FILES | head -1)
		else
			DEFAULT_S11KEY="no file found"
		fi
		#echo "DEFAULT_S11CERT=$DEFAULT_S11CERT"
		#echo "DEFAULT_S11KEY=$DEFAULT_S11KEY"
		if [ -f "$DEFAULT_S11CERT" -a -f "$DEFAULT_S11KEY" ]; then
			# we found cert and key file in the default location
			DEFAULT_FILES_IN_PLACE=true
			echo
			echo "Furthermore, the following existing files have been found and can be used for testing as well:"
			echo
			echo "$DEFAULT_S11CERT"
			echo "$DEFAULT_S11KEY"
			echo
			if [ -x "$OPENSSL" ]; then
				echo "Expire date of certificate: $($OPENSSL x509 -in $DEFAULT_S11CERT -noout -enddate 2>/dev/null)"
				echo
			fi
			echo "If the above files should be used to access the Solaris 11 Repository, just press <ENTER>"
			echo "when prompted for the path to the cert and key files."
			echo
		fi
		if $DEFAULT_FILES_IN_PLACE; then
			printf "Enter path to S11 Certificate (default: $DEFAULT_S11CERT): "
		else
			printf "Enter path to S11 Certificate: "
		fi
		read S11CERT
		if [ "$S11CERT" = "" ]; then
		        S11CERT="$DEFAULT_S11CERT"
		fi
		if [ ! -f "$S11CERT" ]; then
			echo
			echo "ERROR: File not found: $S11CERT"
			exit 1
		fi
		if $DEFAULT_FILES_IN_PLACE; then
			printf "Enter path to S11 Key (default: $DEFAULT_S11KEY): "
		else
			printf "Enter path to S11 Key: "
		fi
		read S11KEY
		if [ "$S11KEY" = "" ]; then
		        S11KEY="$DEFAULT_S11KEY"
		fi 
		if [ ! -f "$S11KEY" ]; then
			echo
			echo "ERROR: File not found: $S11KEY"
			exit 1
		fi
	fi
fi

wget_wrapper(){				#### $1 output file  $2 = link
    #encode special chars %,@,/,: in HTTP_USER and HTTP_PASSWD
    HTTP_USER_ENCODED1=`echo $HTTP_USER | ${SED} 's/:/%3A/g;s/@/%40/g;s/\//%2f/g;s/\*/%2a/g;s/+/%2b/g;s/,/%2c/g;s/;/%3b/g;s/=/%3d/g;s/!/%21/g;s/#/%23/g;s/\&/%26/g;s/?/%3f/g;s/(/%28/g;s/)/%29/g;s/\[/%5b/g;s/\]/%5d/g'`
    # escaping ' is a special case
    HTTP_USER_ENCODED=`echo $HTTP_USER_ENCODED1 | ${SED} s/\'/%27/g`
    HTTP_PASSWD_ENCODED1=`echo $HTTP_PASSWD | ${SED} 's/:/%3A/g;s/@/%40/g;s/\//%2f/g;s/\*/%2a/g;s/+/%2b/g;s/,/%2c/g;s/;/%3b/g;s/=/%3d/g;s/!/%21/g;s/#/%23/g;s/\&/%26/g;s/?/%3f/g;s/(/%28/g;s/)/%29/g;s/\[/%5b/g;s/\]/%5d/g'`
    # escaping ' is a special case
    HTTP_PASSWD_ENCODED=`echo $HTTP_PASSWD_ENCODED1 | ${SED} s/\'/%27/g`

	TLS_STR=$3
	URL_FILE="/var/tmp/url.$$"
	ORIGINAL_URL="$2"
	if [ "$HTTP_USER" = "" ]; then
    	URL="https://$ORIGINAL_URL"    
    else
    	URL="https://$HTTP_USER_ENCODED:$HTTP_PASSWD_ENCODED@$ORIGINAL_URL"
    fi
    echo "$URL" > ${URL_FILE}
    chmod 500 ${URL_FILE}

	### The following line will always fail because WGET doesn't authenticate against the forwarded to login page
	### We need to extract the forwarded page URL
	WGET_OUTPUT=`${WGET} ${PROXY_STRING} --user-agent="${USER_AGENT}" ${TLS_STR} ${CERTFLAG} --retry-connrefused -i ${URL_FILE} -O $1 2>&1`
	### extract the URL it is redirected to - only the "login....." part only, without https:// etc
	WGET_REDICRECT_URL=`printf "%s\n" "$WGET_OUTPUT" | grep -i "^Location" | awk '{print $2}' 2>/dev/null | sed -e 's/https:\/\///' 2>/dev/null`
	if [ "$WGET_REDICRECT_URL" = "" ]; then
		### in case we were not able to extract the new URL, use the same one like originally provided, again
		echo "$URL" > ${URL_FILE}
	else
		### If we have a new redirect login page, use that
		echo "https://$HTTP_USER_ENCODED:$HTTP_PASSWD_ENCODED@$WGET_REDICRECT_URL" > ${URL_FILE}
	fi
	chmod 500 ${URL_FILE}
	#### Now download the real file
	WGET_OUTPUT=`${WGET} ${PROXY_STRING} --user-agent="${USER_AGENT}" ${TLS_STR} ${CERTFLAG} --retry-connrefused -i ${URL_FILE} -O $1 2>&1`
	RETVAL=$?
	
    WGET_DISPLAYOUTPUT=`printf "%s\n" "$WGET_OUTPUT" | egrep -v "Certificate verification error for|Self-signed certificate encountered|cannot verify login.oracle.com|cannot verify getupdates.oracle.com|Unable to locally verify the issuer"`
    #echo ${URL_FILE}
    rm -f ${URL_FILE}        
    return $RETVAL
}

NEW_METHOD_FAILED=0
TMPFILE="/var/tmp/download_test.out1.$$"


##### 
echo
echo "Test 1/5: Checking CC service reachability (without using user/password yet)"
echo "=============================================================================="
URL3="hs-ws1.oracle.com/ochi/servicecheck?type=cc"
echo "Connecting to https://$URL3"
HTTP_USER_ORIG=$HTTP_USER
HTTP_USER=""
wget_wrapper $TMPFILE $URL3 $WGET_SEC
HTTP_USER=$HTTP_USER_ORIG
if [ $? -eq 0 ]; then
	OUTPUT=`grep ">OK<" $TMPFILE 2>/dev/null`
	if [ "$OUTPUT" = "" ]; then
		NEW_METHOD_FAILED=1
		echo "ERROR: Unable to get 'OK' from $URL3".
		echo "FILE CONTENT:"
		cat $TMPFILE
		echo
		echo "GET OUTPUT:"
	  	printf "%s\n" "$WGET_DISPLAYOUTPUT"
	  	echo
	else
		echo "OK: CC status is OK"
	fi
else
	NEW_METHOD_FAILED=1
	echo "ERROR: Unable to reach $URL3"
	echo "OUTPUT:"
  	printf "%s\n" "$WGET_DISPLAYOUTPUT"
  	echo
fi
rm -f $TMPFILE >/dev/null 2>/dev/null
echo
##### 
echo "Test 2/5: Checking GUUS service (KnowledgeBase Service) reachability (without using user/password yet)"
echo "=============================================================================="
URL3="hs-ws1.oracle.com/ochi/servicecheck?type=guus"
echo "Connecting to https://$URL3"
HTTP_USER_ORIG=$HTTP_USER
HTTP_USER=""
wget_wrapper $TMPFILE $URL3 $WGET_SEC
HTTP_USER=$HTTP_USER_ORIG
if [ $? -eq 0 ]; then
	OUTPUT=`grep ">OK<" $TMPFILE 2>/dev/null`
	if [ "$OUTPUT" = "" ]; then
		NEW_METHOD_FAILED=1
		echo "ERROR: Unable to get 'OK' from $URL3".
		echo "FILE CONTENT:"
		cat $TMPFILE
		echo
		echo "GET OUTPUT:"
	  	printf "%s\n" "$WGET_DISPLAYOUTPUT"
	  	echo
	else
		echo "OK: GUUS status is OK"
	fi
else
	NEW_METHOD_FAILED=1
	echo "ERROR: Unable to reach $URL3"
	echo "OUTPUT:"
  	printf "%s\n" "$WGET_DISPLAYOUTPUT"
  	echo
fi
echo
rm -f $TMPFILE >/dev/null 2>/dev/null
#wget -q --no-check-certificate  https://hs-ws1.oracle.com/ochi/servicecheck?type=guus -O /dev/stdout

echo "Test 3/5: Downloading Knowledge Channels file from updates.oracle.com"
echo "==========================================================================="
echo "Connecting to https://$URL1"

wget_wrapper $TMPFILE $URL1 $WGET_SEC

if [ $? -eq 0 ]; then 
  OUTPUT2=`file "$TMPFILE" | grep -i xml`
  if [ ! "$OUTPUT2" = "" ]; then
  	echo "OK: Knowledge download was successful!"
	rm -f $TMPFILE
  else 
  	NEW_METHOD_FAILED=1
  	echo "ERROR: Knowledge download failed! File $TMPFILE is not XML type."
	echo "OUTPUT:"
  	printf "%s\n" "$WGET_DISPLAYOUTPUT"
  	echo
  fi
  echo
else
  NEW_METHOD_FAILED=1
  echo
  echo "ERROR: Knowledge download failed!"
  ERRCODE=`echo "$WGET_OUTPUT" | egrep '403 |401 '`
  if [ ! "$ERRCODE" = "" ]; then
	echo "       Got error 401/403 - can it be that your username and password are incorrect?"
  fi
  echo 
  echo "OUTPUT:"
  printf "%s\n" "$WGET_DISPLAYOUTPUT"
  echo
  rm -f $TMPFILE
fi
rm -f $TMPFILE >/dev/null 2>/dev/null

TMPFILE="/var/tmp/download_test.out2.$$"
echo "Test 4/5: Downloading patch ${TEST_PATCHID} from updates.oracle.com"
echo "==========================================================================="
echo "Connecting to https://$URL2"

wget_wrapper $TMPFILE $URL2 $WGET_SEC

if [ $? -eq 0 ]
then 
  OUTPUT2=`file "$TMPFILE" | grep -i zip`
  if [ ! "$OUTPUT2" = "" ]; then
  	echo "OK: Patch download was successful!"
	rm -f $TMPFILE
  else 
  	NEW_METHOD_FAILED=1
  	echo "ERROR: Patch download failed! File $TMPFILE is not ZIP type."
	echo "OUTPUT:"  
	printf "%s\n" "$WGET_DISPLAYOUTPUT"
	echo
  fi
  echo
else
  NEW_METHOD_FAILED=1
  echo
  echo "ERROR: Patch download failed!"
  ERRCODE=`echo "$WGET_OUTPUT" | egrep '403 |401 '`
  if [ ! "$ERRCODE" = "" ]; then
	echo "       Got error 401/403 - can it be that your username and password are incorrect?"
  fi
  echo
  echo "OUTPUT:"
  printf "%s\n" "$WGET_DISPLAYOUTPUT"
  echo
fi

if [ "$NEW_METHOD_FAILED" = "1" ]; then
	echo ""
	echo "Error connecting to Oracle. Please visit the docs site to learn more about what IPs should be open in the firewall or proxy:"
	echo "Main Document page: "
        echo "  http://docs.oracle.com/en/enterprise-manager/?tab=2"
	echo "  Under the specific version of Ops Center, the applicable section is 'Ports and Protocols'"
	echo ""
fi
rm -f $TMPFILE >/dev/null 2>/dev/null

if $IS_S11; then

	S11_REPO="/var/tmp/s11_repo.$$"
	S11_SUPPORT_REPO_URL="https://pkg.oracle.com/solaris/support"
        #TEST_PKG=`pkg list -af entire | head -n 2 | tail -1 | awk '{print $1 "@" $2}'`
	TEST_PKG="entire@11.4-11.4.6.0.1.4.0"
	TMPFILE="/var/tmp/s11_download_test.out.$$"

	echo "Test 5/5: Check Connectivity to S11 Support repository"
	echo "==========================================================================="
	echo "Expire date of certificate: $(openssl x509 -in $S11CERT -noout -enddate)"
	echo
	pkgrepo create $S11_REPO
	echo "Downloading S11 packages from $S11_SUPPORT_REPO_URL" 
	pkgrecv --key $S11KEY --cert $S11CERT -s $S11_SUPPORT_REPO_URL -d $S11_REPO $TEST_PKG >$TMPFILE 2>&1
	if [ $? -eq 0 ]; then
		echo "OK: Download of package $TEST_PKG from S11 Support Repository was successful!"
	else
		echo "ERROR: S11 package download failed!"
		echo
		echo "Output from 'pkgrecv' command:"
		echo
		cat $TMPFILE
	fi
	echo

	rm -rf $S11_REPO $TMPFILE
	
else
	echo "skipping Test 5/5: Check Connectivity to S11 Support repository"
	echo
fi
