#!/bin/bash

if [[ "$(/usr/bin/id|cut -d"(" -f1|cut -d"=" -f2)" != "0" ]]; then
  echo "ERROR: $(basename $0) must be run as root, nothing checked!"
  exit 1
fi

PRINTALL=true
DELTA=false
if [ "$1" = "-e" ];then
	PRINTALL=false
	if [ "$2" = "12" ]; then		#### when running troubleshoot, on delta we will get this paramter
		DELTA=true
	fi
fi
ANYERRORS=0

#
# checking available main memory
#

MEMORY=`/usr/bin/free -m| grep "^Mem:" | awk '{print $2}'`
if [ $MEMORY -lt 6000  ]; then
  printf "ERROR: Not enough Main Memory! 6 GB is the minimum supported, but only $MEMORY MB found\n\n"
  ANYERRORS=1
else
  $PRINTALL && printf "OK: $MEMORY MB of memory\n"
fi

#
# checking swap space
#

SWAPSIZE=`/usr/bin/free -m| grep "^Swap:" | awk '{print $2}'`
if [ $SWAPSIZE -lt 6000  ]; then
  printf "ERROR: Not enough swap space configured! 6 GB is the minimum required, but only $SWAPSIZE MB found\n\n"
  ANYERRORS=1
else
  $PRINTALL && printf "OK: $SWAPSIZE MB of swap\n"
fi

#
# Checking disk space
#

if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
        MOUNT="/var"
        if [ -d "/var/opt" ]; then
                MOUNT="/var/opt"
                if [ -d "/var/opt/sun" ]; then
                        MOUNT="/var/opt/sun"
                        if [ -d "/var/opt/sun/xvm" ]; then
                                MOUNT="/var/opt/sun/xvm"
                        fi
                fi
        fi

        AVAILABLE=`df -Pk $MOUNT | tail -1 | awk '{print \$4}'`
        AVAILABLEH=`df -Ph $MOUNT | tail -1 | awk '{print \$4}'`
        REQUIRED=75497472
        if [ $AVAILABLE -lt $REQUIRED ]; then
                printf "WARNING: Not enough disk space on $MOUNT - Need 72G but only have $AVAILABLEH\n"
                printf "         If this is a POC or a test environment then this might not be as critical\n\n"
        else
                printf "OK: $AVAILABLEH available on $MOUNT\n"
        fi
fi


#
# checking Redhat Version
#

RHVERFILE="/etc/redhat-release"
if [ -f $RHVERFILE ];then
	RHVER=`cat /etc/redhat-release`
	if [ "$RHVER" = "Red Hat Enterprise Linux Server release 5.4 (Tikanga)" ];then
		printf "WARNING: RedHat 5.4 is not supported and the installation will fail, do not attempt to modify /etc/redhat-release as it is not enough to make it work - some libraries are different\n\n"	
		ANYERRORS=1
	else
		SUPPORTED=0
		if [ "$RHVER" = "Red Hat Enterprise Linux Server release 5.3 (Tikanga)" ];then
			$PRINTALL && printf "OK: Oracle/RedHat Linux 5.3\n"
			SUPPORTED=1
		fi
		if [ "$RHVER" = "Red Hat Enterprise Linux Server release 5.5 (Tikanga)" ];then
			$PRINTALL && printf "OK: Oracle/RedHat Linux 5.5\n"
			SUPPORTED=1
		fi
		if [ "$RHVER" = "Red Hat Enterprise Linux Server release 5.6 (Tikanga)" ];then
			$PRINTALL && printf "OK: Oracle/RedHat Linux 5.6\n"
			SUPPORTED=1
		fi
		if [ $SUPPORTED -eq 0 ]; then
			printf "WARNING: Currently only Oracle / RedHat Linux 5.3, 5.5 and 5.6 are supported, this system is:\n"
			printf "$RHVER\n\n"
			ANYERRORS=1
		fi
	fi
else
	printf "ERROR: Could not find $RHVERFILE - is this a RedHat machine?\n\n"
	ANYERRORS=1
fi

#
# checking XEN kernel (Bug 15643413)
#

XEN=`uname -r | grep xen`
if [ ! "$XEN" = "" ]; then
	printf "WARNING: 'uname -r' shows that you are running the XEN kernel, which may result in slow EC performance.\n"
	echo "         For optimal performance, it is recommended that the system be reconfigured to use the standard (non-XEN) kernel."
	echo "         This can be achieved by modifying the /boot/grub/menu.lst file and set 'default=N' to a number corresponding to"
	echo "         the non-XEN kernel (requires reboot)."
	echo ""
else
	$PRINTALL && printf "OK: XEN kernel is not loaded\n"
fi


# do we have all required RPMs? 
#

if [ $DELTA = false ]; then 					### If not in Delta yet
	cat <<!EOF! > /tmp/rpms.$$ 
	python-2.4.3
	expect-5.43.0
	perl-DBD-Pg
	xinetd
	tftp-server
	dhcp
	gettext
	perl-XML-Parser
	ncompress
	libxml2
	gcc
	httpd
	wget
	make
	bc
	policycoreutils
!EOF!
	while read rpm
	do
	  rpm -q $rpm >/dev/null
	  if [ $? -eq 0 ]; then
	    $PRINTALL && echo "OK: $rpm is installed."
	    #printf "."
	  else
	    printf "WARNING: RPM $rpm is MISSING\n\n"
	    ANYERRORS=1
	  fi
	done < /tmp/rpms.$$
	rm -f /tmp/rpms.$$
else 		### if DELTA
	cat <<!EOF! > /tmp/rpms.$$ 
	python-2.4.3
	expect-5.43.0
	xinetd
	tftp-server
	dhcp
	gettext
	perl-XML-Parser
	libxml2
	gcc
	httpd
	wget
	make
	bc
	policycoreutils
!EOF!
	while read rpm
	do
	  rpm -q $rpm >/dev/null
	  if [ $? -eq 0 ]; then
	    $PRINTALL && echo "OK: $rpm is installed."
	    #printf "."
	  else
	    printf "WARNING: RPM $rpm is MISSING\n\n"
	    ANYERRORS=1
	  fi
	done < /tmp/rpms.$$
	rm -f /tmp/rpms.$$
fi

# On 64-bit Linux Systems, check to see if necessary 32-bit packages are installed
## Assumes this is RedHat or Oracle Enterprise Linux

UNAMEI=`uname -i`

cat <<!EOF! > /tmp/32bitrpms.$$
libxml2
pam
!EOF!

if [ "$UNAMEI" = "x86_64" ]; then

        while read rpm
        do
                # Check for i386/i568/i686 version of the rpm
                rpm -q --qf "%{NAME}-%{VERSION}-%{RELEASE}:%{ARCH}\n" $rpm | grep i[0-9]86 > /dev/null
                if [ $? -eq 0 ]; then
                        $PRINTALL && echo "OK: $rpm is installed."
                else
                        printf "ERROR: 32-bit RPM $rpm is MISSING on this x86_64 machine\n\n"
                        ANYERRORS=1
                fi

        done < /tmp/32bitrpms.$$
        rm -f /tmp/32bitrpms.$$
fi

#
# do we have correct umask
#

maskok=0
mask=022

if [[ "$(umask)" != "$mask" && "$(umask)" != "0$mask" ]]; then
  printf "WARNING: umask of user root is not $mask, Ops Center will fail\n"
  ANYERRORS=1
  maskok=1
else
  $PRINTALL && printf "OK: root umask is $mask\n"
fi

for file in /etc/profile* /etc/bash*; do
  if [[ "$(grep umask "$file" 2> /dev/null|cut -d"#" -f1|egrep -v "(0$mask|$mask)"|grep -v "^$")" != "" ]]; then
    PROBLEM=1
    if [ "$file" = "/etc/bashrc" ]; then
	### Check if this is not the default Linux bashrc, which is OK as there's a condition there
	OUTPUT=`source /etc/bashrc >/dev/null 2>/dev/null ; umask`                                     
        if [ "$OUTPUT" = "$mask" ] || [ "$OUTPUT" = "0$mask" ]; then
		$PRINTALL && printf "OK: $file has the umask of $mask\n"
		PROBLEM=0
	fi
    fi
    if [ "$PROBLEM" = "1" ]; then
	    printf "WARNING: it seems like $file may set a umask other than $mask. Ops Center may fail after installation.\n\n"
	    ANYERRORS=1
	    maskok=1
    fi
  else
    $PRINTALL && printf "OK: $file has the umask of $mask\n"
  fi
done

if [[ "$(grep CMASK /etc/default/init 2> /dev/null|cut -d"#" -f1|egrep -v "(0$mask|$mask)")" != "" ]]; then
  printf "WARNING: it seems like /etc/default/init may set a umask other than $mask. Ops Center may fail after installation.\n\n"
  ANYERRORS=1
  maskok=1
else
  $PRINTALL && printf "OK: /etc/default/init has the umask of $mask\n"
fi

#
# is someone using our ports 
#
if [ $PRINTALL = true ];then		### Run only if we check everything and not through troubleshooting (the ports then SHOULD be in use)
	netports=0
	function portused () {
		port=$1
		comment=$2
		if [[ "$(netstat -an |grep LISTEN|fgrep  "${receive}${port} ")" == "" ]]; then
    			# $PRINTALL && printf "OK: Port $port is not in use\n"
			return 0
		else
    			printf "WARNING: someone is listening on port ${port}! $comment\n\n"
			ANYERRORS=1
			netports=1
			return 1
		fi
	}

	if [[ "$(uname -s)" == "Linux" ]]; then
	  receive=":"
	else
	  receive="*."
	fi

	portused 80 "BUI will connect here"
	portused 9443 "BUI will connect here"
	portused 443 "Proxy communication" 
	portused 21165 "Agent pushes Inventory to Proxy - only needed when Management node is Proxy"
	portused 8002 "Agent downloads from Proxy - only needed when Management node is Proxy"
	portused 8004 "OS provisioning completion status only - only needed when Management node is Proxy and OS Provisioning is wanted"
	portused 11172 "Enterprise Controller Cacao instance oem-ec will use this port"
	portused 162 "SNMP port will be used by Proxy - see the doc in the howto folder to adjust this port"

	if [ $netports -eq 0 ]; then
		$PRINTALL && printf "OK: All ports are available (not in use)\n"
	fi

fi

#
# checking ssh requirements for OC
#

CHECK=0
function checkfile () {
        file=$1
	if [[ -f $file || -h $file ]] ; then
		false && $PRINTALL && printf "."
	else
		printf "WARNING: File or link $file not found\n\n"
		ANYERRORS=1
		CHECK=1
	fi
}
checkfile /usr/bin/scp
checkfile /usr/bin/ssh
checkfile /usr/bin/ssh-keygen
checkfile /usr/bin/ssh-keyscan
if [ $CHECK -eq 0 ]; then
	$PRINTALL && printf "OK: All SSH requirements are met\n"
fi

#
# Check SELinux
#
SECONF="/etc/selinux/config"
if [ -f $SECONF ]; then
	SEL=`grep "^SELINUX=" $SECONF | awk -F"=" '{print $2}'`
	if [ "$SEL" = "enforcing" ]; then
		echo "ERROR: SELinux is enabled in $SECONF - must be disabled before installing Ops Center"
		echo ""
		ANYERRORS=1
	else
		$PRINTALL && echo "OK: SELinux doesn't show up in $SECONF"		#'
	fi
else
	$PRINTALL && echo "OK: No SELinux config file found"
fi
SEBIN="/usr/sbin/selinuxenabled"
if [ -f $SEBIN ]; then
	$SEBIN
	if [ $? -ne 0 ]; then
       		$PRINTALL && echo "OK: SELinux is not enable based on $SEBIN"
	else
	        echo "ERROR: $SEBIN is indicating that SELinux is running - SELinux must be disabled before installing Ops Center"
		echo ""
		ANYERRORS=1
	fi
fi

#
# checking for multiple NICs
#

#if [ $PRINTALL = true ]; then
#	$PRINTALL && printf "Checking for multiple configured NICs:"
#	NIC_NO=`ifconfig -a|grep inet | grep -v 'inet6' |grep -v 'inet addr:127.0.0.1' |grep -v 'inet addr:0.0.0.0'|wc -l`
#	if [ $NIC_NO -gt 1 ] 
#	then
#	  printf "\nWARNING: This system has multiple configured IP addresses !"
#	  printf "\nWARNING: Do not select 'Simple Deployment' during the Initial Configuration !"
#	  printf "\nWARNING: If a local Proxy is required use the command"
#	  printf "\nWARNING:    proxyadm configure -s localhost -a <ip-address-to-be-used> ..."
#	  printf "\nWARNING: to configure the proxy later on! \n"
#	  ANYERRORS=1
#	else
#	  $PRINTALL && printf " OK\n"
#	fi
#fi

#
# Check for 32 bit version of the glibc-devel (required by OCM)
#
if [ $PRINTALL = true ]; then			### Only run this in prereq - NOT in troubleshoot
	DEVEL=`rpm -q --qf "%{ARCH}\n" glibc-devel | egrep "i386|i686"`
        if [ "$DEVEL" = "" ]; then
                echo "ERROR: Did not find 32 bit version of glibc-devel RPM."
                echo "       The 32 bit version is required"
                echo "       You may run the following command to check the version:"
                echo ""
                echo "# rpm -q --qf \"%{NAME}-%{VERSION}-%{RELEASE}:%{ARCH}\n\" glibc-devel"
                echo ""
        else
                echo "OK: glibc-devel 32 bit is installed"
        fi
fi

#
# Check for existing UID/GID 60
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
                                                ### in troubleshoot we run individual tests so in colocated it prints only one message
        CHECK=0
	OUTPUT=`getent passwd 60`
	if [ ! "$OUTPUT" = "" ];then
                CHECK=1
                echo
                echo "WARNING: Found existing user with UID 60! Please, remove user before installing Ops Center!"
		echo "         Try: getent passwd 60"
                echo
        fi
	OUTPUT=`getent group 60`
	if [ ! "$OUTPUT" = "" ];then
                CHECK=1
                echo
                echo "WARNING: Found existing group with GID 60! Please, remove group before installing Ops Center!"
		echo "         Try: getent group 60"
                echo
        fi
        if [ $CHECK -eq 0 ]; then
                echo "OK: xvm UID/GID 60 is not in use"
        fi
fi

#
# Check for a leftover Local Library
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
    if [ -d /guests ]; then
        echo 'WARNING: Found an existing directory /guests with an Ops Center Local Library!'
        echo 'WARNING: Remove this directory to avoid any conflict due to left content in the Library!'
    else
        echo 'OK: Directory /guests does not exist.'
    fi
fi

#
# Check for proper locale settings
#
if [ $PRINTALL = true ]; then                              ### Only run this in prereq - NOT in troubleshoot (have a specific test for it)
        FAILED=0

        LC_CTYPE=`locale | grep LC_CTYPE | awk -F"=" '{print $2}' | sed -e 's/\"//g'`
        LC_MESSAGES=`locale | grep LC_MESSAGES | awk -F"=" '{print $2}' | sed -e 's/\"//g'`

        LC_CTYPE_EN=`echo $LC_CTYPE|grep -i en_US`
        if [ ! "$LC_CTYPE" = "C" ] && [ "$LC_CTYPE_EN" = "" ]; then
                FAILED=1
                FAILED_L=$LC_CTYPE
        fi

        LC_MESSAGES_EN=`echo $LC_MESSAGES|grep -i en_US`
        if [ ! "$LC_MESSAGES" = "C" ] && [ "$LC_MESSAGES_EN" = "" ]; then
                FAILED=1
                FAILED_L=$LC_MESSAGES
        fi

        if [ $FAILED -eq 0 ]; then
                echo "OK: Locales are OK (\"$LC_CTYPE\")"
        else
                echo "WARNING: Locales are set to \"$FAILED_L\". This may cause issues when upgrading. Make sure you run:"
                echo "         # export LC_ALL=C"
                echo "         # export LANG=C"
                echo "         You can verify the settings by running:"
                echo "         # locale"
                echo ""
                ANYERRORS=1
        fi
fi


#
# Do old UCE rpms exist on the system? 
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
cat <<!EOF! > /tmp/uce.$$
sun-uce-agent
sun-uce-server
sun-uce-engine
!EOF!

	while read rpm
	do
	  rpm -q $rpm >/dev/null
	  if [ $? -eq 0 ]; then
	    printf "ERROR: $rpm is installed. You must uninstall $rpm before installing Ops Center\n\n"
	    ANYERRORS=1
	  else
	    $PRINTALL && printf "OK: RPM $rpm not installed\n"
	  fi
	done < /tmp/uce.$$
	rm -f /tmp/uce.$$
fi

#
# Check if the string with all interfaces will be larger than 100 chars
#

ITF_SIZE=`ifconfig -a | grep ': '| grep -v 'lo0' |awk '{print $1}' |wc -c`

if [ "${ITF_SIZE}" -gt 100 ]; then
  echo "ERROR: The string length of all configured network interfaces is extending 100 chars!"
  echo "ERROR: This will cause an issue when importing ISO images (Bug 15699033)!"
  echo ""
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Number of configured interfaces is not exceeding maximum."
fi

	
exit $ANYERRORS
