#!/usr/bin/ksh

PRINTALL=true
DELTA=false
if [ "$1" = "-e" ];then
	PRINTALL=false
	if [ "$2" = "12" ]; then                #### when running troubleshoot, on delta we will get this paramter
		DELTA=true
        fi
fi
ANYERRORS=0

#
# are we root :-)
#

if [[ "$(/usr/bin/id|cut -d"(" -f1|cut -d"=" -f2)" != "0" ]]; then
  echo "ERROR: $(basename $0) must be run as root, nothing checked!"
  exit 1
fi

$PRINTALL && echo '========== Checking Proxy Controller Requirements ... ===================='

#
# Check if this is Open Solaris
#
if [ $DELTA = false ]; then
	OS_TYPE=`uname -s`
	OS_REL=`uname -r`
	if [ "$OS_TYPE" = "SunOS" -a "$OS_REL" = "5.11" ]; then
	    echo "WARNING: Found Solaris 11. Please be aware that Ops Center 11g does NOT support Solaris 11."
	    echo "         Solaris 11 is only supported by the future unreleased version of Ops Center - 12c."
	    DELTA=true		#### Notified user, now assume this is OK from now on
	fi
fi

#
# checking available main memory
#

memory=$(prtconf 2>/dev/null | nawk '$1 == "Memory" {if ($4 ~ /Giga/) print 1024*$3; else print $3}')
if [[ ${memory} -lt 4000  ]]; then
  printf "\nWARNING: Not enough Main Memory! 4 GB is the minimum supported, but only ${memory} MB found!\n\n"
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Size of Main Memory: ${memory} MB"
fi

#
# checking swap space
#

if swap -l 1>/dev/null 2>&1
then
  swapsize=$(( $(swap -l | nawk ' $1 != "swapfile" { SWAPSIZE = SWAPSIZE + $4 }; END {print SWAPSIZE}') / 2048 ))
else
  swapsize=0
fi
if [[ ${swapsize} -lt 4000  ]]; then
  printf "\nERROR: Not enough swap space configured! 4 GB is the minimum required, but only ${swapsize} MB found!\n\n"
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Size of swap space: ${swapsize} MB"
fi

#
# Checking disk space
#

if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
        #$PRINTALL && printf "\n\nChecking size of available disk space:"
        MOUNT="/var"
        if [ -d "/var/opt" ]; then
                MOUNT="/var/opt"
                if [ -d "/var/opt/sun" ]; then
                        MOUNT="/var/opt/sun"
                        if [ -d "/var/opt/sun/xvm" ]; then
                                MOUNT="/var/opt/sun/xvm"
                        fi
                fi
        fi
        AVAILABLE=`df -k $MOUNT | tail -1 | awk '{print \$4}'`
        AVAILABLEH=`df -h $MOUNT | tail -1 | awk '{print \$4}'`
        REQUIRED=75497472
        if [ $AVAILABLE -lt $REQUIRED ]; then
                printf "\nWARNING: Not enough disk space on $MOUNT - Need 72G but only have $AVAILABLEH\n"
		printf "         If this is a POC or a test environment then this might not be as critical\n\n"
        else
                echo "OK: Found enough disk space on $MOUNT ($AVAILABLEH)"
        fi
fi


#
# checking Solaris Cluster 
#
OS_REL=`uname -r`
if [ ! "$OS_REL" = "5.11" ]; then               ### Solaris 11 uses AI, so no CLUSTER
	cluster="$(cut -d= -f2 /var/sadm/system/admin/CLUSTER 2>/dev/null)"
	if [[ "$cluster" == "" ]]; then
	  printf "\nWARNING: CAN'T CHECK CLUSTER! Maybe we are in a local zone?\n\n"		#'
	  ANYERRORS=1
	else
	  if [[ "$cluster" != "SUNWCall" && "$cluster" != "SUNWCXall" ]] ; then
	    printf "\nWARNING: WRONG CLUSTER installed ($cluster)! Should be minimum of SUNWCall\n\n"
	    ANYERRORS=1
	  else
	    $PRINTALL && echo "OK: Installed Solaris Package Cluster: $cluster"
	  fi
	fi
fi

#
# checking Solaris Release 
#

UNAMER=`uname -r`
if [ "$UNAMER" = "5.10" ]; then
        $PRINTALL && echo "OK: Solaris 10 found"
elif [ "$UNAMER" == "5.11" -a $DELTA = true ]; then
        $PRINTALL && echo "OK: Solaris 11 found"
else
	printf "\nERROR: Enterprise Controller can be only installed on Solaris 10, not on $UNAMER\n\n"
	exit
fi

if [ "$UNAMER" = "5.10" ]; then
release=`grep Solaris /etc/release | head -1 | cut -f2 -d_ | cut -f1 -dw`
if [[ "$release" == "u1" || "$release" == "u2"  ]] ; then
   printf "\nWARNING: WRONG Release ($release)! Should be minimum of U3\n\n"
   ANYERRORS=1
 else
    if [[ "$release" == "u10" || "$release" == "u11" ]]; then
        $PRINTALL && echo "WARNING: Found Solaris 10 $release"                  #### Only print this in prereq
        $PRINTALL && echo "         There is a known installation issue with $release (Bug 15728510) - the installation will fail thinking this is u1."
        $PRINTALL && echo "         To work around this, change /etc/release:"
        $PRINTALL && echo "         from: s10s_${release}wos_10"
        $PRINTALL && echo "         to:   s10s_u9wos_10"
        $PRINTALL && echo
        $PRINTALL && echo "         You can put '$release' back in place after the installation is done."
        $PRINTALL && echo
   else
        $PRINTALL && echo "OK: Solaris 10 $release found"
   fi
fi
fi

#
# checking for running Cacao instance
#

if [ $PRINTALL = true ]; then			### Only run this in prereq - NOT in troubleshoot
ONLINE=`svcs '*common-agent-container-*' 2>/dev/null | grep -v "\:default" | grep -w online`	## In Echelon we don't use default anymore
if [ -n "${ONLINE}" ]; then
   $PRINTALL && printf "\n\nWARNING: One or more Cacao instances are running on this system:\n\n"
   $PRINTALL && printf "$ONLINE\n"
   $PRINTALL && printf "\nThese must be stopped and eventually removed before installing Ops Center Software!\n\n"
else
  $PRINTALL && echo "OK: no running Cacao instance found"
fi
fi	### End of "if [ $PRINTALL = true ]"

SVCCFG=/usr/sbin/svccfg
SMF_COUNT=$( $SVCCFG list | grep common-agent-container- | wc -l )
if [ "${SMF_COUNT}" -gt 1 ]; then
        printf "\nWARNING: More than one SMF instance for the Cacao service does exist:\n\n"
        $SVCCFG list | grep common-agent-container-
        printf "\nThis must be analyzed and cleaned up!\n\n"
        printf "Review the cacao document in the howto folder to fix this!\n\n"
        printf "Do not try to install or update an EC or PC on this system before this issue is fixed!\n\n"
        ANYERRORS=1
else
        $PRINTALL && echo "OK: None or unique Cacao SMF instance found"
fi

#
# do we have all required pkgs 
#

xvmocpkgcheck=0
OS_REL=`uname -r`
if [ $DELTA = false ] || [ "$OS_REL" = "5.10" ]; then                                  ### If not in Delta yet, or if it's Solaris 10
	cat <<!EOF! > /tmp/pkgs.$$ 
	SUNWPython
	SUNWPython-share
	SUNWTcl
	SUNWTk
	SUNWadmap
	SUNWadmc
	SUNWadmfr
	SUNWadmfw
	SUNWant
	SUNWapch2r
	SUNWapch2u
	SUNWarc
	SUNWbash
	SUNWbinutils
	SUNWbip
	SUNWbzip
	SUNWcpp
	SUNWctpls
	SUNWdtcor
	SUNWesu
	SUNWftpr
	SUNWftpu
	SUNWgcmn
	SUNWggrp
	SUNWgss
	SUNWgssc
	SUNWgssk
	SUNWgtar
	SUNWgzip
	SUNWhea
	SUNWj3dev
	SUNWj3rt
	SUNWlexpt
	SUNWlibC
	SUNWlibm
	SUNWlibmr
	SUNWlibms
	SUNWlibmsr
	SUNWlibpopt
	SUNWloc
	SUNWlxml
	SUNWmfrun
	SUNWnfsckr
	SUNWnfscr
	SUNWnfscu
	SUNWnfsskr
	SUNWnfssr
	SUNWnfssu
	SUNWperl-xml-parser
	SUNWperl584core
	SUNWperl584usr
	SUNWrsgk
	SUNWsprot
	SUNWswmt
	SUNWtftp
	SUNWtftpr
	SUNWtoo
	SUNWwgetr
	SUNWwgetu
	SUNWxcu4
	SUNWxwdv
	SUNWxwfnt
	SUNWxwice
	SUNWxwplr
	SUNWxwplt
	SUNWxwrtl
	SUNWzip
	SUNWzlib
	SUNWgccruntime
!EOF!

	while read pkg
	do
	  if ! pkginfo -q $pkg; then
	    printf "\nWARNING: Package $pkg is required but not installed"
	    ANYERRORS=1
	    xvmocpkgcheck=1
	  fi
	done < /tmp/pkgs.$$
	rm /tmp/pkgs.$$
else							### If it's Delta AND it's Solaris 11
	##### check for IPS packages ####
	cat <<!EOF! > /tmp/pkgs.$$ 
        pkg://solaris/archiver/gnu-tar
        pkg://solaris/shell/bash
        pkg://solaris/web/wget
        pkg://solaris/system/xopen/xcu4
        pkg://solaris/developer/build/make
        pkg://solaris/library/perl-5/xml-parser
!EOF!
	
	while read pkg
	do
	  if ! pkg list $pkg >/dev/null 2>/dev/null; then
	    printf "\nWARNING: Package $pkg is required but not installed (Try 'pkg install $pkg')"
	    ANYERRORS=1
	    xvmocpkgcheck=1
	  fi
	done < /tmp/pkgs.$$
	rm /tmp/pkgs.$$
fi		### Done with Solaris 11

if [[ $xvmocpkgcheck -eq 0 ]]; then
  $PRINTALL && echo "OK: All required packages are installed"
else
  printf "\n\n"
fi

#
# Check for extra packages known to conflict with Ops Center 
#

xvmocpkgcheck=0
cat <<!EOF! > /tmp/pkgs.$$ 
ASPerl
!EOF!

while read pkg
do
  if pkginfo -q $pkg; then
    printf "\nERROR: Package $pkg is installed and known to conflict with Ops Center. Please remove before installation."
    ANYERRORS=1
    xvmocpkgcheck=1
  fi
done < /tmp/pkgs.$$
rm /tmp/pkgs.$$

if [[ $xvmocpkgcheck -eq 0 ]]; then
  $PRINTALL && echo "OK: No known conflicting packages exist"
else
  printf "\n\n"
fi

#
# checking for library extendedFILE.so.1
#

if [[ -f /usr/lib/extendedFILE.so.1 ]]; then
  $PRINTALL && echo "OK: Patches for extendedFILE library are installed"
else
  printf "\nWARNING: library /usr/lib/extendedFILE.so.1 MISSING\n"
  printf "\nWARNING: Patches 125100/1-04, 120473/4-05 and 125800/1-01 must be installed\n\n"
  ANYERRORS=1
fi

#
# do we have correct umask
#

maskok=0
mask=022

if [[ "$(umask)" != "$mask" && "$(umask)" != "0$mask" ]]; then
  printf "\nWARNING: umask of user root is not $mask, OpsCenter will fail!\n\n"
  ANYERRORS=1
  maskok=1
fi

for file in /etc/profile* /etc/bash*; do
  if [[ "$(grep umask "$file" 2> /dev/null|cut -d"#" -f1|egrep -v "(0$mask|$mask)"|grep -v "^$")" != "" ]]; then
    printf "\nWARNING: $file seems to set a umask other than $mask. OpsCenter might fail!\n\n"
    ANYERRORS=1
    maskok=1
  fi
done

if [[ "$(grep CMASK /etc/default/init 2> /dev/null|cut -d"#" -f1|egrep -v "(0$mask|$mask)")" != "" ]]; then
  printf "\nWARNING: /etc/default/init seems to set a umask other than $mask. OpsCenter might fail!\n\n"
  ANYERRORS=1
  maskok=1
fi

if [ $maskok -eq 0 ]; then
    $PRINTALL && echo "OK: Verified correct umask"
fi

#
# is someone using our ports 
#

# we only run this when checking for prerequisites
if ${PRINTALL}; then
  netports=0
  TMP_PFILES=/tmp/_pfiles_out_$$
  mkdir $TMP_PFILES
  ##### Do we have any nskernd running?
  pgrep nskernd > /tmp/nskernd-pids.$$
  NSKERNDRUNNING=$?		#### 1 for not running, 0 for running 
  for pid in $(cd /proc; ls); do
    if [ "$NSKERNDRUNNING" -eq "0"  ]; then
	#echo "nskernd is running"
	### is this PID a nskernd PID? if so, skip to avoid hangup
	grep "^$pid$" /tmp/nskernd-pids.$$ >/dev/null 2>/dev/null
	if [ $? -ne 0 ]; then		
		#echo "pid $pid is not nskernd"
    		pfiles $pid 2>/dev/null > ${TMP_PFILES}/pfiles.$pid
	#else
		#echo "pid $pid IS NSKERND"
	fi
    else
	#echo "nskernd is NOT running"
    	pfiles $pid 2>/dev/null > ${TMP_PFILES}/pfiles.$pid
    fi
  done 
  rm -f /tmp/nskernd-pids.$$
  cat <<!EOF! | while read nr comment; do
21165 Used by Agents to connect to Proxy
8002 Used by Agents to download content from Proxy
8004 Upload OS provisioning completion status - needed when this system is used for OS Provisioning
162 SNMP listening port used by the Proxy - see the doc in the howto folder to adjust this port
!EOF!
    if egrep "sockname: AF_INET .* port: ${nr}\$" ${TMP_PFILES}/pfiles.* > /dev/null; then 
      echo
      echo "WARNING: OpsCenter needed port ${nr} is in use!"
      echo "WARNING: ${comment}"
      echo "WARNING: Port is in use by process(es):"
      for pid_file in $(egrep -l "sockname: AF_INET .* port: ${nr}\$" ${TMP_PFILES}/pfiles.*); do
        head -1 $pid_file
      done 
      echo
      netports=1
    fi
  done
  [[ $netports -eq 0 ]] && echo "OK: Network ports needed by Management node and Proxy are not in use"
  rm -r ${TMP_PFILES}
fi

#
# checking SMF requirements for OC 
#

servicescheck=0
cat <<!EOF! | while read service; do
svc:/system/cryptosvc:default
svc:/network/rpc/gss:default
!EOF!
  if [[ "$(/usr/bin/svcs $service | tail -1 | cut -d" "  -f1)" == "online" ]] ; then
    #echo "OK: $service online."
    $PRINTALL #&& printf "."
  else
    printf "\nWARNING: service $service NOT ONLINE\n\n"
    ANYERRORS=1
    servicescheck=1
  fi
done
if [[ $servicescheck -eq 0 ]]; then
    $PRINTALL && echo "OK: All required SMF services are online"
fi

#
# checking ssh requirements for OC
#

CHECK=0
cat <<!EOF! | while read file; do
/usr/bin/scp
/usr/bin/ssh
/usr/bin/ssh-keygen
/usr/bin/ssh-keyscan
!EOF!
  if [[ -f $file || -h $file ]] ; then
    $PRINTALL #&& printf "."
  else
    printf "\nWARNING: File or link $file not found\n\n"
    ANYERRORS=1
    CHECK=1
  fi
done
if [ $CHECK -eq 0 ]; then
    $PRINTALL && echo "OK: Checked for ssh requirements"
fi

#
# checking for incompatible packages (skipping for 2.5, since no incompatible pkgs known)
#

#
# checking for installed SUNWjass package
#

if [[ -d "/var/sadm/pkg/SUNWjass" ]] ; then
    printf "\nWARNING: Ops Center installation may fail on hardened systems (SUNWjass)\n"
    printf "         Even if all JASS changes have been un-done, there is a good chance installation will fail\n\n"
    ANYERRORS=1
  else
    $PRINTALL && echo "OK: No SUNWjass installed"
fi

#
# checking for user/group webservd
#

ENTRIES=`cat /etc/group /etc/passwd | grep '^webservd:' | wc -l`
if [ $ENTRIES -ne 2 ] 
then
  printf "\nWARNING: The user and/or group 'webservd' does not exist !"
  printf "\nWARNING: This user and group must exist prior to installation ! \n\n"
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Checked for user & group 'webservd'"
fi

ANYOUTPUT=`su root -c "/bin/bash /etc/profile"`
#ANYOUTPUT=`su - webservd -c true`  
if [ "$ANYOUTPUT" = "" ];then
	$PRINTALL && echo "OK: Checked for output messages from /etc/profile"
else
        printf "\nERROR: /etc/profile prints out messages.  This can affect the scndb user that will be created during the Ops Center install\n"
        echo "Check in /etc/profile and remove those messages - otherwise installation may fail at step 11 - 'Initialize database'"
	ANYERRORS=1
fi

#
# Check for partially installed packages
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
                                                ### in troubleshoot we run individual tests so in colocated it prints only one message
        OUTPUT=`pkginfo -p`
        if [ "$OUTPUT" = "" ]; then
                echo "OK: No partially installed packages"
        else
                echo
                echo "WARNING: Found the following partially installed packages (pkginfo -p), please check if that's a problem:"	#'
                printf "$OUTPUT\n"
                echo ""
        fi
fi

#
# Check for an old zonectrlr.id file (Bug 15628914)
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
                                                ### in troubleshoot we run individual tests so in colocated it prints only one message
        if [ "$OS_TYPE" = "SunOS" -a "$OS_REL" = "5.10" ]; then
          if [ -f /etc/opt/sun/oc/zonectrlr.id ]; then
            echo 'WARNING: Found existing file /etc/opt/sun/oc/zonectrlr.id (Bug 15628914)!' 
            echo '         Remove this file before installing Ops Center!'
          else
            echo 'OK: No zonectrlr.id leftover file found.'
          fi
        fi
fi
        
#
# checking for leftovers from a previous installs
#

CHECK=0
cat <<!EOF! | while read file; do
CPANperl-dbd-pg
CPANperl-dbi-scs
CSKlibs
CSKncurses
CSKpython
CSKruntime
JetFLASH
JetJASS
JetLDOM
JetWanBoot
PGSQLscs
SFWexpct
SUNWcacaocrews
SUNWcacaome
SUNWcacaowsvr
SUNWjet
SUNWn1hss-agentdm
SUNWn1hss-agentdm-config
SUNWn1hss-core
SUNWn1hss-core-arch
SUNWn1hss-core-config
SUNWn1hss-core-i386
SUNWn1hss-core-usr
SUNWn1hss-drvrs
SUNWn1hss-servicescr
SUNWn1hss-ui-en
SUNWn1hss-ui-ja
SUNWscn-agent-utils
SUNWscn-agentfacade-r
SUNWscn-agentfacade-u
SUNWscn-agentfacade-vc-config
SUNWscn-agentupgrade-u
SUNWscn-agentupgrade-vc-r
SUNWscn-agentupgrade-vc-u
SUNWscn-cs
SUNWscn-jobmgrui
SUNWscn-monitorui
SUNWscn-osp
SUNWscn-osp-config
SUNWscn-osp-drivers
SUNWscn-osp-s
SUNWscn-osp-s-db
SUNWscn-provui
SUNWscn-prsf
SUNWscn-prsfc
SUNWscn-update-agent
SUNWscn-update-agent-r
SUNWscn-update-db
SUNWscn-update-util
SUNWscn-updateui
SUNWscnauth
SUNWscncon
SUNWscnconnmgt
SUNWscnconnmgt-r
SUNWscnconnmgt-ra
SUNWscnconnmgt-rp
SUNWscnconnmgt-rs
SUNWscncrs
SUNWscndb
SUNWscnjobmgr-agent
SUNWscnjobmgr-agent-config
SUNWscnjobmgr-common-api
SUNWscnjobmgr-common-impl
SUNWscnjobmgr-proxy
SUNWscnjobmgr-proxy-config
SUNWscnjobmgr-satellite
SUNWscnjobmgr-satellite-config
SUNWscnjobmgr-satellite-db
SUNWscnjobmgr-vc-config
SUNWscnnotifsvc
SUNWscnproxyadm
SUNWscnreportsvc
SUNWscnreportsvc-db
SUNWscnsatadm
SUNWscnsatmgmt
SUNWscportal
SUNWscs-agent
SUNWscs-allstart
SUNWscs-conf
SUNWscs-db
SUNWscs-modulemgr
SUNWscs-service
SUNWscs-task
SUNWsms-facade
SUNWuce-cli
SUNWucea
SUNWuceconsole
SUNWucee
SUNWucelarge
SUNWucelos
SUNWucepa
SUNWuces
SUNWxvm-ajaxterm
SUNWxvm-bui-tools
SUNWxvm-client
SUNWxvm-proxyrun-base
SUNWxvm-satrun-base
SUNWxvm-vc-driver-common
SUNWxvm-xvmsvrdm-config
SUNWxvm-zones-r
SUNWxvm-zstat
SUNWxvm-zstat-init
SUNWxvmoc-client
SUNWxvmoc-proxyrun-oc
SUNWxvmoc-satrun-oc
SUNWxvmoc-winpm
SUNWxvmoc-winpm-config
SUNWxvmoc-wme
SUNWxvmocbui
UPdhcp
!EOF!
  if [[ -d "/var/sadm/pkg/$file" ]] ; then
    $PRINTALL && printf "\nWARNING: Package $file found "
    CHECK=1
  else
    $PRINTALL #&& echo "."
  fi
done
if [ $CHECK -eq 0 ]; then
    $PRINTALL && echo "OK: No leftovers from previous installs found"
else
    $PRINTALL && printf "\n\nWARNING: Found above leftovers from a previous UCE / Ops Center installation!"
    $PRINTALL && printf "\nWARNING: Please, properly uninstall old UCE / Ops Center software components!\n"
fi

#
# Check for an existing read-only /usr/local filesystem
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
    if cd /usr/local 2>/dev/null; then
         TESTFILE=_oc-test_$$
         if ! touch $TESTFILE 2>/dev/null; then
             echo 'WARNING: /usr/local is a read-only filesystem!'
             echo 'WARNING: Installer must be able to install software there!'
         else
             rm $TESTFILE
             echo 'OK: /usr/local is writeable.'
         fi
     else
         echo 'OK: /usr/local does not exist.'
     fi
fi

#
# Check for proper locale settings
#
if [ $PRINTALL = true ]; then		                   ### Only run this in prereq - NOT in troubleshoot (have a specific test for it)
	FAILED=0

	LC_CTYPE=`locale | grep LC_CTYPE | awk -F"=" '{print $2}' | sed -e 's/\"//g'`
	LC_MESSAGES=`locale | grep LC_MESSAGES | awk -F"=" '{print $2}' | sed -e 's/\"//g'`

	LC_CTYPE_EN=`echo $LC_CTYPE|grep -i en_US`
	if [ ! "$LC_CTYPE" = "C" ] && [ "$LC_CTYPE_EN" = "" ]; then
	        FAILED=1
	        FAILED_L=$LC_CTYPE
	fi

	LC_MESSAGES_EN=`echo $LC_MESSAGES|grep -i en_US`
	if [ ! "$LC_MESSAGES" = "C" ] && [ "$LC_MESSAGES_EN" = "" ]; then
	        FAILED=1
	        FAILED_L=$LC_MESSAGES
	fi

	if [ $FAILED -eq 0 ]; then
	        echo "OK: Locales are OK (\"$LC_CTYPE\")"
	else
	        echo "WARNING: Locales are set to \"$FAILED_L\". This may cause issues when upgrading. Make sure you run:"
	        echo "         # export LC_ALL=C"
	        echo "         # export LANG=C"
	        echo "         You can verify the settings by running:"
	        echo "         # locale"
	        echo ""
		ANYERRORS=1
	fi
fi


#*************************************************************************************#

if [ "$OS_TYPE" = "SunOS" ]; then
  # Check if we are using GNU tail which does not have the option "-r"
  TAIL=/usr/bin/tail
  TESTFILE="/tmp/_testfile_.$$"
  touch $TESTFILE

  if [ -x $TAIL ]; then
    if $TAIL -r $TESTFILE 2>/dev/null 1>&2; then
      if $PRINTALL; then
        echo 'OK: Native Solaris "tail" command is available.'
      fi
    else
      echo "WARNING: $TAIL does not support the '-r' option which is required by the Agent!"
      echo "WARNING: Looks like 'GNU tail' is in use by default!"
      ANYERRORS=1
    fi
  else
    echo "WARNING: The command $TAIL is required by the Agent but could not be found!"
    ANYERRORS=1
  fi
  rm $TESTFILE
fi


#*************************************************************************************#

# Check if the string with all interfaces will be larger than 100 chars

ITF_SIZE=`ifconfig -a | grep ': '| grep -v 'lo0' |awk '{print $1}' |wc -c`

if [ "${ITF_SIZE}" -gt 100 ]; then
  echo "ERROR: The string length of all configured network interfaces is extending 100 chars!"
  echo "ERROR: This will cause an issue when importing ISO images (Bug 15699033)!"
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Number of configured interfaces is not exceeding maximum."
fi

#*************************************************************************************#


$PRINTALL && printf "\n\n"

rm -rf /tmp/.$$_patches /tmp/.$$_obsolete /tmp/.$$_pkgs /tmp/.$$_neededpatches

exit $ANYERRORS


