#!/usr/bin/ksh

PRINTALL=true
DELTA=true
if [ "$1" = "-e" ];then
	PRINTALL=false
fi
ANYERRORS=0

# OS Release, will be "5.10" or "5.11"
UNAMER=`uname -r`

#
# are we root :-)
#

if [[ "$(/usr/bin/id|cut -d"(" -f1|cut -d"=" -f2)" != "0" ]]; then
  echo "ERROR: $(basename $0) must be run as root, nothing checked!"
  exit 1
fi

THIS_DIR=`dirname $0`
OCDOCTOR_ROOT=`cd $THIS_DIR/..; pwd`
# source various common functions
. $OCDOCTOR_ROOT/functions

# define Solaris 11 parameters
solaris11_stuff

$PRINTALL && echo '========== Checking 12c Proxy Controller Requirements ... ===================='
#$PRINTALL && echo "OK: This prerequisites script is for 12c Proxy. Run --proxy-prereq-11g if you need the old version"

#
# checking available main memory
#

memory=$(prtconf 2>/dev/null | nawk '$1 == "Memory" {if ($4 ~ /Giga/) print 1024*$3; else print $3}')
if [[ ${memory} -lt 3850  ]]; then
  printf "\nWARNING: Not enough Main Memory! 4 GB is the minimum supported, but only ${memory} MB found!\n\n"
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Size of Main Memory: ${memory} MB"
fi

#
# checking swap space
#

if swap -l 1>/dev/null 2>&1
then
  swapsize=$(( $(swap -l | nawk ' $1 != "swapfile" { SWAPSIZE = SWAPSIZE + $4 }; END {print SWAPSIZE}') / 2048 ))
else
  swapsize=0
fi
if [[ ${swapsize} -lt 3850  ]]; then
  printf "\nERROR: Not enough swap space configured! 4 GB is the minimum required, but only ${swapsize} MB found!\n\n"
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Size of swap space: ${swapsize} MB"
fi

#
# Checking /tmp size
#
if [ -f /etc/vfstab ]; then
	OUTPUT=`grep "^swap" /etc/vfstab | grep "/tmp" | grep -i "size="`
	if [ "$OUTPUT" = "" ]; then
		$PRINTALL && echo "OK: /tmp size is not limited in /etc/vfstab"
	else
		echo "WARNING: /tmp size is limited in /etc/vfstab, this may cause issues."
		echo "         It is recommended to remove this limitation by replacing 'size=...' to '-' in /etc/vfstab and reboot"
		echo ""
		ANYERRORS=1
	fi
fi

#
# Checking disk space
#

if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
        #$PRINTALL && printf "\n\nChecking size of available disk space:"
        MOUNT="/var"
        if [ -d "/var/opt" ]; then
                MOUNT="/var/opt"
                if [ -d "/var/opt/sun" ]; then
                        MOUNT="/var/opt/sun"
                        if [ -d "/var/opt/sun/xvm" ]; then
                                MOUNT="/var/opt/sun/xvm"
                        fi
                fi
        fi
        AVAILABLE=`df -k $MOUNT | tail -1 | awk '{print \$4}'`
        AVAILABLEH=`df -h $MOUNT | tail -1 | awk '{print \$4}'`
        REQUIRED=75497472
        if [ $AVAILABLE -lt $REQUIRED ]; then
                printf "\nWARNING: Not enough disk space on $MOUNT - Need 72G but only have $AVAILABLEH\n"
		printf "         If this is a POC or a test environment then this might not be as critical\n\n"
        else
                echo "OK: Found enough disk space on $MOUNT ($AVAILABLEH)"
        fi
fi


#
# checking Solaris Cluster 
#
if [ ! "$UNAMER" = "5.11" ]; then               ### Solaris 11 uses AI, so no CLUSTER
	cluster="$(cut -d= -f2 /var/sadm/system/admin/CLUSTER 2>/dev/null)"
	if [[ "$cluster" == "" ]]; then
	  printf "\nWARNING: CAN'T CHECK CLUSTER! Maybe we are in a local zone?\n\n"		#'
	  ANYERRORS=1
	else
	  if [[ "$cluster" != "SUNWCall" && "$cluster" != "SUNWCXall" ]] ; then
	    printf "\nWARNING: WRONG CLUSTER installed ($cluster)! Should be minimum of SUNWCall\n\n"
	    ANYERRORS=1
	  else
	    $PRINTALL && echo "OK: Installed Solaris Package Cluster: $cluster"
	  fi
	fi
fi

#
# checking Solaris Release 
#

if [ "$UNAMER" = "5.10" ]; then
	release=`grep Solaris /etc/release | head -1 | cut -f2 -d_ | cut -f1 -dw`
	if [[ "$release" == "u1" || "$release" == "u2"  ]] ; then
		printf "\nWARNING: WRONG Release ($release)! Should be minimum of U3\n\n"
		ANYERRORS=1
	else
		$PRINTALL && echo "OK: Solaris 10 $release found"
	fi
fi

#
# checking for running Cacao instance
#

if [ $PRINTALL = true ]; then			### Only run this in prereq - NOT in troubleshoot
ONLINE=`svcs '*common-agent-container-*' 2>/dev/null | grep -v "\:default" | grep -w online`	## In Echelon we don't use default anymore
if [ -n "${ONLINE}" ]; then
   $PRINTALL && printf "\n\nWARNING: One or more Cacao instances are running on this system:\n\n"
   $PRINTALL && printf "$ONLINE\n"
   $PRINTALL && printf "\nThese must be stopped and eventually removed before installing Ops Center Software!\n\n"
else
  $PRINTALL && echo "OK: no running Cacao instance found"
fi
fi	### End of "if [ $PRINTALL = true ]"

SVCCFG=/usr/sbin/svccfg
SMF_COUNT=$( $SVCCFG list | grep common-agent-container- | wc -l )
if [ "${SMF_COUNT}" -gt 1 ]; then
        printf "\nWARNING: More than one SMF instance for the Cacao service does exist:\n\n"
        $SVCCFG list | grep common-agent-container-
        printf "\nThis must be analyzed and cleaned up!\n\n"
        printf "Review the cacao document in the howto folder to fix this!\n\n"
        printf "Do not try to install or update an EC or PC on this system before this issue is fixed!\n\n"
        ANYERRORS=1
else
        $PRINTALL && echo "OK: None or unique Cacao SMF instance found"
fi

#
# do we have all required pkgs 
#

xvmocpkgcheck=0
if [ $DELTA = false ] || [ "$UNAMER" = "5.10" ]; then                                  ### If not in Delta yet, or if it's Solaris 10
	cat <<!EOF! > /tmp/pkgs.$$ 
	SUNWPython
	SUNWPython-share
	SUNWTcl
	SUNWTk
	SUNWadmap
	SUNWadmc
	SUNWadmfr
	SUNWadmfw
	SUNWant
	SUNWapch2r
	SUNWapch2u
	SUNWarc
	SUNWbash
	SUNWbinutils
	SUNWbip
	SUNWbzip
	SUNWcpp
	SUNWctpls
	SUNWdtcor
	SUNWesu
	SUNWftpr
	SUNWftpu
	SUNWgcmn
	SUNWggrp
	SUNWgss
	SUNWgssc
	SUNWgssk
	SUNWgtar
	SUNWgzip
	SUNWhea
	SUNWj3dev
	SUNWj3rt
	SUNWlexpt
	SUNWlibC
	SUNWlibm
	SUNWlibmr
	SUNWlibms
	SUNWlibmsr
	SUNWlibpopt
	SUNWloc
	SUNWlxml
	SUNWmfrun
	SUNWnfsckr
	SUNWnfscr
	SUNWnfscu
	SUNWnfsskr
	SUNWnfssr
	SUNWnfssu
	SUNWperl-xml-parser
	SUNWperl584core
	SUNWperl584usr
	SUNWrsgk
	SUNWsprot
	SUNWswmt
	SUNWtftp
	SUNWtftpr
	SUNWtoo
	SUNWwgetr
	SUNWwgetu
	SUNWxcu4
	SUNWxwdv
	SUNWxwfnt
	SUNWxwice
	SUNWxwplr
	SUNWxwplt
	SUNWxwrtl
	SUNWzip
	SUNWzlib
	SUNWgccruntime
!EOF!

	while read pkg
	do
	  if ! pkginfo -q $pkg; then
	    printf "\nWARNING: Package $pkg is required but not installed"
	    ANYERRORS=1
	    xvmocpkgcheck=1
	  fi
	done < /tmp/pkgs.$$
	rm /tmp/pkgs.$$
else							### If it's Delta AND it's Solaris 11
	##### check for IPS packages ####
	cat <<!EOF! > /tmp/pkgs.$$ 
        pkg://solaris/archiver/gnu-tar
        pkg://solaris/shell/bash
        pkg://solaris/web/wget
        pkg://solaris/system/xopen/xcu4
        pkg://solaris/developer/build/make
        pkg://solaris/library/perl-5/xml-parser
!EOF!
	
	while read pkg
	do
	  if ! pkg list $pkg >/dev/null 2>/dev/null; then
	    printf "\nWARNING: Package $pkg is required but not installed (Try 'pkg install $pkg')"
	    ANYERRORS=1
	    xvmocpkgcheck=1
	  fi
	done < /tmp/pkgs.$$
	rm /tmp/pkgs.$$
fi		### Done with Solaris 11

if [[ $xvmocpkgcheck -eq 0 ]]; then
  $PRINTALL && echo "OK: All required packages are installed"
else
  printf "\n\n"
fi
# check for installed package osp_script_framework

if [ "$UNAMER" = "5.11" ] && $PRINTALL ; then
        if pkg list osp_script_framework >/dev/null 2>&1; then
                echo
                echo "ERROR: Leftover package 'osp_script_framework' from OS Provisiong found!"
                echo
                echo "This package can cause conflicts with the Proxy Controller Software and needs to get uninstalled!"
                echo
                echo "Run 'pkg uninstall osp_script_framework' to remove the package prior to installation of the Proxy."
                echo
        else
                echo "OK: No leftover package from OS Provisioning found"
        fi
fi

# Check for Repo connectivity
if [ "$UNAMER" = "5.11" ]; then
	########## Check if you can reach the remote repository ####
	export PKG_CLIENT_CONNECT_TIMEOUT=15
	export PKG_CLIENT_MAX_TIMEOUT=2 
	pkg refresh solaris >/dev/null 2>/dev/null		#### refresh would actually go to the remote, while info will not
	RETVAL=$?
	if [ $RETVAL -ne 0 ]; then
		echo
		echo "ERROR: unable to run 'pkg refresh solaris' to reach the remote repository. Running 'pkg publisher':"
		pkg publisher
		echo 
		### Print the following only if running --prereq, and not during Troubleshoot as when the product is installed, it must point to the localhost MSR
		$PRINTALL && echo "To set the solaris publisher to the Solaris 11 GA repo use: (this should have been the default though)"
		$PRINTALL && echo "# pkg set-publisher -G '*' -g http://pkg.oracle.com/solaris/release solaris"
		$PRINTALL && echo ""
		$PRINTALL && echo "Note that the \"-G '*'\" option will remove any current publishers."
		$PRINTALL && echo ""
		echo "It can be that you need a proxy to access this repository. If you do, specify the following:"
		echo "export http_proxy=\"webproxy.domain.com:port\""
		echo "If you do need a proxy, make sure to specify the http_proxy before you start the Proxy Controller install."
		echo ""
		echo "Another option is that you may need to exclude the EC host from your proxy (if the proxy does not know about this hostname):"
		echo "Run 'pkg publisher' to see what is the hostname it is trying to connect to and set the following env variable:"
		echo "no_proxy=<hostname from the 'pkg publisher' command> ; export no_proxy"
		echo "And try to run this test again."
		echo ""
		ANYERRORS=1
	else
		PREFERRED_PUBLISHER=`pkg publisher -P solaris | grep "URI" | awk '{print $3}' | head -1`
		$PRINTALL && echo "OK: Connected to the Solaris repository successfully ($PREFERRED_PUBLISHER)"
	fi
fi

# Check for multiple IPS repository instances (will break IPS refresh
if [ "$UNAMER" = "5.11" ]; then
	INSTANCES=`svccfg -s svc:/application/pkg/server list | grep -v "^:properties" | wc -l | awk '{print $1}'`
	if [ $INSTANCES -gt 1 ]; then
		echo "ERROR: Found multiple svc:/application/pkg/server instances:"
		svccfg -s svc:/application/pkg/server list | grep -v "^:properties"
		echo ""
		echo "You must have only one instance - the 'default' instance. You should remove the rest using"
		echo "# svccfg delete svc:/application/pkg/server:<instance name>"
		echo ""
		echo "NOTE: do NOT remove the default instance!"
		echo ""
	else
		if [ $INSTANCES -eq 1 ]; then
			$PRINTALL && echo "OK: Found only one pkg/server instance"
		fi
	fi
fi

#
# Check for extra packages known to conflict with Ops Center 
#

xvmocpkgcheck=0
cat <<!EOF! > /tmp/pkgs.$$ 
ASPerl
!EOF!

while read pkg
do
  if pkginfo -q $pkg; then
    printf "\nERROR: Package $pkg is installed and known to conflict with Ops Center. Please remove before installation."
    ANYERRORS=1
    xvmocpkgcheck=1
  fi
done < /tmp/pkgs.$$
rm /tmp/pkgs.$$

if [[ $xvmocpkgcheck -eq 0 ]]; then
  $PRINTALL && echo "OK: No known conflicting packages exist"
else
  printf "\n\n"
fi

# Check /etc/netboot folder
if [ "$UNAMER" = "5.11" ]; then
	if [ -d /etc/netboot ]; then
		$PRINTALL && echo "OK: /etc/netboot folder exists"
	else
		echo "WARNING: Did not find /etc/netboot folder (Bug 15781475)."
		echo "         Run 'mkdir /etc/netboot' prior to installing the Proxy to avoid issues with Linux OS provisioning from this S11 proxy."
		echo "         You can ignore this message if you are not planning on using this proxy for Linux OS provisioning."
		echo ""
		ANYERRORS=1
	fi
fi

# Check if SRU 9 or above - if so need to install JRE (Bug 15805500)
if [ "$UNAMER" = "5.11" ]; then
	OUTPUT=`pkg info entire 2>/dev/null| grep Branch | awk -F"." '{printf("%s %s\n",$3,$4)}'`
	UPDATELEVEL=""
	if [ "$OUTPUT" = "" ]; then
		echo "WARNING: Could not get the version of the 'entire' package on this Solaris 11."
		echo "         Command used: 'pkg info entire | grep Branch'"
		echo "         While Ops Center may still work in this environment, it is an unsupported Solaris configuration."
		echo ""
	else
		UPDATELEVEL=`echo $OUTPUT | awk '{print $1}'`
		SRU=`echo $OUTPUT | awk '{print $2}'`
	fi
	if [ "$UPDATELEVEL" = "" ]; then		### get SRU level from kernel instead
		OUTPUT=`pkg info kernel | grep Branch | awk -F"." '{printf("%s %s\n",$3,$4)}'`
		if [ "$OUTPUT" = "" ]; then
			echo "ERROR: Could not get the version of the 'kernel' package either, please check your Solaris installation"
			echo "       Command used: 'pkg info kernel | grep Branch'"
			echo ""
		else
			UPDATELEVEL=`echo $OUTPUT | awk '{print $1}'`
			SRU=`echo $OUTPUT | awk '{print $2}'`
		fi
	fi		
	if [ ! "$UPDATELEVEL" = "" ]; then		#### if we got the update level through either entire or kernel
		if [ $UPDATELEVEL -eq 0 ]; then
			if [ $SRU -ge 9 ]; then
				### Check if runtime/java/jre-7 exists
				pkg info runtime/java/jre-7 >/dev/null 2>/dev/null
				if [ $? -eq 0 ]; then
					$PRINTALL && echo "OK: SRU $SRU detected, and 'runtime/java/jre-7' is installed"
				else
					echo "ERROR: This is Solaris 11 SRU $SRU. You must install the following package prior to installing the Proxy:"
					echo "# pkg install --accept runtime/java/jre-7"
					echo ""
				fi
			else
				if [ $SRU -gt 0 ]; then
					$PRINTALL && echo "OK: SRU $SRU is installed"
				fi
			fi
		else
			$PRINTALL && echo "OK: Solaris 11 Update $UPDATELEVEL is installed"
		fi
	fi
fi

#***************************** Check SRU 11.3.14, 11.3.15, 11.3.16 ***************************#
# Bug 26354192 OCDoctor check for alert 2225239.1 Solaris 11.3 SRU 14,15,16 present EC, PC, AC
if [ "$UNAMER" = "5.11" ]; then
        RELEASE2="11.$(pkg list -H entire|cut -d. -f5,6)"
        if [ "$RELEASE2" == "11.3.14" ] || [ "$RELEASE2" == "11.3.15" ] || [ "$RELEASE2" == "11.3.16" ]; then
            echo
            echo "ERROR: Solaris 11.3.14/15/16 causes communications problems between EC/PC/AC"
            echo "       Please review DOC: 2225239.1 for further details."
            echo
            ANYERRORS=1
        else
            echo "OK: Not Solaris 11.3.14|15|16"
        fi
else
        echo "OK: Not Solaris 11"
fi

# Bug 29503952 OCDoctor to check and report missing svr4 package on S11.x systems
if [ $PRINTALL = true ] && [ "$UNAMER" = "5.11" ]; then             ### Only run this in prereq - NOT in troubleshoot
    if ! pkg info -q "pkg://solaris/package/svr4"; then
        echo
        echo "WARNING: Package pkg://solaris/package/svr4 is required but not installed (Try pkg install pkg://solaris/package/svr4)"
        echo
    else
        echo "OK: pkg://solaris/package/svr4 is installed"
    fi
fi

#
# Check for Java 1.6.0_71 - 1.6.0_74 (Bug 18175308)
#
# We have to test if one of the broken versions is installed and warn the user.
# If there is no Java 6 installed and we are running S11 SRU 15 or SRU16 then 
# the installer will fetch a broken version from the IPS repository, so we have
# to warn the user as well
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
	INSTALLED_JAVA_6="`ls /usr/jdk/instances/jdk1.6.0/bin/java 2>/dev/null`"

	if [ -n "$INSTALLED_JAVA_6" ]; then
		JAVA_VERSION=`$INSTALLED_JAVA_6 -version 2>&1 | awk -F\" '/^java version/ {print $2}'`
		JAVA_MINOR=`echo $JAVA_VERSION | cut -d_ -f2`
		if [ "$JAVA_MINOR" -ge 71 -a "$JAVA_MINOR" -le 74 ]; then
			# found a broken version
			echo		
			echo "ERROR: Java $JAVA_VERSION is installed on this system!"
			echo
			echo "For a Proxy Controller the Java 6 version must not be in the range 1.6.0_71 - 1.6.0_74"
			echo
			echo "The current recommended version for a Proxy Controller is 1.6.0_65 or 1.6.0_75"
			echo
			if $IS_S11; then
				echo "The following script can be used to uninstall the current Java 6 version and install 1.6.0_65:"
				echo
				echo "$OCDOCTOR_ROOT/toolbox/s11_install_java_1.6.0_65.sh"
				echo
			else
				echo "See MOS Doc ID 1439822.1 for download links of this Java 6 version for all platforms"
				echo
			fi
			ANYERRORS=1
		else
			# the installed version is OK
			echo "OK: Installed Java 6 version $JAVA_VERSION is not in the range 1.6.0_71 - 1.6.0_74"
		fi
	else
		# no version of Java 6 is installed

		# this is only an issue if we are running Solaris 11.1 SRU 15, 16 or 17
		if [ $IS_S11 -a $S11_RELEASE -eq 1 -a $S11_SRU -ge 15 -a $S11_SRU -le 17 ]; then
			echo
			echo "ERROR: No version of Java 6 is installed and this system is running Solaris 11.1.${S11_SRU}.${S11_SRU_MINOR}.0 !"
			echo
			echo "NOTE: This check is only relevant if you are trying to install OC 12.2.1 or earlier!"
			echo
			echo "The Java 6 version coming with the installed SRU is not supported for a Proxy Controller"
			echo "but it will get installed as part of the OpsCenter installation."
			echo
			echo "The Proxy Controller requires Java 1.6.0_65 or 1.6.0_75, versions 1.6.0_71 - 1.6.0_74 are not supported"
			echo
			echo "The following script can be used to install 1.6.0_65 on this system before starting the Ops Center installation:"
			echo
			echo "$OCDOCTOR_ROOT/toolbox/s11_install_java_1.6.0_65.sh"
			echo 
			ANYERRORS=1
		else
			echo "OK: Java 6 is not installed, the Ops Center installer will install a supported version"
		fi
	fi
fi


#
# checking for library extendedFILE.so.1
#

if [[ -f /usr/lib/extendedFILE.so.1 ]]; then
  $PRINTALL && echo "OK: Patches for extendedFILE library are installed"
else
  printf "\nWARNING: library /usr/lib/extendedFILE.so.1 MISSING\n"
  printf "\nWARNING: Patches 125100/1-04, 120473/4-05 and 125800/1-01 must be installed\n\n"
  ANYERRORS=1
fi

#
# do we have correct umask
#

maskok=0
mask=022

if [[ "$(umask)" != "$mask" && "$(umask)" != "0$mask" ]]; then
  printf "\nWARNING: umask of user root is not $mask, OpsCenter will fail!\n\n"
  ANYERRORS=1
  maskok=1
fi

for file in /etc/profile* /etc/bash*; do
if [ -f $file ]; then
	OUTPUT=`umask 0$mask ; source $file >/dev/null 2>/dev/null ; umask`
	if [ "$OUTPUT" = "$mask" ] || [ "$OUTPUT" = "0$mask" ]; then
		$PRINTALL && printf "OK: $file has the umask of $mask\n"
	else
		printf "WARNING: it seems like $file may set a umask other than $mask. Ops Center may fail after installation.\n\n"
		ANYERRORS=1
		maskok=1
	fi
fi
done

if [[ "$(grep CMASK /etc/default/init 2> /dev/null|cut -d"#" -f1|egrep -v "(0$mask|$mask)")" != "" ]]; then
  printf "\nWARNING: /etc/default/init seems to set a umask other than $mask. OpsCenter might fail!\n\n"
  ANYERRORS=1
  maskok=1
fi

if [ $maskok -eq 0 ]; then
    $PRINTALL && echo "OK: Verified correct umask"
fi

#
# is someone using our ports 
#

# we only run this when checking for prerequisites
if ${PRINTALL}; then
  netports=0
  TMP_PFILES=/tmp/_pfiles_out_$$
  mkdir $TMP_PFILES
  ##### Do we have any running processes which will cause pfiles to hang ?
  SKIP_PROCESSES="nskernd modload modunload"

  for pid in $(cd /proc; ls); do
    # we will check if $pid is a process which should be skipped
    if ! echo $SKIP_PROCESSES | grep -w $(basename $(pargs $pid 2>/dev/null | nawk '/^argv\[0\]:/ {print $2}') ) >/dev/null 2>&1; then
    	pfiles $pid 2>/dev/null > ${TMP_PFILES}/pfiles.$pid
    fi
  done 

  cat <<!EOF! | while read nr comment; do
21165 Used by Agents to connect to Proxy
8002 Used by Agents to download content from Proxy
8004 Upload OS provisioning completion status - needed when this system is used for OS Provisioning
162 SNMP listening port used by the Proxy - see the doc in the howto folder to adjust this port
!EOF!
    if egrep "sockname: AF_INET .* port: ${nr}\$" ${TMP_PFILES}/pfiles.* > /dev/null; then 
      echo
      echo "WARNING: OpsCenter needed port ${nr} is in use!"
      echo "WARNING: ${comment}"
      echo "WARNING: Port is in use by process(es):"
      for pid_file in $(egrep -l "sockname: AF_INET .* port: ${nr}\$" ${TMP_PFILES}/pfiles.*); do
        head -1 $pid_file
      done 
      echo
      netports=1
    fi
  done
  [[ $netports -eq 0 ]] && echo "OK: Network ports needed by Management node and Proxy are not in use"
  rm -r ${TMP_PFILES}
fi

#
# checking SMF requirements for OC 
#

servicescheck=0
cat <<!EOF! | while read service; do
svc:/system/cryptosvc:default
svc:/network/rpc/gss:default
!EOF!
  if [[ "$(/usr/bin/svcs $service | tail -1 | cut -d" "  -f1)" == "online" ]] ; then
    #echo "OK: $service online."
    $PRINTALL #&& printf "."
  else
    printf "\nWARNING: service $service NOT ONLINE\n\n"
    ANYERRORS=1
    servicescheck=1
  fi
done
if [[ $servicescheck -eq 0 ]]; then
    $PRINTALL && echo "OK: All required SMF services are online"
fi

#
# checking ssh requirements for OC
#

CHECK=0
cat <<!EOF! | while read file; do
/usr/bin/scp
/usr/bin/ssh
/usr/bin/ssh-keygen
/usr/bin/ssh-keyscan
!EOF!
  if [[ -f $file || -h $file ]] ; then
    $PRINTALL #&& printf "."
  else
    printf "\nERROR: File or link $file not found\n\n"
    ANYERRORS=1
    CHECK=1
  fi
done
if [ $CHECK -eq 0 ]; then
    $PRINTALL && echo "OK: Checked for ssh requirements"
fi

#
# checking for incompatible packages (skipping for 2.5, since no incompatible pkgs known)
#

#
# checking for installed SUNWjass package
#

if [[ -d "/var/sadm/pkg/SUNWjass" ]] ; then
    printf "\nWARNING: Ops Center installation may fail on hardened systems (SUNWjass)\n"
    printf "         Even if all JASS changes have been un-done, there is a good chance installation will fail\n\n"
    ANYERRORS=1
  else
    $PRINTALL && echo "OK: No SUNWjass installed"
fi

#
# checking for user/group webservd
#

ENTRIES=`cat /etc/group /etc/passwd | grep '^webservd:' | wc -l`
if [ $ENTRIES -ne 2 ] 
then
  printf "\nWARNING: The user and/or group 'webservd' does not exist !"
  printf "\nWARNING: This user and group must exist prior to installation ! \n\n"
  ANYERRORS=1
else
  $PRINTALL && echo "OK: Checked for user & group 'webservd'"
fi

ANYOUTPUT=`su root -c "/bin/bash /etc/profile"`
#ANYOUTPUT=`su - webservd -c true`  
if [ "$ANYOUTPUT" = "" ];then
	$PRINTALL && echo "OK: Checked for output messages from /etc/profile"
else
        printf "\nERROR: /etc/profile prints out messages.  This can affect the scndb user that will be created during the Ops Center install\n"
        echo "Check in /etc/profile and remove those messages - otherwise installation may fail at step 11 - 'Initialize database'"
	ANYERRORS=1
fi

#
# Check for partially installed packages
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
                                                ### in troubleshoot we run individual tests so in colocated it prints only one message
        OUTPUT=`pkginfo -p`
        if [ "$OUTPUT" = "" ]; then
                echo "OK: No partially installed packages"
        else
                echo
                echo "WARNING: Found the following partially installed packages (pkginfo -p), please check if that's a problem:"	#'
                printf "$OUTPUT\n"
                echo ""
        fi
fi

#
# Check for an old zonectrlr.id file (Bug 15628914)
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
                                                ### in troubleshoot we run individual tests so in colocated it prints only one message
        if [ "$OS_TYPE" = "SunOS" -a "$UNAMER" = "5.10" ]; then
          if [ -f /etc/opt/sun/oc/zonectrlr.id ]; then
            echo 'WARNING: Found existing file /etc/opt/sun/oc/zonectrlr.id (Bug 15628914)!' 
            echo '         Remove this file before installing Ops Center!'
          else
            echo 'OK: No zonectrlr.id leftover file found.'
          fi
        fi
fi
        
#
# checking for leftovers from a previous installs
#

if [ $PRINTALL = true -a "$UNAMER" = "5.10" ]; then                   ### Only run this in prereq - NOT in troubleshoot
CHECK=0
cat <<!EOF! | while read file; do
CPANperl-dbd-pg
CPANperl-dbi-scs
CSKlibs
CSKncurses
CSKpython
CSKruntime
JetFLASH
JetJASS
JetLDOM
JetWanBoot
PGSQLscs
SFWexpct
SUNWcacaocrews
SUNWcacaome
SUNWcacaowsvr
SUNWjet
SUNWn1hss-agentdm
SUNWn1hss-agentdm-config
SUNWn1hss-core
SUNWn1hss-core-arch
SUNWn1hss-core-config
SUNWn1hss-core-i386
SUNWn1hss-core-usr
SUNWn1hss-drvrs
SUNWn1hss-servicescr
SUNWn1hss-ui-en
SUNWn1hss-ui-ja
SUNWscn-agent-utils
SUNWscn-agentfacade-r
SUNWscn-agentfacade-u
SUNWscn-agentfacade-vc-config
SUNWscn-agentupgrade-u
SUNWscn-agentupgrade-vc-r
SUNWscn-agentupgrade-vc-u
SUNWscn-cs
SUNWscn-jobmgrui
SUNWscn-monitorui
SUNWscn-osp
SUNWscn-osp-config
SUNWscn-osp-drivers
SUNWscn-osp-s
SUNWscn-osp-s-db
SUNWscn-provui
SUNWscn-prsf
SUNWscn-prsfc
SUNWscn-update-agent
SUNWscn-update-agent-r
SUNWscn-update-db
SUNWscn-update-util
SUNWscn-updateui
SUNWscnauth
SUNWscncon
SUNWscnconnmgt
SUNWscnconnmgt-r
SUNWscnconnmgt-ra
SUNWscnconnmgt-rp
SUNWscnconnmgt-rs
SUNWscncrs
SUNWscndb
SUNWscnjobmgr-agent
SUNWscnjobmgr-agent-config
SUNWscnjobmgr-common-api
SUNWscnjobmgr-common-impl
SUNWscnjobmgr-proxy
SUNWscnjobmgr-proxy-config
SUNWscnjobmgr-satellite
SUNWscnjobmgr-satellite-config
SUNWscnjobmgr-satellite-db
SUNWscnjobmgr-vc-config
SUNWscnnotifsvc
SUNWscnproxyadm
SUNWscnreportsvc
SUNWscnreportsvc-db
SUNWscnsatadm
SUNWscnsatmgmt
SUNWscportal
SUNWscs-agent
SUNWscs-allstart
SUNWscs-conf
SUNWscs-db
SUNWscs-modulemgr
SUNWscs-service
SUNWscs-task
SUNWsms-facade
SUNWuce-cli
SUNWucea
SUNWuceconsole
SUNWucee
SUNWucelarge
SUNWucelos
SUNWucepa
SUNWuces
SUNWxvm-ajaxterm
SUNWxvm-bui-tools
SUNWxvm-client
SUNWxvm-proxyrun-base
SUNWxvm-satrun-base
SUNWxvm-vc-driver-common
SUNWxvm-xvmsvrdm-config
SUNWxvm-zones-r
SUNWxvm-zstat
SUNWxvm-zstat-init
SUNWxvmoc-client
SUNWxvmoc-proxyrun-oc
SUNWxvmoc-satrun-oc
SUNWxvmoc-winpm
SUNWxvmoc-winpm-config
SUNWxvmoc-wme
SUNWxvmocbui
UPdhcp
!EOF!
    if [[ -d "/var/sadm/pkg/$file" ]] ; then
      $PRINTALL && printf "\nWARNING: Package $file found "
      CHECK=1
    else
      $PRINTALL #&& echo "."
    fi
  done
  if [ $CHECK -eq 0 ]; then
    $PRINTALL && echo "OK: No leftovers from previous installs found"
  else
    $PRINTALL && printf "\n\nWARNING: Found above leftovers from a previous UCE / Ops Center installation!"
    $PRINTALL && printf "\nWARNING: Please, properly uninstall old UCE / Ops Center software components!\n"
  fi
fi

# Check for Ops Center leftovers on Solaris 11
#
if [ $PRINTALL = true -a "$UNAMER" = "5.11" ]; then                   ### Only run this in prereq - NOT in troubleshoot
	CHECK=0
	pkg list -H '*em-sysmgmt*' 2>/dev/null | grep -v '/cacao_pers_dirs' | nawk '{print $1}' | while read PKGNAME
	do
		CHECK=1
		PKGVERSION=$(pkg info $PKGNAME | nawk '/Version: / {print $2}')
		printf "\nFound installed Ops Center package '${PKGNAME}@${PKGVERSION}'\n"
	done
	if [ $CHECK -eq 0 ]; then
		echo 'OK: No Solaris 11 leftover packages found'
	else
		echo
		echo 'WARNING: Remove the leftover package(s) prior to installing Ops Center Proxy by running'
		echo
		echo 'pkg uninstall <pkg name> <pkg name> ...'
		echo
	fi
fi


#
# Check for an existing read-only /usr/local filesystem
#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
    if cd /usr/local 2>/dev/null; then
         TESTFILE=_oc-test_$$
         if ! touch $TESTFILE 2>/dev/null; then
             echo 'WARNING: /usr/local is a read-only filesystem!'
             echo 'WARNING: Installer must be able to install software there!'
         else
             rm $TESTFILE
             echo 'OK: /usr/local is writeable.'
         fi
     else
         echo 'OK: /usr/local does not exist.'
     fi
fi

#
# Check for proper locale settings
#
if [ $PRINTALL = true ]; then		                   ### Only run this in prereq - NOT in troubleshoot (have a specific test for it)
	FAILED=0

	LC_CTYPE=`locale | grep LC_CTYPE | awk -F"=" '{print $2}' | sed -e 's/\"//g'`
	LC_MESSAGES=`locale | grep LC_MESSAGES | awk -F"=" '{print $2}' | sed -e 's/\"//g'`

	LC_CTYPE_EN=`echo $LC_CTYPE|grep -i en_US`
	if [ ! "$LC_CTYPE" = "C" ] && [ "$LC_CTYPE_EN" = "" ]; then
	        FAILED=1
	        FAILED_L=$LC_CTYPE
	fi

	LC_MESSAGES_EN=`echo $LC_MESSAGES|grep -i en_US`
	if [ ! "$LC_MESSAGES" = "C" ] && [ "$LC_MESSAGES_EN" = "" ]; then
	        FAILED=1
	        FAILED_L=$LC_MESSAGES
	fi

	if [ $FAILED -eq 0 ]; then
	        echo "OK: Locales are OK (\"$LC_CTYPE\")"
	else
	        echo "WARNING: Locales are set to \"$FAILED_L\". This may cause issues when upgrading. Make sure you run:"
	        echo "         # export LC_ALL=C"
	        echo "         # export LANG=C"
	        echo "         You can verify the settings by running:"
	        echo "         # locale"
	        echo ""
		ANYERRORS=1
	fi
fi


#*************************************************************************************#

if [ "$OS_TYPE" = "SunOS" ]; then
  # Check if we are using GNU tail which does not have the option "-r"
  TAIL=/usr/bin/tail
  TESTFILE="/tmp/_testfile_.$$"
  touch $TESTFILE

  if [ -x $TAIL ]; then
    if $TAIL -r $TESTFILE 2>/dev/null 1>&2; then
      if $PRINTALL; then
        echo 'OK: Native Solaris "tail" command is available.'
      fi
    else
      echo "WARNING: $TAIL does not support the '-r' option which is required by the Agent!"
      echo "WARNING: Looks like 'GNU tail' is in use by default!"
      ANYERRORS=1
    fi
  else
    echo "WARNING: The command $TAIL is required by the Agent but could not be found!"
    ANYERRORS=1
  fi
  rm $TESTFILE
fi


#*************************************************************************************#
### Check that hostname resolves properly
HOSTNAME=`hostname`
IPfromGetent=`getent hosts \`hostname\` | awk '{print $1}' 2>/dev/null`
if [ "$IPfromGetent" = "127.0.0.1" ]; then
	echo "ERROR: getent hosts \`hostname\` says my IP is 127.0.0.1, please review /etc/hosts and fix."
	echo ""
	ANYERRORS=1
else
	$PRINTALL && echo "OK: Hostname $HOSTNAME doesn't resolve to 127.0.0.1"				#'
	HostnameNoDot=`echo "$HOSTNAME" | awk -F"." '{print $1}' 2>/dev/null`
	HostFromGetEnt=`getent hosts "$IPfromGetent" | awk '{print $2}' 2>/dev/null | awk -F"." '{print $1}' 2>/dev/null`
	if [ ! "$HostnameNoDot" = "$HostFromGetEnt" ]; then
		echo "ERROR: Using getent, my IP does not resolve to my hostname:"
		echo ""
		echo "getent hosts $HostnameNoDot   -> Got IP \"$IPfromGetent\""
		echo "  then"
		echo "getent hosts $IPfromGetent   -> Got hostname \"$HostFromGetEnt\""
		echo ""
		echo "Please review /etc/hosts and /etc/nsswitch.conf to fix."
		echo ""
		ANYERRORS=1
	else
		$PRINTALL && echo "OK: Hostname $HOSTNAME resolves to $IPfromGetent and back properly"
	fi
fi
#*************************************************************************************#
### Check that localhost resolves properly
IPfromGetent=`getent hosts localhost | awk '{print $1}' 2>/dev/null`
if [ "$IPfromGetent" != "127.0.0.1" ] && [ "$IPfromGetent" != "::1" ]; then
	echo "ERROR: 'getent hosts localhost' says localhost IP is NOT 127.0.0.1, please review /etc/hosts and fix."
	echo ""
	ANYERRORS=1
else
	$PRINTALL && echo "OK: localhost resolves to 127.0.0.1"	
fi
IPfromHosts=`grep -v "^#" /etc/hosts | grep localhost | grep -v "^127.0.0.1" | grep -v "^::1"`
if [ "$IPfromHosts" != "" ]; then
	echo "ERROR: it seems like 'localhost' shows up in /etc/hosts under the wrong IP."
	echo "       Make sure it is only used under 127.0.0.1, otherwise you will have many connectivity issues."
	echo ""
	ANYERRORS=1
fi
	
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
	if [ -f /n1gc-setup/.version.properties ]; then
		echo "ERROR: Found an existing /n1gc-setup/.version.properties file, did you uninstall the previous version properly?"
		echo "       Removing the file may not be enough, as there may be some other leftovers."
		echo ""
		ANYERRORS=1
	fi
fi

#********** Check for development cacao build (Bug 15780343) *************************************************#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
	OUTPUT=`grep PSTAMP /var/sadm/pkg/SUNWcacao*/pkginfo 2>/dev/null| grep snapshot`
	if [ "$OUTPUT" = "" ]; then
		echo "OK: No development build of cacao is installed"
	else
		echo "ERROR: Found the following development build of cacao (has 'snapshot' in the PSTAMP)."
		echo "       Those packages must be removed prior to the Proxy Controller installation:"
		printf "$OUTPUT\n\n"
	fi
fi

#**************** Check if HMP tools/libs 2.2.1 are installed - needs to be removed as the product installer will break
if [ "$UNAMER" = "5.11" ]; then		### Only relevant on S11
	if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot (we have special troubleshoot tests for it
		ARCH=`uname -p`
		if [ "$ARCH" = "i386" ]; then
			pkg list hmp-tools@2.2.1 >/dev/null 2>/dev/null
			if [ $? -ne 0 ]; then
				echo "OK: package hmp-tools@2.2.1 is not installed"
				#### Test the 2nd package:
				pkg list hmp-libs@2.2.1 >/dev/null 2>/dev/null
				if [ $? -ne 0 ]; then
					echo "OK: package hmp-libs@2.2.1 is not installed"
				else
					echo "ERROR: package hmp-libs@2.2.1 is installed - it should be removed before you install the proxy."
					echo "       Otherwise, the install may fail or not complete successfully."
					echo ""
					echo "       To fix this, you must uninstall the following:"
					echo ""
					echo "# pkg uninstall hmp-libs"
					echo "And then reboot."
					echo ""
					echo "Please contact support if you are unable to remove this properly."
					echo ""
					ANYERRORS=1
				fi
				#### End of 2nd package
			else
				echo "ERROR: package hmp-tools@2.2.1 is installed - it should be removed before you install the proxy."
				echo "       Otherwise, the install may fail or not complete successfully."
				echo ""
				echo "       To fix this, you must uninstall the following:"
				echo ""
				echo "# pkg uninstall hmp-tools hmp-libs"
				echo "And then reboot."
				echo ""
				echo "Please contact support if you are unable to remove this properly."
				echo ""
				ANYERRORS=1
			fi
		else	### SPARC
			pkg list hmp-tools@2.2.1 >/dev/null 2>/dev/null
			if [ $? -ne 0 ]; then
				echo "OK: package hmp-tools@2.2.1 is not installed"
				#### Test the 2nd package:
				pkg list driver/x11/xsvc >/dev/null 2>/dev/null
				if [ $? -ne 0 ]; then
					echo "OK: package driver/x11/xsvc is not installed"
				else
					echo "ERROR: package driver/x11/xsvc is installed - it MUST be removed before you install the proxy."
					echo "       It incorrectly installs X86 files on this SPARC box and will cause the install to fail."
					echo ""
					echo "       To fix this, you must uninstall the following:"
					echo ""
					echo "# pkg uninstall driver/x11/xsvc"
					echo "And then reboot."
					echo ""
					echo "Please contact support if you are unable to remove this properly."
					echo ""
					ANYERRORS=1
				fi
				#### End of 2nd package
			else
				echo "ERROR: package hmp-tools@2.2.1 is installed - it MUST be removed before you install the proxy."
				echo "       It incorrectly installs X86 files on this SPARC box and will cause the install to fail."
				echo ""
				echo "       To fix this, you must uninstall the following:"
				echo ""
				echo "# pkg uninstall hmp-tools driver/x11/xsvc"
				echo "And then reboot."
				echo ""
				echo "Please contact support if you are unable to remove this properly."
				echo ""
				ANYERRORS=1
			fi
		fi	## end of "If Sparc
	fi #### End of PRINTALL=true
fi	### End of "If Solaris 11

#**************** Check for an existing /var/js/directory ******************************#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
        if [ -d /var/js ]; then
                if [ "$(find /var/js 2>/dev/null | wc -l)" -gt 1 ]; then
                        echo
                        echo "ERROR: Found an existing directory /var/js with content in it!"
                        echo
                        echo "This directory should be removed or cleaned up prior to install the EC. Existing old content can cause installation failures!"
                        echo
                else
                        echo "OK: No old content found in /var/js directory."
                fi
        else
                echo "OK: No leftover /var/js directory from a previous installation found."
        fi
fi

#**************** Check for leftover SMF services ******************************#
if [ $PRINTALL = true ]; then                   ### Only run this in prereq - NOT in troubleshoot
	TMP_SMF_DATA=/tmp/smf_data.$$
	svcs -a | egrep '/application/scn/|:oem-ec|:scn-proxy|:scn-agent' > $TMP_SMF_DATA
        if [ -s "$TMP_SMF_DATA" ]; then
		echo 
		echo "ERROR: Found leftover SMF services from a previous OpsCenter EC, PC or Agent installation:"
		echo '---'
		cat $TMP_SMF_DATA
		echo '---' 
		echo
		echo "These SMF services must get deleted before attempting to install the Proxy Controller!"
		echo
	else
		echo "OK: No leftover SMF services from a previous OpsCenter EC, PC or Agent installation found." 
	fi
	rm -f $TMP_SMF_DATA
fi
	

#**************** Check if root is a role **********************
# removed check due to fix/close of bug 15731720
#if [ "$UNAMER" = "5.11" ]; then		### Only relevant on S11
#	grep "^root::::type=role" /etc/user_attr >/dev/null 2>/dev/null
#	if [ $? -eq 0 ]; then
#		echo "ERROR: User 'root' should not be a role. You should convert it to a normal user before the installation."
#		echo "       This can be done by running:"
#		echo ""
#		echo "# rolemod -K type=normal root"
#		echo ""
#		ANYERRORS=1
#	else
#		$PRINTALL && echo "OK: 'root' user is not a role"
#	fi
#fi
	
	
#*************************************************************************************#
$PRINTALL && printf "\n\n"

rm -rf /tmp/.$$_patches /tmp/.$$_obsolete /tmp/.$$_pkgs /tmp/.$$_neededpatches

exit $ANYERRORS


