#!/bin/bash
#
# check if SSLv3 is disabled - CVE-2014-3566 (SSLv3 vulnerability Poodle)
#
# not yet ready for release, exiting silently ...
exit

MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        source $MY_DIR/../../functions
	GF_TARFILE=$MY_DIR/../../toolbox/gf_jars.tar
	ABS_GF_TARFILE="<OCDoctor>/toolbox/gf_jars.tar"
else
        if [ -f /var/opt/sun/xvm/OCDoctor/functions ]; then
                source /var/opt/sun/xvm/OCDoctor/functions
		GF_TARFILE=/var/opt/sun/xvm/OCDoctor/toolbox/gf_jars.tar
		ABS_GF_TARFILE=$GF_TARFILE
        else
                exit
        fi
fi

get_version
if [ $VERSIONNUM -lt "12100000" ]; then
	# so far we cannot fix tomcat webserver used by cacao
	CACAO_FIX_AVAILABLE=false
else
	CACAO_FIX_AVAILABLE=true
fi

if [ ! -f $GF_TARFILE ]; then
	echo "${0}: ERROR: File $GF_TARFILE not found!"
	exit
fi
 
if [ "`uname`" = "Linux" ]; then
	CONF_FILE=/var/opt/sun/xvm/uce/etc/uce_server/httpd-ssl.conf
	GF_JAR=/opt/sun/cacao2/share/ext/gfish/lib/cacao_gfish_private.jar
	WGET="/usr/bin/wget"
	GF_JAR_FIXED=cacao_gfish_private.jar_linux_i386
	SATADM="/opt/sun/xvmoc/bin/satadm"
else
	CONF_FILE=/var/opt/sun/xvm/uce/etc.opt/server/uce_server/httpd-ssl.conf
	GF_JAR=/usr/lib/cacao/ext/gfish/lib/cacao_gfish_private.jar
	WGET="/usr/sfw/bin/wget"
	if [ "`uname -p`" = "sparc" ]; then
		GF_JAR_FIXED=cacao_gfish_private.jar_solaris_sparc
	else
		GF_JAR_FIXED=cacao_gfish_private.jar_solaris_i386
	fi
	SATADM="/opt/SUNWxvmoc/bin/satadm"
fi

if [ -x $WGET ]; then
	WGET_FOUND=true
	WGET_ARGS="-q -O /dev/null --no-check-certificate --secure-protocol SSLv3" 
	WGET_GF_URL="https://localhost:21165/SCRK/PING?type=plain"
	WGET_APACHE_URL="https://localhost:8002/channels.xml"
else
	WGET_FOUND=false
fi

if [ -f $SATADM ]; then
	COLOCATED=true
else
	COLOCATED=false
fi

CONF_FILE_ORIG=${CONF_FILE}.ocdoctor.sslv3-fix.orig
GF_JAR_ORIG=${GF_JAR}.ocdoctor.sslv3-fix.orig

# test if we still allow SSLv3 connections
if $WGET_FOUND; then
	$WGET $WGET_ARGS $WGET_GF_URL
	if [ $? -eq 0 ]; then
		GF_FIXED=false
	else
		GF_FIXED=true
	fi
	$WGET $WGET_ARGS $WGET_APACHE_URL
	if [ $? -eq 0 ]; then
		APACHE_FIXED=false
	else
		APACHE_FIXED=true
	fi
else
	if [ -f $GF_JAR_ORIG ]; then
		GF_FIXED=true
	else
		GF_FIXED=false
	fi
	if egrep 'SSLProtocol.* -SSLv3' $CONF_FILE > /dev/null 2>&1; then
		 APACHE_FIXED=true
	elif [ -f $CONF_FILE_ORIG ]; then
		APACHE_FIXED=true
	else
		APACHE_FIXED=false
	fi
fi
	
# do not check Apache in case of a colocated Proxy
if ! $COLOCATED; then
	# apache server
	if $APACHE_FIXED; then
		echo "OK: UCE Webserver does not allow SSLv3 connections"
	else
		# apache is still allowing SSLv3 connections
		echo
		echo "ERROR: UCE Webserver does allow SSLv3 connections (CVE-2014-3566)"
		echo
		if [ "$OCDOCTOR_FIX" = "1" ]; then
			echo "Trying to automatically fix this..."
			if [ -f $CONF_FILE_ORIG ]; then
				echo "WARNING: File $CONF_FILE_ORIG exists!"
				echo "The PC has probably not been restarted after applying the fix!"
			else
				cp $CONF_FILE $CONF_FILE_ORIG
				sed 's/SSLProtocol .*$/SSLProtocol ALL -SSLv2 -SSLv3/' $CONF_FILE_ORIG > $CONF_FILE
				echo
				echo "UCE Webserver config has been corrected, the PC must get restarted now!"
			fi
		else
			if [ -f $CONF_FILE_ORIG ]; then
				echo "WARNING: File $CONF_FILE_ORIG exists, so the fix has already been applied!"
				echo "The PC has probably not yet been restarted after applying the fix!"
			else
				echo "To disallow SSLv3 connections, you have to modify the UCE Webserver config file"
				echo
				echo "$CONF_FILE"
				echo
				echo "so that the line starting with 'SSLProtocol' looks like this:"
				echo
				echo "SSLProtocol All -SSLv2 -SSLv3"
				echo
				echo "followed by a restart of the PC."
				echo
				echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			fi
		fi
		echo
	fi
fi

$CACAO_FIX_AVAILABLE || exit

if $GF_FIXED; then
	echo "OK: Glassfish Webserver does not allow SSLv3 connections"
else
	# glassfish is still allowing SSLv3 connections
	if $COLOCATED; then
		# we do not have to replace the JAR file, this has been done already to fix the EC
		# but a restart of the Proxy is required
		echo
		echo "ERROR: Glassfish Webserver of Proxy instance does allow SSLv3 connections (CVE-2014-3566)"
		echo
		if [ -f $GF_JAR_ORIG ]; then
			# we have already replaced the jar file but not yet restarted the Proxy
			echo "The colocated Proxy instance needs to get restarted to make applied changes effective"
		else
			echo "This is a colocated Proxy, please run the steps recommended above for the EC,"
			echo "followed by a restart of the EC and PC instances/services" 
		fi
		echo
	else
		echo
		echo "ERROR: Glassfish Webserver does allow SSLv3 connections (CVE-2014-3566)"
		echo
		if [ "$OCDOCTOR_FIX" = "1" ]; then
			echo "Trying to automatically fix this..."
			echo
			if [ -f $GF_JAR_ORIG ]; then
				echo "WARNING: File $GF_JAR_ORIG exists, so the fix has already been applied!"	
				echo "The PC has probably not yet been restarted after applying the fix!"
			else
				cd /tmp
				tar xf $GF_TARFILE $GF_JAR_FIXED 
				cp $GF_JAR $GF_JAR_ORIG
				cp $GF_JAR_FIXED $GF_JAR
				rm $GF_JAR_FIXED
				echo "Glassfish Webserver config has been corrected, the PC must get restarted now!"
			fi
		else
			if [ -f $GF_JAR_ORIG ]; then
				echo "WARNING: File $GF_JAR_ORIG exists, so the fix has already been applied!"
				echo "The PC has probably not yet been restarted after applying the fix!"
			else
				echo "To disallow SSLv3 connections, the file $GF_JAR must be replaced with file"
				echo "$GF_JAR_FIXED from tarball $ABS_GF_TARFILE"
				echo
				echo "followed by a restart of the PC."
				echo
				echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			fi
		fi		
		echo
	fi
fi
