#!/bin/bash

#### Check if cacao facet is set to true incorrectly - Bug 15813405

MY_DIR=`dirname $0`
if [ -f $MY_DIR/../../functions ]; then
        source $MY_DIR/../../functions
	solaris11_stuff
else
                exit
fi

if ! $IS_S11; then
        exit
fi

# Solaris 11.4 does not deliver cacao-incorporation
# Ignoring this check for Solaris 11.4
if $IS_S11 && [ "$S11_RELEASE" -gt 3 ]; then
    exit 0
fi

# get current cacao facet setting
if [ $S11_RELEASE -lt 2 ]; then
	cfacet=`pkg facet -H facet.version-lock.consolidation/cacao/cacao-incorporation | awk '{print $2}'`
else
	cfacet=`pkg facet -H -i facet.version-lock.consolidation/cacao/cacao-incorporation | awk '{print $2}'`
fi

if [ ! "$cfacet" = "True" ]; then
	echo "OK: Cacao facet is set to $cfacet"
	exit
fi

REPAIR="no"
pkg info entire >/dev/null 2>/dev/null
if [ $? -ne 0 ]; then
	echo "ERROR: Could not find the 'entire' package, and the cacaco facet is set to True, which may be incorrect and may cause upgrade issues."
	echo "       You may want to set the facet to False to avoid various issues (Bug 15813405)"
	echo "       IMPORTANT NOTE: not having the 'entire' package installed is NOT supported and may cause serious stability issues."
	echo ""
	REPAIR="yes"
else
	# get version of cacao-incorporation bundled with installed OS
	cincorp=`pkg contents -m entire | grep cacao-incorp | grep "5.11" | awk '{print $3}' | grep fmri | sed -e 's/fmri=//'`
	pkg list $cincorp >/dev/null 2>/dev/null
	if [ $? -ne 0 ]; then
		### if the installed version is different the the version listed in Entire
		echo "ERROR: The cacao facet is True but it needs to be False. This is a known issue (Bug 15813405)"
		echo "       The cacao incorporation listed under 'entire' is not the one installed and therefore"
		echo "       facet needs to be set to False" 
		echo ""
		REPAIR="yes"
	fi 
fi
if [ $REPAIR = "no" ]; then
	echo "OK: Facet is set to True and all conditions support that"
else
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to automatically fix this..."
		pkg change-facet --no-backup-be facet.version-lock.consolidation/cacao/cacao-incorporation=False
		echo "Done."
		echo ""
	else
		echo "To fix this, set the cacao facet to False:"
		echo ""
		echo "# pkg change-facet --no-backup-be facet.version-lock.consolidation/cacao/cacao-incorporation=False"
		echo ""
		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		echo ""
	fi
fi
