#!/bin/bash
#
# Validate enough disk space in common areas
#
# Todo: This check needs to get enhanced to take into account more things like
#       - is /var/tmp and /var/opt/sun/xvm belonging to the same filesystem/dataset
#	- is EC using a local DB or remote DB
#       - do we have already the DB files in place in /var/tmp/downloads or not
#	- is /var/tmp/ocdumpdir really the directory configured in the DB
#	- what is the size of the DB and is 10% of it a good estimate for the dump size
#	- is the EC already updated to latest available release or not

MY_DIR=`dirname $0`
. $MY_DIR/../../functions
get_version              # defines VERSIONNUM and LATESTVERNUM

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	ECADM=/opt/sun/xvmoc/bin/ecadm
	LOCALDB_PROP=/opt/orcl/orcl-sysman-db/etc/localOracleConfig.properties
	AWK=/usr/bin/awk
else
	ECADM=/opt/SUNWxvmoc/bin/ecadm
	LOCALDB_PROP=/opt/ORCLsysman-db/etc/localOracleConfig.properties
	AWK=/usr/bin/nawk
fi

TEMPFILE=/tmp/disk-usage1.$$.txt
MP_SPACE=/tmp/disk-usage2.$$.txt

check_space(){
	# RECOMMENDED is in KB, hRECOMMENDED in GB
	hRECOMMENDED=$( echo "scale=1; $RECOMMENDED / 1024 / 1024" | bc )G

	if [ -d $MOUNT ]; then
		if [ "$UNAME" = "Linux" ]; then
			AVAILABLE=`df -Pk $MOUNT | tail -1 | awk '{print \$4}'`
			AVAILABLEH=`df -Ph $MOUNT | tail -1 | awk '{print \$4}'`
		else
			AVAILABLE=`df -k $MOUNT | tail -1 | awk '{print \$4}'`
			AVAILABLEH=`df -h $MOUNT | tail -1 | awk '{print \$4}'`
		fi
		# for testing purposes
		#AVAILABLE=1024
		#AVAILABLEH=1G
		if [ $AVAILABLE -lt $RECOMMENDED ]; then
			echo "WARNING: Free space in $MOUNT is very low - only $AVAILABLEH is available, required are $hRECOMMENDED"
			echo ""
		else
			echo "OK: $AVAILABLEH available in $MOUNT"
		fi
	else
		echo "ERROR: Unable to check disk space on $MOUNT, folder does not exist"
		echo ""
	fi
}

get_mountpoint(){
	DIR_NAME="$1"
	if [ "$UNAME" = "Linux" ]; then
		MOUNT_POINT=$(df $DIR_NAME 2>/dev/null | tail -1 | $AWK '{print $6}')
	else
		MOUNT_POINT=$(df $DIR_NAME 2>/dev/null | tail -1 | $AWK '{print $1}')
	fi
	[ -d "$MOUNT_POINT" ] || MOUNT_POINT="/"
	echo "$MOUNT_POINT"
}

if [ -f $ECADM ]; then
        # in case this is a EC, we did run this check already
        exit
fi

if [ $VERSIONNUM -lt 12100000 ]; then
	# we are not even on 12.1 GA, we will exit silently, there is an extra one for 11g ECs
	exit 0
elif [ $VERSIONNUM -lt $LATESTVERNUM ]; then
#elif true; then
	# ok, we will recommend higher numbers to ensure enough free space for an update
	UPDATE_SAVED_STATE=/var/opt/sun/xvm/update-saved-state
	[ -d $UPDATE_SAVED_STATE ] || UPDATE_SAVED_STATE=/var/opt/sun/xvm
	UPDATE_SAVED_STATE_MP=$(get_mountpoint $UPDATE_SAVED_STATE)
	
	# unzipped distribution dir
	echo "$UPDATE_SAVED_STATE_MP 1500000" >> $TEMPFILE
	# PC backup w/o DBDUMP (1 GB estimated)
	echo "$UPDATE_SAVED_STATE_MP 1000000" >> $TEMPFILE

fi

	# ok, standard recommendations for a running EC

	# / 2GB
	echo "/ 2097152"  >> $TEMPFILE

	# /var 2GB
	MP=$(get_mountpoint /var)
	echo "$MP 2097152"  >> $TEMPFILE

	# /var/tmp 2GB
	MP=$(get_mountpoint /var/tmp)
	echo "$MP 2097152"  >> $TEMPFILE

	# /var/opt/sun/xvm 4GB
	MP=$(get_mountpoint /var/opt/sun/xvm)
	echo "$MP 4194304"  >> $TEMPFILE

	# /opt 1GB
	MP=$(get_mountpoint /opt)
	echo "$MP 1048576"  >> $TEMPFILE

# now, we sort all entries and sum them up

	sort $TEMPFILE | $AWK 'BEGIN { MP_SAVED=""; SUM_OF_SIZES=0}
			{if (MP_SAVED == $1) { SUM_OF_SIZES += $2 } else {
			if (MP_SAVED != "") { print MP_SAVED " " SUM_OF_SIZES; MP_SAVED=$1; SUM_OF_SIZES=$2 }
			else { MP_SAVED=$1; SUM_OF_SIZES=$2 }
			} }
			END {if (MP_SAVED != "")  print MP_SAVED " " SUM_OF_SIZES}' > $MP_SPACE

	while read MOUNT RECOMMENDED
	do
		# for testing purposes
		#echo "MOUNT=$MOUNT"
		#echo "RECOMMENDED=$RECOMMENDED"
		check_space
	done < $MP_SPACE

	rm -f $TEMPFILE $MP_SPACE

