#!/bin/bash

#### General variables ###
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	exit
fi

MY_DIR=`dirname $0`
source $MY_DIR/../../functions
get_version ""

if [ ! "$VERSIONNUM" = "12132305" ]; then
	#### Only test this on Update 3 systems
	exit
fi

UPDATEFOLDER="/var/opt/sun/xvm/update-saved-state/update_EC_minor_bundle_12.1.3.2305"
if [ ! -d $UPDATEFOLDER ]; then
	UPDATEFOLDER="/var/opt/sun/xvm/update-saved-state/update_PC_minor_bundle_12.1.3.2305"
	if [ ! -d $UPDATEFOLDER ]; then
		#### Fresh install will not have this folder
		exit
	fi
fi

###### Check patch.matrix #########
if [ -f /opt/SUNWjet/Products/ldom/patch.matrix ]; then
	OUTPUT=`grep "^5.10:sparc:3.0:147147" /opt/SUNWjet/Products/ldom/patch.matrix`
	if [ "$OUTPUT" = "" ]; then
		echo "ERROR: LDOM 3.0 is not configured in /opt/SUNWjet/Products/ldom/patch.matrix . This is a known issue in Update 3 (Bug 16681480)."
		echo ""
		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo "Trying to automatically fix this..."
			BACKUPNAME="/opt/SUNWjet/Products/ldom/patch.matrix.doctor.$$"
			echo "Creating backup file $BACKUPNAME"
			cp -p /opt/SUNWjet/Products/ldom/patch.matrix $BACKUPNAME
			echo "Inserting line..."
			echo "5.10:sparc:3.0:147147 148888 148324 148322 149644 150011 150107" >> /opt/SUNWjet/Products/ldom/patch.matrix
			echo "Done."
			echo ""
		else
			echo "To fix, run the following:"
			echo "# echo \"5.10:sparc:3.0:147147 148888 148324 148322 149644 150011 150107\" >> /opt/SUNWjet/Products/ldom/patch.matrix"
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			echo ""
		fi
	else
		echo "OK: LDOM 3.0 is configured in /opt/SUNWjet/Products/ldom/patch.matrix"
	fi
else
	echo "ERROR: Unable to locate /opt/SUNWjet/Products/ldom/patch.matrix in LDOM3.0 test."
	exit
fi


###### Check LDOM 3.0 binary #######
FLAGGED="" 			### Will be set to 1 if need to run "copy_product_media"
if [ -f /var/opt/sun/xvm/osp/ldom/p15880570_30_SOLARIS64.zip ]; then
	if [ -d /var/opt/sun/xvm/osp/ldom/OVM_Server_SPARC-3_0 ]; then
		echo "OK: Found LDOM 3.0 binary in /var/opt/sun/xvm/osp/ldom/ folder and it is extracted"
	else
		echo "ERROR: The LDOM 3.0 binary was not extracted in /var/opt/sun/xvm/osp/ldom/"
		echo ""
		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo "Trying to automatically fix this..."
			cd /var/opt/sun/xvm/osp/ldom/
			unzip -q p15880570_30_SOLARIS64.zip
			cd - >/dev/null
			echo "Done."
			echo ""
		else
			echo "To fix, run the following:"
			echo "# cd /var/opt/sun/xvm/osp/ldom/"
			echo "# unzip p15880570_30_SOLARIS64.zip"
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			echo ""
		fi
	fi
else
	echo "ERROR: Missing LDOM 3.0 binary (p15880570_30_SOLARIS64.zip) in /var/opt/sun/xvm/osp/ldom/. This is a known issue in Update 3 (16681480)."
	echo ""
	### Determine the location of this file
	FILELOC=`find $UPDATEFOLDER -name p15880570_30_SOLARIS64.zip | head -1`
	if [ "$FILELOC" = "" ] || [ ! -f $FILELOC ]; then
		echo "ERROR: Unable to find p15880570_30_SOLARIS64.zip in installation files in /var/opt/sun/xvm/update-saved-state/"
		echo "       Cannot provide a workaround."
		echo ""
	else
		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo "Trying to automatically fix this..."
			cp -p $FILELOC /var/opt/sun/xvm/osp/ldom/
			cd /var/opt/sun/xvm/osp/ldom/
			unzip -q p15880570_30_SOLARIS64.zip
			cd - >/dev/null
			echo "Done."
			echo ""
		else
			echo "To fix, run the following:"
			echo "# cp -p $FILELOC /var/opt/sun/xvm/osp/ldom/"
			echo "# cd /var/opt/sun/xvm/osp/ldom/"
			echo "# unzip p15880570_30_SOLARIS64.zip"
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			echo ""
		fi
	fi
fi
if [ ! -d /var/js/pkg/ldom/3.0 ]; then
	echo "-------------------------------------------------------------------------------------------"
	echo "To finalize the above change, you will need to also run the command 'copy_product_media'"
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to automatically fix this..."
		/opt/SUNWjet/bin/copy_product_media ldom 3.0 /var/opt/sun/xvm/osp/ldom/OVM_Server_SPARC-3_0/Product/ sparc
		echo "Done."
		echo ""
	else
		echo "To fix, run the following (after you fixed all of the above):"
		echo "# /opt/SUNWjet/bin/copy_product_media ldom 3.0 /var/opt/sun/xvm/osp/ldom/OVM_Server_SPARC-3_0/Product/ sparc"
		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		echo ""
	fi
	echo "-------------------------------------------------------------------------------------------"
fi

##### Check miniroot folder ######
MINIROOTSFOLDER="/var/opt/sun/xvm/osp/miniroots"
while read NEWMINIFILE; do
	MINIROOTSHORTNAME=`basename $NEWMINIFILE`
	diff $NEWMINIFILE ${MINIROOTSFOLDER}/${MINIROOTSHORTNAME} >/dev/null
	if [ $? -eq 0 ]; then
		echo "OK: Miniroot $MINIROOTSHORTNAME is properly placed in $MINIROOTSFOLDER"
	else
		echo "ERROR: Miniroot $MINIROOTSHORTNAME in $MINIROOTSFOLDER is not the latest one. This is a known issue in Update 3 (16681480)."
		echo ""
		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo "Trying to automatically fix this..."
			cp -p ${MINIROOTSFOLDER}/${MINIROOTSHORTNAME} ${MINIROOTSFOLDER}/${MINIROOTSHORTNAME}.OCDoctor.$$
			/bin/cp $NEWMINIFILE ${MINIROOTSFOLDER}/
			echo "Done."
			echo ""
		else
			echo "To fix, run the following:"
			echo "# cp -p ${MINIROOTSFOLDER}/${MINIROOTSHORTNAME} ${MINIROOTSFOLDER}/${MINIROOTSHORTNAME}.OCDoctor.$$"
			echo "# cp $NEWMINIFILE ${MINIROOTSFOLDER}/"
			echo ""
			echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			echo ""
		fi
	fi
done < <(find $UPDATEFOLDER -name "solaris-*-miniroot.tar.zip")

##### Check patch files #######
PATCHFOLDER="/var/js/patch/ldom"
FLAGGED="" 			### Will be set to 1 if need to run "copy_product_patches"
cat <<!EOF! > /tmp/ocdoctor-ldom-patches.$$
147147-26
150011-02
148322-07
149644-01
148324-06
150107-01
148888-01
!EOF!
while read patchname; do
	if [ -f ${PATCHFOLDER}/${patchname}.zip ]; then
		if [ -d ${PATCHFOLDER}/${patchname} ]; then
			echo "OK: Patch $patchname is copied and extracted"
		else
			
			echo "ERROR: Patch $patchname is copied but not extracted in $PATCHFOLDER"
			if [ "$OCDOCTOR_FIX" = "1" ];then
				echo "Trying to automatically fix this..."
				cd ${PATCHFOLDER}
				unzip -q ${patchname}.zip
				cd - >/dev/null
				echo "Done."
				echo ""
				FLAGGED="1"
			else
				echo "To fix, run the following:"
				echo "# cd ${PATCHFOLDER}"
				echo "# unzip ${patchname}.zip"
				echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
				echo ""
				FLAGGED="1"
			fi
		fi
	else
		echo "ERROR: Patch $patchname is not copied to $PATCHFOLDER . This is a known issue in Update 3 (16681480)."
		### Determine the location of this file
		FILELOC=`find $UPDATEFOLDER -name ${patchname}.zip | head -1`
		if [ "$FILELOC" = "" ] || [ ! -f $FILELOC ]; then
			echo "ERROR: Unable to find ${patchname}.zip in installation files in /var/opt/sun/xvm/update-saved-state/"
			echo "       Cannot provide a workaround for this patch."
			echo ""
		else
			if [ "$OCDOCTOR_FIX" = "1" ];then
				echo "Trying to automatically fix this..."
				cp -p $FILELOC ${PATCHFOLDER}/
				cd ${PATCHFOLDER}
				unzip -q ${patchname}.zip
				cd - >/dev/null
				echo "Done."
				echo ""
				FLAGGED="1"
			else
				echo "To fix, run the following:"
				echo "# cp -p $FILELOC ${PATCHFOLDER}/"
				echo "# cd ${PATCHFOLDER}"
				echo "# unzip ${patchname}.zip"
				echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
				echo ""
				FLAGGED="1"
			fi
		fi
	fi
done < /tmp/ocdoctor-ldom-patches.$$
rm -f /tmp/ocdoctor-ldom-patches.$$

if [ "$FLAGGED" = "1" ]; then
	echo "-------------------------------------------------------------------------------------------"
	echo "To finalize the above changes, you will need to also run the command 'copy_product_patches'"
	#### Changes were requested/applied - Need to run the copy_product_patches
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Trying to automatically fix this..."
		/opt/SUNWjet/bin/copy_product_patches ldom 3.0 /var/js/patch/ldom sparc
		echo "Done."
		echo ""
	else
		echo "To fix, run the following (after you fixed all of the above):"
		echo "# /opt/SUNWjet/bin/copy_product_patches ldom 3.0 /var/js/patch/ldom sparc"
		echo "or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
		echo ""
	fi
	echo "-------------------------------------------------------------------------------------------"
fi



