#!/bin/bash
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
	PROXY_BIN="/opt/sun/xvmoc/bin/proxyadm"
	SAT_BIN="/opt/sun/xvmoc/bin/satadm"
	HTTPDCONF="/var/opt/sun/xvm/uce/etc/uce_server/httpd.conf"
	OS_REL="Linux"
else
	PROXY_BIN="/opt/SUNWxvmoc/bin/proxyadm"
	SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
	HTTPDCONF="/var/opt/sun/xvm/uce/etc.opt/server/uce_server/httpd.conf"
	OS_REL=`uname -r`
fi

if [ -f $SAT_BIN ]; then
	### This is a colocated proxy - don't change anything here
	DONOTHING=1
	exit
fi

if [ ! -f $HTTPDCONF ]; then
	echo "ERROR: Can't find $HTTPDCONF"		#'
	echo
	exit
fi

MAXCLIENTS=`grep "^MaxClients " $HTTPDCONF | awk '{print $2}'`
if [ "$OS_REL" = "5.11" ]; then
	if [ "$MAXCLIENTS" = "10" ]; then
		echo "OK: Web Server MaxClients on this remote proxy is $MAXCLIENTS"
		if [ ! -f /var/tmp/OCDoctor-skip-maxclients-notice ]; then
			echo "NOTE: If you are planning on doing Solaris 11 bare-metal provisioning using this proxy, this"
			echo "      number needs to be at 100 (Bug 15786704)."
			echo "      If Solaris 11 provisioning is not planned, it is recommended to keep it at 10."
			echo 
			echo "      To adjust for S11, edit $HTTPDCONF and change:"
			echo "         MaxClients $MAXCLIENTS"
			echo "              to"
			echo "         MaxClients 100"
			echo ""
			echo "      Then restart the Proxy services:"
			echo "      # $PROXY_BIN stop -w -v"
			echo "      # $PROXY_BIN start -w -v"
			echo ""
			echo "      To remove this note from future OCDoctor runs, create the file /var/tmp/OCDoctor-skip-maxclients-notice"
			echo ""
		fi
	elif [ "$MAXCLIENTS" = "100" ]; then
		echo "OK: Web Server MaxClients on this remote proxy is $MAXCLIENTS (optimized for S11 bare-metal provisioning)"
	else
		echo "WARNING: MaxClients value in httpd.conf on a remote proxy should be 10 or 100, but it is $MAXCLIENTS"
		echo "         If you are planning on doing Solaris 11 bare-metal provisioning using this proxy, this"
		echo "         number needs to be at 100 (Bug 15786704)."
		echo "         If Solaris 11 provisioning is not planned, it is recommended to keep it at 10."
		echo
		if [ "$OCDOCTOR_FIX" = "1" ] && [ "$UIDOCTOR" != "1" ]; then
			echo "       Trying to fix automatically..."
			`sed "s/^MaxClients $MAXCLIENTS/MaxClients 100/" $HTTPDCONF > /var/tmp/httpdconf.tmp`
			cp -p $HTTPDCONF $HTTPDCONF.doctor.$$
			cp /var/tmp/httpdconf.tmp $HTTPDCONF
			rm -f /var/tmp/httpdconf.tmp
			echo "       Done - fixed $HTTPDCONF"
			echo "       A backup file was created - $HTTPDCONF.doctor.$$"
			echo ""
			STATUS=`$PROXY_BIN status`
			if [ "$STATUS" = "online" ];then
				printf "Would you like to restart the proxy now? (you can do this later as well) (y/n): "
				read yesno
				if [ "$yesno" = "yes" ]; then
					yesno="y"
				fi
				if [ "$yesno" = "Y" ]; then
	                                yesno="y"
	                        fi
				if [ "$yesno" = "y" ]; then
					echo "--- Stopping proxy ---"
	                                $PROXY_BIN stop -w -v
					echo "--- Starting proxy ---"
	                                $PROXY_BIN start -w -v
	                        fi
				echo ""
			else
				echo "       Proxy is already offline - not restarting"
				echo ""
			fi
		else
			echo "       To fix, edit $HTTPDCONF and change:"
			echo "         MaxClients $MAXCLIENTS"
			echo "              to"
			echo "         MaxClients 100"
			echo ""
			echo "       Then restart the Proxy services:"
			echo "       # $PROXY_BIN stop -w -v"
			echo "       # $PROXY_BIN start -w -v"
			echo ""
			if [ "$UIDOCTOR" != "1" ]; then
				echo "       or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			fi
			echo ""
		fi
	fi
else			############# Solaris 10 ############
	if [ "$MAXCLIENTS" = "10" ]; then
		echo "OK: Web Server MaxClients on this remote proxy is $MAXCLIENTS"
	else
		echo "WARNING: MaxClients value in httpd.conf on a remote proxy should be 10, but it is $MAXCLIENTS"
		echo
		if [ "$OCDOCTOR_FIX" = "1" ] && [ "$UIDOCTOR" != "1" ]; then
			echo "       Trying to fix automatically..."
			`sed "s/^MaxClients $MAXCLIENTS/MaxClients 10/" $HTTPDCONF > /var/tmp/httpdconf.tmp`
			cp -p $HTTPDCONF $HTTPDCONF.doctor.$$
			cp /var/tmp/httpdconf.tmp $HTTPDCONF
			rm -f /var/tmp/httpdconf.tmp
			echo "       Done - fixed $HTTPDCONF"
			echo "       A backup file was created - $HTTPDCONF.doctor.$$"
			echo ""
			STATUS=`$PROXY_BIN status`
			if [ "$STATUS" = "online" ];then
				printf "Would you like to restart the proxy now? (you can do this later as well) (y/n): "
				read yesno
				if [ "$yesno" = "yes" ]; then
					yesno="y"
				fi
				if [ "$yesno" = "Y" ]; then
		                            yesno="y"
		                    fi
				if [ "$yesno" = "y" ]; then
					echo "--- Stopping proxy ---"
		                            $PROXY_BIN stop -w -v
					echo "--- Starting proxy ---"
		                            $PROXY_BIN start -w -v
		                    fi
				echo ""
			else
				echo "       Proxy is already offline - not restarting"
				echo ""
			fi
		else
			echo "       To fix, edit $HTTPDCONF and change:"
			echo "         MaxClients $MAXCLIENTS"
			echo "              to"
			echo "         MaxClients 10"
			echo ""
			echo "       Then restart the Proxy services:"
			echo "       # $PROXY_BIN stop -w -v"
			echo "       # $PROXY_BIN start -w -v"
			echo ""
			if [ "$UIDOCTOR" != "1" ]; then
				echo "       or use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this"
			fi
			echo ""
		fi
	fi
fi

