#!/bin/bash

UNAME=`uname`
if [[ $UNAME == "Linux" ]];then
	LOGDIR="/var/opt/sun/xvm/uce/usr.local/server/logs/uce_server"
else
	LOGDIR="/var/opt/sun/xvm/uce/opt/server/logs/uce_server"
fi

# Max size of UCE log file to be warned at, 1.5GB
MAX_SIZE="1610612736"
# UCE log file size capped at 1GB
TRIM_SIZE="1073741824"
# UCE Server needs to be restarted when new log file gets created
DO_SERVER_RESTART=false

stop_UCE_server() {
	if [[ $UNAME == "Linux" ]];then
		/var/opt/sun/xvm/uce/usr.local/server/bin/serverctl graceful-stop
	else
		/var/opt/sun/xvm/uce/opt/server/bin/serverctl graceful-stop
	fi
}

start_UCE_server() {
	echo "OK: Done. Finished with the UCE log cleanup, starting UCE server."
	if [[ $UNAME == "Linux" ]];then
		/var/opt/sun/xvm/uce/usr.local/server/bin/serverctl start
	else
		/var/opt/sun/xvm/uce/opt/server/bin/serverctl start
	fi
}

restart_UCE_server() {
	echo "OK: Done. Finished with the UCE log cleanup, restarting UCE server gracefully."
	if [[ $UNAME == "Linux" ]];then
		/var/opt/sun/xvm/uce/usr.local/server/bin/serverctl graceful
	else
		/var/opt/sun/xvm/uce/opt/server/bin/serverctl graceful
	fi
}

get_ec_status() {
	if [ "$UNAME" = "Linux" ]; then
		SAT_BIN="/opt/sun/xvmoc/bin/satadm"
	else
		SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
	fi

	if [ -f $SAT_BIN ]; then
		echo `$SAT_BIN status`
	fi
}

get_pc_status() {
	if [ "$UNAME" = "Linux" ]; then
		PROXY_BIN="/opt/sun/xvmoc/bin/proxyadm"
	else
		PROXY_BIN="/opt/SUNWxvmoc/bin/proxyadm"
	fi

	if [ -f $PROXY_BIN ]; then
		echo `$PROXY_BIN status`
	fi
}

show_info_msg() {
	echo "WARNING: UCE log file $1 is larger than 1GB"
	echo "         Please use '# ./OCDoctor.sh --troubleshoot --fix' to automatically fix this (Require UCE server restart)"
	echo "         or use 'tail -${TRIM_SIZE} $1 > tmp.log;mv tmp.log $1' to trim the log file manually. Restart UCE Server to apply log file changes"
	echo " "
}

# Show message and purge log
trim_logs() {
	echo "INFO: UCE log file $1 is larger than 1GB, trimming it to 1GB."

	if [[ "$DO_SERVER_RESTART" == false ]];then
		# Stop the UCE server to allow log file modifications
		stop_UCE_server
	fi

	DO_SERVER_RESTART=true

	tail -${TRIM_SIZE}c $1 > $1_tmp
	mv $1_tmp $1
}


# check log file size and trim it if it is larger than max size
check_and_trim_logs() {
	LOGNAME=$1
	LOGNAME_SIZE=$(ls -la $LOGNAME | awk '{ print $5}')

	if [[ "$LOGNAME_SIZE" -gt "$MAX_SIZE" ]]; then
		if [[ "$OCDOCTOR_FIX" == "1" ]];then
			trim_logs $LOGNAME
		else
			show_info_msg $LOGNAME
		fi
	fi
}


check_and_trim_logs "${LOGDIR}/access_log"
check_and_trim_logs "${LOGDIR}/error_log"
check_and_trim_logs "${LOGDIR}/ssl_engine_log"
check_and_trim_logs "${LOGDIR}/ssl_request_log"

EC_STATUS=$( get_ec_status )
PC_STATUS=$( get_pc_status )

if [[ ("$DO_SERVER_RESTART" == true ) && ( "$EC_STATUS" == "online" || "$PC_STATUS" == "online") ]];then
	if [[ $UNAME == "Linux" ]];then
		UCE_STATUS=$(/var/opt/sun/xvm/uce/usr.local/server/bin/serverctl status | awk '{print $2 $3}')
	else
		UCE_STATUS=$(/var/opt/sun/xvm/uce/opt/server/bin/serverctl status | awk '{print $2 $3}')
	fi

	if [[ $UCE_STATUS == "isrunning." ]];then
		restart_UCE_server
	else
		start_UCE_server
	fi
fi
