#!/bin/bash
#
# check if any SMF service is in maintenance mode
#

UNAME=`uname`
UNAMER=`uname -r`

TMPFILE=/tmp/maintenance.$$

if [ -f /opt/SUNWxvmoc/bin/ecadm ]; then
	# in case this is a EC, we did run this check already
	exit
fi
#if [ -f /opt/SUNWxvmoc/bin/proxyadm ]; then
#	# in case this is a PC, we did run this check already
#	exit
#fi

WRITE_OK_MESSAGE=false
if [ "$UNAME" = "SunOS" ] && [ "$UNAMER" = "5.10" -o "$UNAMER" = "5.11" ]; then

	svcs -a 2>/dev/null | grep ^maintenance | grep -v application/scn/dhcpd > $TMPFILE
	if [ -s $TMPFILE ]; then
		echo
		echo "WARNING: One or more SMF services are in maintenance state:"
		echo
		echo "STATE          STIME    FMRI"
		cat $TMPFILE
		echo
	else
		WRITE_OK_MESSAGE=true
	fi
fi
rm -f $TMPFILE

if [ "$UNAME" = "SunOS" -a  "$UNAMER" = "5.11" ] && svcs application/scn/dhcpd 2>/dev/null | grep ^maintenance > /dev/null; then
	echo "INFO: SMF service svc:/application/scn/dhcpd:default is in maintenance state."
	echo "INFO: This is not critical, the service is no longer needed on Solaris 11 and higher".
	echo "INFO: Just run 'svcadm disable svc:/application/scn/dhcpd:default' to resolve the issue."
	WRITE_OK_MESSAGE=false
fi

if $WRITE_OK_MESSAGE; then
	echo "OK: None of the SMF services found in maintenance state"
fi
