#!/bin/bash
#
# AssetCount.sh - Script to list counts of managed assets, split by Proxy Controller
#

Usage(){
cat << EOF

	$PROG [-v] { standard | machine | agent | all }

	standard - show Asset count
	machine - show machine output with Assets names
	agent - show information about agents, agentless Assets, Service Processors
	all - show all the information together

	-v : verbose output, present additional notes around the counting algorithm

	(Version 1.1 2015/05/15)

EOF
exit 1
}

PROG=$(basename $0)

if  [ "$1" = "-q" ]; then
	# quiet mode (undocumented)
	QUIET_MODE=true
	shift
else
	QUIET_MODE=false
fi

if [ "$1" = "-v" ]; then
	# verbose mode
	PRINT_BACKGROUND=true
	shift
else
	PRINT_BACKGROUND=false
fi

[ $# -ne 1 ] && Usage

# if not running as root, exit
if ! /usr/bin/id | grep "uid=0(root)" >/dev/null 2>&1; then
    echo "$PROG must be run by the root user"
    exit 1;
fi

# added more possible locations to search for a valid JAVA HOME directory
if [ "$(uname)" = "Linux" ]; then
	JAVA=$(ls -d /usr/java/jdk1.7* /usr/java/instances/jdk1.7* /usr/java/jdk1.8* /usr/java/instances/jdk1.8* 2>/dev/null | tail -1)
	ECADM=/opt/sun/xvmoc/bin/ecadm
else
	JAVA=$(ls -d /usr/jdk/jdk1.7* /usr/jdk/instances/jdk1.7* /usr/jdk/jdk1.8* /usr/jdk/instances/jdk1.8* 2>/dev/null | tail -1)
	ECADM=/opt/SUNWxvmoc/bin/ecadm
fi

VERSION_PROPERTIES=/n1gc-setup/.version.properties
if [ -f $VERSION_PROPERTIES ]; then
	MAJOR_VERSION=$( grep ^product.version= $VERSION_PROPERTIES | cut -d= -f2 | cut -d. -f1 )
	if [ "$MAJOR_VERSION" -lt 12 ]; then
		echo "$PROG can be used only on Enterprise Controller of version 12c R1 or higher"
		exit 1
	fi
else
	echo "$PROG must be run on the OpsCenter Enterprise Controller only"
	exit 1
fi

if [ ! -x $ECADM ]; then
	echo "$PROG must be run on the OpsCenter Enterprise Controller only"
	exit 1
fi

STATUS=$($ECADM status 2>/dev/null)
if [ "$STATUS" != "online" ]; then
	echo "OpsCenter Enterprise Controller is not 'online'"
	exit 1
fi

if [ -d "$JAVA" ]; then
	JAVA=$JAVA/bin/java
else
	echo "$PROG requires at minimum Java 7"
	exit 1
fi

CLASSPATH="/opt/sun/n1gc/lib/*:/usr/lib/cacao/lib/*:/usr/lib/cacao/ext/crews/lib/*:/opt/sun/cacao2/share/lib/*:/opt/sun/cacao2/share/ext/crews/lib/*:/opt/SUNWjdmk/5.1/lib/*:/usr/share/lib/jdmk/*:/opt/sun/jdmk/5.1/lib/*:/opt/sun/xvm/lib/*:$(dirname $0)/lib/AssetCounter/AssetCounter.jar"

echo
$JAVA -cp $CLASSPATH assetcounter.AssetCounter $1
EXIT_CODE=$?

if [ $EXIT_CODE -ne 0 ]; then
	echo "ERROR: Java program exited with error code ${EXIT_CODE}!"
	exit 1
fi

$QUIET_MODE && exit

if $PRINT_BACKGROUND; then
	cat <<EOF

Additional notes:

The number in the Assets column represents the number of 'Access Points' to the various asset types.

A single Asset, such as a physical server, might have multiple Access Points. For example, a Proxy Controller 
can gather data by accessing the Service Processor or by using the Agent running inside the operating system. 
Another example is an LDom Guest, where we obtain data from the Control Domain Agent and the Agent running 
inside the LDom Guest OS.

When different Proxy Controllers are used to access an asset, a single asset is listed and counted separately
for each Proxy Controller because the asset impacts the load for each Proxy Controller.

The number presented for the Enterprise Controller (EC) is the sum of all Access Points handled by the various
Proxy Controllers. Therefore, the number presented is higher than the actual number of managed assets when 
assets are managed by multiple Proxy Controllers because the access points generate load for the EC.

EOF
else
	echo
	echo "Use option '-v' to see additional notes on the counting algorithm."
	echo
fi
