#!/bin/sh


if [ "`uname -s`" = "SunOS" ]; then
    SUCMD=/sbin/su
    DB_ROOT_DIR=/opt/ORCLsysman-db
elif [ "`uname -s`" = "Linux" ]; then
    SUCMD=/bin/su
    DB_ROOT_DIR=/opt/orcl/orcl-sysman-db
fi

   configFile=$DB_ROOT_DIR/etc/localOracleConfig.properties

   if [ ! -f $configFile ]; then
    echo "FAILURE: Cannot find Oracle Configuration File in " + `pwd` + $configFile
    exit 1
   else
    # it is a shell file, source it
    . $configFile
   fi

    outfile=/var/tmp/DBSpaceCheck_`hostname`_`date +%T%m%d%y`.dbdata.out

    echo "Date:  " > $outfile
    date >> $outfile
    echo "\n\n Filesystem Space Free:" >> $outfile
    df -h >> $outfile
    echo "\n\n DB Files:" >> $outfile
    ls -ltr /var/opt/sun/xvm/oracle/oradata/OCDB >> $outfile
    echo "\n\n Rollup Log:" >> $outfile
    echo "select count(*) as rollup_log_count, rollup_status from rm_resource_rollup_log group by rollup_status;"| /opt/*oc/bin/ecadm sqlplus>>$outfile
    echo "\n\n Daily Trend:" >> $outfile
    echo "select count(*) as daily_trend_count, trunc(trend_date) from rm_resource_daily_trend group by trunc(trend_date) order by 2;"| /opt/*oc/bin/ecadm sqlplus>>$outfile

    su - $embedded_oracle_user -c "sqlplus / as sysdba << EOF
    whenever sqlerror exit sql.sqlcode;
    column segment_name format a45
    column tablespace_name format a20
    column file_name format a60
    column bytes format 999,999,999,999,999
    column maxbytes format 999,999,999,999,999
    column user_bytes format 999,999,999,999,999
    column pct_allocated format 999.99
    column log_date format a40
    column job_name format a40
    set lines 200
    TTITLE LEFT 'DBA Segments: ' skip 2
    select  * from (select owner, segment_name, bytes from dba_segments where tablespace_name = 'OC_DEFAULT_TS' order by bytes desc) where rownum < 11;
    TTITLE LEFT 'Data Files: ' skip 2
    select file_name,tablespace_name, maxbytes, user_bytes, bytes ,  100- ((maxbytes-bytes)/greatest(maxbytes,1) *100) pct_alloc from dba_data_files;
    select 'TOTAL Space used by dba_data_files: ' || to_char(sum(bytes),'999,999,999,999,999') from dba_data_files;
    TTITLE LEFT 'Free Space: ' skip 2
    select tablespace_name,  to_char(sum(bytes),'999,999,999,999,999') from dba_free_space group by tablespace_name;  
    TTITLE Left 'Last 5 stats Jobs: ' skip 2
    select * from (select job_name, log_date, status from dba_scheduler_job_log where job_name like 'OC_GATHER%' order by log_date desc) where rownum < 6;
    TTITLE LEFT 'Last Stats Duration: ' skip 2
    select job_name, last_run_duration from dba_scheduler_jobs where job_name like 'OC%';
    TTITLE LEFT 'Free Space Below HW Mark: ' skip 2
set serverout on
declare
v_unformatted_blocks NUMBER;
v_unformatted_bytes number;
v_fs1_blocks number;
v_fs1_bytes number;
v_fs2_blocks number;
v_fs2_bytes number;

v_fs3_blocks number;
v_fs3_bytes number;

v_fs4_blocks number;
v_fs4_bytes number;
v_full_blocks number;
v_full_bytes number;

cursor index_cur is
 select index_name
  from all_indexes
 where owner = 'OC'
   and index_name like 'RM_RESOURCE%';

cursor table_cur is
 select table_name
  from all_tables
 where owner = 'OC'
   and table_name like 'RM_RESOURCE%';

begin
dbms_output.enable(100000);
for table_rec in table_cur
loop
dbms_space.space_usage('OC',table_rec.table_name,'TABLE',v_unformatted_blocks,
v_unformatted_bytes, v_fs1_blocks, v_fs1_bytes, v_fs2_blocks, v_fs2_bytes,
v_fs3_blocks, v_fs3_bytes, v_fs4_blocks, V_fs4_bytes, v_full_blocks, v_full_bytes);
dbms_output.put_line('Table: '||table_rec.table_name);
dbms_output.put_line('Total Blocks that are Full: ' || v_full_blocks);
dbms_output.put_line('Total Blocks that are 0-25% Free: ' || v_fs1_blocks);
dbms_output.put_line('Total Blocks that are 25-50% Free: ' || v_fs2_blocks);
dbms_output.put_line('Total Blocks that are 50-75% Free: ' || v_fs3_blocks);
dbms_output.put_line('Total Blocks that are 75-100% Free: ' || v_fs4_blocks);
dbms_output.put_line('Total Blocks unformatted: ' || v_unformatted_blocks);
end loop;

for index_rec in index_cur
loop
dbms_space.space_usage('OC',index_rec.index_name,'INDEX',v_unformatted_blocks,
v_unformatted_bytes, v_fs1_blocks, v_fs1_bytes, v_fs2_blocks, v_fs2_bytes,
v_fs3_blocks, v_fs3_bytes, v_fs4_blocks, V_fs4_bytes, v_full_blocks, v_full_bytes);
dbms_output.put_line('Index: '|| index_rec.index_name);
dbms_output.put_line('Total Blocks that are Full: ' || v_full_blocks);
dbms_output.put_line('Total Blocks that are 0-25% Free: ' || v_fs1_blocks);
dbms_output.put_line('Total Blocks that are 25-50% Free: ' || v_fs2_blocks);
dbms_output.put_line('Total Blocks that are 50-75% Free: ' || v_fs3_blocks);
dbms_output.put_line('Total Blocks that are 75-100% Free: ' || v_fs4_blocks);
dbms_output.put_line('Total Blocks unformatted: ' || v_unformatted_blocks);
end loop;
end;
/
    exit sql.sqlcode
EOF" >> $outfile

 /opt/sun/xvm/bin/jmxexec s root wellknown com.sun.xvm.services:type=ReportService reportServiceTest list >> $outfile
 echo "\n\n ReportService Stats:" >> $outfile
 /opt/sun/xvm/bin/jmxdump s t root wellknown com.sun.cacao.instrum:* | grep -i reportservice >> $outfile

echo "\n  Output collected in $outfile \n"
