#!/bin/bash

#
# Copyright (c) 2015 Oracle and/or its affiliates.  All rights reserved.
# Use is subject to license terms.
#

CLASS_PATH="./lib/*:/opt/sun/n1gc/lib/*:/opt/sun/n1gc/lib/SCRK/WEB-INF/lib/*:/opt/sun/occli/private/lib/*:/opt/sun/cacao2/share/lib/*:/opt/sun/jdmk/5.1/lib/jdmkrt.jar:/opt/sun/n1gc/lib/oracle/*:./emailTester.jar"
ARGUMENTS=""
JAVA_COMMAND="/usr/java/latest/bin/java -cp $CLASS_PATH com.oracle.sysman.email.EmailTester"
DEBUG=""
FUNCTION=""
FUNCTION_ARG1=""

if [ `uname -s` == "SunOS" ]; then
  CLASS_PATH="./lib/*:/opt/sun/n1gc/lib/*:/opt/sun/n1gc/lib/SCRK/WEB-INF/lib/*:/usr/lib/cacao/lib/*:/usr/share/lib/jdmk/jdmkrt.jar:/opt/sun/n1gc/lib/oracle/*:./emailTester.jar"
  JAVA_COMMAND="/usr/jdk/latest/bin/java -cp $CLASS_PATH com.oracle.sysman.email.EmailTester"
fi

function usage(){

  echo "Usage: emailTester.sh [-v] --print-notif-users | --print-email-setting | --test-email-setting <user>"
  echo "  --print-notif-users          It prints users which have email set in"
  echo "                               the notification profile. It shows priority"
  echo "                               of incident in which email should be send."
  echo "  --print-email-setting        It prints users notification's email settings"
  echo "                               (Mail Host, Port, Protocol, User Mail,"
  echo "                               to Address, from Address)"
  echo "  -v                           It adds verbose messages [-v] [-vv] [-vvv]"
  echo "  --test-email-setting <user>  It sends test message according to"
  echo "                               the notification's email settings"
  echo "  -h --help                    It prints this help message"
}

function printNotifUsers(){
  $JAVA_COMMAND --print-notif-users $DEBUG
}
function printEmailSetting(){
  $JAVA_COMMAND --print-email-setting $DEBUG
}
function testEmailSetting(){
  $JAVA_COMMAND --test-email-setting $FUNCTION_ARG1 $DEBUG
}

function checkFunction(){
  if [ ! -z "$FUNCTION" ]; then
    echo "Please use only one function"
    usage
    exit 1
  fi
  FUNCTION=$1
}

##########
### Main

while [ $# -gt 0 ]; do
  case "$1" in

    --print-notif-users)
      checkFunction printNotifUsers
      shift;;

    --print-email-setting)
      checkFunction printEmailSetting
      shift;;

   -v)
      DEBUG="--fine"
      shift;;

   -vv)
      DEBUG="--finer"
      shift;;

   -vvv*)
      DEBUG="--finest"
      shift;;

   --test-email-setting)
      checkFunction testEmailSetting
      shift
      FUNCTION_ARG1=$1
      shift;;

    -h|--help)
      usage
      exit;;

    *)
      echo "Unknown option: $1"
      usage
      exit 1;;
  esac
done

if [ -z "$FUNCTION" ]; then
  usage
  exit 1
fi

eval $FUNCTION

