#!/bin/bash
#
# Script to change the maximum allowed heap size of EC, PC or Agent cacao instance
#

#checking number of parameters passed
if [ "$#" -ne 3 ]; then
	echo "Missing or too many parameters: "
	echo "Syntax:"
	echo "./changeXmxValue <size> <unit> <oc component>"
	echo "size		- the size of memory"
	echo "unit		- memory unit [g|G|m|M|k|K]"
	echo "oc component 	- oc component [agent|proxy|ec]"
	exit 1
fi

#checking if unit argument is ok
unitPattern="[g|G|m|M|k|K]{1}"
if ! [[ "$2" =~ $unitPattern ]]; then
	echo "Wrong unit it can be only [g|G|m|M|k|K]"
	exit 1
fi

#checking if size is a number
numberPattern="[0-9]+"
if ! [[ "$1" =~ $numberPattern ]]; then
	echo "Size argument is not a number"
	exit 1
fi

#Check if root user and OS type(linux, solaris)
if ! /usr/bin/id | grep "uid=0(root)" >/dev/null 2>&1; then
        echo "Script must be run by the root user"
        exit 1;
fi


os=`uname`
if [ "$os" = "Linux" ]; then
        OC_BIN_PATH="/opt/sun/xvmoc/bin/"
        CACAOADM="/opt/sun/cacao2/bin/cacaoadm" 
else
        OC_BIN_PATH="/opt/SUNWxvmoc/bin/"
        CACAOADM="/usr/sbin/cacaoadm"
fi



#set component or error if does not match any
if [ "$3" = "agent" ]; then
        instance="scn-agent"
	startCommand="$OC_BIN_PATH/agentadm start" 
	stopCommand="$OC_BIN_PATH/agentadm stop"
elif [ "$3" = "proxy" ]; then
        instance="scn-proxy"
        startCommand="$OC_BIN_PATH/proxyadm start -w"
        stopCommand="$OC_BIN_PATH/proxyadm stop -w"
elif [ "$3" = "ec" ]; then
        instance="oem-ec"
        startCommand="$OC_BIN_PATH/satadm start -w"
        stopCommand="$OC_BIN_PATH/satadm stop -w"
else
	echo "There is no such component [ec|proxy|agent]"
	exit 1 
fi

if ! $CACAOADM list-instances | grep $instance >/dev/null 2>&1; then
	echo "No $instance running on this host"
	exit 1
fi 


javaFlags=`$CACAOADM get-param java-flags -i $instance`
setNewFlag="$CACAOADM set-param -i $instance"

printf "The script will now stop the $3 services to apply the change. Press <ENTER> to continue ..."
read JUNK

#stoping OC component
echo "Stopping component JVM..."
$stopCommand >/dev/null 2>&1
echo "Setting new Xmx value for JVM..."
flags="${javaFlags//java-flags=}"
pattern="-Xmx[0-9]+[g|G|m|M|k|K]{1}"
for flag in $flags
do
	if [[ "$flag" =~ $pattern ]]; then 
		result="$result -Xmx$1$2"
	else
		result="$result $flag"
	fi
done

$setNewFlag java-flags=$result
echo "Starting component JVM with new Xmx value..."
$startCommand  >/dev/null 2>&1
