#!/bin/bash
if [ ! -f /var/opt/sun/xvm/db.properties ]; then
	echo "ERROR: Could not find /var/opt/sun/xvm/db.properties, is the EC installed on this machine?"
	echo ""
	exit 1
fi
export PATH=/usr/sbin:/usr/bin:$PATH
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        ECADM="/opt/sun/xvmoc/bin/ecadm"
else
        ECADM="/opt/SUNWxvmoc/bin/ecadm"
fi


######################################################################################################
is_monitored(){
	PNAME=$1
	FNAME="/opt/sun/n1gc/etc/xvmoc-resourcecontroller.xml"
	if [ ! -f $FNAME ]; then
		echo "ERROR: Unable to find $FNAME"
		echo ""
		exit 1
	fi
	### The following will get rid of XML comments
	OUTPUT=`cat $FNAME | sed '/<!--.*-->/d'| sed '/<!--/,/-->/d'|grep "<attribute" | awk -F"\"" '{print $2}' | grep "^${PNAME}"`
	if [ "$OUTPUT" = "" ]; then
		MONITORED="no"
	else
		MONITORED="yes"
	fi 
}
######################################################################################################
determine_shortest_name(){
	### Will look for the shortest name in xvmoc-resourcecontroller.xml
	### If parameter is OS_Disk, it will see check how many instances of it exist - if more than one, then it will add "_" 
	PNAME=$1
	FNAME="/opt/sun/n1gc/etc/xvmoc-resourcecontroller.xml"
	if [ ! -f $FNAME ]; then
		echo "ERROR: Unable to find $FNAME"
		echo ""
		exit 1
	fi
	### The following will get rid of XML comments
	ALLATTRIBUTES=`cat $FNAME | grep "<attribute" | awk -F"\"" '{print $2}' `
	COUNTWITHOUTADDITIONS=`printf "$ALLATTRIBUTES\n" | grep "^${PNAME}" | wc -l | awk '{print $1}'`
	COUNTWITHUNDERSCORE=`printf "$ALLATTRIBUTES\n" | grep "^${PNAME}_" | wc -l | awk '{print $1}'`
	if [ $COUNTWITHOUTADDITIONS -eq 1 ]; then
		SHORTESTNAME=$PNAME
	elif [ $COUNTWITHUNDERSCORE -eq 1 ]; then
		SHORTESTNAME=${PNAME}_
	else
		### in case the property is completely out of the XML (removed instead of commented out)
		SHORTESTNAME=$PNAME
	fi
}
######################################################################################################
remove_attribute_from_xml(){
	### This will comment out a specific attribute
	PNAME=$1
	if [ "$PNAME" = "" ]; then
		echo "ERROR: Unable to remove an empty attribute"
		echo ""
		exit 1
	fi
	
	
	echo "[1/5] Removing '$PNAME' from the monitored attributes..."
	determine_shortest_name $PNAME		### Obtain $SHORTESTNAME
	echo "[2/5] Determined that the final name to remove is '$SHORTESTNAME' "
	
	FNAME="/opt/sun/n1gc/etc/xvmoc-resourcecontroller.xml"
	echo "[3/5] Making a copy of $FNAME as $FNAME.OCDoctor.$$"
	cp -p $FNAME $FNAME.OCDoctor.$$
	FNEW="/var/tmp/xvmoc-resourcecontroller.xml.new.$$"
	echo "[4/5] Writing to temporary file $FNEW, please wait..."
	rm -f $FNEW
	if [ ! -f $FNAME ]; then
		echo "ERROR: Unable to find $FNAME"
		echo ""
		exit 1
	fi
	STARTED=0
	IFS=""
	cat $FNAME | while IFS="" read LINE; do
		OUTPUT=`echo $LINE | grep "<attribute" | awk -F"\"" '{print $2}' | grep "^${SHORTESTNAME}"`
		if [ "$OUTPUT" = "" ]; then
			echo "$LINE" >>$FNEW
			if [ $STARTED -eq 1 ]; then
				### Check if </attribute> is printed
				OUTPUT2=`echo $LINE | grep "</attribute>"`
				if [ ! "$OUTPUT2" = "" ]; then
					echo "-->" >> $FNEW
					STARTED=0
				fi
			fi
		else
			echo "<!-- REMOVED_BY_OCDOCTOR" >> $FNEW
			echo "$LINE" >> $FNEW
			STARTED=1
		fi
	done
	echo "[5/5] Moving temporary file to permanent file $FNAME"
	mv -f $FNEW $FNAME
	echo ""
	echo "Done - Attribute '$SHORTESTNAME' is now commented out in the XML."
	echo ""
	echo "You can verify that the comments were added in the right places using the following diff command:"
	echo "# diff -C 10 $FNAME.OCDoctor.$$ $FNAME |more"
	echo ""
	echo "Make sure you restart the EC for these changes to take effect:"
	echo ""
	echo "# $ECADM stop -w"
	echo "# $ECADM start -w"
	echo ""
	echo "NOTE: You may continue and choose to stop monitoring of additional attributes before restarting the EC "
	echo "      (there is no need to restart every time but only when you are done disabling attributes)"
	echo ""
	echo "NOTE 2: Data in the database was not removed! The EC will just not gather new data from this attribute from now on."
	echo "        You may rerun this script and choose to delete old data to accomplish DB cleanup."
	echo "        Also, this data will automatically be rolled up and cleaned up within 6 days - assuming rollup works properly."
	echo ""
	echo "        In either case, please note that the actual disk space used by the DB will not go down. Instead, new records"
	echo "        will not consume additional disk space but will reuse the existing allocated space."
	echo ""
	exit
}
######################################################################################################
delete_specific_attribute(){
	### Delete a specific attribute
	### This is called from delete_attribute_data_from_db which manages the whole delete process
	ATTRTODELETE=$1
	if [ "$ATTRTODELETE" = "" ]; then
		echo "ERROR: Attribute to delete is empty"
		echo ""
		exit 1
	fi
	CLEANNAME=`echo "$ATTRTODELETE" | sed 's/\_/\\\_/g'`
	if [ "$CLEANNAME" = "" ]; then
		echo "ERROR: Clean attribute to delete is empty"
		echo ""
		exit 1
	fi
	
	echo "delete from rm_resource_daily_trend" > /var/tmp/ocdoctor.sql.$$
    echo "where resource_attribute_id in (select RESOURCE_ATTRIBUTE_ID from rm_resource_attribute where resource_attribute_name like '$CLEANNAME' ESCAPE '\');" >>  /var/tmp/ocdoctor.sql.$$		#'
    
    #echo "-----------------------------------------------------------------------------------------------"
    #cat /var/tmp/ocdoctor.sql.$$
    #echo "-----------------------------------------------------------------------------------------------"

    echo "@/var/tmp/ocdoctor.sql.$$" | $ECADM sqlplus >/dev/null 2>/dev/null
    rm -f /var/tmp/ocdoctor.sql.$$
    
}

######################################################################################################
delete_attribute_data_from_db(){
	### This will comment out a specific attribute
	PNAME=$1
	if [ "$PNAME" = "" ]; then
		echo "ERROR: Unable to delete an empty attribute"
		echo ""
		exit 1
	fi
	echo "[1/3] Deleting attribute '$PNAME' from the database"
	determine_shortest_name $PNAME		### Obtain $SHORTESTNAME
	echo "[2/3] Determined that the final name to delete is '$SHORTESTNAME'"
	echo "[3/3] Breaking down this attribute to the smallest chunks for effecient deletes on a large DB..."
	
	echo "set lines 300" > /var/tmp/ocdoctor.sql.$$
	echo "set space 1" >> /var/tmp/ocdoctor.sql.$$
	echo "set pagesize 0" >> /var/tmp/ocdoctor.sql.$$
	echo "set headsep off" >> /var/tmp/ocdoctor.sql.$$
	echo "column RESOURCE_ATTRIBUTE_NAME format a200"  >> /var/tmp/ocdoctor.sql.$$
	echo "column NUM_SAMPLES format 99999999999999"  >> /var/tmp/ocdoctor.sql.$$
	echo "set term off"  >> /var/tmp/ocdoctor.sql.$$
	echo "set trim off"  >> /var/tmp/ocdoctor.sql.$$
	echo "set trimspool off"  >> /var/tmp/ocdoctor.sql.$$
	echo "spool /var/tmp/ocdoctor.sql.out.$$" >> /var/tmp/ocdoctor.sql.$$
	echo "	select rra.resource_attribute_name RESOURCE_ATTRIBUTE_NAME, count(*) num_samples" >> /var/tmp/ocdoctor.sql.$$
	echo "	from rm_resource_daily_trend rrdt,	rm_resource_attribute rra" >> /var/tmp/ocdoctor.sql.$$
	echo "	where rrdt.resource_attribute_id = rra.resource_attribute_id" >> /var/tmp/ocdoctor.sql.$$
	#### need to backslash any "_" otherwise it is an Oracle wildcard inside LIKE
	CLEANSHORTNAME=`echo "$SHORTESTNAME" | sed 's/\_/\\\_/g'`
	echo "  and rra.resource_attribute_name like '${CLEANSHORTNAME}%' ESCAPE '\'" >> /var/tmp/ocdoctor.sql.$$		#'
	echo " 	group by rra.resource_attribute_name" >> /var/tmp/ocdoctor.sql.$$
	echo " 	order by 2;" >> /var/tmp/ocdoctor.sql.$$
	echo "spool off" >> /var/tmp/ocdoctor.sql.$$
	rm -f /var/tmp/ocdoctor.sql.out.$$
	echo "@/var/tmp/ocdoctor.sql.$$" | $ECADM sqlplus >/dev/null 2>/dev/null
	OUTPUT=`cat /var/tmp/ocdoctor.sql.out.$$ 2>/dev/null | grep "_" | grep -v NUM_SAMPLES`
	ITEMSTODELETE=`printf "$OUTPUT\n" | wc -l | awk '{print $1}'`
	COUNT=1
	while read LINE; do
		ATTR=`echo $LINE | awk '{print $1}'`
		SAMPLES=`echo $LINE | awk '{print $2}'`
		if [ "$ATTR" = "" ]; then
			echo "ERROR: Unable to read attributes to delete... something is wrong!"
			echo ""
			exit 1
		fi
		echo "Deleting $COUNT out of $ITEMSTODELETE: attribute '$ATTR' with $SAMPLES samples..."
		delete_specific_attribute "$ATTR"
		let COUNT++
	done < <(printf "$OUTPUT\n")
	
	echo "Done - deleteted attribute '$PNAME' from the database."
	echo ""
	echo "NOTE: The database files will still occupy the same amount of space on the disk, even after deleting this attribute."
	echo "      However, there is now more space available for the database to populate new data - so the disk use should not increase."
	echo ""
	exit
}
######################################################################################################


########################### MAIN ########################
echo "set lines 300" > /var/tmp/ocdoctor.sql.$$
echo "set space 1" >> /var/tmp/ocdoctor.sql.$$
echo "set pagesize 0" >> /var/tmp/ocdoctor.sql.$$
echo "set headsep off" >> /var/tmp/ocdoctor.sql.$$
echo "column RESOURCE_ATTRIBUTE_NAME format a200"  >> /var/tmp/ocdoctor.sql.$$
echo "column NUM_SAMPLES format 99999999999999"  >> /var/tmp/ocdoctor.sql.$$
echo "set term off"  >> /var/tmp/ocdoctor.sql.$$
echo "set trim off"  >> /var/tmp/ocdoctor.sql.$$
echo "set trimspool off"  >> /var/tmp/ocdoctor.sql.$$
echo "spool /var/tmp/ocdoctor.sql.out.$$" >> /var/tmp/ocdoctor.sql.$$
echo "select * from (" >> /var/tmp/ocdoctor.sql.$$
echo "	select regexp_substr(rra.resource_attribute_name,'OS_[a-zA-Z]*|ZS_[a-zA-Z]*_[a-zA-Z]*|Server_[a-zA-Z]*|Grp_[a-zA-Z]*|ISA_[a-zA-Z]*') RESOURCE_ATTRIBUTE_NAME, count(*) num_samples" >> /var/tmp/ocdoctor.sql.$$
echo "	from rm_resource_daily_trend rrdt,	rm_resource_attribute rra" >> /var/tmp/ocdoctor.sql.$$
echo "	where rrdt.resource_attribute_id = rra.resource_attribute_id" >> /var/tmp/ocdoctor.sql.$$
echo " 	group by regexp_substr(rra.resource_attribute_name,'OS_[a-zA-Z]*|ZS_[a-zA-Z]*_[a-zA-Z]*|Server_[a-zA-Z]*|Grp_[a-zA-Z]*|ISA_[a-zA-Z]*')" >> /var/tmp/ocdoctor.sql.$$
echo " 	order by 2 desc) where  rownum <21;" >> /var/tmp/ocdoctor.sql.$$
echo "spool off" >> /var/tmp/ocdoctor.sql.$$
rm -f /var/tmp/ocdoctor.sql.out.$$

if [ -f /var/tmp/ocdoctor-database-analysis-cache.txt ]; then
	DATEOFFILE=`head -1 /var/tmp/ocdoctor-database-analysis-cache.txt| awk -F"|" '{print $2}'`
	echo "Found an existing cache file with the following timestamp:"
	echo "${DATEOFFILE}"
	echo -n "Do you want to use it? (answering 'no' may take very long but will give up-to-date info) [Y/n] "
	read yesno
    if [ "$yesno" = "no" ]; then
            yesno="n"
    fi
    if [ "$yesno" = "No" ]; then
            yesno="n"
    fi
    if [ "$yesno" = "N" ]; then
            yesno="n"
    fi
    if [ "$yesno" = "n" ]; then
    	echo "Removing cache file."
    	echo ""
    	rm -f /var/tmp/ocdoctor-database-analysis-cache.txt
    else
    	echo "Reusing cache file."
    	echo ""
    fi
fi

if [ ! -f /var/tmp/ocdoctor-database-analysis-cache.txt ]; then
	### Create cache file if doesnt exist
	echo "No cache file found - reading from DB... (next run will be much faster)"
	echo "Please wait, analyzing 'rm_resource_daily_trend' - TOP 20 attributes... (this can take hours on a large DB)"
	echo "@/var/tmp/ocdoctor.sql.$$" | $ECADM sqlplus >/dev/null 2>/dev/null
	CURRENTDATE=`date`
	echo "DATE|$CURRENTDATE" > /var/tmp/ocdoctor-database-analysis-cache.txt
	cat /var/tmp/ocdoctor.sql.out.$$ >> /var/tmp/ocdoctor-database-analysis-cache.txt
fi

OUTPUT=`cat /var/tmp/ocdoctor-database-analysis-cache.txt 2>/dev/null`
	
rm -f /var/tmp/ocdoctor.sql.$$ /var/tmp/ocdoctor.sql.out.$$

echo ""
echo "The following are the top monitored data DB consumers:"
echo ""
COUNT=1
while read LINE; do
	ATTR=`echo $LINE | awk '{print $1}'`
	is_monitored $ATTR
	ATTR_DISPLAY=$ATTR
	if [ "$ATTR" = "OS_CpuUsagePercentage" ]; then
		ATTR_DISPLAY="$ATTR (see note #2)"
	fi
	if [ "$ATTR" = "OS_SystemLoadAvr5" ]; then
		ATTR_DISPLAY="$ATTR (see note #2)"
	fi
	if [ "$ATTR" = "OS_MemoryUsagePercentage" ]; then
		ATTR_DISPLAY="$ATTR (see note #2)"
	fi
	
	SAMPLES=`echo $LINE | awk '{print $2}'`
	if [ "$MONITORED" = "yes" ]; then
		printf "%-3s %-70s %s\n" ${COUNT}\) "${ATTR_DISPLAY}" $SAMPLES
	else
		printf "%-3s %-70s %s\n" ${COUNT}\) "${ATTR_DISPLAY} (Currently NOT Monitored)" $SAMPLES
	fi
	let COUNT++
done < <(printf "$OUTPUT\n" | grep "_" | grep -v NUM_SAMPLES | grep -v DATE)

#if [ $COUNT -lt 21 ]; then
#	echo ""
#	echo "WARNING: There are less than 20 entries - which means this script was not able to capture one of the attributes."
#	echo "         Please contact support to assist with identifying the missing attribute."
#	echo ""
#fi
echo ""
echo "IMPORTANT NOTE: Disabling certain attributes may cause some charts to not display data in the user interface."
echo ""
echo "NOTE #2: The attributes OS_CpuUsagePercentage, OS_SystemLoadAvr5 and OS_MemoryUsagePercentage are used by"
echo "         the server pool placement policies and should not be disabled or deleted."
echo ""
echo -n "Type the number you wish to stop monitoring or delete data: "
read CONT

if [ "$CONT" = "" ]; then
	echo "Aborted."
	echo ""
	exit
fi

if [ ! "$CONT" = "" ] && [ $CONT -gt 0 ] && [ $CONT -lt 21 ]; then
	echo ""
	COUNT=1
	OUTPUT=`cat /var/tmp/ocdoctor-database-analysis-cache.txt 2>/dev/null`
	while read LINE; do
		if [ $COUNT -lt 21 ]; then
			if [ $COUNT -eq $CONT ]; then
				ATTR=`echo $LINE | awk '{print $1}'`
				is_monitored $ATTR
				if [ "$MONITORED" = "yes" ]; then
					echo "Attribute '$ATTR' was selected."
					echo ""
					echo "Enter 's' to stop monitoring it"
					echo "  OR  "
					echo "Enter 'd' to delete the data already in the database for this attribute"
					echo "      You may delete the data after you stop monitoring it"
					echo ""
					echo -n "Your selection? [s]/[d]/[anything else to exit] "
				else
					echo ""
					echo "Attribute $ATTR was selected, and it is already not monitored"
					echo "Enter 'd' to delete the data already in the database for this attribute"
					echo ""
					echo -n "Your selection? [d]/[anything else to exit] "
				fi
				COUNT=21
				ATTRTOWORKON=$ATTR
			fi
		fi
		let COUNT++	
	done < <(printf "$OUTPUT\n" | grep "_" | grep -v NUM_SAMPLES | grep -v DATE)
	
	read STOPORDELETE
	
	if [ "$STOPORDELETE" = "d" ]; then
		###### DELETE HERE ######
		echo ""
		echo -n "Are you sure you want to delete the data of the attribute '$ATTRTOWORKON'? [N/y] "
		read yesno
	    if [ "$yesno" = "yes" ]; then
	            yesno="y"
	    fi
	    if [ "$yesno" = "Y" ]; then
	            yesno="y"
	    fi
	    if [ "$yesno" = "y" ]; then
	    	echo ""
			delete_attribute_data_from_db $ATTRTOWORKON
		else
			echo "Aborted."
			echo ""
		fi
		exit
	fi
	if [ "$STOPORDELETE" = "s" ]; then
		###### STOP MONITORING HERE ######
		echo ""
		echo -n "Are you sure you want to disable monitoring of the attribute '$ATTRTOWORKON'? [N/y] "
		read yesno
	    if [ "$yesno" = "yes" ]; then
	            yesno="y"
	    fi
	    if [ "$yesno" = "Y" ]; then
	            yesno="y"
	    fi
	    if [ "$yesno" = "y" ]; then
	    	echo ""
			remove_attribute_from_xml $ATTRTOWORKON
		else
			echo "Aborted."
			echo ""
		fi
		exit
	fi

fi


