#!/bin/bash
#
# Usage: findlog search_string [lines-to-show]
#        findlog 
#
# Purpose: find log files with matching search string
#
#
# Copyright 2010 Sun Microsystems, Inc. All rights reserved.
# Use is subject to license terms.
#
# Author: Juergen.Fleischer@sun.com
# 
# Version 1.3 (2010/04/19)
#

LINES_TO_SHOW=3


LOGFILES=/tmp/_xvmoc_logfiles_

# /var/adm/messages
ls /var/adm/messages 2>/dev/null > $LOGFILES
ls /var/log/messages  2>/dev/null >> $LOGFILES

# Tomcat Application Server
find /var/opt/sun/xvm/bui/logs/ -type f -name '*.log' 2>/dev/null >> $LOGFILES
find /var/opt/sun/xvm/bui/logs/ -type f -name '*.out' 2>/dev/null >> $LOGFILES

# scportal application
find /var/opt/sun/xvm/ajaxterm/logs/ -type f -name '*.log' 2>/dev/null >> $LOGFILES

# cacao container logs
find /var/cacao/instances/*/logs -type f -name 'cacao.[0-9]'  2>/dev/null >> $LOGFILES
find /var/opt/sun/cacao2/instances/*/logs -type f -name 'cacao.[0-9]'  2>/dev/null >> $LOGFILES

# Proxy DB logs
ls /var/cacao/instances/scn-proxy/derby.log 2>/dev/null >> $LOGFILES
ls /var/opt/sun/cacao2/instances/scn-proxy/derby.log 2>/dev/null >> $LOGFILES

# xvm logs
find /var/opt/sun/xvm/logs/ -type f -name '*.log' 2>/dev/null >> $LOGFILES

# HA logs
find /var/opt/sun/xvm/ha/ -type f -name '*.log' 2>/dev/null >> $LOGFILES

# xvm DB logs
find /var/opt/sun/xvm/db/mgmt/logs/ /var/opt/sun/xvm/db/report/logs/ -type f -name '*.log' 2>/dev/null >> $LOGFILES

# UCE logs
find /var/opt/sun/xvm/uce/var.opt/*/logs -type f -name '*.log' 2>/dev/null >> $LOGFILES
find /var/opt/sun/xvm/uce/var.opt/server/logs/uce_server -type f -name '*_log' 2>/dev/null >> $LOGFILES

# OSP los
find /var/opt/sun/xvm/osp/logs/ -type f -name '*.log' 2>/dev/null >> $LOGFILES

TMPFILE=/tmp/__tmpfile__

if [ $# -eq 0 ] 
then
  echo
  echo Usage: $(basename $0) search_string [# of matching lines]
  echo 
  echo Purpose: find log files with \"search_string\" \(case insensitive, regexp is fine\)
  echo
  echo By default show the last $LINES_TO_SHOW matching lines per file
  echo
  echo The following log files will be egrep\'ped:
  echo
  cat $LOGFILES
  echo
else
  cat $LOGFILES | while read logfile
  do
    if [ -f "$logfile" ]
    then
      egrep -i -e "$1" $logfile > $TMPFILE
      if [ $? -eq 0 ]
      then
        echo "+++ Log file: $logfile +++"
        echo 
        tail -${2:-$LINES_TO_SHOW} $TMPFILE
        echo 
      fi
    fi
  done
fi

rm -f $LOGFILES $TMPFILE
