#!/bin/sh

# This script will take a brand new agent bundle and will insert it to the local Solaris 11 repository

# Note that this script currently expects the Agent IPS ZIP to be in /var/opt/sun/xvm/images along with this script. 
# So to execute, first copy this script there:
# cp -p ./publish_S11_agent_to_local_repo.sh /var/opt/sun/xvm/images/
# cd /var/opt/sun/xvm/images
#
# Then, move the ZIP file to the images folder, for example:
# mv agent/OpsCenterAgent.SolarisIPS.all.12.1.1.2083.zip .
#
# Then, run the script, for example:
# ./publish_S11_agent_to_local_repo.sh OpsCenterAgent.SolarisIPS.all.12.1.1.2083.zip
#
# This will create a smaller (19-20K) ZIP file in the /var/opt/sun/xvm/images/agent along with a new signature file.
#

BASE_DIR=/var/opt/sun/xvm
IMAGE_DIR=$BASE_DIR/images
IPS_DIR=$IMAGE_DIR/IPS
AGENT_IMAGE_DIR=$IMAGE_DIR/agent

cd $IMAGE_DIR

if [ $# -ne 1 ]; then
    echo "Error $#: no AC wad supplied"
    exit 1
fi

# name of IPS AC zip wad
AC_WAD=$1

AC_ARCHIVE=ac-archive.p5p
AC_ARCHIVE_IN_WAD=OpsCenterAgent/$AC_ARCHIVE

if [ -f $IPS_DIR/$AC_ARCHIVE ]; then
    echo "mv $IPS_DIR/$AC_ARCHIVE $IPS_DIR/$AC_ARCHIVE.old"
    mv $IPS_DIR/$AC_ARCHIVE $IPS_DIR/$AC_ARCHIVE.old
fi

rm -rf $IMAGE_DIR/OpsCenterAgent

echo "unzip -q $AC_WAD $AC_ARCHIVE_IN_WAD"
/usr/bin/unzip -q $AC_WAD $AC_ARCHIVE_IN_WAD

mv $AC_ARCHIVE_IN_WAD $IPS_DIR
rm -rf OpsCenterAgent

echo "zip -q -d $AC_WAD $AC_ARCHIVE_IN_WAD -O $IMAGE_DIR/$AC_WAD"
/usr/bin/zip -q -d $AC_WAD $AC_ARCHIVE_IN_WAD -O $AGENT_IMAGE_DIR/$AC_WAD

echo "digest -a sha1 $AGENT_IMAGE_DIR/$AC_WAD > $AGENT_IMAGE_DIR/$AC_WAD.sig"
/usr/bin/digest -a sha1 $AGENT_IMAGE_DIR/$AC_WAD > $AGENT_IMAGE_DIR/$AC_WAD.sig

# create the local AC file repo

AC_REPO=$AGENT_IMAGE_DIR/ac-ips-repo

rm -rf $AC_REPO

echo "/usr/bin/pkgrepo create $AC_REPO"
/usr/bin/pkgrepo create $AC_REPO

echo "/usr/bin/pkgrecv -s $IPS_DIR/$AC_ARCHIVE -d $AC_REPO '*'"
/usr/bin/pkgrecv -s $IPS_DIR/$AC_ARCHIVE -d $AC_REPO '*'

# now push the AC pkgs to the MSR

# MSR pkg server
PKG_SERVER=application/pkg/server
PKG_SERVER_INST=${PKG_SERVER}:default

IPS_ROOT="$(/usr/bin/svcprop -c -p pkg/inst_root $PKG_SERVER_INST)"

if /usr/bin/pkgrepo info -s "$IPS_ROOT" >/dev/null 2>&1; then
	echo "IPS_ROOT: $IPS_ROOT"
else
	# we will try it again, this time without the default instance part
	IPS_ROOT="$(/usr/bin/svcprop -c -p pkg/inst_root $PKG_SERVER)"
	if /usr/bin/pkgrepo info -s "$IPS_ROOT" >/dev/null 2>&1; then
		echo "IPS_ROOT: $IPS_ROOT"
	else
		echo "ERROR: Unable to obtain the path to the Solaris 11 MSR"
		echo "ERROR: Manual upload of Agent pkgs are required by running the command"
		echo "ERROR: pkgrecv -s $IPS_DIR/$AC_ARCHIVE -d path/to/MSR '*' "
		exit 1
	fi
fi

echo "pkgrecv -s $IPS_DIR/$AC_ARCHIVE -d $IPS_ROOT '*'"
/usr/bin/pkgrecv -s $IPS_DIR/$AC_ARCHIVE -d $IPS_ROOT '*'

# now restart the service
/usr/sbin/svcadm restart $PKG_SERVER_INST

exit 0
