#!/bin/bash
#
# remove-old-stuff.sh
#
# Version 1.0 (2015/09/01)
#
#set -x
usage(){
    cat << EOF

	Usage: $PROG [ --force | -f ] [ --help | -h ]

	Use this command/script to delete old stuff like backup folders from previous updates, etc.

	Use option '--force' to skip the confirmation for the actual removal of detected files/folders

EOF
    exit 0
}

#############################################################################################################

remove_temp_files(){

    rm -f $REMOVEME $EMPTYME $DISK_USAGE_DETAILS
    exit
}

trap remove_temp_files SIGHUP SIGINT SIGTERM

add_old_update_dirs(){
    # we will keep only the current listed product.installLocation
    
    ls -dtr /var/opt/sun/xvm/*Controller_installer*/ ${UPDATE_SAVED_STATE}/*/ 2>/dev/null | grep -v "$PRODUCT_DIR" 2>/dev/null >> $REMOVEME

#
#    if we want to keep more backup directories, this code can be used instead of the above line
#
#    NO_OF_INSTALL_AND_BACKUP_DIRS=$(ls -d /var/opt/sun/xvm/*Controller_installer*/ ${UPDATE_SAVED_STATE}/*/ 2>/dev/null | wc -l)
#
#    if [ $NO_OF_INSTALL_AND_BACKUP_DIRS -gt 2 ]; then
#       ls -dtr /var/opt/sun/xvm/*Controller_installer*/ ${UPDATE_SAVED_STATE}/*/ 2>/dev/null | grep -v "$PRODUCT_DIR" 2>/dev/null | head -$(( $NO_OF_INSTALL_AND_BACKUP_DIRS - 2 )) >> $REMOVEME
#    fi
#

}

add_old_ec_pc_ac_bundles(){
    
    EC_PC_BUNDLES=${IMAGES_DIR}/productUpdate
    PC_BUNDLE_LINKS=${IMAGES_DIR}/proxy
    AC_BUNDLES=${IMAGES_DIR}/agent

    # EC Bundles
    # we only need to keep an enterprise-controller bundle if we have not yet upgraded the EC
    COUNT=$(ls ${EC_PC_BUNDLES}/enterprise-controller*.zip 2>/dev/null | wc -l)
    if [ "$COUNT" -eq 1 ]; then
	if ls ${EC_PC_BUNDLES}/enterprise-controller*.zip | grep $PRODUCT_VERSION >/dev/null; then
	    # we can delete it since we are already running this version
	    ls ${EC_PC_BUNDLES}/enterprise-controller*.zip* >> $REMOVEME
	fi
    elif [ "$COUNT" -gt 1 ]; then
	if ls ${EC_PC_BUNDLES}/enterprise-controller*.zip | tail -1 | grep $PRODUCT_VERSION >/dev/null; then
	    # we can delete all of them since we are already running the version of the latest one
	    ls ${EC_PC_BUNDLES}/enterprise-controller*.zip* >> $REMOVEME
        else
	    # we have to keep the last one
	    LATEST_BUNDLE=$(ls ${EC_PC_BUNDLES}/enterprise-controller*.zip | tail -1)
            ls ${EC_PC_BUNDLES}/enterprise-controller*.zip* | grep -v "$LATEST_BUNDLE" >> $REMOVEME
	fi
    fi

    # PC Bundles
    # we can remove all bundles but the latest one for each platform
    for PLATFORM in Linux.i686 Solaris.i386 Solaris.sparc
    do
        COUNT=$(ls ${EC_PC_BUNDLES}/proxy-controller.${PLATFORM}.*.zip 2>/dev/null | wc -l)
        ls ${EC_PC_BUNDLES}/proxy-controller.${PLATFORM}.*.zip 2>/dev/null | head -$(( $COUNT -1 )) | while read FILENAME
	do
	    echo "$FILENAME" >> $REMOVEME
	    echo "$FILENAME" | sed "s@${EC_PC_BUNDLES}@${PC_BUNDLE_LINKS}@" >> $REMOVEME
	done
    done

    # AC Bundles
    # we will remove all Agent bundles but will keep the latest and previous version for each platform
    for PLATFORM in Linux.i686 Solaris.i386 Solaris.sparc SolarisIPS.all
    do
	PREVIOUS_VERSION_WO_BUILD=$(ls ${AC_BUNDLES}/OpsCenterAgent.${PLATFORM}.*.zip 2>/dev/null | grep -v "${PRODUCT_VERSION_WO_BUILD}" | tail -1 | cut -d. -f4-6)
	ls ${AC_BUNDLES}/OpsCenterAgent.${PLATFORM}.*.zip* 2>/dev/null | egrep -v "${PRODUCT_VERSION_WO_BUILD}|${PREVIOUS_VERSION_WO_BUILD}" >> $REMOVEME
    done
    
}

add_old_DB-Files(){

    # check directory /var/tmp/downloads for no longer required Oracle DB files
    DOWNLOAD_DIR=/var/tmp/downloads

    # we will use function get_version() to define the integer variable VERSIONNUM
    get_version    # this defines VERSIONNUM like e.g. VERSIONNUM=12301407

    # 11.2.0.3 files are no longer needed when EC is running 12.2.2 or higher
    # 11.2.0.4 files are no longer needed when EC is running 12.3.1 or higher

    if [ "$VERSIONNUM" -gt 12220000 ]; then
	ls ${DOWNLOADS}/p10404530_* 2>/dev/null >> $REMOVEME
    fi

    if [ "$VERSIONNUM" -gt 12310000 ]; then
	ls ${DOWNLOADS}/p13390677_* 2>/dev/null >> $REMOVEME
    fi

}

add_jet_leftovers(){

    # leftovers from failed/interrupted Solaris 10 OSP Jobs
    ls -d /opt/SUNWjet/Clients/* 2>/dev/null | egrep -v /common.files >> $REMOVEME

}

add_agent_files(){

    # add leftovers from UCE Agent (Solaris 8 - 10 and Linux)
    [ "$UNAME" = "Solaris" ] && [ "$UNAME_MIN_REL" -gt 10 ] && return 0

    if ls ${UPDATE_AGENT}/blobs/* >/dev/null 2>&1; then
        echo "${UPDATE_AGENT}/blobs" >> $EMPTYME
    fi
    ls -d ${UPDATE_AGENT}/config_files/.Job_* >> $REMOVEME 2>/dev/null

} 

show_disk_usage(){

    $DRYRUN || printf "\nList of files/directories to get removed / cleaned up:\n\n"

    cat $REMOVEME $EMPTYME | while read ITEM
    do
	du -sk $ITEM 2>/dev/null
    done >$DISK_USAGE_DETAILS

    if $DRYRUN; then 
	$AWK 'BEGIN {SUM=0}
        {SUM=SUM+$1}
        END {print SUM}' $DISK_USAGE_DETAILS
    else
	$AWK 'BEGIN {SUM=0}
        {SUM=SUM+$1; $1=""; print}
        END {SUM_MB = SUM / 1024; SUM_GB = SUM_MB / 1024; printf "\nTotal size of files/directories = %d KB / %.1f MB / %.1f GB\n\n", SUM, SUM_MB, SUM_GB}' $DISK_USAGE_DETAILS
    fi
}

#####################################################################################
#
# main program starts here
#
#####################################################################################

if [ -z "$OCDOCTOR" ]; then
    PROG=$(basename $0)
else
    PROG="OCDoctor.sh --cleanup"
fi

DRYRUN=false
FORCE=false
# -------- Reading params -------
for ARG in "$@"
do
    case $ARG in
        --force | -f )
            FORCE=true
            ;;
        --dryrun )
	    # used by OCDoctor to just get a size in KB of wasted disk space
            DRYRUN=true
            ;;
        * )
	    usage
	    ;;
    esac
done

UNAME=$(uname)
UNAME_MIN_REL=$(uname -r |cut -d. -f2)
if [ "$UNAME" = "Linux" ]; then
    OC_BIN=/opt/sun/xvmoc/bin
    CACAO_LOGS=/var/opt/sun/cacao2/instances
    UPDATE_AGENT=/var/opt/sun/scn/update-agent
    UPDATE_AGENT_SAVED_STATE=/var/opt/sun/scn/update-saved-stateyy
    AWK=/usr/bin/awk
else
    OC_BIN=/opt/SUNWxvmoc/bin
    CACAO_LOGS=/var/cacao/instances
    UPDATE_AGENT=/var/scn/update-agent
    UPDATE_AGENT_SAVED_STATE=/var/scn/update-saved-stateyy
    AWK=/usr/bin/nawk
fi

#######################################
# various definitions
#######################################

PROG_DIR=$(cd $(dirname $0); pwd)
FUNCTIONS="${PROG_DIR}/../functions"
CURRENT_DIR=$(pwd)
VERSION_PROPERTIES=/n1gc-setup/.version.properties
PRODUCT_DIR=$($AWK -F= '/^product.installLocation/ {print $2}' $VERSION_PROPERTIES 2>/dev/null | sed 's@/distribution$@@')
PRODUCT_VERSION=$($AWK -F= '/^product.version/ {print $2}' $VERSION_PROPERTIES 2>/dev/null)
PRODUCT_VERSION_WO_BUILD=$(echo $PRODUCT_VERSION | cut -d. -f1-3)
OC_BASE=/var/opt/sun/xvm
OC_DUMPDIR=/var/tmp/ocdumpdir
UPDATE_SAVED_STATE=${OC_BASE}/update-saved-state
IMAGES_DIR=${OC_BASE}/images
JET_CLIENT=/opt/SUNWjet/Clients
ECADM=${OC_BIN}/ecadm
PROXYADM=${OC_BIN}/proxyadm
AGENTADM=${OC_BIN}/agentadm
AGENT_VERSION=$($AGENTADM junk 2>/dev/null | $AWK '/agentadm: Version/ {print $3}')

DISK_USAGE_DETAILS=/tmp/disk_usage_details.$$
REMOVEME=/tmp/remove-this-dirs-and-files.$$
EMPTYME=/tmp/emptx-this-dirs.$$
touch $REMOVEME $EMPTYME

# we will source now the common OCDoctor functions
if [ -f "$FUNCTIONS" ]; then
    . $FUNCTIONS
else
    echo "ERROR: ${PROG}: File $FUNCTIONS not found!"
    exit 1
fi

#
# now we are collecting the names of files and directories to get deleted
# and store them in file $REMOVEME or $EMPTYME
#
IS_AGENT=false
IS_PROXY=false
if [ -x $ECADM ]; then
    if [ "$($PROXYADM status 2>/dev/null)" = "online" ]; then
	IS_PROXY=true
    fi
    # this is an EC, eventually with a colocated PC
    $DRYRUN || echo "Cleaning up Ops Center Enterprise Controller Version ${PRODUCT_VERSION}" 

    add_old_update_dirs

    add_old_ec_pc_ac_bundles

    add_old_DB-Files

    # disabling it for now, I should make it optional 
    #add_jet_leftovers

    add_agent_files

elif [ -x $PROXYADM ]; then
    IS_PROXY=true
    # this is a remote PC
    $DRYRUN || echo "Cleaning up Ops Center Proxy Controller Version ${PRODUCT_VERSION}" 

    add_old_update_dirs

    # disabling it for now, I should make it optional 
    #add_jet_leftovers

    add_agent_files

elif [ -x $AGENTADM ]; then
    IS_AGENT=true
    # this is an AC/VC
    $DRYRUN || echo "Cleaning up Ops Center Agent Controller Version ${AGENT_VERSION}" 

    add_agent_files

fi

if [ "$(cat $REMOVEME $EMPTYME | wc -l)" -eq 0 ]; then
    if $DRYRUN; then
	echo "0"
    else
        printf "\nAll good, nothing there to clean up!\n\n"
    fi
else    
    show_disk_usage

    if ! $DRYRUN; then
	if ! $FORCE; then
	    if $IS_AGENT; then
		echo
		echo "Ensure that there is no Update Provisioning Job running for the Agent right now!"
	    elif $IS_PROXY; then
		echo
           	echo "Ensure that there is no OS Provisisoning Job running using this Proxy Controller right now!"
            fi
	    echo
	    echo "Please review the list and press <ENTER> to continue or ^C to abort ..."
	    read junk
	fi

        # for debugging purposes only
	#DEBUG=echo
	DEBUG=""

	printf "\nDeleting items, please be patient "
	while read LINE
	do
	    printf "."
	    $DEBUG rm -rf $LINE
	done < $REMOVEME
	while read LINE
	do
	    printf "."
	    $DEBUG rm -rf ${LINE}/*
	done < $EMPTYME
	printf " done\n\nNote: In case of further Boot Environments, you may not see any increase in free disk space until the other BEs got destroyed!\n\n"
    fi
fi    

remove_temp_files
