#!/bin/ksh
CSV="NO"
VERSION="0.6"

Elapsed ()
{
START=$1
END=$2
START_HOURS=${START:%%:*}
START_MIN=${START:%:*}
START_MIN=${START_MIN:##*:}
START_SEC=${START:##*:}
END_HOURS=${END:%%:*}
END_MIN=${END:%:*}
END_MIN=${END_MIN:##*:}
END_SEC=${END:##*:}

START_HOURS_SEC=$((START_HOURS * 3600 ))
START_MIN_SEC=$((START_MIN * 60 ))
START_SEC_TOTAL=$((START_HOURS_SEC + START_MIN_SEC + START_SEC ))

END_HOURS_SEC=$((END_HOURS * 3600 ))
END_MIN_SEC=$((END_MIN * 60 ))
END_SEC_TOTAL=$((END_HOURS_SEC + END_MIN_SEC + END_SEC ))

if [ ${END_SEC_TOTAL} -ge ${START_SEC_TOTAL} ]
	then
	ELAPSED_SEC=$((END_SEC_TOTAL - START_SEC_TOTAL))
	else
	END_SEC_TOTAL=$((END_SEC_TOTAL + 86400 ))
	ELAPSED_SEC=$((END_SEC_TOTAL - START_SEC_TOTAL))
fi

echo ${ELAPSED_SEC}
}

Delta_Percent ()
{
if [ ${PREV_ELAPSED} -ne 0 ]
	then
	PERCENT=$((ELAPSED * 100 ))
	PERCENT=$((PERCENT / PREV_ELAPSED))
	PERCENT=$((PERCENT -100))
	else
	PERCENT="-"
fi
echo ${PERCENT}
}


Report ()
{
SERVICE=$1
shift
TYPE=$*
# Locate the log file for the SMF service
svcs -l ${SERVICE} 2>/dev/null|grep logfile|read DISCARD LOG DISCARD
# Check we can actually find the log file value
if [ ! -z ${LOG} ]
	then
	# Check we can actually find the log file
	if [ -f ${LOG} ]
		then
		# print out the required header
		if [ "${CSV}" == "NO" ]
			then
			echo "************ Analyzing Historical ${TYPE} Startup Times ************"
			else
			echo "Type,Startup Time,Elapsed Time,Delta Seconds,Delta Percent"
		fi
		# Unset the variable [PREV_ELAPSED] so we don't get carry over on combined EC/PC
		unset PREV_ELAPSED
		cat ${LOG}|
		while
			read BR MONTH DAY TIME PARAM1 PARAM2 IGNORE
		do
			if [ "${PARAM1} ${PARAM2}" == "Executing start" ]
				then
				START_MONTH=${MONTH}
				START_DAY=${DAY}
				START_TIME="${TIME}"
			fi
			if [ "${PARAM1} ${PARAM2}" == "Method \"start\"" ]
				then
				ELAPSED="`Elapsed ${START_TIME} ${TIME}`"
				if [ -z ${PREV_ELAPSED} ]
					then
					PREV_ELAPSED="${ELAPSED}"
				fi
				DELTA_PERCENT=`Delta_Percent`

				if [ "${CSV}" == "NO" ]
					then
					printf "Startup @ %2s %s %s - Elapsed time: %6ss  [Delta: %6ss / %6s%s]\n" ${START_DAY} ${START_MONTH} ${START_TIME} ${ELAPSED} $((ELAPSED - PREV_ELAPSED)) ${DELTA_PERCENT} %
					else
					echo "${TYPE},${START_DAY},${START_MONTH},${START_TIME},${ELAPSED},$((ELAPSED - PREV_ELAPSED)),${DELTA_PERCENT}"
				fi
				PREV_ELAPSED="${ELAPSED}"
			fi
		done
		else
		echo "ERROR: Could not find log file [${LOG}]"
	fi
	#allow a little space between the EC/PC/AC
	echo
	echo
fi
}

Usage ()
{
echo "Usage: `basename $0` [-c|--csv]
		-c|--csv	# Prints the report output as a csv file instead of human readable

		This script reports the startup times and deltas for Ops Center EC, PC and AC components."
exit 1
}

Module_Startup ()
{
SERVICE=$1
shift
LABEL=$*
# if we are running an EC/PC collect the module startup times
# Check for the SMF services
svcs -l ${SERVICE} 2>/dev/null|grep logfile|read DISCARD LOG DISCARD
# Check we can actually find the log file value
if [ ! -z ${LOG} ]
        then
	#Set the Controller type
	case ${SERVICE} in
		oem-ec) # Enterprise controller
			CONTROLLER=s
			;;
		scn-proxy) # Enterprise controller
			CONTROLLER=p
			;;
		scn-agent) # Enterprise controller
			CONTROLLER=a
			;;
	esac
	if [ "${CSV}" == "NO" ]
		then
		echo "************ Analyzing Current ${LABEL} Module Startup Times ************"
		/opt/sun/xvm/bin/jmxdump ${CONTROLLER} t root wellknown com.sun.cacao:type=com.sun.cacao.CacaoMBean Stats 2>/dev/null|grep -v ObjectName|grep -v ^\*|egrep 'com.|Seconds'|sed -e 's/^[ \t]*//'|grep -v "^0"
		else
		/opt/sun/xvm/bin/jmxdump ${CONTROLLER} t root wellknown com.sun.cacao:type=com.sun.cacao.CacaoMBean Stats 2>/dev/null|grep -v ObjectName|grep -v ^\*|egrep 'com.|Seconds'|
		while
			read Seconds Module
		do
			echo "${LABEL},${Seconds},${Module}"
		done
	fi
	#allow a little space between the EC/PC/AC
	echo
	echo
fi
}

#
## Main ##
#
case $1 in
	-c|--csv) 
		# generate output in CSV format
	 	CSV="YES"
		;;
	-?|--help) 
		# catchall - print usage message
		Usage
		;;
esac
# Check if we are running on Solaris or Linux... this script only works on Solaris
if [ "`uname -s`" != "SunOS" ]
	then
	echo "ERROR: Sorry this script can only report times on Solaris systems as it uses SMF timings."
	exit 2
fi
# Check if we are running as root so all the jmxdump stuff works
if [ "`whoami`" != "root" ]
	then
	echo "ERROR: Sorry this script should be run as root so that it can read all the required data."
	exit 3
fi
Report oem-ec Enterprise Controller
Report scn-proxy Proxy Controller
Report scn-agent Agent Controller
Module_Startup oem-ec Enterprise Controller
Module_Startup scn-proxy Proxy Controller
Module_Startup scn-agent Agent Controller
