#!/bin/sh
#
# restart_agent
#
# Pre-/Post-Action script to restart an Ops Center 2.x Agent
#
# Copyright 2010 Sun Microsystems, Inc. All rights reserved.
# Use is subject to license terms.
#
# Author: Juergen.Fleischer@sun.com
#
# Version 1.0 2010/06/10
#

# log files
LOGFILE=/var/tmp/agent_restart.log.$$

# TIMEOUT  (grace period to wait after 'at job' has been submitted before restarting the agent)
TIMEOUT=300

Log(){
  # copy log entry to logfile and stdout
  printf "$* \n\n" | tee -a $LOGFILE
}

Log "Starting agent restart ..."

AT=`which at`
if [ ! -x "$AT" ]
then
  Log "Required program 'at' not found, exiting!"
  exit 1
fi

# verify if 'at' is working as expected
TESTFILE=/tmp/_patch_agent_test_file_
Log "Submitting a test command via 'at'"
echo "touch $TESTFILE" | $AT now >> $LOGFILE 2>&1
error_code=$?
if [ $error_code -ne 0 ]
then
  Log "Error: 'at' command exited with exit code: $error_code"
  exit 1
fi
# OK, at -job has been submitted. We will give it some seconds and then we will check it
sleep 5
if [ ! -f $TESTFILE ]
then
  Log "Error: 'at' command was not able to run test command. Check emails of user 'root' for more details."
  exit 1
else
  Log "'at' test has been successful!"
  rm $TESTFILE  
fi

# check OS
if uname -a | grep Linux > /dev/null
then
  LINUX=true
  SOLARIS=false
  AGENTADM=/opt/sun/xvmoc/bin/agentadm
  START_AGENT="$AGENTADM start"
  STOP_AGENT="$AGENTADM stop"
else
  LINUX=false
  SOLARIS=true
  AGENTADM=/opt/SUNWxvmoc/bin/agentadm
  START_AGENT="$AGENTADM start"
  STOP_AGENT="$AGENTADM stop"
fi


# now we have to create the actual restart script, dependent on OS and Agent version
# (for trouble shooting reasons, we will not remove it later on)

EXEC_SCRIPT=/var/tmp/exec_agent_restart

cat > $EXEC_SCRIPT <<EOF
#!/bin/sh

printf "Starting script to restart agent ...\n\n" >> $LOGFILE
printf "Waiting $TIMEOUT seconds to allow job to finish and upload job log to server even on very slow machines.\n\n" >> $LOGFILE

# let's give the agent time to finish job
sleep $TIMEOUT


printf "Stopping agent.\n\n" >> $LOGFILE
$STOP_AGENT >> $LOGFILE 2>&1

printf "Starting agent.\n\n" >> $LOGFILE
$START_AGENT >> $LOGFILE 2>&1

EOF

Log "Successfully created agent restart script $EXEC_SCRIPT ..."

chmod 700 $EXEC_SCRIPT
cd /tmp

# submit restart script via "at now"
echo "$EXEC_SCRIPT" | at now  >> $LOGFILE 2>&1
result=$?

if [ $result -eq 0 ]
then
  Log "Successfully submitted restart script via 'at'. "
  Log "Actual restart will be performed in $TIMEOUT seconds."
  Log "Verify correct restart in file $LOGFILE ."
else
  Log "Could not submit restart job via 'at' !'"
  Log "'at' command exited with error code: $result !" 
  exit $result
fi
