#!/bin/bash
#
# OCDoctor/toolbox/s11_install_java_1.6.0_65.sh
#
# This script is targeted for Enterprise and Proxy Controllers running Solaris 11.1.15.4.0 (aka SRU 15) or higher
#
# It will replace Java version 1.6.0_71 or higher with 1.6.0_65 which is supported for a Proxy Controller
#
# Version: 1.1 (2014-03-26)
# Author: juergen.fleischer@oracle.com
#

PKG=/usr/bin/pkg
JDK6_INCORPORATION=consolidation/ub_javavm-6/ub_javavm-6-incorporation
INC_VERSION=1.6.0.65.0-0
PKG_VERSION=1.6.0.65,5.11-0.175.1.12.0.5.0
SRU_VERSION=0.5.11-0.175.1.12.0.5.0

UPDATE_LIST="$JDK6_INCORPORATION@$INC_VERSION consolidation/ub_javavm/ub_javavm-incorporation@$SRU_VERSION"
INSTALL_LIST=""
JAVA_PKG="runtime/java"
JRE_PKG="runtime/java/jre-6"
DEV_PKG="developer/java/jdk-6"
DEMO_PKG="library/java/java-demo-6"

if [ ! -x $PKG ]; then
	echo
	echo "This script is only applicable for systems running Solaris 11, exiting ..."
	echo
	exit 1
fi

JAVA6_PROC="$(ps -ef|grep '1\.6\.0.*java ')"
if [ -n "$JAVA6_PROC" ]; then
	echo
	echo "WARNING: There is a running Java 6 process:"
	echo
	echo $JAVA6_PROC
	echo
	echo "Ensure that all Java 6 related processes are stopped before running this script"
	echo
	exit 1
fi

if $PKG list $DEV_PKG 2>/dev/null 1>&2; then
	# we have to add the developer package to the update list
	UPDATE_LIST="$UPDATE_LIST $DEV_PKG@$PKG_VERSION"
fi

if $PKG list $DEMO_PKG 2>/dev/null 1>&2; then
	# we have to add the demo package to the update list
	UPDATE_LIST="$UPDATE_LIST $DEMO_PKG@$PKG_VERSION"
fi

if $PKG list $JAVA_PKG 2>/dev/null 1>&2; then
	# we have to add the package runtime/java to the update list
	UPDATE_LIST="$UPDATE_LIST $JAVA_PKG@$PKG_VERSION"
else
	# we have to add the package runtime/java to the install list
	INSTALL_LIST="$INSTALL_LIST $JAVA_PKG@$PKG_VERSION"
fi

if $PKG list $JRE_PKG 2>/dev/null 1>&2; then
	# we have to add the package runtime/java/jre-6 to the update list
	UPDATE_LIST="$UPDATE_LIST $JRE_PKG@$PKG_VERSION"
else
	# we have to add the package runtime/java/jre-6 to the install list
	INSTALL_LIST="$INSTALL_LIST $JRE_PKG@$PKG_VERSION"
fi


INSTALLED_INC=$($PKG list -H $JDK6_INCORPORATION 2>/dev/null | awk -F. '{print $4}')

if [ -n "$INSTALLED_INC" ]; then
	# ok, we are on S11.1 SRU15 or greater
	if [ $INSTALLED_INC -ge 71 -a $INSTALLED_INC -le 74 ]; then
		# ok, we have a broken Java 6 installed
		# check if the IPS Repository contains version 65
		if $PKG list -af $UPDATE_LIST $INSTALL_LIST 2>/dev/null 1>&2; then
			echo 
			echo "All required Java 1.6.0_65 packages were found in the IPS repository, press <RETURN> to continue with installation..."
			read junk

			# change facet to false
			CMD="$PKG change-facet --no-backup-be facet.version-lock.$JDK6_INCORPORATION=false"
			echo $CMD
			$CMD
			echo

			# update to version 1.6.0_65
			CMD="$PKG update --accept --deny-new-be --no-backup-be $UPDATE_LIST"
			echo $CMD
			$CMD
			echo

			# install missing pkgs of version 1.6.0_65
			if [ -n "$INSTALL_LIST" ]; then
				CMD="$PKG install --accept --deny-new-be --no-backup-be $INSTALL_LIST"
				echo $CMD
				$CMD
				echo
			fi

			# verify installation
			if $PKG list $JRE_PKG@$PKG_VERSION 2>/dev/null 1>&2; then
				echo "Verified a successful installation of Java 1.6.0_65"
				echo
			else
				echo "ERROR: Failed to install Java 1.6.0_65 !!!" 
				echo
				exit 1
			fi
		else
			echo
			echo "ERROR: The Solaris 11 IPS Repository does not contain the required packages to install Java 1.6.0_65 !"
			echo
			echo "       Check the publisher settings or the content of the used IPS Repository."
			echo
			echo "       Required packages:"
			echo
			printf "\t$(echo $UPDATE_LIST $INSTALL_LIST | sed 's/ /\\n\\t/g')\n\n"
			echo
			echo "See MOS Doc ID 1439822.1 for download links of Java 6 version 1.6.0_65 for all platforms"
			echo
			exit 1
		fi
	else
		echo
		echo "The installed Java 6 version is not in the range 1.6.0_71 - 1.6.0_74, nothing to do."
		echo
	fi
else
	echo
	echo "This script is only applicable for systems running Solaris 11.1.15.4.0 (aka SRU 15.4) or higher"
	echo
fi

exit 0
