#!/bin/bash
export PATH=/usr/sbin:/usr/bin:$PATH
export LD_LIBRARY_PATH=/usr/lib:/lib
if [ "$1" = "--fix" ];then
	OCDOCTOR_FIX=1
fi
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        DB_BIN="/opt/sun/scs/sbin/db_tool.pl"
else
        DB_BIN="/opt/SUNWscs/sbin/db_tool.pl"
fi


##### Variables #####
TOOMANY=1500
TODELETE=1000

if [ -f $DB_BIN ]; then
	ERROR=0

	### Check if DB is running ###
        OUTPUT=`$DB_BIN status 2>/dev/null | grep running | awk '{printf("%s %s %s\n",$2,$3,$4)}'`
        if [ "$OUTPUT" = "postmaster is running" ]; then
                DONOTHING=1
        else
                echo "ERROR: Database is not running, can't check for the number of notifications"
                echo ""
                exit
        fi

	### Generated notifications ###
	echo "select count(notification_id) from hd_generated_notifications" | $DB_BIN psql > /var/tmp/db.out.$$ 2>/dev/null
	VERIFY=`grep "(1 row)" /var/tmp/db.out.$$`
        if [ "$VERIFY" = "(1 row)" ]; then
                GENNOTIF=`head -3 /var/tmp/db.out.$$ | tail -1 | awk '{print $1}'`
                rm -f /var/tmp/db.out.$$
        else
                echo "ERROR: Couldn't get number of generated notifications from the database, got the output:"
                cat /var/tmp/db.out.$$
                rm -f /var/tmp/db.out.$$
                exit
        fi
	if [ $GENNOTIF -gt $TOOMANY ];then
                echo "WARNING: Too many generated notifications: $GENNOTIF (recommended < $TOOMANY)"
                ERROR=1
        else
        	echo "OK: Old Generated notifications: $GENNOTIF (lower or equal to $TOOMANY)"
        fi

	if [ "$ERROR" = "1" ]; then
		echo "         This is a known issue (CR 6931298)."
		echo "         This will cause slow performance and in large environments may result in out of memory errors."
		echo ""
		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo "Fixing this automatically..."
			
                        echo "--- Deleting from hd_user_notifications (This may take a long time) ---"
			echo "delete from hd_user_notifications where notification_id not in (select notification_id from hd_generated_notifications order by create_dtt desc limit $TODELETE)" | $DB_BIN psql 2>/dev/null
                        echo "--- Deleting from hd_generated_notifications (This may take a long time) ---"
			echo "delete from hd_generated_notifications where notification_id not in (select notification_id from hd_generated_notifications order by create_dtt desc limit $TODELETE)" | $DB_BIN psql 2>/dev/null
                        echo ""
			echo "Done."
			echo ""
		else
			echo "To fix, you will need to clean the old notifications from the database."
			echo "This will delete all notifications and keep only the last $TODELETE. To do that, run the following:"
			echo ""
			echo "# $DB_BIN psql"
			echo "mgmt=> delete from hd_user_notifications where notification_id not in (select notification_id from hd_generated_notifications order by create_dtt desc limit $TODELETE);"
			echo "mgmt=> delete from hd_generated_notifications where notification_id not in (select notification_id from hd_generated_notifications order by create_dtt desc limit $TODELETE);"
			echo "mgmt=> \q"
			echo ""
			echo "NOTICE: the delete commands may take a few minutes to even a few hours in a big environment."
			echo ""
			echo " OR run again with --fix to automatically fix this:"
			echo " # ./OCDoctor.sh --tuning --fix"
			echo ""
		fi
		PWD=`pwd`
		echo ""
		echo "It is recommended that you run this test weekly. You may add the following to the crontab for automatic cleanups:"
		echo "(This example will run it on Sunday at midnight)"
		echo ""
		if [ -f $PWD/tuning/11/clear_old_notifications.sh ]; then
			echo "0 0 * * 0 $PWD/tuning/11/clear_old_notifications.sh --fix >/dev/null 2>/dev/null"
		else
			echo "0 0 * * 0 <PATH_TO>/clear_old_notifications.sh --fix >/dev/null 2>/dev/null"
		fi
		echo ""
	fi


else
	echo "ERROR: Couldn't find $DB_BIN"
	echo ""
fi



