#!/bin/bash

MY_DIR=`dirname $0`
source $MY_DIR/../../functions

UNAME=`uname`
if [ $UNAME = "Linux" ];then
	export JAVA_HOME=/usr/java/jdk1.6.0_14/
	JMXDUMP="/opt/sun/xvm/lib/jmxdump/jmxdump"
	XMLFILE="/etc/opt/sun/cacao2/instances/default/modules/reportservicemodule.xml"
else
	export JAVA_HOME=/usr/jdk/jdk1.6.0_14/
	JMXDUMP="/opt/sun/xvm/bin/jmxdump"
	XMLFILE="/etc/cacao/instances/default/modules/reportservicemodule.xml"
fi

### Only applies to 1171 and earlier ###
get_version ""		### Provide VERSIONNUM
if [ $VERSIONNUM -gt "2501171" ];then
        echo "OK - This tuning is for version 1171 or earlier, this is $VERSION"
        exit
fi

### First check reportservicemodule.xml to see if report services are disabled
OUTPUT=`grep reportservicemodule $XMLFILE | grep UNLOCKED`
if [ "$OUTPUT" = "" ]; then
	echo "OK: Report services are disabled in reportservicemodule.xml, no need to change rollup timing"
	exit
fi

echo "Checking rollup timing..."
printf "Enter Ops Center admin username (Enter to skip): "
read username
if [ "$username" = "" ];then
	echo "Skipping..."
	exit
fi
printf "Password (hidden while you type): "
stty -echo
read password
stty echo
echo ""
echo "Please wait..."
rm -f /var/tmp/jmxdump-rollup.out

$JMXDUMP s t $username $password com.sun.cacao.instrum:* > /var/tmp/jmxdump-rollup.out 2>&1

### Check authentication ###
OUTPUT=`grep "authentication failure" /var/tmp/jmxdump-rollup.out`
if [ "$OUTPUT" = "" ]; then
	echo "Authenticated OK"
else
	echo "ERROR: wrong credentials, please try again"
	echo
	rm -f /var/tmp/jmxdump-rollup.out
	exit
fi

### Check report services are running ###
OUTPUT=`grep ReportService /var/tmp/jmxdump-rollup.out  | wc -l`
if [ $OUTPUT -lt 10 ]; then					### Should be around 21
	echo "OK: Report services are disabled, no need to change rollup timing"
	exit
fi

### Check rollup info ###
OUTPUT=`cat /var/tmp/jmxdump-rollup.out | grep -i roll | grep max`
if [ "$OUTPUT" = "" ]; then
	echo "Did not find any rollup information yet - perhaps the Enterprise controller was restarted? The first rollup happens after midnight. Try again tomorrow."
	echo ""
else

	############ We have valid data ##########
	OUTPUT1H=`cat /var/tmp/jmxdump-rollup.out | grep -i roll | grep max | grep 1hour | awk '{print $8}' | awk -F"=" '{print $2}' | awk -F"," '{print $1}'`
	MINUTES_1H=`expr $OUTPUT1H / 60000`
	if [ "$MINUTES_1H" = "0" ];then
		MINUTES_1H=1
	fi
	OUTPUT12H=`cat /var/tmp/jmxdump-rollup.out | grep -i roll | grep max | grep 12hours | awk '{print $8}' | awk -F"=" '{print $2}' | awk -F"," '{print $1}'`
	MINUTES_12H=`expr $OUTPUT12H / 60000`
	if [ "$MINUTES_12H" = "0" ];then
		MINUTES_12H=1
	fi
	### Problem begins at:
	### ReportService.rollup.1hour MAX is bigger than (or getting close to) 1 hour =  60*60*1000 =   3600000
	### ReportService.rollup.12hours MAX is bigger than (or getting close to) 2 hors = 120*60*1000 = 7200000
	WARNING1H="2700000"			### 45 minutes
	WARNING12H="6300000"			### 1 hour 45 minutes
	if [ $OUTPUT1H -gt $WARNING1H ];then
		echo
		echo "WARNING!!! You may be hitting CR 6916872 soon!"
		echo "In order to avoid collisions of the database rollups, you should change the scheduling and provide more room for it to run:"
		echo "Edit /opt/sun/n1gc/etc/reportserviceproperties.xml - and look for:"
		echo "<entry key="repsvc.threeweeks-rollup-time">00:00:00</entry>            (this is the 1 hour rollup)"
		echo "<entry key="repsvc.sixweeks-rollup-time">01:00:00</entry>              (this is the 12 hour rollup)"
 		echo "<entry key="repsvc.sixmonths-rollup-time">03:00:00</entry>             (this is the 24 hour rollup)"
		echo ""
		echo "The 1 hour rollup took more than 45 minutes (it was $MINUTES_1H minutes) - so you need to move the time the 12 hour rollup begins"
		echo "To do this, you may change it to something like this:"
		echo "<entry key="repsvc.threeweeks-rollup-time">00:00:00</entry>            (this is the 1 hour rollup)"
                echo "<entry key="repsvc.sixweeks-rollup-time">02:00:00</entry>              (this is the 12 hour rollup)"
                echo "<entry key="repsvc.sixmonths-rollup-time">04:00:00</entry>             (this is the 24 hour rollup)"
		echo
		echo "Then restart the Enterprise Controller:"
		echo "# /opt/SUNWxvmoc/bin/satadm stop -w ; /opt/SUNWxvmoc/bin/satadm start -w"
		echo
		echo "NOTE: You may see this message even if you already changed this - in this case make sure the time it took ($MINUTES_1H mins) is still less than the window allocated."
		echo

	else
		echo "OK: 1 hour rollup is still less than 1 hour - currently $MINUTES_1H minutes"
	fi
	
	if [ $OUTPUT12H -gt $WARNING12H ];then
                echo
                echo "WARNING!!! You may be hitting CR 6916872 soon!"
                echo "In order to avoid collisions of the database rollups, you should change the scheduling and provide more room for it to run:"
                echo "Edit /opt/sun/n1gc/etc/reportserviceproperties.xml - and look for:"
                echo "<entry key="repsvc.threeweeks-rollup-time">00:00:00</entry>            (this is the 1 hour rollup)"
                echo "<entry key="repsvc.sixweeks-rollup-time">01:00:00</entry>              (this is the 12 hour rollup)"
                echo "<entry key="repsvc.sixmonths-rollup-time">03:00:00</entry>             (this is the 24 hour rollup)"
                echo ""
                echo "The 12 hour rollup took more than 1 hour and 45 minutes (it was $MINUTES_12H minutes) - so you need to move the time the 24 hour rollup begins"
                echo "To do this, you may change it to something like this:"
                echo "<entry key="repsvc.threeweeks-rollup-time">00:00:00</entry>            (this is the 1 hour rollup)"
                echo "<entry key="repsvc.sixweeks-rollup-time">01:00:00</entry>              (this is the 12 hour rollup)"
                echo "<entry key="repsvc.sixmonths-rollup-time">05:00:00</entry>             (this is the 24 hour rollup)"
                echo
                echo "Then restart the Enterprise Controller:"
                echo "# /opt/SUNWxvmoc/bin/satadm stop -w ; /opt/SUNWxvmoc/bin/satadm start -w"
                echo
                echo "NOTE: You may see this message even if you already changed this - in this case make sure the time it took ($MINUTES_12H mins) is still less than the window allocated."
                echo

        else
                echo "OK: 12 hour rollup is still less than 2 hours - currently $MINUTES_12H minutes"
        fi
fi
rm -f /var/tmp/jmxdump-rollup.out
