#!/bin/bash

MY_DIR=`dirname $0`
source $MY_DIR/../../functions

UNAME=`uname`
if [ $UNAME = "Linux" ];then
	SAT_BIN="/opt/sun/xvmoc/bin/satadm"
	XMLFILE="/etc/opt/sun/cacao2/instances/default/modules/reportservicemodule.xml"
	DB_BIN="/opt/sun/scs/sbin/db_tool.pl"
	SAT_CONF="/opt/sun/n1gc/lib/XVM_SATELLITE.properties"
else
	SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
	XMLFILE="/etc/cacao/instances/default/modules/reportservicemodule.xml"
	DB_BIN="/opt/SUNWscs/sbin/db_tool.pl"
	SAT_CONF="/opt/sun/n1gc/lib/XVM_SATELLITE.properties"
fi

### Check the total amount of agents, ignore if this is less than 100
if [ -f $DB_BIN ]; then

        ### Check if DB is running ###
        OUTPUT=`$DB_BIN status 2>/dev/null| grep running | awk '{printf("%s %s %s\n",$2,$3,$4)}'`
        if [ "$OUTPUT" = "postmaster is running" ]; then
                DONOTHING=1
        else
                echo "ERROR: Database is not running, can't check the number of agents"
                echo ""
                exit
        fi

        ### Total agents ###
        echo "select count(agent_ip) from agent_table" | $DB_BIN psql > /var/tmp/db.out.$$ 2>/dev/null
        VERIFY=`grep "(1 row)" /var/tmp/db.out.$$`
        if [ "$VERIFY" = "(1 row)" ]; then
                TOTALA=`head -3 /var/tmp/db.out.$$ | tail -1 | awk '{print $1}'`
                rm -f /var/tmp/db.out.$$
        else
                echo "ERROR: Couldn't get number of agents from the database, got the output:"
                cat /var/tmp/db.out.$$
                rm -f /var/tmp/db.out.$$
                exit
        fi
	AGENTMIN=100
	if [ $TOTALA -lt $AGENTMIN ]; then
		echo "OK: Total number of agents ($TOTALA) is lower than $AGENTMIN, no need to do anything."
		exit
	else
		echo "Found enough agents ($TOTALA) to run this test..."
	fi
else
        echo "ERROR: Couldn't find $DB_BIN"
        echo ""
	exit
fi

get_version ""          ### Provide VERSIONNUM
if [ $VERSIONNUM -gt "2501171" ];then               #### Is this newer than 1171?

	### First, check if previous fix (1171 and earlier) was already implemented
	OUTPUT=`grep reportservicemodule $XMLFILE | grep UNLOCKED`
	if [ "$OUTPUT" = "" ]; then
	        echo "OK: Report services are already disabled in reportservicemodule.xml"
		echo "    Please review the README of Update 3 for a better method to disable the reporting service"
		echo ""
		echo "    You could also revert the current change (pre-Update 3 workaround) and rerun the Doctor to see the new method."
		echo "    To rollback the pre-Update 3 workaround, edit $XMLFILE and change:"
		echo "        <module name=\"reportservicemodule\" initial-administrative-state=\"LOCKED\">"
		echo "    to:"
		echo "        <module name=\"reportservicemodule\" initial-administrative-state=\"UNLOCKED\">"
		echo
	        exit
	fi

	COMMENT=`grep "#report.service.disable=true" $SAT_CONF` 
	LINE=`grep "^report.service.disable=true" $SAT_CONF` 
	if [ ! "$LINE" = "" ]; then
		echo "OK: Report services are already disabled in $SAT_CONF"
		exit
	fi
	if [ "$COMMENT" = "" ]; then
		echo "ERROR: Didn't find comment \"#report.service.disable=true\" in $SAT_CONF - although it should be there"
		echo ""
		exit
	else
		echo "NOTICE: There is a known issue which may cause the Enterprise Controller to slow down in large environments (a few hundreds of agents)."
		echo "        This is due to a bug in the report services (CR 6927387). If you have a large environment - you may want to consider disabling"
		echo "        the report services. This will stop the data collection that is used by the graphs in the Web Interface but will reduce"
		echo "        the load as well."

		if [ "$OCDOCTOR_FIX" = "1" ];then
			echo ""
	                echo "Configuring this automatically..."
	                STATUS=`$SAT_BIN status`
	                if [ "$STATUS" = "online" ];then
	                        printf "Would you like to stop the Enterprise Controller now? Answering no will cancel this specific fix (y/n): "
	                        read yesno
	                        if [ "$yesno" = "yes" ]; then
	                                yesno="y"
	                        fi
	                        if [ "$yesno" = "Y" ]; then
	                                yesno="y"
	                        fi
	                        if [ "$yesno" = "y" ]; then
					echo "--- Stopping cacao ---"
					$SAT_BIN stop -w
					echo "--- Modifying $SAT_CONF ---"
					echo "Creating a backup in $SAT_CONF-ocdoctor.$$"
					cp -p $SAT_CONF $SAT_CONF-ocdoctor.$$
					`sed "s/#report.service.disable/report.service.disable/g" $SAT_CONF > /var/tmp/satconf_temp`
					cp /var/tmp/satconf_temp $SAT_CONF
					rm -f /var/tmp/satconf_temp
					echo "Done."
					echo "--- Starting cacao ---"
					$SAT_BIN start -w
					echo ""
					echo "Done."
					echo ""
					exit
				else
					echo "Skipping... try running without --fix to see the manual procedure"
					echo ""
					exit
				fi
			fi
		else
			echo "        To do that, modify the following line in $SAT_CONF"
			echo "        change:"
			echo "            #report.service.disable=true"
			echo "        to:"
			echo "            report.service.disable=true"
			echo "        and restart the Enterprise Controller:"
			echo "            # $SAT_BIN stop -w ; sleep 2 ; $SAT_BIN start -w"
			echo ""
			echo "OR run again with --fix to automatically configure this:"
		        echo "# ./OCDoctor.sh --tuning --fix"
			echo ""
		fi
	fi
	


	################################################## End of newer than 1171 ###############################
else
	#### 1171 and earlier
	### First check reportservicemodule.xml to see if report services are disabled
	OUTPUT=`grep reportservicemodule $XMLFILE | grep UNLOCKED`
	if [ "$OUTPUT" = "" ]; then
		echo "OK: Report services are already disabled in reportservicemodule.xml"
		exit
	else
		echo "NOTICE: There is a known issue which may cause the Enterprise Controller to crash in large environments (${AGENTMIN}+ agents)"
		echo "        This is due to a bug in the report services (CR 6927387). If you have a large environment - it is recommended that you disable"
		echo "        the report services. This will stop the data collection that is used by the graphs in the BUI."
		echo "        To do that, modify the following line in $XMLFILE"
		echo "        change:"
		echo "            <module name=\"reportservicemodule\" initial-administrative-state=\"UNLOCKED\">"
		echo "        to:"
		echo "            <module name=\"reportservicemodule\" initial-administrative-state=\"LOCKED\">"
		echo "        and restart the Enterprise Controller:"
		echo "            # $SAT_BIN stop -w ; sleep 2 ; $SAT_BIN start -w"
		echo ""
	fi
fi
