#!/bin/bash
UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        DB_BIN="/opt/sun/scs/sbin/db_tool.pl"
	DB_DUMP="/opt/sun/scs/bin/pg_dump"
	DB_RESTORE="/opt/sun/scs/bin/pg_restore"
else
        DB_BIN="/opt/SUNWscs/sbin/db_tool.pl"
	DB_DUMP="/opt/SUNWscs/bin/pg_dump"
	DB_RESTORE="/opt/SUNWscs/bin/pg_restore"
	LIB_PATH="/usr/sfw/lib"
fi

if [ "$1" = "--fix" ];then
        OCDOCTOR_FIX=1
fi

##### Backup function #####
backup(){
	today=`date +%F-%T`
	printf "What folder do you want to use for the DB backup? [/var/tmp]: "
	read FOLDER
	if [ "$FOLDER" = "" ]; then
		FOLDER="/var/tmp"
	fi
	if [ ! -d $FOLDER ]; then
		echo "ERROR: $FOLDER not found"
		echo
		exit
	fi
        backupfile="$FOLDER/inventory_table-$today.sql"
        echo "Creating a backup file $backupfile..."
        unset DBUSER PGBASE PGCLIENTENCODING PGDATA PGDATABASE PGDATESTYLE PGDUMPDIR
        unset PGGROUP PGHOME PGLOGDIR PGLOGFILE PGPASSWORD PGPORT PGTZ PGUSER PGHOST
        export PGPASSWORD="`$DB_BIN getpw`"
	if [ "$LIB_PATH" = "" ]; then
	        su - scndb -c "PGPASSWORD=$PGPASSWORD  $DB_DUMP mgmt -Fc -i -v -p 5434 -U scndb -Z9 -t inventory_table --clean -f $backupfile"
	else
	        su - scndb -c "LD_LIBRARY_PATH=$LIB_PATH PGPASSWORD=$PGPASSWORD $DB_DUMP mgmt -Fc -i -v -p 5434 -U scndb -Z9 -t inventory_table --clean -f $backupfile"
	fi
        unset DBUSER PGBASE PGCLIENTENCODING PGDATA PGDATABASE PGDATESTYLE PGDUMPDIR
        unset PGGROUP PGHOME PGLOGDIR PGLOGFILE PGPASSWORD PGPORT PGTZ PGUSER PGHOST
        echo "Done."
	echo ""
	echo "If you need to restore this table, you can use the following command:"
	PWD=`pwd`
	if [ -f $PWD/tuning/25/delete-old-NIDs.sh ]; then
		echo "# $PWD/tuning/25/delete-old-NIDs.sh --restore $backupfile"
	else 
		echo "# <PATH_TO>/OCDoctor/tuning/25/delete-old-NIDs.sh --restore $backupfile"
	fi
	echo ""
	printf "Please review the above messages for any errors!! if everything looks OK, type 'y' to continue to the delete part: "
	read yesno
	if [ "$yesno" = "yes" ]; then
	        yesno="y"
        fi
        if [ "$yesno" = "Y" ]; then
                yesno="y"
        fi
        if [ ! "$yesno" = "y" ]; then
		echo "Aborting."
		exit
	fi
}


##### Restore function #####
restore(){
	filename="$1"
        echo "Restoring from $filename"
        unset DBUSER PGBASE PGCLIENTENCODING PGDATA PGDATABASE PGDATESTYLE PGDUMPDIR
        unset PGGROUP PGHOME PGLOGDIR PGLOGFILE PGPASSWORD PGPORT PGTZ PGUSER PGHOST
        export PGPASSWORD="`$DB_BIN getpw`"
	if [ "$LIB_PATH" = "" ]; then
	        su - scndb -c "PGPASSWORD=$PGPASSWORD $DB_RESTORE -Fc -i -v -p 5434 -U scndb -d mgmt -t inventory_table --clean $filename"
	else
	        su - scndb -c "PGPASSWORD=$PGPASSWORD LD_LIBRARY_PATH=$LIB_PATH $DB_RESTORE -Fc -i -v -p 5434 -U scndb -d mgmt -t inventory_table --clean $filename"
	fi
        unset DBUSER PGBASE PGCLIENTENCODING PGDATA PGDATABASE PGDATESTYLE PGDUMPDIR
        unset PGGROUP PGHOME PGLOGDIR PGLOGFILE PGPASSWORD PGPORT PGTZ PGUSER PGHOST
        echo "Restored."
        exit
}

function is_integer() {
    printf "%d" $1 > /dev/null 2>&1
    return $?
}

#### Deal with restore ####
if [ "$1" = "--restore" ];then
        RESTORE_FILE=$2
        if [ ! -f $RESTORE_FILE ]; then
                echo "ERROR: Could not find $RESTORE_FILE"
                echo ""
                exit
        fi
	echo "Restoring..."
	printf "Are you sure you want to restore the inventory_table from $RESTORE_FILE ? "
	read yesno
	if [ "$yesno" = "yes" ]; then
                yesno="y"
        fi
        if [ "$yesno" = "Y" ]; then
                yesno="y"
        fi
        if [ ! "$yesno" = "y" ]; then
                echo "Aborting."
                exit
        fi
        restore "$RESTORE_FILE"
fi

#### Check version ####
MY_DIR=`dirname $0`
source $MY_DIR/../../functions
get_version ""          ### Provide VERSIONNUM
if [ $VERSIONNUM -gt "2501186" ];then               #### Is this newer than 1171?
	echo
	echo "OK: This tuning only applies to version 2.5.1186 and earlier (pre Update 5)"
	exit		#### Only applies to 1186
fi

#### Check if we have any blob IDs in the inventory ####
echo "Checking if inventory tables have old Node IDs - this can take a good few minutes..."
### Query only the 2008/08/26 baselines. These are the latest to be removed from the vtree. If they are missing then older ones may be a problem as well (we delete ALL missing ones but the test here will be much faster checking the latest only)
OUTPUT=`$DB_BIN psql 2>/dev/null <<EOF | head -3 | tail -1
select count(agent_name) from agent_table where inventory_id in
( select inventory_id from inventory_table where component_id in
( 40017801, 400117813, 40017814, 40017800, 50014811, 50014812, 50014824, 50014825, 20016725, 20016726, 20016727, 20016724, 46018841, 46018842, 46018843, 46018844 ));
EOF `

if ! is_integer $OUTPUT; then
	echo "ERROR: Got an error trying to query the DB. Received the following output (expected a number):"
	printf "$OUTPUT\n"
	echo
	exit
fi


if (($OUTPUT > 0 )); then
	echo ""
	printf "WARNING: Found %d hosts with lost Node IDs\n" $OUTPUT
	echo ""
	echo "There is known issue which will impact performance and will cause the inventory cache to reload every 14 minutes. In large environments this can result in constant cache refresh (CR 6961790). This is also fixed in the coming Update 5."
	echo ""
	if [ "$OCDOCTOR_FIX" = "1" ];then
		echo "Running a backup of the specific table which will get modified:"
		backup
	else
		echo "The workaround involves database modifications. You can use --fix to remove inventories Node IDs which are causing this:"
		echo "# ./OCDoctor.sh --tuning --fix"
		echo 
		echo " - OR call this script directly -"
		PWD=`pwd`
	        if [ -f $PWD/tuning/25/delete-old-NIDs.sh ]; then
       	        	echo "# $PWD/tuning/25/delete-old-NIDs.sh --fix"
       	 	else
       	        	echo "# <PATH_TO>/OCDoctor/tuning/25/delete-old-NIDs.sh --fix"
       		fi
		echo
		echo "This will also take a backup of the specific table modified."
		echo
		exit
	fi
else
	echo
	echo "OK: No hosts found with lost Node IDs"
	exit
fi

	
if [ "$OCDOCTOR_FIX" = "1" ];then
printf "Deleting Node IDs - please wait"
cat <<!EOF! | while read NID; do
40010068
40010069
40010070
40010324
40010325
40010326
40011727
40011728
40011729
40015209
40015210
40015222
40015368
40015369
40015372
40015522
40015526
40015527
40016914
40016915
40016916
40017076
40017077
40017078
40017262
40017272
40017276
40017488
40017489
40017490
40017801
40017813
40017814
40010067
40010323
40011726
40015208
40015367
40015521
40016913
40017075
40017261
40017487
40017800
40007293
40007463
40007701
40009294
40009480
40009582
40009701
40007294
40007295
40007296
40007464
40007466
40007467
40007702
40007703
40007704
40009295
40009296
40009297
40009481
40009482
40009483
40009583
40009628
40009629
40009702
40009703
40009704
50012452
50012453
50012454
50012598
50012600
50012605
50012798
50012799
50012800
50006788
50006890
50007023
50008634
50008786
50008903
50008956
50009239
50009467
50009798
50012451
50012597
50012797
50014051
50014161
50014323
50014531
50014811
50014324
50014325
50014326
50014812
50014824
50014825
50014532
50014533
50014534
50006789
50006791
50006792
50006891
50006892
50006894
50007024
50007025
50007026
50014162
50014163
50014164
50008635
50008636
50008637
50008787
50008788
50008789
50008904
50008905
50008906
50008957
50008961
50008964
50009240
50009241
50009242
50009468
50009469
50009470
50009799
50009800
50009801
50014052
50014053
50014054
20013193
20013197
20013198
20013296
20013297
20013298
20011744
20011745
20011746
20013418
20013419
20013420
20013454
20013459
20013460
20013595
20013596
20013597
20013988
20013989
20013990
20013832
20013833
20013834
20015595
20015597
20015750
20015854
20015855
20015858
20016064
20016065
20016066
20016187
20016188
20016189
20016277
20016293
20016294
20016361
20016366
20016367
20016482
20016483
20016484
20016725
20016726
20016727
20011600
20011601
20011602
20011599
20011743
20011899
20013192
20013295
20013417
20013453
20013594
20013831
20013987
20015594
20015853
20016063
20016186
20016276
20016360
20016481
20016724
20011900
20011901
20011902
46011854
46012026
46012201
46013584
46013687
46013803
46013844
46014026
46014205
46014416
46015334
46017938
46018050
46018362
46018413
46018463
46018596
46018841
46011855
46011856
46011857
46012027
46012028
46012029
46012202
46012203
46012208
46013585
46013594
46013605
46013688
46013689
46013690
46013804
46013805
46013806
46013845
46013846
46013847
46014027
46014028
46014029
46014206
46014207
46014208
46014417
46014418
46014419
46015335
46015336
46015337
46017939
46017940
46017944
46018051
46018086
46018087
46018363
46018365
46018366
46018414
46018415
46018416
46018464
46018473
46018474
46018597
46018598
46018599
46018842
46018843
46018844
!EOF!
printf "."
echo "DELETE FROM inventory_table WHERE component_id=$NID" | $DB_BIN psql 1>/dev/null 2>/dev/null
done
echo
echo "Done."
echo 
fi	### if OCDOCTOR FIX

