#!/bin/bash

MY_DIR=`dirname $0`
source $MY_DIR/../../functions

### Only applies to 1166 or 1171 ###
get_version ""		### Provide VERSIONNUM
if [ "$VERSIONNUM" != "2501166" -a "$VERSIONNUM" != "2501171" ]; then
        echo "OK - This tuning is for version 1166 or 1171, this is $VERSION"
        exit
fi

UNAME=`uname`
if [ "$UNAME" = "Linux" ]; then
        PROXY_BIN="/opt/sun/xvmoc/bin/proxyadm"
	JAVADB="./cli/javadb_tool"				#### not provided in Linux for some reason although it works 
else
        PROXY_BIN="/opt/SUNWxvmoc/bin/proxyadm"
	JAVADB="/opt/SUNWxvmoc/lib/javadb_tool"
fi
STATUS=`$PROXY_BIN status`
if [ "$STATUS" = "online" ];then
        echo "NOTICE: Can't check for CR 6922341 (missing proxy indexes) when proxy is online."
	echo "        You may stop the proxy and rerun the tuning:"
	echo ""
	echo "        # $PROXY_BIN stop -w		(THIS WILL STOP ANY RUNNING JOBS!)"
	echo "        # ./OCDoctor --tuning"
	echo
else
	echo "OK: Proxy is already offline"
	MBEAN=`echo "show indexes from hd_cached_mbean;" | $JAVADB | grep HD_CACHED | wc -l | awk '{print \$1}'`
	MBEAN_TYPE=`echo "show indexes from hd_cached_mbean_type;" | $JAVADB | grep HD_CACHED | wc -l | awk '{print \$1}'`
	FAILURE=0
	if [ $MBEAN -lt 5 ]; then
		FAILURE=1
	fi
	if [ $MBEAN -lt 3 ]; then
		FAILURE=1
	fi
	if [ $FAILURE -eq 1 ]; then
		echo "SUGGESTION: The following indexes may be added to improve the Proxy speed (CR 6922341)"
		echo "            To add them, run the following while the proxy is offline:"
		echo ""
		echo "# $JAVADB << EOF"
		echo "CREATE INDEX idx_hd_cached_mbean_connectionid ON "
		echo "hd_cached_mbean(connectionid);"
		echo "CREATE INDEX idx_hd_cached_mbean_objectname ON hd_cached_mbean(objectname);"
		echo "CREATE INDEX idx_hd_cached_mbean_type_connectionid ON "
		echo "hd_cached_mbean_type(connectionid);"
		echo "CREATE INDEX idx_hd_cached_mbean_type_classname ON "
		echo "hd_cached_mbean_type(class_name);"
		echo "CREATE INDEX idx_hd_cached_mbean_connectionid_objectname ON "
		echo "hd_cached_mbean(connectionid, objectname);"
		echo "EOF"
		echo ""
		echo "            ** Don't forget to start the proxy after you're done! **"
		echo "            Only start it if it should be online:"
		echo "            # $PROXY_BIN start -w"

 
	else
		echo "OK: hd_cached_mbean indexes are properly configured on the proxy"
		echo "      ** Don't forget to start the proxy after you're done! **"
		echo "      Only start it if it should be online:"
		echo "      # $PROXY_BIN start -w"
	fi	
	
fi

