#!/bin/bash

OS=`uname`
if [ $OS == "Linux" ]
then
   ggrep=/bin/grep
   PUBLIC=/usr/local/uce/server/public
else
   ggrep=/usr/sfw/bin/ggrep
   PUBLIC=/opt/SUNWuce/server/public
fi

ACTIVE_CHANNELS=$PUBLIC/activated_channels.xml
CHANNELS_XML=$PUBLIC/channels.xml
CONFIG_FILES=$PUBLIC/config_files

if [ ! -d $CONFIG_FILES ]; then
        echo "ERROR: Could not find $CONFIG_FILES"
        echo
        exit 2
fi
if [ ! -f $CHANNELS_XML ]; then
        echo "ERROR: Could not find $CHANNELS_XML"
        echo
        exit 2
fi

if [ ! -f $ACTIVE_CHANNELS ]; then
        echo "ERROR: Could not find $ACTIVE_CHANNELS"
        echo
        exit 2
fi


if [ "$1" == "" ]; then
	echo
	echo "Patch ID is missing. An example:"
	echo "./OCDoctor.sh --getblobid 119118-46"
	echo
	exit 2
fi

PATCH=$1
CHANNELS=$($ggrep CHANNEL_ID $ACTIVE_CHANNELS | cut -d ">" -f2 | cut -d "<" -f1 | sort)
echo "Looking up patch $PATCH in all available channels..."
count=0
for i in $CHANNELS; do
        EXTENSION=$($ggrep -B 7 "<CHANNEL_ID>$i</CHANNEL_ID>" $CHANNELS_XML | $ggrep "<EXTENSION>" | cut -d ">" -f2 | cut -d "<" -f1)
	BLOB=$($ggrep -B 9 "\[CDATA\[$PATCH\]\]></NTS>" $CONFIG_FILES/$EXTENSION/.vtree.xml | $ggrep NID | sed 's/<NID>//g;s/<\/NID>/ /g')
	if [ ${#BLOB} -gt 0 ];then
	    count=`expr $count + 1`
	    BLOB=$(echo $BLOB | cut -f1 -d " ")
            echo "-------------------------------------------------------"
            echo "Patch: $PATCH"
            echo "Blob is: $BLOB ($EXTENSION)"
            echo "-------------------------------------------------------"
        fi
done
if (( $count<1 )); then
            echo "-------------------------------------------------------"
            echo "Patch: $PATCH"
            echo Blob not found!
            echo "-------------------------------------------------------"
fi

