#!/bin/bash

OS=`uname`
if [ $OS == "Linux" ]; then
	ggrep=/bin/grep
	UCE_RC="/var/opt/sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc"
	if [ -d /var/opt/sun/xvm/uce/usr.local/server/public/ ]; then	# 12c with no update library goes here
		PUBLIC_FOLDER=/var/opt/sun/xvm/uce/usr.local/server/public/
	fi
	SAT_BIN="/opt/sun/xvmoc/bin/satadm"
else
	ggrep=/usr/sfw/bin/ggrep
	if [ ! -x $ggrep ]; then
		echo "ERROR: Could not find GNU grep (ggrep) in $ggrep"
		UNAMER=`uname -r`
		if [ "$UNAMER" = "5.11" ]; then
			echo "Try 'pkg install /text/gnu-grep' to install it"
		fi
		echo
		exit 1
	fi
	UCE_RC="/var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc"
	if [ -d /var/opt/sun/xvm/uce/opt/server/public ]; then		#12c with no update library goes here
    	PUBLIC_FOLDER=/var/opt/sun/xvm/uce/opt/server/public
    fi
    SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
fi

if [ ! -f $SAT_BIN ];then
	echo "ERROR: Please run this on the Enterprise Controller only"
	echo ""
	exit 1
fi

if [ ! -f ${UCE_RC} ]; then
	echo "ERROR: Could not find ${UCE_RC} - is the EC installed?"
	echo ""
	exit 2
fi
### Determine library path
PUBLIC_FOLDER_TMP=`grep "public_dir_name" $UCE_RC 2>/dev/null | awk -F"\"" '{print $2}' 2>/dev/null`
if [ ! "$PUBLIC_FOLDER_TMP" = "" ]; then
	if [ -d $PUBLIC_FOLDER_TMP ]; then			### 12c has libraries
		PUBLIC_FOLDER=$PUBLIC_FOLDER_TMP
	fi
fi
if [ ! -d $PUBLIC_FOLDER ]; then
	echo "ERROR: Could not find the public folder with channels.xml"
	echo ""
	exit 2 
fi

CHANNELS_XML=$PUBLIC_FOLDER/channels.xml
ACTIVE_CHANNELS=$PUBLIC_FOLDER/activated_channels.xml
CONFIG_FILES=$PUBLIC_FOLDER/config_files

if [ ! -d $CONFIG_FILES ]; then
        echo "ERROR: Could not find $CONFIG_FILES"
        echo
        exit 2
fi
if [ ! -f $CHANNELS_XML ]; then
        echo "ERROR: Could not find $CHANNELS_XML"
        echo
        exit 2
fi

if [ ! -f $ACTIVE_CHANNELS ]; then
        echo "ERROR: Could not find $ACTIVE_CHANNELS"
        echo
        exit 2
fi


if [ "$1" == "" ]; then
	echo
	echo "Patch ID is missing. An example:"
	echo "./OCDoctor.sh --getblobid 119118-46"
	echo
	exit 2
fi

PATCH=$1
CHANNELS=$($ggrep CHANNEL_ID $ACTIVE_CHANNELS | cut -d ">" -f2 | cut -d "<" -f1 | sort)
echo "Looking up patch $PATCH in all available channels..."
count=0
for i in $CHANNELS; do
        EXTENSION=$($ggrep -B 7 "<CHANNEL_ID>$i</CHANNEL_ID>" $CHANNELS_XML | $ggrep "<EXTENSION>" | cut -d ">" -f2 | cut -d "<" -f1)
	BLOB=$($ggrep -B 9 "\[CDATA\[$PATCH\]\]></NTS>" $CONFIG_FILES/$EXTENSION/.vtree.xml | $ggrep NID | sed 's/<NID>//g;s/<\/NID>/ /g')
	if [ ${#BLOB} -gt 0 ];then
	    count=`expr $count + 1`
	    BLOB=$(echo $BLOB | cut -f1 -d " ")
            echo "-------------------------------------------------------"
            echo "Patch: $PATCH"
            echo "Blob is: $BLOB ($EXTENSION)"
            echo "-------------------------------------------------------"
        fi
done
if (( $count<1 )); then
            echo "-------------------------------------------------------"
            echo "Patch: $PATCH"
            echo Blob not found!
            echo "-------------------------------------------------------"
fi

