#!/bin/bash

echo
if [ $# -lt "1" ]
then
   echo "Blob number required!"
   echo
   echo "Usage: $0 blob# blob#"
   echo "Script will accept a space separated list of blobids"
   echo
   exit 1
fi

OS=`uname`
if [ $OS == "Linux" ]; then
	ggrep=/bin/grep
	UCE_RC="/var/opt/sun/xvm/uce/usr.local/server/cgi-bin/.uce.rc"
	if [ -d /var/opt/sun/xvm/uce/usr.local/server/public/ ]; then	# 12c with no update library goes here
		PUBLIC_FOLDER=/var/opt/sun/xvm/uce/usr.local/server/public/
	fi
	SAT_BIN="/opt/sun/xvmoc/bin/satadm"
else
	ggrep=/usr/sfw/bin/ggrep
	if [ ! -x $ggrep ]; then
		echo "ERROR: Could not find GNU grep (ggrep) in $ggrep"
		UNAMER=`uname -r`
		if [ "$UNAMER" = "5.11" ]; then
			echo "Try 'pkg install /text/gnu-grep' to install it"
		fi
		echo
		exit 1
	fi
	UCE_RC="/var/opt/sun/xvm/uce/opt/server/cgi-bin/.uce.rc"
	if [ -d /var/opt/sun/xvm/uce/opt/server/public ]; then		#12c with no update library goes here
    	PUBLIC_FOLDER=/var/opt/sun/xvm/uce/opt/server/public
    fi
    SAT_BIN="/opt/SUNWxvmoc/bin/satadm"
fi

if [ ! -f $SAT_BIN ];then
	echo "ERROR: Please run this on the Enterprise Controller only"
	echo ""
	exit 1
fi

if [ ! -f ${UCE_RC} ]; then
	echo "ERROR: Could not find ${UCE_RC} - is the EC installed?"
	echo ""
	exit 2
fi
### Determine library path
PUBLIC_FOLDER_TMP=`grep "public_dir_name" $UCE_RC 2>/dev/null | awk -F"\"" '{print $2}' 2>/dev/null`
if [ ! "$PUBLIC_FOLDER_TMP" = "" ]; then
	if [ -d $PUBLIC_FOLDER_TMP ]; then			### 12c has libraries
		PUBLIC_FOLDER=$PUBLIC_FOLDER_TMP
	fi
fi
if [ ! -d $PUBLIC_FOLDER ]; then
	echo "ERROR: Could not find the public folder with channels.xml"
	echo ""
	exit 2 
fi

CHANNELS_XML=$PUBLIC_FOLDER/channels.xml
CONFIG_FILES=$PUBLIC_FOLDER/config_files

if [ ! -d $CONFIG_FILES ]; then
	echo "ERROR: Could not find $CONFIG_FILES"
	echo
	exit
fi
if [ ! -f $CHANNELS_XML ]; then
	echo "ERROR: Could not find $CHANNELS_XML"
	echo
	exit
fi

while [ $# -ge 1 ]
do
   BLOB=$1
   CHANNEL=${BLOB:0:2}
   CHANNEL_NAME=`$ggrep -B 10 "<CHANNEL_ID>$CHANNEL</CHANNEL_ID>" $CHANNELS_XML  | grep NAME | head -1 | cut -d ">" -f2 | cut -d "<" -f1`
   EXTENSION=`$ggrep -B 10 "<CHANNEL_ID>$CHANNEL</CHANNEL_ID>" $CHANNELS_XML | grep EXTENSION | head -1 | cut -d ">" -f2 | cut -d "<" -f1`
   
   echo "-------------------------------------------------"
   echo Blob $BLOB is:
   echo
   
   if [ "$EXTENSION" = "OS_IMAGES" ]; then
		DETAIL=`$ggrep -A 10 "<NodeId>$BLOB</NodeId>" $CONFIG_FILES/$EXTENSION/osp_catalog.xml | egrep 'NTS'| cut -d ">" -f2 | cut -d "<" -f1`
   elif [ "$EXTENSION" = "FIRMWARE" ]; then
		### Firmware
		if [ -f $PUBLIC_FOLDER/public_blobs/FIRMWARE/$BLOB.blob ]; then
			DETAIL="Blob $BLOB is firmware. Here is the unzip -t output of this file (to determine what firmware is it):\n\n"
			OUTPUT=`cd $PUBLIC_FOLDER/public_blobs/FIRMWARE/ ; unzip -t $BLOB.blob`
			DETAIL="${DETAIL}\n${OUTPUT}"
		else
			DETAIL="Blob $BLOB is firmware, but it was not downloaded to this system yet, so can't show more info"	#'
		fi
   else
		DETAIL=`$ggrep -A 10 "<NID>$BLOB</NID>" $CONFIG_FILES/$EXTENSION/.vtree.xml | egrep 'NTS|DESC'| cut -d "[" -f3 | cut -d "]" -f1`   
   fi
  
   if [ ${#DETAIL} -lt 1 ]
   then
      echo Blob not found
   else
   printf "$DETAIL\n"
   fi
   
   echo "Channel - $CHANNEL_NAME ($EXTENSION)"
   echo
   echo "-------------------------------------------------"
shift
done
